#
# LAPIS lightweight structured text processing system
#
# Copyright (C) 1998-2002 Carnegie Mellon University,
# Copyright (C) 2003 Massachusetts Institute of Technology.
# All rights reserved.
#
# This library is free software; you can redistribute it
# and/or modify it under the terms of the GNU General
# Public License as published by the Free Software
# Foundation, version 2.
#
# LAPIS homepage: http://graphics.lcs.mit.edu/lapis/
#

#
# Global parameters
#


# Backup extension.  Whenever a file is saved, the original version will be backed up in
# a file with this extension added.  (Applies to File/Save, the save script command, 
# and the -inplace option.)  Setting this option to an empty string turns off backup.
set lapis::backup ~

# display limit (TTY shell will display at most this many lines from
# a document)
set lapis::displayLimit 25



#
# Built-in LAPIS tools
#
lapis::bind doc lapis.tools.Doc
lapis::bind property lapis.tools.Property
lapis::bind lcat lapis.tools.Concat
lapis::bind insert lapis.tools.Insert
lapis::bind omit lapis.tools.Delete
lapis::bind delete lapis.tools.Delete
lapis::bind keep lapis.tools.Keep
lapis::bind sort lapis.tools.Sort
lapis::bind replace lapis.tools.Replace
lapis::bind extract lapis.tools.Extract
lapis::bind click lapis.tools.Click
lapis::bind enter lapis.tools.Enter
lapis::bind submit lapis.tools.Submit
lapis::bind webquery lapis.tools.WebQuery
lapis::bind calc lapis.tools.Calc
lapis::bind save lapis.tools.Save
lapis::bind parse lapis.tools.Parse
lapis::bind label lapis.tools.Label
lapis::bind prefix lapis.tools.Prefix
lapis::bind unknown lapis.tools.Unknown
lapis::bind highlight lapis.tools.Highlight
lapis::bind relocate lapis.tools.PageRelocator
lapis::bind count lapis.tools.Count
lapis::bind internal-browse lapis.swing.Browser
lapis::bind back lapis.tools.Back
lapis::bind b lapis.tools.Back
lapis::bind forward lapis.tools.Forward
lapis::bind f lapis.tools.Forward
lapis::bind show lapis.tools.Show
lapis::bind history lapis.tools.ShowHistory
lapis::bind server lapis.servlet.Server
lapis::bind load-region-set lapis.tools.LoadRegionSet
lapis::bind save-region-set lapis.tools.SaveRegionSet



# lines extracts the lines in a document (omitting linebreaks) as a Tcl list.
# Useful for command substitution, e.g.
#     eval ls -l [lines [find . -type d]]
proc lines { args } {
    eval extract -as tcl {{line trim linebreak}} $args
}

# tokens extracts the whitespace-separated tokens in a document as a Tcl 
# list.  Useful for command substitution.
proc tokens { args } {
    eval extract -as tcl token $args
}

# words extracts the whitespace/punctuation-separated tokens in a document
# as a Tcl list.  Useful for command substitution.
proc words { args } {
    eval extract -as tcl word $args
}

# putting a Tcl script on the LAPIS menu and toolbar
proc makeTool { name command } {
    set toolbox [java::call lapis.Toolbox getDefaultToolbox]
    set tool [java::new lapis.tcl.TclTool $command]
#    $toolbox remove $name
    $toolbox add $name $tool
}
# removing a Tcl script from the LAPIS menu and toolbar
proc removeTool { name} {
    set toolbox [java::call lapis.Toolbox getDefaultToolbox]
    $toolbox remove $name
}

proc toolbar { name command } { makeTool $name $command }


#
# Parser library
#
#parse $LAPISDIR/lib/lapis-lib.tcl
java::call lapis.LibraryLoader loadParser

# US state names
java::call lapis.parsers.ListParser loadList "$LAPISDIR/parsers/lists/Business.Address._StateName" "CASE-INSENSITIVE" "WORD-BOUNDARY"
java::call lapis.parsers.ListParser loadList "$LAPISDIR/parsers/lists/Business.Address._StateAbbreviation" "CASE-SENSITIVE" "WORD-BOUNDARY"

# Top-level domain names
java::call lapis.parsers.ListParser loadList "$LAPISDIR/parsers/lists/Internet.Hostname._GenericTopLevelDomain" "CASE-INSENSITIVE" "WORD-BOUNDARY"
java::call lapis.parsers.ListParser loadList "$LAPISDIR/parsers/lists/Internet.Hostname._CountryCodeDomain" "CASE-INSENSITIVE" "WORD-BOUNDARY"
#java::call lapis.parsers.ListParser loadList "$LAPISDIR/parsers/lists/English.Dictionary" "CASE-INSENSITIVE" "WORD-BOUNDARY"
java::call lapis.parsers.ListParser loadList "$LAPISDIR/parsers/lists/Business.Address.Country"
java::call lapis.parsers.ListParser loadList "$LAPISDIR/parsers/lists/List.University"
java::call lapis.parsers.ListParser loadList "$LAPISDIR/parsers/lists/List.President"


# External Parsers
set OSNAME [java::call System getProperty "os.name"]

set EMAIL "$LAPISDIR/parsers/external/email.pl"
java::call lapis.parsers.ExternalParser loadExternalParser "perl -I$LAPISDIR/lib $EMAIL" "perl -I$LAPISDIR/lib $EMAIL getPatterns" $OSNAME

set BRILL_PERL "$LAPISDIR/parsers/external/brill.pl"
set BRILL_BIN "$LAPISDIR/parsers/external/RULE_BASED_TAGGER_V1.14/Bin_and_Data"
java::call lapis.parsers.ExternalParser loadExternalParser "perl $BRILL_PERL $BRILL_BIN $OSNAME" "perl $BRILL_PERL $BRILL_BIN getPatterns" $OSNAME "SentenceCooker"

set LINKGRAMMAR "$LAPISDIR/parsers/external/LinkGrammar-4.1/link-4.1/adapter"
java::call lapis.parsers.ExternalParser loadExternalParser "$LINKGRAMMAR $LAPISDIR" "$LINKGRAMMAR getPatterns" $OSNAME "SentenceCooker"

#TC patterns
java::call lapis.LibraryLoader loadTC


#
# Don't use the following patterns for inference:
#
foreach pattern { 
    # redundant with LineBreak
    "Layout.Line.Break"

    # redundant with Word
    "Characters.Token.Alphanumeric"

    # redundant with Number
    "Business.Number.ScientificNotation"

    # useless patterns
    "System.*"

    # experimental parsers
    "English.Sentence.*"
    "English.Dictionary"
    "English.Dictionary.Misspelling"
    "XML.*"
} {
    java::call lapis.ml.LibraryGenerator skipNamesMatching $pattern
}


#
# External browsers
#

# The LAPIS_BROWSER variable controls what happens when you type
# "browse" at a Tcl prompt.  By default, "browse" just pops up a
# Lapis window showing the current document.  But you can also have
# it call an external browser, by setting the LAPIS_BROWSER (and
# sometimes LAPIS_TEMP) as shown in the examples below.

# Browse with Lapis 
set LAPIS_BROWSER internal-browse

# Browse with Netscape under Unix
#set LAPIS_BROWSER netscape-remote
#set LAPIS_TEMP /tmp

# Browse with Lynx under Unix
#set LAPIS_BROWSER exec:lynx
#set LAPIS_TEMP /tmp

# Browse with Netscape under Windows.  Change the pathnames if necessary.
#set LAPIS_BROWSER "exec:c:/program files/netscape/communicator/program/netscape.exe"
#set LAPIS_TEMP c:/windows/temp

# Browse with Internet Explorer under Windows 98/2K.
#set LAPIS_BROWSER exec:explorer.exe
#set LAPIS_TEMP c:/windows/temp


proc browse { args } {
    global LAPIS_BROWSER
    if { [string match exec:* $LAPIS_BROWSER] } {
        set fn [eval saveToTemp $args]
        set olddoc [doc]
        $LAPIS_BROWSER $fn
        doc $olddoc
    } else {
        eval $LAPIS_BROWSER $args
    }
}

proc netscape-remote { args } {
    set fn [eval saveToTemp $args]
    set olddoc [doc]
    if { [catch { exec:netscape -remote "openURL($fn,lapis-window)" } result] } {
        exec:netscape $fn
    }
    doc $olddoc
}

proc saveToTemp { args } {
    global LAPIS_TEMP

    if { [llength args] > 0 } {
        eval doc $args
    }

    if { [string match text/html [property content-type]] } {
        set fn $LAPIS_TEMP/lapis.html
        relocate
    } else {
        set fn $LAPIS_TEMP/lapis.txt
    }
    save $fn

    if { [string match /* $fn] } {
        return "file:$fn"
    } else {
        return "file:/$fn"
    }
}
