
#
# Parser library
#

# System parser (all, any, background)
parse lapis.parsers.SystemParser

# HTML pages
parse lapis.parsers.HTMLParser
parse $LAPISDIR/parsers/HTML.tc

# XML documents
parse lapis.parsers.XMLParser

# Character classes
parse lapis.parsers.CharacterParser

# Layout structure (e.g. Line, Paragraph, etc)
#   requires CharacterParser
parse $LAPISDIR/parsers/Layout.tc


# US state names
java::call lapis.parsers.ListParser loadList "$LAPISDIR/parsers/lists/Business.Address._StateName" "CASE-INSENSITIVE" "WORD-BOUNDARY"
java::call lapis.parsers.ListParser loadList "$LAPISDIR/parsers/lists/Business.Address._StateAbbreviation" "CASE-SENSITIVE" "WORD-BOUNDARY"

# US English conventions (e.g. addresses, phone numbers, currency)
#   requires CharacterParser, BackgroundParser, state lists
parse $LAPISDIR/parsers/USEnglish.tc

# Top-level domain names
java::call lapis.parsers.ListParser loadList "$LAPISDIR/parsers/lists/Internet.Hostname._GenericTopLevelDomain" "CASE-INSENSITIVE" "WORD-BOUNDARY"
java::call lapis.parsers.ListParser loadList "$LAPISDIR/parsers/lists/Internet.Hostname._CountryCodeDomain" "CASE-INSENSITIVE" "WORD-BOUNDARY"

# Internet conventions (e.g. URLs, email addresses)
#   requires CharacterParser, SystemParser, top level domain lists
parse $LAPISDIR/parsers/Internet.tc

# Java source
parse lapis.parsers.JavaParser
parse $LAPISDIR/parsers/Java.tc

# C source
#parse lapis.parsers.CParser

# Lists
java::call lapis.parsers.ListParser loadList "$LAPISDIR/parsers/lists/English.Dictionary" "CASE-INSENSITIVE" "WORD-BOUNDARY"
java::call lapis.parsers.ListParser loadList "$LAPISDIR/parsers/lists/Business.Address.Country"
java::call lapis.parsers.ListParser loadList "$LAPISDIR/parsers/lists/List.University"
java::call lapis.parsers.ListParser loadList "$LAPISDIR/parsers/lists/List.President"


# External Parsers
set OSNAME [java::call System getProperty "os.name"]

set EMAIL "$LAPISDIR/parsers/external/email.pl"
java::call lapis.parsers.ExternalParser loadExternalParser "perl -I$LAPISDIR/lib $EMAIL" "perl -I$LAPISDIR/lib $EMAIL getPatterns" $OSNAME

set BRILL_PERL "$LAPISDIR/parsers/external/brill.pl"
set BRILL_BIN "$LAPISDIR/parsers/external/RULE_BASED_TAGGER_V1.14/Bin_and_Data"
java::call lapis.parsers.ExternalParser loadExternalParser "perl $BRILL_PERL $BRILL_BIN $OSNAME" "perl $BRILL_PERL $BRILL_BIN getPatterns" $OSNAME "SentenceCooker"

set LINKGRAMMAR "$LAPISDIR/parsers/external/LinkGrammar-4.1/link-4.1/adapter"
java::call lapis.parsers.ExternalParser loadExternalParser "$LINKGRAMMAR $LAPISDIR" "$LINKGRAMMAR getPatterns" $OSNAME "SentenceCooker"


# Unix programs and file formats
# FIX: put these back once the file formats can be detected
# parse $LAPISDIR/parsers/passwd.tc
# parse $LAPISDIR/parsers/termcap.tc
# parse $LAPISDIR/parsers/ps.tc
# parse $LAPISDIR/parsers/ls.tc
# parse $LAPISDIR/parsers/cvs.tc


# Spelling
parse lapis.parsers.SpellingParser

   
