/*
 * LAPIS lightweight structured text processing system
 *
 * Copyright (C) 1998-2002 Carnegie Mellon University,
 * Copyright (C) 2003 Massachusetts Institute of Technology.
 * All rights reserved.
 *
 * This library is free software; you can redistribute it
 * and/or modify it under the terms of the GNU General
 * Public License as published by the Free Software
 * Foundation, version 2.
 *
 * LAPIS homepage: http://graphics.lcs.mit.edu/lapis/
 */



package lapis;
import java.io.Reader;
import java.util.Dictionary;

public interface Document {

    public String    getText ();
    public String    getText (Region r);
    public Reader    getReader ();
    public Region    toRegion ();
    public Dictionary getProperties ();
    public Object getProperty (Object key);
    public void putProperty (Object key, Object value);
    public PatternCache getPatternCache (); 
    public DocumentFactory getFactory ();
    public DocumentVersion getVersion ();
    
    public DocumentView getDefaultView ();
    public DocumentView getCookedView ();
    
    /**
     * Property name for the command used to create the document.
     */
    public final static String CommandProperty = "command";

    /**
     * Property name for the document's URL.
     */
    public final static String URLProperty = "url";

    /**
      * Property name for the base URL of a document
      * (the URL used for relative references).
      */
    public final static String BaseProperty = "base";


    /**
     * Property name for the document's MIME type (e.g. text/plain, text/html).
     */
    public final static String MIMEProperty = "content-type";

    /**
     * Property name for the Process that generated this document, if any.
     */
    public final static String ProcessProperty = "process";

    /**
     * Property name for the associated output document.
     * (The output of a program typically has an output document
     * containing the contents of standard output.)
     */
    public final static String StdoutProperty = "stdout";

    /**
     * Property name for the associated error document.
     * (The output of a program typically has an error document
     * containing the contents of standard error.)
     */
    public final static String StderrProperty = "stderr";

    /**
     * Property name for dirty flag.  Type is DocumentVersion.
     */
    public static final String SavedVersionProperty = "saved-version";

    public final static Document DEFAULT = BasicDocument.defaultFactory.make ("");
}
