/*
 * LAPIS lightweight structured text processing system
 *
 * Copyright (C) 1998-2002 Carnegie Mellon University,
 * Copyright (C) 2003 Massachusetts Institute of Technology.
 * All rights reserved.
 *
 * This library is free software; you can redistribute it
 * and/or modify it under the terms of the GNU General
 * Public License as published by the Free Software
 * Foundation, version 2.
 *
 * LAPIS homepage: http://graphics.lcs.mit.edu/lapis/
 */



package lapis;
import java.io.*;
import java.net.*;
import java.util.*;

public class DocumentWriter extends PrintWriter implements Document, DocumentView {
    DocumentFactory factory;

    Hashtable metadata = new Hashtable ();
    PatternCache patternCache = null;

    StringWriter stringWriter;
    String content;

    boolean closed = false;
    
    DocumentVersion version = null;

	/*
	DocumentView view = new DocumentView (this) {
		public String getText () {
			if (!closed)
				close ();

			if (content != null)
				return content;
			else if (stringWriter != null) 
				return stringWriter.toString ();
			else
				return "";
		}

		public String getText (Region r) {
			String content = getText ();

			int l = content.length ();
			int s = Math.min (l, Math.max (0, r.getStart ()));
			int e = Math.min (l, Math.max (0, r.getEnd ()));
			return (s < e) ? content.substring (s, e) : "";
		}

		public Region toRegion () {
			return new Region (0, getText ().length (), this.getVersion());
		}		
	};
	*/
	
    public DocumentWriter (DocumentFactory factory) {
        this (factory, new StringWriter ());
    }

    private DocumentWriter (DocumentFactory factory, StringWriter out) {
        super (out);
        this.stringWriter = out;
        this.factory = factory;
    }

    public DocumentWriter (DocumentFactory factory, Writer out) {
        super (out);
        this.factory = factory;
    }

    public DocumentWriter (DocumentFactory factory, OutputStream out) {
        super (out);
        this.factory = factory;
    }

    public void close () {
        if (!closed) {
            closed = true;
            super.close ();
            
            if (stringWriter != null) {
                content = stringWriter.toString ();
                stringWriter = null;
            }
        }
    }

    public String getText () {
        if (!closed)
            close ();

        if (content != null)
            return content;
        else if (stringWriter != null) 
            return stringWriter.toString ();
        else
            return "";
    }

    public String getText (Region r) {
        String content = getText ();

        int l = content.length ();
        int s = Math.min (l, Math.max (0, r.getStart ()));
        int e = Math.min (l, Math.max (0, r.getEnd ()));
        return (s < e) ? content.substring (s, e) : "";
    }

    public Region toRegion () {    	
        return new Region (0, getText ().length (), getVersion());
    }

    public Reader getReader () {
        return new StringReader (getText ());
    }

    public Dictionary getProperties () {
        return metadata;
    }

    public Object getProperty (Object key) {
        return getProperties ().get (key);
    }

    public void putProperty (Object key, Object value) {
        if (value == null)
            getProperties ().remove (key);
        else
            getProperties ().put (key, value);
    }

    public PatternCache getPatternCache () {
        if (patternCache == null)
            patternCache = new PatternCache ();
        return patternCache;
    }

    public DocumentFactory getFactory () {
        return factory;
    }

    public DocumentVersion getVersion () {
		return (version != null) 
				? version 
				: DocumentVersion.getOriginal((DocumentView)this); // not editable
    }

    public String toString () {
        String cmd = (String) getProperty (CommandProperty);
        if (cmd != null && cmd.length () > 0)
            return cmd;

        URL url = (URL) getProperty (URLProperty);
        if (url != null)
            return url.toString ();

        return lapisx.util.Str.abbreviate (getText (), 70);
    }
    
    public DocumentView getDefaultView () {
    	return this;
    }
    
    public DocumentView getCookedView () {
    	return this;
    }
    
    public Document getDocument () {
    	return this;
    }
}
