/*
 * LAPIS lightweight structured text processing system
 *
 * Copyright (C) 1998-2002 Carnegie Mellon University,
 * Copyright (C) 2003 Massachusetts Institute of Technology.
 * All rights reserved.
 *
 * This library is free software; you can redistribute it
 * and/or modify it under the terms of the GNU General
 * Public License as published by the Free Software
 * Foundation, version 2.
 *
 * LAPIS homepage: http://graphics.lcs.mit.edu/lapis/
 */



package lapis;

public class EmptyRegion extends Region {

    //public static final EmptyRegion EMPTY = new EmptyRegion ();

    static final int LOW = MAX_INDEX + 1;
    static final int HIGH = MIN_INDEX - 1;

    public EmptyRegion () {
        
    }

    //
    // Accessor methods
    //

    public int getStartLow () {
        return LOW;
    }

    public int getStartHigh () {
        return HIGH;
    }

    public int getEndLow () {
        return LOW;
    }

    public int getEndHigh () {
        return HIGH;
    }
    
    public int getStart () {
        return LOW;
    }

    public int getEnd () {
        return HIGH;
    }

    public RegionSet freeze () {
        return this; // because I'm immutable
    }

    public int getSize () {
        return 0;
    }

    public boolean isEmpty () {
        return true;
    }

    public boolean isFlat () {
        return true;
    }

    public boolean isCrisp () {
        return true;
    }

    public RegionEnumeration regions () {
        return RegionSet.EMPTY.regions ();
    }

    public RegionEnumeration regions (Region bbox) {
        return regions ();
    }

    public String extract (Document doc) {
        return "";
    }

    public RegionSet crispen () {
        return this;
    }

    public RegionSet flatten () {
        return this;
    }

    public RegionSet melt () {
        return this;
    }

    public RegionSet convert (CoordinateMap coords) {
        return this;
    }

    public RegionSet convert (Versions vers) {
        return this;
    }

    public int fuzzify (int x, int direction) {
        return x;
    }

    public String toString () {
        return "EMPTY";
    }
    
    public DocumentVersion getVersion () {
    	return null;
    }
    
    public Document getDocument () {
    	return null;
    }
    
    public Versions getVersions() {
        return EmptyRegionSet.EMPTY_VERSIONS;
    }

    public SubsetEnumeration singleDocize () {
        return new SubsetEnumeration () {
            public RegionSet firstFast () { return null; }
            public RegionSet nextFast () { return null; }
        };
    }
}
