/*
 * LAPIS lightweight structured text processing system
 *
 * Copyright (C) 1998-2002 Carnegie Mellon University,
 * Copyright (C) 2003 Massachusetts Institute of Technology.
 * All rights reserved.
 *
 * This library is free software; you can redistribute it
 * and/or modify it under the terms of the GNU General
 * Public License as published by the Free Software
 * Foundation, version 2.
 *
 * LAPIS homepage: http://graphics.lcs.mit.edu/lapis/
 */



package lapis;

import java.util.*;

public class EmptyRegionSet extends RegionSet {

    static final int LOW = MAX_INDEX + 1;
    static final int HIGH = MIN_INDEX - 1;
    
    static final RegionEnumeration EMPTY_ENUMERATION =
        new RegionEnumeration () {
                public Region first () {
                    return null;
                }
    
                public Region next () {
                    return null;
                }

                public Region firstFast () {
                    return null;
                }
    
                public Region nextFast () {
                    return null;
                }
            };

    static final Versions EMPTY_VERSIONS =
        new Versions () {
            public Iterator versions () {
                return new Iterator () {
                    public boolean hasNext() {
                        return false;
                    }
                    public Object next() {
                        return null;
                    }
                    public void remove() {
                    }
                };
            }
            public Iterator documents () {
                return new Iterator () {
                    public boolean hasNext() {
                        return false;
                    }
                    public Object next() {
                        return null;
                    }
                    public void remove() {
                    }
                };
            }
            public int getSize () {
                return 0;
            }
            public boolean contains (DocumentVersion ver) {
                return false;
            }
            public boolean contains (Document doc) {
                return false;
            }
            public DocumentVersion getVersion(Document doc) {
                return null;
            }
            public boolean equals (Object obj) {
                if (obj instanceof RegionSet && ((RegionSet)obj).isEmpty())
                    return true;
                else
                    return false;
            }
            public boolean compatible (Versions vs) {
                return true;
            }
        };

    public EmptyRegionSet () {
    }

    public RegionSet freeze () {
        return this; // because I'm immutable
    }

    public int getSize () {
        return 0;
    }

    public boolean isEmpty () {
        return true;
    }

    public RegionEnumeration regions () {
        return EMPTY_ENUMERATION;
    }

    public RegionEnumeration regions (Region bbox) {
        return regions ();
    }

    public String extract (Document doc) {
        return "";
    }

    public RegionSet crispen () {
        return this;
    }

    public RegionSet flatten () {
        return this;
    }

    public RegionSet melt () {
        return this;
    }

    public RegionSet convert (CoordinateMap coords) {
        return this;
    }

    public RegionSet convert (Versions vers) {
        return this;
    }

    public int fuzzify (int x, int direction) {
        return x;
    }

    public String toString () {
        return "EMPTY";
    }

    public SubsetEnumeration singleDocize () {
		return new SubsetEnumeration () {
			public RegionSet firstFast () { return null; }
			public RegionSet nextFast () { return null; }
		};
    }

	public SingleDocRegionSet getSingleDocRegionSet (Document doc) {
		return Region.EMPTY;
	}
	
	public RegionEnumeration regions (RegionSet bboxs) {
		return regions();
	}
    
    public Versions getVersions () {
        return EMPTY_VERSIONS;
    }
}
