/*
 * LAPIS lightweight structured text processing system
 *
 * Copyright (C) 1998-2002 Carnegie Mellon University,
 * Copyright (C) 2003 Massachusetts Institute of Technology.
 * All rights reserved.
 *
 * This library is free software; you can redistribute it
 * and/or modify it under the terms of the GNU General
 * Public License as published by the Free Software
 * Foundation, version 2.
 *
 * LAPIS homepage: http://graphics.lcs.mit.edu/lapis/
 */



package lapis;

public interface Interpreter {
    /**
     * Evaluate a script.
     */
    public abstract Object eval (String code) throws Exception;

    /**
     * Evaluate a script.
     */
    public abstract Object evalFile (String filename) throws Exception;
    
    /**
      * Quote metacharacters in a string.
      */
    public abstract String quote (String s);

    /**
      * Get a variable's value.
      */
    public abstract Object getVar (String name);

    /**
      * Set a variable's value.
      */
    public abstract void setVar (String name, Object obj);

    /**
      * Register a LAPIS tool as a script command.
      */
    public abstract void bindTool (String name, Tool tool);

    /**
      * Script variable storing the current document.
      */
    public static final String DOCUMENT_VAR = "lapis_document";

    /**
      * Script variable storing the document history.
      */
    public static final String HISTORY_VAR = "lapis::history";

    /**
      * Script variable storing the "parameters" document for a
      * demonstrated script.
      */
    public static final String PARAMETERS_VAR = "source";

    /**
      * Script variable storing the interpreter's associated DocumentFactory.
      */
    public static final String FACTORY_VAR = "lapis::factory";
    
    /**
      * Script variable storing the current label prefix (set by Prefix
      * tool).
      */
    public static final String PREFIX_VAR = "lapis::prefix";

    /**
      * Script variable storing the maximum number of lines to display
      * from a document in tty shell.
      */
    public static final String DISPLAY_LIMIT_VAR = "lapis::displayLimit";

    /**
      * Script variable storing the current directory as a File object.
      */
    public static final String CURRENT_DIRECTORY_VAR = "lapis::cwd";

    /**
      * Script variable storing the script arguments.
      */
    public static final String ARGUMENTS_VAR = "argv";

    /**
      * Script variable indicating whether commands are being run 
      * interactively (1) or from a script (0).
      */
    public static final String INTERACTIVE_VAR = "tcl_interactive";


    /**
      * Script variable storing the lapis directory.
      */
    public static final String LAPIS_DIR_VAR = "LAPISDIR";

    /**
      * Script variable storing the extension to give to backup files.
      */
    public static final String BACKUP_EXTENSION_VAR = "lapis::backup";

    
}
