package lapis;

import java.io.BufferedReader;
import java.io.BufferedWriter;
import java.io.File;
import java.io.IOException;
import java.io.FileReader;
import java.io.FileWriter;
import java.io.ObjectOutputStream;
import java.io.ObjectInputStream;
import java.io.FileOutputStream;
import java.io.FileInputStream;
import java.io.EOFException;
import java.io.Serializable;
import java.util.Enumeration;
import java.util.List;
import java.util.ArrayList;
import java.util.Hashtable;
import lapis.tc.TC;
import lapis.tc.TCToken;
import lapis.tc.TCSymbols;
import lapisx.net.URLUtil;
import lapisx.util.Config;
import lapis.*;

/*LibraryLoader is a static class that contains methods responsible for saving and loading the global pattern library.
 */
public class LibraryLoader implements Serializable{
    
    public static lapisx.util.Debug debug = lapisx.util.Debug.QUIET;

    public static String logPath = Main.getConfig().getProperty("logPath");
    public static String patternPath = Main.getConfig().getProperty("patternPath");
    public static String loadTCPath = Main.getConfig().getProperty("loadTCPath");
    public static String loadParserPath = Main.getConfig().getProperty("loadParserPath");
	
    //reads the parser filepaths from a file and loads them
    public static void loadParser() throws IOException{

	//loadParserPath is the path of the file containing the paths of the parsers
	File file = new File(Main.getLapisDir(), loadParserPath); 

	//check to see if file is usable
	if(file == null || !file.exists() || file.isDirectory())
	    throw new IOException("Cannot load parsers from: "+file.getAbsolutePath());
	
	String tempParser = null;
	
	try{
	    //loads into the global pattern library
	    PatternLibrary lib = PatternLibrary.getGlobalLibrary(); 
	    BufferedReader br = new BufferedReader(new FileReader(file)); 

	    //add each parser
	    while((tempParser=br.readLine()) != null) {
	        lib.addParser (((Parser)Class.forName (tempParser).newInstance ()));
	    }

	    br.close();
	    
	} catch(Exception e) {
	    debug.println("error loading parsers");
	}
    }
    
    //reads the built-in TC filepaths from a file and loads them
    public static void loadInitTC() throws IOException{

	//reads the built-in TC filepaths from a file and loads them
	File file=new File(Main.getLapisDir(), loadTCPath);

	//check to see if file is usable
	if(file == null || !file.exists() || file.isDirectory())
	    throw new IOException("Cannot load TC: "+loadTCPath+" does not exist.");

	File tempFile;
	String tempPath = null;
	
	try {
	    PatternLibrary lib = PatternLibrary.getGlobalLibrary();
	    BufferedReader br = new BufferedReader(new FileReader(file));
	    while((tempPath=br.readLine()) != null) {
		try{
		    tempFile = new File(Main.getLapisDir(), tempPath);
		    lib.addParser (new TC (tempFile));
		}catch (Exception e) {
		    debug.println("could not load "+tempPath);
		}
	    }
	    
	    br.close();
	    
	} catch (Exception e) {
	    debug.println("error loading TC patterns");
	}
    }

    //loads the TC patterns stored in the pattern-log
    public static void loadPatternLog() {
	PatternLibrary lib = PatternLibrary.getGlobalLibrary();
	try{
	    File file = new File(Config.getHomeDirectory(), logPath);

	    //check to see if file is usable
	    if(file!=null && file.exists() && !file.isDirectory()) {
		lib.addParser(new TC(file));
	    }
	    else debug.println("no pattern-log file"+file.getAbsolutePath());
	    
	} catch(Exception e) {
	    debug.println("error loading pattern-log");
	    debug.report(e);
	}
    }
	    
    //loads serialized TC patterns from a file
    public static void loadFromFile() throws Exception{

	SavedTC tempSaved;
	boolean loopVal = true;
	PatternLibrary lib = PatternLibrary.getGlobalLibrary();
	ObjectInputStream ois;
	String tempName;
	TC tempTC;
	List savedList;

	try{
	    File file = new File(Config.getHomeDirectory(), patternPath);
	    ois = new ObjectInputStream(new FileInputStream(file));

	    //the file should only have one object written: a list of SavedTC objects
	    savedList = (List) ois.readObject();
	    ois.close();

	    //iterate through the list and add each TC pattern to the library
	    for(int i=0;i<savedList.size();i++) {
		tempSaved = (SavedTC) savedList.get(i);
		tempTC = tempSaved.getTC();
		lib.put(tempSaved.getName(), tempTC);
	    }	    
	}catch(Exception e) {
	    debug.report(e);
	    debug.println("could not read file; loading init file");
	    loadInitTC();
	    debug.println("loading pattern-log");
	    loadPatternLog();
	}
    }    
		
    //adds a name and pattern to the pattern-log
    public static void addToLog(String name, Pattern pattern) {

	FileWriter filewriter = null;

	try {
	    filewriter = new FileWriter(new File(Config.getHomeDirectory(), logPath), true);
	    String writeString = pattern.toString();
	    String whiteSpace = "";
	    for(int i=0;i<name.length()+4; i++)
		whiteSpace+=" ";
	    writeString=lapisx.util.Str.replace(writeString, "\n", "\n"+whiteSpace);
	    
	    //additions to the log file are of this form (ex: "foo is word")
	    filewriter.write(name + " is " + writeString + "\n");
	}
	catch(Exception e) {
	    debug.println("log writing error");
	}
	finally {
	    try {
		if(filewriter != null)
		    filewriter.close();
	    }
	    catch(IOException ioex) {
		debug.println("cannot close stream");
	    }
	}
    }

    //adds a name and pattern to the pattern-log (called by assignments through evaluated patterns)
    public static void addToLog(TC pattern) {
	
	FileWriter filewriter = null;

	try {
	    filewriter = new FileWriter(new File(Config.getHomeDirectory(), logPath), true);

	    //pattern is already in the form "foo is word"
	    filewriter.write(pattern.toString()+"\n");
	}
	catch(Exception e) {
	    debug.println("log writing error");
	}
	finally {
	    try {
		if(filewriter != null)
		    filewriter.close();
	    }
	    catch(IOException ioex) {
		debug.println("cannot close stream");
	    }
	}
    }

    //adds an unbind action to the pattern-log (when a pattern is removed from the library)
    public static void unbindToLog(String name) {
	
	FileWriter filewriter = null;

	try {
	    filewriter = new FileWriter(new File(Config.getHomeDirectory(), logPath), true);
	    //unbind commands to the pattern-log are of the form "unbind [pattern-name]"
	    filewriter.write("unbind " + name + "\n");
	}
	catch(Exception e) {
	    debug.println("log writing error");
	}
	finally {
	    try {
		if(filewriter != null)
		    filewriter.close();
	    }
	    catch(IOException ioex) {
		debug.println("cannot close stream");
	    }
	}
	
    }

    //writes all the TC patterns (or CachedPatterns holding TC patterns) to disk from the global pattern library
    public static void writeToFile() {
	
	PatternLibrary lib = PatternLibrary.getGlobalLibrary();
	Enumeration names = lib.allNames();
	ObjectOutputStream oos=null;
	String tempName;
	Pattern tempPattern;
	SavedTC tempSave;
	List saveList = new ArrayList();

	//iterate through all the patterns by name
	while(names.hasMoreElements()) {
	    tempName = (String) names.nextElement();
	    tempPattern = lib.get(tempName);
	    if(tempPattern instanceof CachedPattern) {
		//check to see if it is a CachedPattern and strip it
		tempPattern=((CachedPattern) tempPattern).getPattern();
	    }
	    if(tempPattern instanceof TC){
		//construct a SavedTC and put it in the list
		tempSave = new SavedTC(tempName, (TC) tempPattern);
		saveList.add(tempSave);
	    }
	}

	//once all the patterns are in the list, try writing the whole list to disk
	try {
	    FileOutputStream fos = new FileOutputStream(new File(Config.getHomeDirectory(), patternPath));
	    oos = new ObjectOutputStream(fos);
	    oos.writeObject(saveList);
	    oos.close();
	} catch(Exception e) {
	    debug.println("error writing to disk");
	}
    }

    //loads TC patterns to the library at start-up, either by loading serialized patterns or by parsing the built-in patterns
    public static void loadTC() throws Exception{
	
	File initFile=new File(Main.getLapisDir(), loadTCPath);  //File of built-in TC patterns (pathnames)
	File patternFile=new File(Config.getHomeDirectory(), patternPath);  //File of serialized TC patterns
	File logFile=new File(Config.getHomeDirectory(), logPath);  //pattern-log of TC patterns

	boolean reload = false;  //default is to load the serialized patterns
	String tempPath = null;
	File tempFile;

	try {
	    if(patternFile == null || !patternFile.exists() || patternFile.isDirectory() || //if the pattern file is unusable
	       TC.newerThan(initFile, patternFile) || TC.newerThan(logFile, patternFile))  //or if the pattern file is old, then reload the built-in TC patterns
		reload=true;

	    else {  //check to see if the individual built-in TC files are updated

		PatternLibrary lib = PatternLibrary.getGlobalLibrary();
		BufferedReader br = new BufferedReader(new FileReader(initFile));

		while(!reload && (tempPath=br.readLine()) != null) {
		    tempFile = new File(Main.getLapisDir(), tempPath);
		    if(TC.newerThan(tempFile, patternFile)) {  //if the built-in TC file is newer than the pattern file, reload
			reload=true;
			debug.println("found updated TC file");
		    }
		}
	    }
	    
	    if(reload) {
		debug.println("loading initial TC files");
		loadInitTC();
		debug.println("loading pattern-log");
		loadPatternLog();
	    }
	    
	    else{
		debug.println("loading saved patterns");
		loadFromFile();
	    }
	} catch (Exception e) {
	    debug.println("error loading TC patterns");
	}
    }

    //checks the syntax of a pattern to see if it needs to be added to the log
    public static void checkForLog(TC pattern) {
	TCToken tok = pattern.getSyntax();
	if(isAssignToken(tok)) //adds a pattern to the library
	    addToLog(pattern);
	else if(isUnbindToken(tok)) //removes a pattern from the library
	    addToLog(pattern);
    }

    private static boolean isUnbindToken(TCToken tok) {
	if(tok==null)
	    return false;
	if(tok.sym == TCSymbols.UNBIND)
	    return true;
	return isAssignToken(tok.sibling) || isAssignToken(tok.child);
    }

    private static boolean isAssignToken(TCToken tok) {
	if(tok==null)
	    return false;
	if(tok.sym == TCSymbols.IS)
	    return true;
	return isAssignToken(tok.sibling) || isAssignToken(tok.child);
    }

    //data structure for writing TC patterns to disk
    private static class SavedTC implements Serializable{
	String name;
	TC tc;

	public SavedTC(String name, TC tc) {
	    this.name=name;
	    this.tc=tc;
	}
	
	public String getName() {
	    return name;
	}
	
	public TC getTC() {
	    return tc;
	}
    }

}

