/*
 * LAPIS lightweight structured text processing system
 *
 * Copyright (C) 1998-2002 Carnegie Mellon University,
 * Copyright (C) 2003 Massachusetts Institute of Technology.
 * All rights reserved.
 *
 * This library is free software; you can redistribute it
 * and/or modify it under the terms of the GNU General
 * Public License as published by the Free Software
 * Foundation, version 2.
 *
 * LAPIS homepage: http://graphics.lcs.mit.edu/lapis/
 */

package lapis;

import junit.framework.*;

/**
 * Junit Test for MultiDocRegionSet Functionalities.
 */
public class MultiDocRegionSetFunctionTest extends TestCase {
	private final int MAX = RegionSet.MAX_INDEX;

	private MutableRegionSet bkgd;
	private MutableRegionSet text;
	private MutableRegionSet result;

	private int[] pointRegions;
	private int[] pointStartingContainsRegionSet;
	private int[] pointStartingInRegionSet;
	private int[] pointEndingContainsRegionSet;
	private int[] pointEndingInRegionSet;
	private int[] pointContainsRegionSet;
	private int[] pointInRegionSet;
	
	private int[] pointsRegions;
	private int[] pointsStartingContainsRegionSet;
	private int[] pointsStartingInRegionSet;
	private int[] pointsEndingContainsRegionSet;
	private int[] pointsEndingInRegionSet;
	private int[] pointsContainsRegionSet;
	private int[] pointsInRegionSet;

	static Document doc1 = BasicDocument.defaultFactory.make ("doc1");
	static Document doc2 = BasicDocument.defaultFactory.make ("doc2");

	public static void main(String args[]) {
		junit.textui.TestRunner.run(MultiDocRegionSetFunctionTest.class);
	}

	protected void setUp() {
		bkgd = new MutableRegionSet (5);
		bkgd.insert(50, 175, doc1);
		bkgd.insert(150, 180, doc2);
		bkgd.insert(125, 200, doc1);
		bkgd.insert(50, 100, doc2);
		bkgd.insert(181, 210, doc2);
		
		pointRegions = new int[] {
			150, 225, 1, 50, 180, 2,
			75, 200, 1, 75, 125, 2,
			100, 150, 1, 25, 250, 2
		};
		
		pointStartingContainsRegionSet = new int[] {
			125, 150, 225, MAX, 1, 50, 50, 180, MAX, 2,
			50, 75, 200, MAX, 1, 50, 75, 125, MAX, 2,
			50, 100, 150, MAX, 1, 25, 25, 250, MAX, 2
		};
		
		pointStartingInRegionSet = new int[] {
			150, 200, 0, 225, 1, 50, 100, 0, 180, 2,
			75, 175, 0, 200, 1, 75, 100, 0, 125, 2,
			100, 150, 0, 150, 1, 25, 25, 0, 250, 2
		};
		
		pointEndingContainsRegionSet = new int[] {
			0, 150, 225, 225, 1, 0, 50, 180, 180, 2,
			0, 75, 200, 200, 1, 0, 75, 125, 125, 2,
			0, 100, 150, 200, 1, 0, 25, 250, 250, 2
		};
		
		pointEndingInRegionSet = new int[] {
			150, 225, 225, 225, 1, 50, 180, 150, 180, 2,
			75, 200, 125, 200, 1, 75, 125, 125, 125, 2,
			100, 150, 125, 150, 1, 25, 250, 250, 250, 2
		};
		
		pointContainsRegionSet = new int[] {
			0, 150, 225, MAX, 1, 0, 50, 180, MAX, 2,
			0, 75, 200, MAX, 1, 0, 75, 125, MAX, 2,
			0, 100, 150, MAX, 1, 0, 25, 250, MAX, 2
		};
		
		pointInRegionSet = new int[] {
			150, 225, 0, 225, 1, 50, 180, 0, 180, 2,
			75, 200, 0, 200, 1, 75, 125, 0, 125, 2,
			100, 150, 0, 150, 1, 25, 250, 0, 250, 2
		};
		
		pointsRegions = new int[] {
			25, 75, 1, 
			125, 210, 2,
			75, 200, 2,
			150, 180, 1,
			50, 200, 1,
			60, 160, 2,
			125, 160, 2,
			200, 250, 2, 
			75, 100, 1
		};
		
		pointsStartingContainsRegionSet = new int[] {
			25, 25, 75, MAX, 1, 
			50, 75, 100, MAX, 1,
			125, 150, 180, MAX, 1,
			50, 60, 160, MAX, 2,
			61, 75, 200, MAX, 2,
			125, 125, 160, MAX, 2,
			181, 200, 250, MAX, 2
		};
		
		pointsStartingInRegionSet = new int[] {
			25, 25, 25, 75, 1,
			50, 175, 50, 200, 1,
			176, 180, 0, 180, 1,
			60, 74, 60, 160, 2, 
			75, 100, 60, 200, 2, 
			125, 125, 125, 210, 2, 
			200, 210, 200, 250, 2
		};
		
		pointsEndingContainsRegionSet = new int[] {
			0, 25, 75, 175, 1, 
			0, 150, 180, 200, 1, 
			26, 75, 100, 175, 1, 
			0, 60, 160, 180, 2, 
			0, 75, 200, 210, 2, 
			0, 200, 250, 250, 2, 
			61, 125, 160, 180, 2, 
			76, 125, 210, 210, 2
		};
		
		pointsEndingInRegionSet = new int[] {
			25, 75, 50, 75, 1, 
			50, 200, 125, 200, 1, 
			75, 100, 75, 100, 1,
			60, 160, 150, 160, 2, 
			75, 200, 181, 200, 2,
			125, 210, 181, 210, 2,
			200, 250, 250, 250, 2 
		};
		
		pointsContainsRegionSet = new int[] {
			0, 25, 75, MAX, 1,
			0, 75, 100, MAX, 1, 
			0, 150, 180, MAX, 1, 
			0, 125, 160, MAX, 2, 
			0, 200, 250, MAX, 2	
		};
		
		pointsInRegionSet = new int[] {
			60, 160, 60, 160, 2, 
			75, 200, 75, 200, 2, 
			25, 75, 25, 75, 1, 
			50, 200, 50, 200, 1, 
			125, 210, 125, 210, 2, 
			200, 250, 200, 250, 2	
		};
	}

	public void testPointStartingContains () {
		int j = 0;
		Document doc;
		for (int i = 0; i < pointRegions.length; i += 6) {
			text = new MutableRegionSet ();
			doc = (pointRegions[i+2]==1) ? doc1 : doc2;
			text.insert (pointRegions[i], pointRegions[i+1], doc);
			doc = (pointRegions[i+5]==1) ? doc1 : doc2;
			text.insert (pointRegions[i+3], pointRegions[i+4], doc);
			
			result = new MutableRegionSet ();
			int j0 = pointStartingContainsRegionSet[j];
			int j1 = pointStartingContainsRegionSet[j+1];
			int j2 = pointStartingContainsRegionSet[j+2];
			int j3 = pointStartingContainsRegionSet[j+3];
			doc = (pointStartingContainsRegionSet[j+4]==1) ? doc1 : doc2;
			if (j0 == j1 && j2 == j3)
				result.insert (j0, j2, doc);
			else 
				result.insert (new FuzzyRegion(j0, j1, j2, j3, doc));
			j0 = pointStartingContainsRegionSet[j+5];
			j1 = pointStartingContainsRegionSet[j+6];
			j2 = pointStartingContainsRegionSet[j+7];
			j3 = pointStartingContainsRegionSet[j+8];
			doc = (pointStartingContainsRegionSet[j+9]==1) ? doc1 : doc2;
			if (j0 == j1 && j2 == j3)
				result.insert (j0, j2, doc);
			else 
				result.insert (new FuzzyRegion(j0, j1, j2, j3, doc));
			
			assertTrue( (text.startingContains(bkgd)).slowEquals(result) );
			
			j += 10;
		}
	}

	public void testPointStartingIn () {
		int j = 0;
		Document doc;
		for (int i = 0; i < pointRegions.length; i += 6) {
			text = new MutableRegionSet ();
			doc = (pointRegions[i+2]==1) ? doc1 : doc2;
			text.insert (pointRegions[i], pointRegions[i+1], doc);
			doc = (pointRegions[i+5]==1) ? doc1 : doc2;
			text.insert (pointRegions[i+3], pointRegions[i+4], doc);
			
			result = new MutableRegionSet ();
			int j0 = pointStartingInRegionSet[j];
			int j1 = pointStartingInRegionSet[j+1];
			int j2 = pointStartingInRegionSet[j+2];
			int j3 = pointStartingInRegionSet[j+3];
			doc = (pointStartingInRegionSet[j+4]==1) ? doc1 : doc2;
			if (j0 == j1 && j2 == j3)
				result.insert (j0, j2, doc);
			else 
				result.insert (new FuzzyRegion(j0, j1, j2, j3, doc));
			j0 = pointStartingInRegionSet[j+5];
			j1 = pointStartingInRegionSet[j+6];
			j2 = pointStartingInRegionSet[j+7];
			j3 = pointStartingInRegionSet[j+8];
			doc = (pointStartingInRegionSet[j+9]==1) ? doc1 : doc2;
			if (j0 == j1 && j2 == j3)
				result.insert (j0, j2, doc);
			else 
				result.insert (new FuzzyRegion(j0, j1, j2, j3, doc));
			
			assertTrue( (text.startingIn(bkgd)).slowEquals(result) );
			
			j += 10;
		}
	}
	
	public void testPointEndingContains () {
		int j = 0;
		Document doc;
		for (int i = 0; i < pointRegions.length; i += 6) {
			text = new MutableRegionSet ();
			doc = (pointRegions[i+2]==1) ? doc1 : doc2;
			text.insert (pointRegions[i], pointRegions[i+1], doc);
			doc = (pointRegions[i+5]==1) ? doc1 : doc2;
			text.insert (pointRegions[i+3], pointRegions[i+4], doc);
			
			result = new MutableRegionSet ();
			int j0 = pointEndingContainsRegionSet[j];
			int j1 = pointEndingContainsRegionSet[j+1];
			int j2 = pointEndingContainsRegionSet[j+2];
			int j3 = pointEndingContainsRegionSet[j+3];
			doc = (pointEndingContainsRegionSet[j+4]==1) ? doc1 : doc2;
			if (j0 == j1 && j2 == j3)
				result.insert (j0, j2, doc);
			else 
				result.insert (new FuzzyRegion(j0, j1, j2, j3, doc));
			j0 = pointEndingContainsRegionSet[j+5];
			j1 = pointEndingContainsRegionSet[j+6];
			j2 = pointEndingContainsRegionSet[j+7];
			j3 = pointEndingContainsRegionSet[j+8];
			doc = (pointEndingContainsRegionSet[j+9]==1) ? doc1 : doc2;
			if (j0 == j1 && j2 == j3)
				result.insert (j0, j2, doc);
			else 
				result.insert (new FuzzyRegion(j0, j1, j2, j3, doc));
			
			assertTrue( (text.endingContains(bkgd)).slowEquals(result) );
			
			j += 10;
		}
	}

	public void testPointEndingIn () {
		int j = 0;
		Document doc;
		for (int i = 0; i < pointRegions.length; i += 6) {
			text = new MutableRegionSet ();
			doc = (pointRegions[i+2]==1) ? doc1 : doc2;
			text.insert (pointRegions[i], pointRegions[i+1], doc);
			doc = (pointRegions[i+5]==1) ? doc1 : doc2;
			text.insert (pointRegions[i+3], pointRegions[i+4], doc);
			
			result = new MutableRegionSet ();
			int j0 = pointEndingInRegionSet[j];
			int j1 = pointEndingInRegionSet[j+1];
			int j2 = pointEndingInRegionSet[j+2];
			int j3 = pointEndingInRegionSet[j+3];
			doc = (pointEndingInRegionSet[j+4]==1) ? doc1 : doc2;
			if (j0 == j1 && j2 == j3)
				result.insert (j0, j2, doc);
			else 
				result.insert (new FuzzyRegion(j0, j1, j2, j3, doc));
			j0 = pointEndingInRegionSet[j+5];
			j1 = pointEndingInRegionSet[j+6];
			j2 = pointEndingInRegionSet[j+7];
			j3 = pointEndingInRegionSet[j+8];
			doc = (pointEndingInRegionSet[j+9]==1) ? doc1 : doc2;
			if (j0 == j1 && j2 == j3)
				result.insert (j0, j2, doc);
			else 
				result.insert (new FuzzyRegion(j0, j1, j2, j3, doc));
			
			assertTrue( (text.endingIn(bkgd)).slowEquals(result) );
			
			j += 10;
		}
	}

	public void testPointContains () {
		int j = 0;
		Document doc;
		for (int i = 0; i < pointRegions.length; i += 6) {
			text = new MutableRegionSet ();
			doc = (pointRegions[i+2]==1) ? doc1 : doc2;
			text.insert (pointRegions[i], pointRegions[i+1], doc);
			doc = (pointRegions[i+5]==1) ? doc1 : doc2;
			text.insert (pointRegions[i+3], pointRegions[i+4], doc);
			
			result = new MutableRegionSet ();
			int j0 = pointContainsRegionSet[j];
			int j1 = pointContainsRegionSet[j+1];
			int j2 = pointContainsRegionSet[j+2];
			int j3 = pointContainsRegionSet[j+3];
			doc = (pointContainsRegionSet[j+4]==1) ? doc1 : doc2;
			if (j0 == j1 && j2 == j3)
				result.insert (j0, j2, doc);
			else 
				result.insert (new FuzzyRegion(j0, j1, j2, j3, doc));
			j0 = pointContainsRegionSet[j+5];
			j1 = pointContainsRegionSet[j+6];
			j2 = pointContainsRegionSet[j+7];
			j3 = pointContainsRegionSet[j+8];
			doc = (pointContainsRegionSet[j+9]==1) ? doc1 : doc2;
			if (j0 == j1 && j2 == j3)
				result.insert (j0, j2, doc);
			else 
				result.insert (new FuzzyRegion(j0, j1, j2, j3, doc));
			
			assertTrue( (text.contains()).slowEquals(result) );
			
			j += 10;
		}
	}

	public void testPointIn () {
		int j = 0;
		Document doc;
		for (int i = 0; i < pointRegions.length; i += 6) {
			text = new MutableRegionSet ();
			doc = (pointRegions[i+2]==1) ? doc1 : doc2;
			text.insert (pointRegions[i], pointRegions[i+1], doc);
			doc = (pointRegions[i+5]==1) ? doc1 : doc2;
			text.insert (pointRegions[i+3], pointRegions[i+4], doc);
			
			result = new MutableRegionSet ();
			int j0 = pointInRegionSet[j];
			int j1 = pointInRegionSet[j+1];
			int j2 = pointInRegionSet[j+2];
			int j3 = pointInRegionSet[j+3];
			doc = (pointInRegionSet[j+4]==1) ? doc1 : doc2;
			if (j0 == j1 && j2 == j3)
				result.insert (j0, j2, doc);
			else 
				result.insert (new FuzzyRegion(j0, j1, j2, j3, doc));
			j0 = pointInRegionSet[j+5];
			j1 = pointInRegionSet[j+6];
			j2 = pointInRegionSet[j+7];
			j3 = pointInRegionSet[j+8];
			doc = (pointInRegionSet[j+9]==1) ? doc1 : doc2;
			if (j0 == j1 && j2 == j3)
				result.insert (j0, j2, doc);
			else 
				result.insert (new FuzzyRegion(j0, j1, j2, j3, doc));
			
			assertTrue( (text.in()).slowEquals(result) );
			
			j += 10;
		}
	}
	
	public void testPointsStartingContains () {
		Document doc;
		text = new MutableRegionSet ();
		for (int i = 0; i < pointsRegions.length; i += 3) {
			doc = (pointsRegions[i+2]==1) ? doc1 : doc2;
			text.insert (pointsRegions[i], pointsRegions[i+1], doc);			
		}
		result = new MutableRegionSet ();
		for (int i = 0; i < pointsStartingContainsRegionSet.length; i += 5) {
			doc = (pointsStartingContainsRegionSet[i+4]==1) ? doc1 : doc2;
			result.insert(new FuzzyRegion(pointsStartingContainsRegionSet[i],
										  pointsStartingContainsRegionSet[i+1],
										  pointsStartingContainsRegionSet[i+2],
										  pointsStartingContainsRegionSet[i+3], 
										  doc));
		}
		assertTrue ( (text.startingContains(bkgd)).slowEquals(result) );
	}

	public void testPointsStartingIn () {
		Document doc;
		text = new MutableRegionSet ();
		for (int i = 0; i < pointsRegions.length; i += 3) {
			doc = (pointsRegions[i+2]==1) ? doc1 : doc2;
			text.insert (pointsRegions[i], pointsRegions[i+1], doc);			
		}
		result = new MutableRegionSet ();
		for (int i = 0; i < pointsStartingInRegionSet.length; i += 5) {
			doc = (pointsStartingInRegionSet[i+4]==1) ? doc1 : doc2;
			result.insert(new FuzzyRegion(pointsStartingInRegionSet[i],
										  pointsStartingInRegionSet[i+1],
										  pointsStartingInRegionSet[i+2],
										  pointsStartingInRegionSet[i+3], 
										  doc));
		}
		assertTrue ( (text.startingIn(bkgd)).slowEquals(result) );
	}

	public void testPointsEndingContains () {
		Document doc;
		text = new MutableRegionSet ();
		for (int i = 0; i < pointsRegions.length; i += 3) {
			doc = (pointsRegions[i+2]==1) ? doc1 : doc2;
			text.insert (pointsRegions[i], pointsRegions[i+1], doc);			
		}
		result = new MutableRegionSet ();
		for (int i = 0; i < pointsEndingContainsRegionSet.length; i += 5) {
			doc = (pointsEndingContainsRegionSet[i+4]==1) ? doc1 : doc2;
			result.insert(new FuzzyRegion(pointsEndingContainsRegionSet[i],
										  pointsEndingContainsRegionSet[i+1],
										  pointsEndingContainsRegionSet[i+2],
										  pointsEndingContainsRegionSet[i+3], 
										  doc));
		}
		assertTrue ( (text.endingContains(bkgd)).slowEquals(result) );
	}

	public void testPointsEndingIn () {
		Document doc;
		text = new MutableRegionSet ();
		for (int i = 0; i < pointsRegions.length; i += 3) {
			doc = (pointsRegions[i+2]==1) ? doc1 : doc2;
			text.insert (pointsRegions[i], pointsRegions[i+1], doc);			
		}
		result = new MutableRegionSet ();
		for (int i = 0; i < pointsEndingInRegionSet.length; i += 5) {
			doc = (pointsEndingInRegionSet[i+4]==1) ? doc1 : doc2;
			result.insert(new FuzzyRegion(pointsEndingInRegionSet[i],
										  pointsEndingInRegionSet[i+1],
										  pointsEndingInRegionSet[i+2],
										  pointsEndingInRegionSet[i+3], 
										  doc));
		}
		assertTrue ( (text.endingIn(bkgd)).slowEquals(result) );
	}

	public void testPointsContains () {
		Document doc;
		text = new MutableRegionSet ();
		for (int i = 0; i < pointsRegions.length; i += 3) {
			doc = (pointsRegions[i+2]==1) ? doc1 : doc2;
			text.insert (pointsRegions[i], pointsRegions[i+1], doc);			
		}
		result = new MutableRegionSet ();
		for (int i = 0; i < pointsContainsRegionSet.length; i += 5) {
			doc = (pointsContainsRegionSet[i+4]==1) ? doc1 : doc2;
			result.insert(new FuzzyRegion(pointsContainsRegionSet[i],
										  pointsContainsRegionSet[i+1],
										  pointsContainsRegionSet[i+2],
										  pointsContainsRegionSet[i+3], 
										  doc));
		}
		assertTrue ( (text.contains()).slowEquals(result) );
	}

	public void testPointsIn () {
		Document doc;
		text = new MutableRegionSet ();
		for (int i = 0; i < pointsRegions.length; i += 3) {
			doc = (pointsRegions[i+2]==1) ? doc1 : doc2;
			text.insert (pointsRegions[i], pointsRegions[i+1], doc);			
		}
		result = new MutableRegionSet ();
		for (int i = 0; i < pointsInRegionSet.length; i += 5) {
			doc = (pointsInRegionSet[i+4]==1) ? doc1 : doc2;
			result.insert(new FuzzyRegion(pointsInRegionSet[i],
										  pointsInRegionSet[i+1],
										  pointsInRegionSet[i+2],
										  pointsInRegionSet[i+3], 
										  doc));
		}
		assertTrue ( (text.in()).slowEquals(result) );
	}
}
