/*
 * LAPIS lightweight structured text processing system
 *
 * Copyright (C) 1998-2002 Carnegie Mellon University,
 * Copyright (C) 2003 Massachusetts Institute of Technology.
 * All rights reserved.
 *
 * This library is free software; you can redistribute it
 * and/or modify it under the terms of the GNU General
 * Public License as published by the Free Software
 * Foundation, version 2.
 *
 * LAPIS homepage: http://graphics.lcs.mit.edu/lapis/
 */

package lapis;

/**
 * A RegionSet implements Mutable interface supports 
 * insertion and deletion of regions.
 */
public interface Mutable {
    /**
     * insert a region represented by start, end, and ver
     * @param start region's start index
     * @param end region's end index
     * @param ver region's version
     */
    public void insert (int start, int end, DocumentVersion ver);

    /**
     * insert a region
     * @param r region to be inserted
     */
    public void insert (Region r);

    /**
     * insert a region set
     * @param s region set to be inserted
     */
    public void insert (RegionSet s);

    /**
     * delete a region
     * @param r region to be deleted
     */
    public void delete (Region r);

    /**
     * delete a region set
     * @param s region set to be deleted
     */
    public void delete (RegionSet s);
}
