/*
 * LAPIS lightweight structured text processing system
 *
 * Copyright (C) 1998-2002 Carnegie Mellon University,
 * Copyright (C) 2003 Massachusetts Institute of Technology.
 * All rights reserved.
 *
 * This library is free software; you can redistribute it
 * and/or modify it under the terms of the GNU General
 * Public License as published by the Free Software
 * Foundation, version 2.
 *
 * LAPIS homepage: http://graphics.lcs.mit.edu/lapis/
 */



package lapis;

import lapis.tc.TC;
import lapisx.util.Debug;
import java.util.*;

/**
 * A NamedRegionSet is a region set that records the pattern that generated 
 * it.  This class is immutable.
 */
public class NamedRegionSet extends RegionSet {

    public static Debug debug = Debug.QUIET;

    RegionSet regions;
    TC pat;

	public NamedRegionSet (RegionSet regions, TC pat) {
		this.regions = regions;
		this.pat = pat;
	}

	public NamedRegionSet (RegionSet regions, String description) {
		this.regions = regions;
		this.pat = new TC (new TC.Constant (this), description);
	}

	public NamedRegionSet (RegionSet regions) {
		this (regions, (TC)null);
	}

	public NamedRegionSet (NamedRegionSet ns) {
		this (ns.regions, ns.pat);
	}

	public NamedRegionSet (NamedRegionSet ns, TC pat) {
		this (ns.regions, pat);
	}

	public NamedRegionSet (NamedRegionSet ns, String description) {
		this (ns.regions, description);
	}
    
    public int getSize () {
        return this.regions.getSize ();
    }

    public TC getPattern () {
        return pat;
    }

    public String toString () {
        return pat != null ? pat.toString () : super.toString ();
    }

	public RegionSet convert (Versions vers) {
		return new NamedRegionSet (this.regions.convert(vers), getPattern ());
	}
    
	public SubsetEnumeration singleDocize () {
		return this.regions.singleDocize();
	}
    
	public SingleDocRegionSet getSingleDocRegionSet (Document d) {
		return this.regions.getSingleDocRegionSet(d);
	}
    
    public RegionSet freeze() {
    	return this.regions.freeze();
    }

	public RegionEnumeration regions(Region bbox) {
		return this.regions.regions(bbox);
	}
	public RegionEnumeration regions(RegionSet bboxs) {
		return this.regions.regions(bboxs);
	}
    public Versions getVersions() {
        return this.regions.getVersions();
    }
}
