/*
 * LAPIS lightweight structured text processing system
 *
 * Copyright (C) 1998-2002 Carnegie Mellon University,
 * Copyright (C) 2003 Massachusetts Institute of Technology.
 * All rights reserved.
 *
 * This library is free software; you can redistribute it
 * and/or modify it under the terms of the GNU General
 * Public License as published by the Free Software
 * Foundation, version 2.
 *
 * LAPIS homepage: http://graphics.lcs.mit.edu/lapis/
 */



package lapis;

/**
 * A Parser binds patterns to names in a PatternLibrary.  The actual
 * parsing of a document should be done behind the scenes when one
 * of those patterns is matched against a document.
 */
public interface Parser {
    /**
     * Bind the parser's patterns into the library.  This method is called by PatternLibrary when 
     * the parser is added to the library.   
     * @param lib Library in which patterns should be bound
     * @effects Parsers should implement this by calling {@link PatternLibrary#put(String,String) PatternLibrary.put()}
     * to add each of their patterns to the library.
     */
    public void bind (PatternLibrary lib);
    
    /**
     * Bind document-specific patterns into a document-specific library.  This method is called by PatternLibrary
     * when {@link PatternLibrary#getDocumentLibrary() getDocumentLibrary} makes a document-specific
     * library for a new document.  
     * @param lib Document-specific library
     * @param doc Document to which library pertains
     * @effects Parsers that have document-specific patterns should examine the document
     * and add the appropriate patterns to the library.  Parsers that don't have document-specific patterns should 
     * do nothing.
     */
    public void bind (PatternLibrary lib, Document doc); 
}
