/*
 * LAPIS lightweight structured text processing system
 *
 * Copyright (C) 1998-2002 Carnegie Mellon University,
 * Copyright (C) 2003 Massachusetts Institute of Technology.
 * All rights reserved.
 *
 * This library is free software; you can redistribute it
 * and/or modify it under the terms of the GNU General
 * Public License as published by the Free Software
 * Foundation, version 2.
 *
 * LAPIS homepage: http://graphics.lcs.mit.edu/lapis/
 */



package lapis;
import java.util.Hashtable;
import java.util.Enumeration;

public class PatternCache implements Cloneable {
    public static lapisx.util.Debug debug = lapisx.util.Debug.QUIET; 

    private Hashtable parsers = new Hashtable ();
        // parsers which have run on this document, 
        // used by wasParsedBy/setParsedBy
    private Hashtable regionSets = new Hashtable ();
        // maps Object -> RegionSet, used by get/contains/put

    public PatternCache () {
    }

    public void clear () {
        parsers.clear ();
        regionSets.clear ();
    }

    public Object clone () {
         try {
            return super.clone ();
         } catch (CloneNotSupportedException e) {
             // shouldn't happen
             throw new RuntimeException (e.toString ());
         }
    }

    public boolean wasParsedBy (Object obj) {
        return parsers.containsKey (obj);
    }

    public void setParsedBy (Object obj) {
        parsers.put (obj, obj);
    }

    public RegionSet get (Object key) {
        return (RegionSet) regionSets.get (key);
    }

    public void put (Object key, RegionSet s) {
	//        debug.println ("caching " + key + " -> " + s);
        //debug.assertion (s.getDocumentVersion () == null
        //                 || s.getDocumentVersion().getDocumentView() == s.getDocument().getDefaultView());
        regionSets.put (key, s);
    }

    public void remove (Object key) {
        regionSets.remove (key);
    }

    public void add (Object key, RegionSet s) {
//    	debug.assertion(false);
        RegionSet v = get (key);

        MutableRegionSet mv;
        if (v == null) {
            mv = new MutableRegionSet ();
            put (key, mv);
        } else if (v instanceof MutableRegionSet)
            mv = (MutableRegionSet) v;
        else {
            mv = new MutableRegionSet (v);
            put (key, mv);
        }

        mv.insert (s);
    }

    public void remove (Object key, RegionSet s) {
        RegionSet v = get (key);

        MutableRegionSet mv;
        if (v == null) {
            mv = new MutableRegionSet ();
            put (key, mv);
        } else if (v instanceof MutableRegionSet)
            mv = (MutableRegionSet) v;
        else {
            mv = new MutableRegionSet (v);
            put (key, mv);
        }

        mv.delete (s);
    }

    public boolean contains (Object key) {
        return regionSets.containsKey (key);
    }

    /**
      * Enumerate the keys in this labeling.  The returned keys are
      * Objects of unknown class (though many of them are probably
      * Patterns).  
      */
    public Enumeration keys () {
        return regionSets.keys ();
    }

	/*
    public void convert (PatternCache cache, CoordinateMap map) {
        for (Enumeration e = cache.keys (); e.hasMoreElements (); ) {
            Object key = e.nextElement ();
            put (key, cache.get (key).convert (map));
        }
    }
    */
}
