/*
 * LAPIS lightweight structured text processing system
 *
 * Copyright (C) 1998-2002 Carnegie Mellon University,
 * Copyright (C) 2003 Massachusetts Institute of Technology.
 * All rights reserved.
 *
 * This library is free software; you can redistribute it
 * and/or modify it under the terms of the GNU General
 * Public License as published by the Free Software
 * Foundation, version 2.
 *
 * LAPIS homepage: http://graphics.lcs.mit.edu/lapis/
 */


package lapis;

import junit.framework.*;

public class RegionSetFunctionTest extends TestCase {
    private final int MAX = RegionSet.MAX_INDEX;

    private MutableRegionSet bkgd;
    private MutableRegionSet text;

    private MutableRegionSet startingContainsResult;
    private MutableRegionSet endingContainsResult;
    private MutableRegionSet startingInResult;
    private MutableRegionSet endingInResult;
    private MutableRegionSet descendantResult;
    private MutableRegionSet ancestorResult;
    private MutableRegionSet beforeResult;
    private MutableRegionSet afterResult;
    private MutableRegionSet containsResult;
    private MutableRegionSet inResult;

    // startingContains and endingContains
    private int[] pointRegions;
    private int[] startingContainsRegionSet;
    private int[] endingContainsRegionSet;
    private int[] startingInRegionSet;
    private int[] endingInRegionSet;

    private int[] doublePointRegions;
    private int[] doubleStartingContainsRegionSet;
    private int[] doubleEndingContainsRegionSet;
    private int[] doubleStartingInRegionSet;
    private int[] doubleEndingInRegionSet;

    private int[] multiPointRegions;
    private int[] multiStartingContainsRegionSet;
    private int[] multiEndingContainsRegionSet;
    private int[] multiStartingInRegionSet;
    private int[] multiEndingInRegionSet;

    private int[] multiPointRegionsAlign;
    private int[] multiStartingContainsRegionSetAlign;
    private int[] multiEndingContainsRegionSetAlign;
    private int[] multiStartingInRegionSetAlign;
    private int[] multiEndingInRegionSetAlign;

    private int[] fuzzyRegions;
    private int[] startingContainsFuzzyRegionSet;
    private int[] endingContainsFuzzyRegionSet;
    private int[] startingInFuzzyRegionSet;
    private int[] endingInFuzzyRegionSet;

    private int[] doubleFuzzyRegions;
    private int[] doubleStartingContainsFuzzyRegionSet;
    private int[] doubleEndingContainsFuzzyRegionSet;
    private int[] doubleStartingInFuzzyRegionSet;
    private int[] doubleEndingInFuzzyRegionSet;

    private int[] multiMicsRegionsVertical;
    private int[] multiStartingContainsMicsRegionSetVertical;
    private int[] multiEndingContainsMicsRegionSetVertical;
    private int[] multiStartingInMicsRegionSetVertical;
    private int[] multiEndingInMicsRegionSetVertical;

    private int[] multiMicsRegionsAlign;
    private int[] multiStartingContainsMicsRegionSetAlign;
    private int[] multiEndingContainsMicsRegionSetAlign;
    private int[] multiStartingInMicsRegionSetAlign;
    private int[] multiEndingInMicsRegionSetAlign;

    // descendant and ancestor
    private int[] pointRegionsDA;
    private int[] descendantRegionSet;
    private int[] ancestorRegionSet;

    private int[] fuzzyRegionsDA;
    private int[] descendantFuzzyRegionSet;
    private int[] ancestorFuzzyRegionSet;

    private int[] fuzzyRegionsDA2;
    private int[] descendantFuzzyRegionSet2;
    private int[] ancestorFuzzyRegionSet2;

    // before and after
    private int[] pointRegionsBA;
    private int[] beforePointRegionSet;
    private int[] afterPointRegionSet;

    private int[] fuzzyRegionsBA;
    private int[] beforeFuzzyRegionSet;
    private int[] afterFuzzyRegionSet;

    private int[] micsRegionsBA;
    private int[] beforeMicsRegionSet;
    private int[] afterMicsRegionSet;

    // contains and in
    private int[] pointRegionsCI;
    private int[] containsPointRegionSet;
    private int[] inPointRegionSet;

    private int[] fuzzyRegionsCI;
    private int[] containsFuzzyRegionSet;
    private int[] inFuzzyRegionSet;

    private int[] pointRegionsCI2;
    private int[] containsPointRegionSet2;
    private int[] inPointRegionSet2;

    private int[] fuzzyRegionsCI2;
    private int[] containsFuzzyRegionSet2;
    private int[] inFuzzyRegionSet2;

	static Document doc = BasicDocument.defaultFactory.make ("");

    public static void main(String args[]) {
	junit.textui.TestRunner.run(RegionSetFunctionTest.class);
    }

    protected void setUp() {
	bkgd = new MutableRegionSet(3);
	bkgd.insert(50, 100, doc);
	bkgd.insert(150, 180, doc);
	bkgd.insert(181, 210, doc);

	pointRegions = new int[] {
	    25, 250,
	    50, 250,
	    75, 250,
	    100, 250,
	    180, 250, 
	    200, 250,
	    240, 250,
	    50, 210,
	    75, 210,
	    181, 210,
	    50, 200,
	    125, 200,
	    150, 200,
	    170, 200,
	    200, 200,
	    75, 160
	};

	startingContainsRegionSet = new int[] {
	    25, 25, 250, MAX,
	    50, 50, 250, MAX,
	    50, 75, 250, MAX,
	    50, 100, 250, MAX,
	    150, 180, 250, MAX,
	    181, 200, 250, MAX,
	    240, 240, 250, MAX,
	    50, 50, 210, MAX,
	    50, 75, 210, MAX,
	    181, 181, 210, MAX,
	    50, 50, 200, MAX,
	    125, 125, 200, MAX,
	    150, 150, 200, MAX,
	    150, 170, 200, MAX,
	    181, 200, 200, MAX,
	    50, 75, 160, MAX
	};

	startingInRegionSet = new int[] {
	    25, 25, 25, 250,
	    50, 100, 50, 250,
	    75, 100, 75, 250,
	    100, 100, 100, 250,
	    180, 180, 180, 250,
	    200, 210, 200, 250,
	    240, 240, 240, 250,
	    50, 100, 50, 210,
	    75, 100, 75, 210,
	    181, 210, 181, 210,
	    50, 100, 50, 200,
	    125, 125, 125, 200,
	    150, 180, 150, 200,
	    170, 180, 170, 200,
	    200, 200, 200, 200,
	    75, 100, 75, 160
	};
	
	endingContainsRegionSet = new int[] {
	    0, 25, 250, 250,
	    0, 50, 250, 250,
	    0, 75, 250, 250,
	    0, 100, 250, 250, 
	    0, 180, 250, 250,
	    0, 200, 250, 250,
	    0, 240, 250, 250,
	    0, 50, 210, 210,
	    0, 75, 210, 210,
	    0, 181, 210, 210,
	    0, 50, 200, 210,
	    0, 125, 200, 210,
	    0, 150, 200, 210,
	    0, 170, 200, 210,
	    0, 200, 200, 210,
	    0, 75, 160, 180
	};

	endingInRegionSet = new int[] {
	    25, 250, 250, 250,
	    50, 250, 250, 250,
	    75, 250, 250, 250,
	    100, 250, 250, 250,
	    180, 250, 250, 250,
	    200, 250, 250, 250,
	    240, 250, 250, 250,
	    50, 210, 181, 210,
	    75, 210, 181, 210,
	    181, 210, 181, 210,
	    50, 200, 181, 200,
	    125, 200, 181, 200,
	    150, 200, 181, 200,
	    170, 200, 181, 200,
	    200, 200, 200, 200,
	    75, 160, 150, 160
	};

	doublePointRegions = new int[] {
	    75, 160, 75, 250,
	    75, 160, 125, 160,
	    25, 75, 60, 155,
	    90, 155, 60, 155,
	    90, 170, 90, 155,
	    90, 170, 60, 155
	};

	doubleStartingContainsRegionSet = new int[] {
	    4, 50, 75, 160, MAX,
	    8, 50, 75, 160, MAX, 125, 125, 160, MAX,
	    8, 25, 25, 75, MAX, 50, 60, 155, MAX,
	    4, 50, 90, 155, MAX,
	    4, 50, 90, 155, MAX,
	    8, 50, 60, 155, MAX, 50, 90, 170, MAX
	};

	doubleStartingInRegionSet = new int[] {
	    4, 75, 100, 75, 250,
	    8, 75, 100, 75, 160, 125, 125, 125, 160,
	    8, 25, 25, 25, 75, 60, 100, 60, 155,
	    4, 60, 100, 60, 155,
	    4, 90, 100, 90, 170,
	    8, 60, 100, 60, 155, 90, 100, 90, 170
	};

	doubleEndingContainsRegionSet = new int[] {
	    8, 0, 75, 160, 180, 0, 75, 250, 250,
	    4, 0, 125, 160, 180,
	    8, 0, 25, 75, 100, 0, 60, 155, 180,
	    4, 0, 90, 155, 180,
	    4, 0, 90, 155, 180,
	    8, 0, 60, 155, 180, 0, 90, 170, 180
	};

	doubleEndingInRegionSet = new int[] {
	    8, 75, 160, 150, 160, 75, 250, 250, 250,
	    4, 75, 160, 150, 160,
	    8, 25, 75, 50, 75, 60, 155, 150, 155,
	    4, 60, 155, 150, 155,
	    4, 90, 170, 150, 170,
	    8, 60, 155, 150, 155, 90, 170, 150, 170
	};

	multiPointRegions = new int[] {
	    125, 160,
	    75, 200,
	    200, 250,
	    25, 140,
	    125, 210,
	    25, 75,
	    60, 160,
	    150, 220
	};

	multiStartingContainsRegionSet = new int[] {
	    25, 25, 75, MAX,
	    50, 60, 160, MAX,
	    61, 75, 200, MAX,
	    125, 125, 160, MAX,
	    150, 150, 220, MAX,
	    181, 200, 250, MAX
	};

	multiStartingInRegionSet = new int[] {
	    25, 25, 25, 140,
	    60, 100, 60, 160,
	    75, 100, 75, 200,
	    125, 125, 125, 210,
	    150, 180, 150, 220,
	    200, 210, 200, 250
	};

	multiEndingContainsRegionSet = new int[] {
	    0, 25, 75, 100,
	    0, 25, 140, 140,
	    0, 60, 160, 180,
	    0, 75, 200, 210,
	    0, 150, 220, 220,
	    0, 200, 250, 250,
	    61, 125, 160, 180,
	    76, 125, 210, 210
	};

	multiEndingInRegionSet = new int[] {
	    25, 75, 50, 75,
	    25, 140, 140, 140,
	    60, 160, 150, 160,
	    75, 200, 181, 200,
	    125, 210, 181, 210,
	    150, 220, 220, 220,
	    200, 250, 250, 250
	};

	multiPointRegionsAlign = new int[] {
	    50, 220,
	    50, 180,
	    50, 110,
	    75, 180, 
	    125, 180, 
	    200, 220
	};

	multiStartingContainsRegionSetAlign = new int[] {
	    50, 50, 110, MAX,
	    50, 75, 180, MAX,
	    125, 125, 180, MAX,
	    181, 200, 220, MAX
	};

	multiStartingInRegionSetAlign = new int[] {
	    50, 100, 50, 220,
	    125, 125, 125, 180,
	    200, 210, 200, 220
	};

	multiEndingContainsRegionSetAlign = new int[] {
	    0, 50, 110, 110,
	    0, 50, 180, 180,
	    0, 50, 220, 220,
	    51, 125, 180, 180,
	    51, 200, 220, 220
	};

	multiEndingInRegionSetAlign = new int[] {
	    50, 110, 110, 110,
	    50, 180, 150, 180,
	    50, 220, 220, 220
	};

	fuzzyRegions = new int[] {
	    25, 75, 125, 160,
	    50, 150, 180, 200,
	    75, 150, 180, 210,
	    100, 125, 180, 250,
	    110, 140, 160, 250,
	    0, MAX, 0, MAX,
	    181, 210, 181, MAX,
	    75, 110, 50, 150,
	    100, 210, 125, 160,
	    100, 200, 50, 150
	};

	startingContainsFuzzyRegionSet = new int[] {
	    25, 75, 125, MAX,
	    50, 150, 180, MAX,
	    50, 150, 180, MAX,
	    50, 125, 180, MAX,
	    110, 140, 160, MAX,
	    0, MAX, 0, MAX,
	    181, 210, 181, MAX,
	    50, 110, 75, MAX,
	    50, 160, 125, MAX,
	    50, 150, 100, MAX
	};

	startingInFuzzyRegionSet = new int[] {
	    25, 100, 25, 160,
	    50, 180, 50, 200,
	    75, 180, 75, 210,
	    100, 125, 100, 250,
	    110, 140, 110, 250,
	    0, MAX, 0, MAX,
	    181, 210, 181, MAX,
	    75, 110, 75, 150,
	    100, 160, 100, 160,
	    100, 150, 100, 150
	};

	endingContainsFuzzyRegionSet = new int[] {
	    0, 75, 125, 180,
	    0, 150, 180, 210,
	    0, 150, 180, 210,
	    0, 125, 180, 250,
	    0, 140, 160, 250,
	    0, MAX, 0, MAX,
	    0, 210, 181, MAX,
	    0, 110, 75, 180,
	    0, 160, 125, 180,
	    0, 150, 100, 180
	};

	endingInFuzzyRegionSet = new int[] {
	    25, 160, 125, 160,
	    50, 200, 150, 200,
	    75, 210, 150, 210,
	    100, 250, 150, 250,
	    110, 250, 150, 250,
	    0, MAX, 0, MAX,
	    181, MAX, 181, MAX,
	    75, 150, 75, 150,
	    100, 160, 125, 160,
	    100, 150, 100, 150
	};

	doubleFuzzyRegions = new int[] {
	    // vertical
	    10, 40, 75, 160, 10, 40, 180, 250,
	    50, 75, 125, 210, 50, 75, 100, 150,
	    125, 160, 210, MAX, 125, 160, 100, 170,
	    170, 200, 170, 250, 170, 200, 260, 300,
	    // horizontal
	    40, 275, 250, 275, 0, 40, 60, 80,
	    50, 175, 100, 125, 60, 210, 150, 170,
	    0, 90, 100, 125, 60, 210, 150, 170,
	    25, 100, 200, 220, 160, 200, 200, 220
	};

	doubleStartingContainsFuzzyRegionSet = new int[] {
	    // vertical
	    4, 10, 40, 75, MAX,
	    4, 50, 75, 100, MAX,
	    4, 125, 160, 125, MAX,
	    4, 150, 200, 170, MAX,
	    // horizontal
	    8, 0, 40, 60, MAX, 40, 275, 250, MAX,
	    8, 50, 125, 100, MAX, 50, 170, 150, MAX,
	    8, 0, 90, 100, MAX, 50, 170, 150, MAX,
	    8, 25, 100, 200, MAX, 150, 200, 200, MAX
	};

	doubleStartingInFuzzyRegionSet = new int[] {
	    4, 10, 40, 10, 250,
	    4, 50, 100, 50, 210,
	    4, 125, 180, 125, MAX,
	    4, 170, 210, 170, 300,
	    8, 0, 40, 0, 80, 40, 275, 40, 275,
	    8, 50, 125, 50, 125, 60, 170, 60, 170,
	    8, 0, 100, 0, 125, 60, 170, 60, 170,
	    8, 25, 100, 25, 220, 160, 210, 160, 220
	};

	doubleEndingContainsFuzzyRegionSet = new int[] {
	    // vertical
	    8, 0, 40, 75, 180, 0, 40, 180, 250,
	    8, 0, 75, 100, 180, 0, 75, 125, 210,
	    8, 0, 160, 125, 180, 0, 160, 210, MAX,
	    8, 0, 200, 170, 250, 0, 200, 260, 300,
	    // horizontal
	    8, 0, 40, 60, 100, 0, 275, 250, 275,
	    8, 0, 125, 100, 125, 0, 170, 150, 180,
	    8, 0, 90, 100, 125, 0, 170, 150, 180,
	    4, 0, 200, 200, 220
	};

	doubleEndingInFuzzyRegionSet = new int[] {
	    8, 10, 160, 50, 160, 10, 250, 150, 250,
	    8, 50, 150, 50, 150, 50, 210, 125, 210,
	    8, 125, 170, 125, 170, 125, MAX, 181, MAX,
	    8, 170, 250, 170, 250, 170, 300, 260, 300,
	    8, 0, 80, 50, 80, 40, 275, 250, 275,
	    8, 50, 125, 50, 125, 60, 170, 150, 170,
	    8, 0, 125, 50, 125, 60, 170, 150, 170,
	    4, 25, 220, 181, 220
	};

	multiMicsRegionsVertical = new int[] {
	    2, 50, 110,
	    2, 50, 180, 
	    2, 50, 220,
	    4, 60, 75, 110, 140,
	    4, 60, 75, 200, 210,
	    2, 75, 150,
	    2, 75, 250,
	    2, 75, 200
	};

	multiStartingContainsMicsRegionSetVertical = new int[] {
	    50, 75, 110, MAX
	};	    

	multiStartingInMicsRegionSetVertical = new int[] {
	    50, 100, 50, 220,
	    75, 100, 75, 250
	};
	
	multiEndingContainsMicsRegionSetVertical = new int[] {
	    0, 75, 110, 140,
	    0, 75, 150, 180,
	    0, 75, 200, 210,
	    0, 50, 220, 220,
	    0, 75, 250, 250
	};

	multiEndingInMicsRegionSetVertical = new int[] {
	    50, 110, 110, 110,
	    50, 180, 150, 180,
	    50, 220, 220, 220,
	    60, 140, 110, 140,
	    60, 210, 181, 210,
	    75, 250, 250, 250
	};

	multiMicsRegionsAlign = new int[] {
	    2, 50, 220,
	    2, 50, 180,
	    2, 50, 110,
	    2, 75, 180, 
	    2, 125, 180,
	    2, 200, 220,
	    4, 60, 140, 160, 160
	};

	multiStartingContainsMicsRegionSetAlign = new int[] {
	    50, 50, 110, MAX,
	    50, 140, 160, MAX,
	    181, 200, 220, MAX
	};

	multiStartingInMicsRegionSetAlign = new int[] {
	    50, 100, 50, 220,
	    101, 140, 101, 160,
	    125, 125, 125, 180,
	    200, 210, 200, 220
	};

	multiEndingContainsMicsRegionSetAlign = new int[] {
	    0, 50, 110, 110,
	    0, 140, 160, 180,
	    0, 50, 220, 220,
	    51, 200, 220, 220
	};

	multiEndingInMicsRegionSetAlign = new int[] {
	    50, 110, 110, 110,
	    50, 180, 150, 180,
	    50, 220, 220, 220
	};

	pointRegionsDA = new int[] {
	    8, 50, 100, 100, 150, 150, 200, 175, 225,
	    8, 50, 250, 50, 200, 50, 100, 50, 150,
	    8, 50, 300, 100, 300, 150, 300, 200, 300,
	    8, 50, 300, 75, 275, 125, 225, 150, 200,
	    6, 100, 150, 150, 300, 125, 225
	};

	descendantRegionSet = new int[] {
	    32, 
	    50, 50, 50, 99,
	    51, 100, 51, 100,
	    100, 100, 100, 149,
	    101, 150, 101, 150,
	    150, 150, 150, 199,
	    151, 200, 151, 200,
	    175, 175, 175, 224,
	    176, 225, 176, 225,
	    8,
	    50, 50, 50, 249,
	    51, 250, 51, 250,
	    8,
	    50, 50, 50, 299,
	    51, 300, 51, 300,
	    8,
	    50, 50, 50, 299,
	    51, 300, 51, 300,
	    24,
	    100, 100, 100, 149,
	    101, 150, 101, 150,
	    125, 125, 125, 224,
	    126, 225, 126, 225,
	    150, 150, 150, 299,
	    151, 300, 151, 300
	};
	
	ancestorRegionSet = new int[] {
	    32,
	    0, 49, 100, 100,
	    0, 50, 101, MAX,
	    0, 100, 151, MAX,
	    0, 150, 201, MAX,
	    0, 175, 226, MAX,
	    51, 99, 150, 150,
	    101, 149, 200, 200,
	    151, 174, 225, 225,
	    8,
	    0, 49, 100, 100,
	    0, 50, 101, MAX,
	    8,
	    0, 199, 300, 300,
	    0, 200, 301, MAX,
	    8,
	    0, 149, 200, 200,
	    0, 150, 201, MAX,
	    24,
	    0, 99, 150, 150,
	    0, 100, 151, MAX,
	    0, 125, 226, MAX,
	    0, 150, 301, MAX,
	    101, 124, 225, 225,
	    126, 149, 300, 300
	};

	fuzzyRegionsDA = new int[] {
	    225, 260, 260, 290,
	    150, 200, 240, 270,
	    50, 100, 200, 250,
	    25, 75, 150, 175,
	    125, 150, 150, 200,
	    0, 75, 100, 125
	};

	fuzzyRegionsDA2 = new int[] {
	    225, 260, 260, 290,
	    150, 200, 240, 270,
	    50, 100, 200, 250,
	    25, 75, 150, 175,
	    140, 160, 125, 175,
	    0, 75, 100, 125
	};

	descendantFuzzyRegionSet = new int[] {
	    0, 0, 0, 124,
	    1, 125, 1, 125,
	    25, 25, 25, 174,
	    26, 175, 26, 175,
	    50, 50, 50, 249,
	    51, 250, 51, 250,
	    150, 150, 150, 269,
	    151, 270, 151, 270,
	    225, 225, 225, 289,
	    226, 290, 226, 290
	};

	descendantFuzzyRegionSet2 = descendantFuzzyRegionSet;

	ancestorFuzzyRegionSet = new int[] {
	    0, 74, 100, 100,
	    0, 75, 101, MAX,
	    0, 150, 151, MAX,
	    0, 200, 241, MAX,
	    0, 260, 261, MAX,
	    76, 149, 150, 150,
	    101, 199, 240, 240,
	    201, 259, 260, 260
	};

	ancestorFuzzyRegionSet2 = new int[] {
	    0, 74, 100, 100,
	    0, 75, 101, MAX,
	    0, 140, 141, MAX,
	    0, 200, 241, MAX,
	    0, 260, 261, MAX,
	    76, 139, 140, 140,
	    101, 199, 240, 240,
	    141, 141, 142, MAX,
	    142, 142, 143, MAX,
	    143, 143, 144, MAX,
	    144, 144, 145, MAX,
	    145, 145, 146, MAX,
	    146, 146, 147, MAX,
	    147, 147, 148, MAX,
	    148, 148, 149, MAX,
	    149, 149, 150, MAX,
	    150, 150, 151, MAX,
	    151, 151, 152, MAX,
	    152, 152, 153, MAX,
	    153, 153, 154, MAX,
	    154, 154, 155, MAX,
	    155, 155, 156, MAX,
	    156, 156, 157, MAX,
	    157, 157, 158, MAX,
	    158, 158, 159, MAX,
	    159, 159, 160, MAX,
	    160, 160, 161, MAX,
	    201, 259, 260, 260
	};

	pointRegionsBA = new int[] {
	    100, 100,
	    50, 150
	};

	beforePointRegionSet = new int[] {
	    0, 100, 0, 100,
	    0, 50, 0, 50
	};

	afterPointRegionSet = new int[] {
	    100, MAX, 100, MAX,
	    150, MAX, 150, MAX
	};

	fuzzyRegionsBA = new int[] {
	    25, 100, 50, 75,
	    25, 75, 50, 75,
	    225, 250, 200, 275,
	    225, 250, 225, 275,
	    125, 200, 100, 175,
	    125, 175, 125, 175,
	    50, 125, 200, 250
	};

	beforeFuzzyRegionSet = new int[] {
	    0, 75, 0, 75,
	    0, 75, 0, 75,
	    0, 250, 0, 250,
	    0, 250, 0, 250,
	    0, 175, 0, 175,
	    0, 175, 0, 175,
	    0, 125, 0, 125
	};

	afterFuzzyRegionSet = new int[] {
	    50, MAX, 50, MAX,
	    50, MAX, 50, MAX,
	    225, MAX, 225, MAX,
	    225, MAX, 225, MAX,
	    125, MAX, 125, MAX,
	    125, MAX, 125, MAX,
	    200, MAX, 200, MAX
	};

	micsRegionsBA = new int[] {
	    8, 50, 100, 100, 150, 150, 200, 175, 225,
	    8, 50, 250, 50, 200, 50, 100, 50, 150,
	    8, 50, 300, 100, 300, 150, 300, 200, 300,
	    8, 50, 300, 75, 275, 125, 225, 150, 200,
	    6, 100, 150, 150, 300, 125, 225,
	    16, 125, 160, 75, 200, 200, 250, 25, 140, 125, 210, 25, 75, 60, 160, 150, 220
	};

	beforeMicsRegionSet = new int[] {
	    0, 175, 0, 175,
	    0, 50, 0, 50, 
	    0, 200, 0, 200,
	    0, 150, 0, 150,
	    0, 150, 0, 150,
	    0, 200, 0, 200,
	    0, 40, 0, 40,
	    0, 75, 0, 75,
	    0, 160, 0, 160,
	    0, 200, 0, 200,
	    0, 275, 0, 275,
	    0, 170, 0, 170,
	    0, 170, 0, 170,
	    0, 200, 0, 200
	};

	afterMicsRegionSet = new int[] {
	    100, MAX, 100, MAX,
	    100, MAX, 100, MAX,
	    300, MAX, 300, MAX,
	    200, MAX, 200, MAX,
	    150, MAX, 150, MAX,
	    75, MAX, 75, MAX,
	    75, MAX, 75, MAX,
	    100, MAX, 100, MAX,
	    125, MAX, 125, MAX,
	    170, MAX, 170, MAX,
	    60, MAX, 60, MAX,
	    100, MAX, 100, MAX,
	    100, MAX, 100, MAX,
	    200, MAX, 200, MAX
	};

	pointRegionsCI = pointRegionsDA;

	containsPointRegionSet = new int[] {
	    16,
	    0, 50, 100, MAX,
	    51, 100, 150, MAX,
	    101, 150, 200, MAX,
	    151, 175, 225, MAX,
	    16,
	    0, 50, 100, MAX,
	    0, 50, 150, MAX,
	    0, 50, 200, MAX, 
	    0, 50, 250, MAX,
	    16,
	    0, 50, 300, MAX,
	    51, 100, 300, MAX,
	    101, 150, 300, MAX,
	    151, 200, 300, MAX,
	    4,
	    0, 150, 200, MAX,
	    12,
	    0, 100, 150, MAX,
	    101, 125, 225, MAX,
	    126, 150, 300, MAX
	};
	
	inPointRegionSet = new int[] {
	    16,
	    50, 100, 50, 100,
	    100, 150, 100, 150,
	    150, 200, 150, 200,
	    175, 225, 175, 225,
	    16,
	    50, 100, 50, 100,
	    50, 150, 50, 150,
	    50, 200, 50, 200,
	    50, 250, 50, 250,
	    16,
	    50, 300, 50, 300,
	    100, 300, 100, 300,
	    150, 300, 150, 300,
	    200, 300, 200, 300,
	    4,
	    50, 300, 50, 300,
	    12,
	    100, 150, 100, 150,
	    125, 225, 125, 225,
	    150, 300, 150, 300
	};

	pointRegionsCI2 = pointRegionsBA;

	containsPointRegionSet2 = new int[] {
	    0, 100, 100, MAX,
	    0, 50, 150, MAX
	};

	inPointRegionSet2 = new int[] {
	    100, 100, 100, 100,
	    50, 150, 50, 150
	};

	fuzzyRegionsCI = fuzzyRegionsDA2;
	
	containsFuzzyRegionSet = new int[] {
	    0, 75, 100, MAX,
	    0, 160, 140, MAX,
	    0, 200, 240, MAX, 
	    0, 260, 260, MAX
	};

	inFuzzyRegionSet = new int[] {
	    0, 125, 0, 125,
	    25, 175, 25, 175,
	    50, 250, 50, 250,
	    150, 270, 150, 270,
	    225, 290, 225, 290
	};

	fuzzyRegionsCI2 = fuzzyRegionsBA;
	
	containsFuzzyRegionSet2 = new int[] {
	    0, 75, 50, MAX,
	    0, 75, 50, MAX,
	    0, 250, 225, MAX,
	    0, 250, 225, MAX,
	    0, 175, 125, MAX,
	    0, 175, 125, MAX,
	    0, 125, 200, MAX
	};

	inFuzzyRegionSet2 = new int[] {
	    25, 75, 25, 75,
	    25, 75, 25, 75,
	    225, 275, 225, 275,
	    225, 275, 225, 275,
	    125, 175, 125, 175,
	    125, 175, 125, 175,
	    50, 250, 50, 250
	};
    }
    
    public void testStarting() {
	int j = 0;
	for (int i = 0; i < pointRegions.length; i += 2) {
	    text = new MutableRegionSet();
	    text.insert(pointRegions[i], pointRegions[i+1], doc);

	    startingContainsResult = new MutableRegionSet();
	    startingContainsResult.insert(new FuzzyRegion
					(startingContainsRegionSet[j], 
					 startingContainsRegionSet[j+1], 
					 startingContainsRegionSet[j+2], 
					 startingContainsRegionSet[j+3],
					 doc)
					);

	    startingInResult = new MutableRegionSet();
	    int j0 = startingInRegionSet[j];
	    int j1 = startingInRegionSet[j+1];
	    int j2 = startingInRegionSet[j+2];
	    int j3 = startingInRegionSet[j+3];
	    if (j0==j1 && j2==j3)
		startingInResult.insert(j0, j2, doc);
	    else
		startingInResult.insert(new FuzzyRegion(j0, j1, j2, j3,
					 doc));

	    assertTrue( (text.startingIn(bkgd)).slowEquals(startingInResult) );
	    assertTrue( (text.startingContains(bkgd)).slowEquals(startingContainsResult) );
   	    j += 4;
	}
    }
    
    public void testEnding() {
	int j = 0;
	for (int i = 0; i < pointRegions.length; i += 2) {
	    text = new MutableRegionSet();
	    text.insert(pointRegions[i], pointRegions[i+1], doc);
	    endingContainsResult = new MutableRegionSet();
	    endingContainsResult.insert(new FuzzyRegion
					(endingContainsRegionSet[j], 
					 endingContainsRegionSet[j+1], 
					 endingContainsRegionSet[j+2], 
					 endingContainsRegionSet[j+3],
					 doc)
					);

	    endingInResult = new MutableRegionSet();
	    int j0 = endingInRegionSet[j];
	    int j1 = endingInRegionSet[j+1];
	    int j2 = endingInRegionSet[j+2];
	    int j3 = endingInRegionSet[j+3];
	    if (j0==j1 && j2==j3)
		endingInResult.insert(j0, j2, doc);
	    else
		endingInResult.insert(new FuzzyRegion(j0, j1, j2, j3,
					 doc));

	    assertTrue( (text.endingIn(bkgd)).slowEquals(endingInResult) );
	    assertTrue( (text.endingContains(bkgd)).slowEquals(endingContainsResult) );
	    j += 4;
	}
    }
    
    public void testDoubleStarting() {
	int j1 = 0;
	int j2 = 0;
	for (int i = 0; i < doublePointRegions.length; i += 4) {
	    text = new MutableRegionSet();
	    text.insert(doublePointRegions[i], doublePointRegions[i+1], doc);
	    text.insert(doublePointRegions[i+2], doublePointRegions[i+3], doc);

	    int offset1 = doubleStartingContainsRegionSet[j1];
	    startingContainsResult = new MutableRegionSet();
	    for (int k = 0; k < offset1; k += 4) {
		startingContainsResult.insert(new FuzzyRegion
					    (doubleStartingContainsRegionSet[j1+1+k],
					     doubleStartingContainsRegionSet[j1+1+k+1],
					     doubleStartingContainsRegionSet[j1+1+k+2],
					     doubleStartingContainsRegionSet[j1+1+k+3],
					 doc)
					    );
	    }

	    int offset2 = doubleStartingInRegionSet[j2];
	    startingInResult = new MutableRegionSet();
	    for (int k = 0; k < offset2; k += 4) {
		startingInResult.insert(new FuzzyRegion
					    (doubleStartingInRegionSet[j2+1+k],
					     doubleStartingInRegionSet[j2+1+k+1],
					     doubleStartingInRegionSet[j2+1+k+2],
					     doubleStartingInRegionSet[j2+1+k+3],
					 doc)
					    );
	    }

	    assertTrue( (text.startingIn(bkgd)).slowEquals(startingInResult) );
	    assertTrue( (text.startingContains(bkgd)).slowEquals(startingContainsResult) );
	    j1 += (offset1+1);
	    j2 += (offset2+1);
	}
    }
    
    public void testDoubleEnding() {
	int j1 = 0;
	int j2 = 0;
	for (int i = 0; i < doublePointRegions.length; i += 4) {
	    text = new MutableRegionSet();
	    text.insert(doublePointRegions[i], doublePointRegions[i+1], doc);
	    text.insert(doublePointRegions[i+2], doublePointRegions[i+3], doc);

	    int offset1 = doubleEndingContainsRegionSet[j1];
	    endingContainsResult = new MutableRegionSet();
	    for (int k = 0; k < offset1; k += 4) {
		endingContainsResult.insert(new FuzzyRegion
					    (doubleEndingContainsRegionSet[j1+1+k],
					     doubleEndingContainsRegionSet[j1+1+k+1],
					     doubleEndingContainsRegionSet[j1+1+k+2],
					     doubleEndingContainsRegionSet[j1+1+k+3],
					 doc)
					    );
	    }

	    int offset2 = doubleEndingInRegionSet[j2];
	    endingInResult = new MutableRegionSet();
	    for (int k = 0; k < offset2; k += 4) {
		endingInResult.insert(new FuzzyRegion
					    (doubleEndingInRegionSet[j2+1+k],
					     doubleEndingInRegionSet[j2+1+k+1],
					     doubleEndingInRegionSet[j2+1+k+2],
					     doubleEndingInRegionSet[j2+1+k+3],
					 doc)
					    );
	    }

	    assertTrue( (text.endingIn(bkgd)).slowEquals(endingInResult) );
	    assertTrue( (text.endingContains(bkgd)).slowEquals(endingContainsResult) );

	    j1 += (offset1+1);
	    j2 += (offset2+1);
	}
    }

    public void testMultiStarting() {
	text = new MutableRegionSet();
	for (int i = 0; i < multiPointRegions.length; i += 2)
	    text.insert(multiPointRegions[i], multiPointRegions[i+1], doc);
	startingContainsResult = new MutableRegionSet();
	for (int i = 0; i < multiStartingContainsRegionSet.length; i += 4)
	    startingContainsResult.insert(new FuzzyRegion
					  (multiStartingContainsRegionSet[i],
					   multiStartingContainsRegionSet[i+1],
					   multiStartingContainsRegionSet[i+2],
					   multiStartingContainsRegionSet[i+3],
					 doc)
					  );
	startingInResult = new MutableRegionSet();
	for (int i = 0; i < multiStartingInRegionSet.length; i += 4)
	    startingInResult.insert(new FuzzyRegion
					  (multiStartingInRegionSet[i],
					   multiStartingInRegionSet[i+1],
					   multiStartingInRegionSet[i+2],
					   multiStartingInRegionSet[i+3],
					 doc)
					  );

	assertTrue( (text.startingIn(bkgd)).slowEquals(startingInResult) );
	assertTrue( (text.startingContains(bkgd)).slowEquals(startingContainsResult) );

	text = new MutableRegionSet();
	for (int i = 0; i < multiPointRegionsAlign.length; i += 2)
	    text.insert(multiPointRegionsAlign[i], multiPointRegionsAlign[i+1], doc);
	startingContainsResult = new MutableRegionSet();
	for (int i = 0; i < multiStartingContainsRegionSetAlign.length; i += 4)
	    startingContainsResult.insert(new FuzzyRegion
					  (multiStartingContainsRegionSetAlign[i],
					   multiStartingContainsRegionSetAlign[i+1],
					   multiStartingContainsRegionSetAlign[i+2],
					   multiStartingContainsRegionSetAlign[i+3],
					 doc)
					  );
	startingInResult = new MutableRegionSet();
	for (int i = 0; i < multiStartingInRegionSetAlign.length; i += 4)
	    startingInResult.insert(new FuzzyRegion
					  (multiStartingInRegionSetAlign[i],
					   multiStartingInRegionSetAlign[i+1],
					   multiStartingInRegionSetAlign[i+2],
					   multiStartingInRegionSetAlign[i+3],
					 doc)
					  );
	assertTrue( (text.startingIn(bkgd)).slowEquals(startingInResult) );
	assertTrue( (text.startingContains(bkgd)).slowEquals(startingContainsResult) );
    }

    public void testMultiEnding() {
	text = new MutableRegionSet();
	for (int i = 0; i < multiPointRegions.length; i += 2)
	    text.insert(multiPointRegions[i], multiPointRegions[i+1], doc);
	endingContainsResult = new MutableRegionSet();
	for (int i = 0; i < multiEndingContainsRegionSet.length; i += 4)
	    endingContainsResult.insert(new FuzzyRegion
					  (multiEndingContainsRegionSet[i],
					   multiEndingContainsRegionSet[i+1],
					   multiEndingContainsRegionSet[i+2],
					   multiEndingContainsRegionSet[i+3],
					 doc)
					  );
	endingInResult = new MutableRegionSet();
	for (int i = 0; i < multiEndingInRegionSet.length; i += 4)
	    endingInResult.insert(new FuzzyRegion
					  (multiEndingInRegionSet[i],
					   multiEndingInRegionSet[i+1],
					   multiEndingInRegionSet[i+2],
					   multiEndingInRegionSet[i+3],
					 doc)
					  );
	assertTrue( (text.endingIn(bkgd)).slowEquals(endingInResult) );
	assertTrue( (text.endingContains(bkgd)).slowEquals(endingContainsResult) );

	text = new MutableRegionSet();
	for (int i = 0; i < multiPointRegionsAlign.length; i += 2)
	    text.insert(multiPointRegionsAlign[i], multiPointRegionsAlign[i+1], doc);
	endingContainsResult = new MutableRegionSet();
	for (int i = 0; i < multiEndingContainsRegionSetAlign.length; i += 4)
	    endingContainsResult.insert(new FuzzyRegion
					  (multiEndingContainsRegionSetAlign[i],
					   multiEndingContainsRegionSetAlign[i+1],
					   multiEndingContainsRegionSetAlign[i+2],
					   multiEndingContainsRegionSetAlign[i+3],
					 doc)
					  );
	endingInResult = new MutableRegionSet();
	for (int i = 0; i < multiEndingInRegionSetAlign.length; i += 4)
	    endingInResult.insert(new FuzzyRegion
					  (multiEndingInRegionSetAlign[i],
					   multiEndingInRegionSetAlign[i+1],
					   multiEndingInRegionSetAlign[i+2],
					   multiEndingInRegionSetAlign[i+3],
					 doc)
					  );
	assertTrue( (text.endingIn(bkgd)).slowEquals(endingInResult) );
	assertTrue( (text.endingContains(bkgd)).slowEquals(endingContainsResult) );
    }

    public void testFuzzyStarting() {
	int j = 0;
	for (int i = 0; i < fuzzyRegions.length; i += 4) {
	    text = new MutableRegionSet();
	    text.insert(new FuzzyRegion
			(fuzzyRegions[i], 
			 fuzzyRegions[i+1],
			 fuzzyRegions[i+2],
			 fuzzyRegions[i+3],
					 doc)
			);
	    startingContainsResult = new MutableRegionSet();
	    startingContainsResult.insert(new FuzzyRegion
					(startingContainsFuzzyRegionSet[j], 
					 startingContainsFuzzyRegionSet[j+1], 
					 startingContainsFuzzyRegionSet[j+2], 
					 startingContainsFuzzyRegionSet[j+3],
					 doc)
					);
	    startingInResult = new MutableRegionSet();
	    startingInResult.insert(new FuzzyRegion
					(startingInFuzzyRegionSet[j], 
					 startingInFuzzyRegionSet[j+1], 
					 startingInFuzzyRegionSet[j+2], 
					 startingInFuzzyRegionSet[j+3],
					 doc)
					);
	    assertTrue( (text.startingIn(bkgd)).slowEquals(startingInResult) );
	    assertTrue( (text.startingContains(bkgd)).slowEquals(startingContainsResult) );
   	    j += 4;
	}
    }

    public void testFuzzyEnding() {
	int j = 0;
	for (int i = 0; i < fuzzyRegions.length; i += 4) {
	    text = new MutableRegionSet();
	    text.insert(new FuzzyRegion
			(fuzzyRegions[i], 
			 fuzzyRegions[i+1],
			 fuzzyRegions[i+2],
			 fuzzyRegions[i+3],
					 doc)
			);
	    endingContainsResult = new MutableRegionSet();
	    endingContainsResult.insert(new FuzzyRegion
					(endingContainsFuzzyRegionSet[j], 
					 endingContainsFuzzyRegionSet[j+1], 
					 endingContainsFuzzyRegionSet[j+2], 
					 endingContainsFuzzyRegionSet[j+3],
					 doc)
					);
	    endingInResult = new MutableRegionSet();
	    endingInResult.insert(new FuzzyRegion
					(endingInFuzzyRegionSet[j], 
					 endingInFuzzyRegionSet[j+1], 
					 endingInFuzzyRegionSet[j+2], 
					 endingInFuzzyRegionSet[j+3],
					 doc)
					);
	    assertTrue( (text.endingIn(bkgd)).slowEquals(endingInResult) );
	    assertTrue( (text.endingContains(bkgd)).slowEquals(endingContainsResult) );
	    j += 4;
	}
    }

    public void testDoubleFuzzyStarting() {
	int j1 = 0;
	int j2 = 0;
	for (int i = 0; i < doubleFuzzyRegions.length; i += 8) {
	    text = new MutableRegionSet();
	    text.insert(new FuzzyRegion
			(doubleFuzzyRegions[i], 
			 doubleFuzzyRegions[i+1],
			 doubleFuzzyRegions[i+2],
			 doubleFuzzyRegions[i+3],
					 doc)
			);
	    text.insert(new FuzzyRegion
			(doubleFuzzyRegions[i+4], 
			 doubleFuzzyRegions[i+5],
			 doubleFuzzyRegions[i+6],
			 doubleFuzzyRegions[i+7],
					 doc)
			);
	    int offset1 = doubleStartingContainsFuzzyRegionSet[j1];
	    startingContainsResult = new MutableRegionSet();
	    for (int k = 0; k < offset1; k += 4) {
		startingContainsResult.insert(new FuzzyRegion
					    (doubleStartingContainsFuzzyRegionSet[j1+1+k],
					     doubleStartingContainsFuzzyRegionSet[j1+1+k+1],
					     doubleStartingContainsFuzzyRegionSet[j1+1+k+2],
					     doubleStartingContainsFuzzyRegionSet[j1+1+k+3],
					 doc)
					    );
	    }
	    int offset2 = doubleStartingInFuzzyRegionSet[j2];
	    startingInResult = new MutableRegionSet();
	    for (int k = 0; k < offset2; k += 4) {
		startingInResult.insert(new FuzzyRegion
					    (doubleStartingInFuzzyRegionSet[j2+1+k],
					     doubleStartingInFuzzyRegionSet[j2+1+k+1],
					     doubleStartingInFuzzyRegionSet[j2+1+k+2],
					     doubleStartingInFuzzyRegionSet[j2+1+k+3],
					 doc)
					    );
	    }
	    assertTrue( (text.startingIn(bkgd)).slowEquals(startingInResult) );
	    assertTrue( (text.startingContains(bkgd)).slowEquals(startingContainsResult) );
	    j1 += (offset1+1);
	    j2 += (offset2+1);
	}
    }

    public void testDoubleFuzzyEnding() {
	int j1 = 0;
	int j2 = 0;
	for (int i = 0; i < doubleFuzzyRegions.length; i += 8) {
	    text = new MutableRegionSet();
	    text.insert(new FuzzyRegion
			(doubleFuzzyRegions[i], 
			 doubleFuzzyRegions[i+1],
			 doubleFuzzyRegions[i+2],
			 doubleFuzzyRegions[i+3],
					 doc)
			);
	    text.insert(new FuzzyRegion
			(doubleFuzzyRegions[i+4], 
			 doubleFuzzyRegions[i+5],
			 doubleFuzzyRegions[i+6],
			 doubleFuzzyRegions[i+7],
					 doc)
			);
	    int offset1 = doubleEndingContainsFuzzyRegionSet[j1];
	    endingContainsResult = new MutableRegionSet();
	    for (int k = 0; k < offset1; k += 4) {
		endingContainsResult.insert(new FuzzyRegion
					    (doubleEndingContainsFuzzyRegionSet[j1+1+k],
					     doubleEndingContainsFuzzyRegionSet[j1+1+k+1],
					     doubleEndingContainsFuzzyRegionSet[j1+1+k+2],
					     doubleEndingContainsFuzzyRegionSet[j1+1+k+3],
					 doc)
					    );
	    }
	    int offset2 = doubleEndingInFuzzyRegionSet[j2];
	    endingInResult = new MutableRegionSet();
	    for (int k = 0; k < offset2; k += 4) {
		endingInResult.insert(new FuzzyRegion
					    (doubleEndingInFuzzyRegionSet[j2+1+k],
					     doubleEndingInFuzzyRegionSet[j2+1+k+1],
					     doubleEndingInFuzzyRegionSet[j2+1+k+2],
					     doubleEndingInFuzzyRegionSet[j2+1+k+3],
					 doc)
					    );
	    }
	    assertTrue( (text.endingIn(bkgd)).slowEquals(endingInResult) );
	    assertTrue( (text.endingContains(bkgd)).slowEquals(endingContainsResult) );
	    j1 += (offset1+1);
	    j2 += (offset2+1);
	}
    }

    public void testMultiMicsStarting() {
	text = new MutableRegionSet();
	for (int i = 0; i < multiMicsRegionsVertical.length; ) {
	    int offset = multiMicsRegionsVertical[i];
	    if (offset == 2)
		text.insert(multiMicsRegionsVertical[i+1], multiMicsRegionsVertical[i+2], doc);
	    else
		text.insert(new FuzzyRegion
			    (multiMicsRegionsVertical[i+1],
			     multiMicsRegionsVertical[i+2],
			     multiMicsRegionsVertical[i+3],
			     multiMicsRegionsVertical[i+4],
					 doc)
			    );
	    i += (offset+1);
	}

	startingContainsResult = new MutableRegionSet();
	for (int i = 0; i < multiStartingContainsMicsRegionSetVertical.length; i += 4) {
	    startingContainsResult.insert(new FuzzyRegion
					 (multiStartingContainsMicsRegionSetVertical[i],
					  multiStartingContainsMicsRegionSetVertical[i+1],
					  multiStartingContainsMicsRegionSetVertical[i+2],
					  multiStartingContainsMicsRegionSetVertical[i+3],
					 doc)
					 );
	}
	assertTrue( (text.startingContains(bkgd)).slowEquals(startingContainsResult) );

	startingInResult = new MutableRegionSet();
	for (int i = 0; i < multiStartingInMicsRegionSetVertical.length; i += 4) {
	    startingInResult.insert(new FuzzyRegion
					 (multiStartingInMicsRegionSetVertical[i],
					  multiStartingInMicsRegionSetVertical[i+1],
					  multiStartingInMicsRegionSetVertical[i+2],
					  multiStartingInMicsRegionSetVertical[i+3],
					 doc)
					 );
	}
	assertTrue( (text.startingIn(bkgd)).slowEquals(startingInResult) );

	text = new MutableRegionSet();
	for (int i = 0; i < multiMicsRegionsAlign.length; ) {
	    int offset = multiMicsRegionsAlign[i];
	    if (offset == 2)
		text.insert(multiMicsRegionsAlign[i+1], multiMicsRegionsAlign[i+2], doc);
	    else
		text.insert(new FuzzyRegion
			    (multiMicsRegionsAlign[i+1],
			     multiMicsRegionsAlign[i+2],
			     multiMicsRegionsAlign[i+3],
			     multiMicsRegionsAlign[i+4],
					 doc)
			    );
	    i += (offset+1);
	}

	startingContainsResult = new MutableRegionSet();
	for (int i = 0; i < multiStartingContainsMicsRegionSetAlign.length; i += 4) {
	    startingContainsResult.insert(new FuzzyRegion
					 (multiStartingContainsMicsRegionSetAlign[i],
					  multiStartingContainsMicsRegionSetAlign[i+1],
					  multiStartingContainsMicsRegionSetAlign[i+2],
					  multiStartingContainsMicsRegionSetAlign[i+3],
					 doc)
					 );
	}
	assertTrue( (text.startingContains(bkgd)).slowEquals(startingContainsResult) );

	startingInResult = new MutableRegionSet();
	for (int i = 0; i < multiStartingInMicsRegionSetAlign.length; i += 4) {
	    startingInResult.insert(new FuzzyRegion
					 (multiStartingInMicsRegionSetAlign[i],
					  multiStartingInMicsRegionSetAlign[i+1],
					  multiStartingInMicsRegionSetAlign[i+2],
					  multiStartingInMicsRegionSetAlign[i+3],
					 doc)
					 );
	}
	assertTrue( (text.startingIn(bkgd)).slowEquals(startingInResult) );
    }
    
    public void testMultiMicsEnding() {
	text = new MutableRegionSet();
	for (int i = 0; i < multiMicsRegionsVertical.length; ) {
	    int offset = multiMicsRegionsVertical[i];
	    if (offset == 2) {
		text.insert(multiMicsRegionsVertical[i+1], multiMicsRegionsVertical[i+2], doc);
	    }
	    else {
		text.insert(new FuzzyRegion
			    (multiMicsRegionsVertical[i+1],
			     multiMicsRegionsVertical[i+2],
			     multiMicsRegionsVertical[i+3],
			     multiMicsRegionsVertical[i+4],
					 doc)
			    );
	    }
	    i += (offset+1);
	}
	endingContainsResult = new MutableRegionSet();
	for (int i = 0; i < multiEndingContainsMicsRegionSetVertical.length; i += 4) {
	    endingContainsResult.insert(new FuzzyRegion
					 (multiEndingContainsMicsRegionSetVertical[i],
					  multiEndingContainsMicsRegionSetVertical[i+1],
					  multiEndingContainsMicsRegionSetVertical[i+2],
					  multiEndingContainsMicsRegionSetVertical[i+3],
					 doc)
					 );
	}
	assertTrue( (text.endingContains(bkgd)).slowEquals(endingContainsResult) );
	endingInResult = new MutableRegionSet();
	for (int i = 0; i < multiEndingInMicsRegionSetVertical.length; i += 4) {
	    endingInResult.insert(new FuzzyRegion
					 (multiEndingInMicsRegionSetVertical[i],
					  multiEndingInMicsRegionSetVertical[i+1],
					  multiEndingInMicsRegionSetVertical[i+2],
					  multiEndingInMicsRegionSetVertical[i+3],
					 doc)
					 );
	}
	assertTrue( (text.endingIn(bkgd)).slowEquals(endingInResult) );

	text = new MutableRegionSet();
	for (int i = 0; i < multiMicsRegionsAlign.length; ) {
	    int offset = multiMicsRegionsAlign[i];
	    if (offset == 2) {
		text.insert(multiMicsRegionsAlign[i+1], multiMicsRegionsAlign[i+2], doc);
	    }
	    else {
		text.insert(new FuzzyRegion
			    (multiMicsRegionsAlign[i+1],
			     multiMicsRegionsAlign[i+2],
			     multiMicsRegionsAlign[i+3],
			     multiMicsRegionsAlign[i+4],
					 doc)
			    );
	    }
	    i += (offset+1);
	}
	endingContainsResult = new MutableRegionSet();
	for (int i = 0; i < multiEndingContainsMicsRegionSetAlign.length; i += 4) {
	    endingContainsResult.insert(new FuzzyRegion
					 (multiEndingContainsMicsRegionSetAlign[i],
					  multiEndingContainsMicsRegionSetAlign[i+1],
					  multiEndingContainsMicsRegionSetAlign[i+2],
					  multiEndingContainsMicsRegionSetAlign[i+3],
					 doc)
					 );
	}
	assertTrue( (text.endingContains(bkgd)).slowEquals(endingContainsResult) );
	endingInResult = new MutableRegionSet();
	for (int i = 0; i < multiEndingInMicsRegionSetAlign.length; i += 4) {
	    endingInResult.insert(new FuzzyRegion
					 (multiEndingInMicsRegionSetAlign[i],
					  multiEndingInMicsRegionSetAlign[i+1],
					  multiEndingInMicsRegionSetAlign[i+2],
					  multiEndingInMicsRegionSetAlign[i+3],
					 doc)
					 );
	}
	assertTrue( (text.endingIn(bkgd)).slowEquals(endingInResult) );
    }

    public void testDescendant() {
		text = new MutableRegionSet();
		for (int i = 0; i < pointRegionsDA.length; ) {
	    	int offset = pointRegionsDA[i];
	    	i++;
	    	for (int j = 0; j < offset/2; j++) {
				text.insert(pointRegionsDA[i], pointRegionsDA[i+1], doc);
				i += 2;
	    	}
		}
		descendantResult = new MutableRegionSet();
		for (int i = 0; i < descendantRegionSet.length; ) {
	    	int offset = descendantRegionSet[i];
	    	i++;
	    	for (int j = 0; j < offset/4; j++) {
				descendantResult.insert(new FuzzyRegion
											(descendantRegionSet[i],
					 						 descendantRegionSet[i+1],
					 						 descendantRegionSet[i+2],
					 						 descendantRegionSet[i+3],
					 						 doc)
										);
				i += 4;
	    	}
		}
		    	
		assertTrue( (text.descendant()).slowEquals(descendantResult) );
    }

    public void testAncestor() {
	text = new MutableRegionSet();
	for (int i = 0; i < pointRegionsDA.length; ) {
	    int offset = pointRegionsDA[i];
	    i++;
	    for (int j = 0; j < offset/2; j++) {
		text.insert(pointRegionsDA[i], pointRegionsDA[i+1], doc);
		i += 2;
	    }
	}
	ancestorResult = new MutableRegionSet();
	for (int i = 0; i < ancestorRegionSet.length; ) {
	    int offset = ancestorRegionSet[i];
	    i++;
	    for (int j = 0; j < offset/4; j++) {
		ancestorResult.insert(new FuzzyRegion
					(ancestorRegionSet[i],
					 ancestorRegionSet[i+1],
					 ancestorRegionSet[i+2],
					 ancestorRegionSet[i+3],
					 doc)
					);
		i += 4;
	    }
	}
	assertTrue( (text.ancestor()).slowEquals(ancestorResult) );
    }

    public void testFuzzyDescendant() {
	text = new MutableRegionSet();
	for (int i = 0; i < fuzzyRegionsDA.length; i += 4)
	    text.insert(new FuzzyRegion
			(fuzzyRegionsDA[i],
			 fuzzyRegionsDA[i+1],
			 fuzzyRegionsDA[i+2],
			 fuzzyRegionsDA[i+3],
					 doc)
			);
	descendantResult = new MutableRegionSet();
	for (int i = 0; i < descendantFuzzyRegionSet.length; i += 4)
	    descendantResult.insert(new FuzzyRegion
			      (descendantFuzzyRegionSet[i],
			       descendantFuzzyRegionSet[i+1],
			       descendantFuzzyRegionSet[i+2],
			       descendantFuzzyRegionSet[i+3],
					 doc)
			      );
	assertTrue( (text.descendant()).slowEquals(descendantResult) );

	text = new MutableRegionSet();
	for (int i = 0; i < fuzzyRegionsDA2.length; i += 4)
	    text.insert(new FuzzyRegion
			(fuzzyRegionsDA2[i],
			 fuzzyRegionsDA2[i+1],
			 fuzzyRegionsDA2[i+2],
			 fuzzyRegionsDA2[i+3],
					 doc)
			);
	descendantResult = new MutableRegionSet();
	for (int i = 0; i < descendantFuzzyRegionSet2.length; i += 4)
	    descendantResult.insert(new FuzzyRegion
			      (descendantFuzzyRegionSet2[i],
			       descendantFuzzyRegionSet2[i+1],
			       descendantFuzzyRegionSet2[i+2],
			       descendantFuzzyRegionSet2[i+3],
					 doc)
			      );
	assertTrue( (text.descendant()).slowEquals(descendantResult) );
    }

    public void testFuzzyAncestor() {
	text = new MutableRegionSet();
	for (int i = 0; i < fuzzyRegionsDA.length; i += 4)
	    text.insert(new FuzzyRegion
			(fuzzyRegionsDA[i],
			 fuzzyRegionsDA[i+1],
			 fuzzyRegionsDA[i+2],
			 fuzzyRegionsDA[i+3],
					 doc)
			);
	ancestorResult = new MutableRegionSet();
	for (int i = 0; i < ancestorFuzzyRegionSet.length; i += 4)
	    ancestorResult.insert(new FuzzyRegion
			      (ancestorFuzzyRegionSet[i],
			       ancestorFuzzyRegionSet[i+1],
			       ancestorFuzzyRegionSet[i+2],
			       ancestorFuzzyRegionSet[i+3],
					 doc)
			      );
	assertTrue( (text.ancestor()).slowEquals(ancestorResult) );

	text = new MutableRegionSet();
	for (int i = 0; i < fuzzyRegionsDA2.length; i += 4)
	    text.insert(new FuzzyRegion
			(fuzzyRegionsDA2[i],
			 fuzzyRegionsDA2[i+1],
			 fuzzyRegionsDA2[i+2],
			 fuzzyRegionsDA2[i+3],
					 doc)
			);
	ancestorResult = new MutableRegionSet();
	for (int i = 0; i < ancestorFuzzyRegionSet2.length; i += 4)
	    ancestorResult.insert(new FuzzyRegion
			      (ancestorFuzzyRegionSet2[i],
			       ancestorFuzzyRegionSet2[i+1],
			       ancestorFuzzyRegionSet2[i+2],
			       ancestorFuzzyRegionSet2[i+3],
					 doc)
			      );
	assertTrue( (text.ancestor()).slowEquals(ancestorResult) );
    }

    public void testPointBefore() {
	int j = 0;
	for (int i = 0; i < pointRegionsBA.length; i += 2) {
	    text = new MutableRegionSet();
	    text.insert(pointRegionsBA[i], pointRegionsBA[i+1], doc);
	    beforeResult = new MutableRegionSet();
	    beforeResult.insert(new FuzzyRegion
				(beforePointRegionSet[j], 
				 beforePointRegionSet[j+1], 
				 beforePointRegionSet[j+2], 
				 beforePointRegionSet[j+3],
					 doc)
				);
	    assertTrue( (text.before()).slowEquals(beforeResult) );
   	    j += 4;
	}
    }

    public void testPointAfter() {
	int j = 0;
	for (int i = 0; i < pointRegionsBA.length; i += 2) {
	    text = new MutableRegionSet();
	    text.insert(pointRegionsBA[i], pointRegionsBA[i+1], doc);
	    afterResult = new MutableRegionSet();
	    afterResult.insert(new FuzzyRegion
				(afterPointRegionSet[j], 
				 afterPointRegionSet[j+1], 
				 afterPointRegionSet[j+2], 
				 afterPointRegionSet[j+3],
					 doc)
				);
	    assertTrue( (text.after()).slowEquals(afterResult) );
   	    j += 4;
	}
    }

    public void testFuzzyBefore() {
	int j = 0;
	for (int i = 0; i < fuzzyRegionsBA.length; i += 4) {
	    text = new MutableRegionSet();
	    text.insert(new FuzzyRegion
			(fuzzyRegionsBA[i], fuzzyRegionsBA[i+1],
			 fuzzyRegionsBA[i+2], fuzzyRegionsBA[i+3],
					 doc)
			);
	    beforeResult = new MutableRegionSet();
	    beforeResult.insert(new FuzzyRegion
				(beforeFuzzyRegionSet[j], 
				 beforeFuzzyRegionSet[j+1], 
				 beforeFuzzyRegionSet[j+2], 
				 beforeFuzzyRegionSet[j+3],
					 doc)
				);
	    assertTrue( (text.before()).slowEquals(beforeResult) );
   	    j += 4;
	}
    }

    public void testFuzzyAfter() {
	int j = 0;
	for (int i = 0; i < fuzzyRegionsBA.length; i += 4) {
	    text = new MutableRegionSet();
	    text.insert(new FuzzyRegion
			(fuzzyRegionsBA[i], fuzzyRegionsBA[i+1],
			 fuzzyRegionsBA[i+2], fuzzyRegionsBA[i+3],
					 doc)
			);
	    afterResult = new MutableRegionSet();
	    afterResult.insert(new FuzzyRegion
				(afterFuzzyRegionSet[j], 
				 afterFuzzyRegionSet[j+1], 
				 afterFuzzyRegionSet[j+2], 
				 afterFuzzyRegionSet[j+3],
					 doc)
				);
	    assertTrue( (text.after()).slowEquals(afterResult) );
   	    j += 4;
	}
    }

    public void testMicsBefore() {
	int k = 0;
	for (int i = 0; i < micsRegionsBA.length; ) {
	    text = new MutableRegionSet();
	    int offset = micsRegionsBA[i];
	    i++;
	    for (int j = 0; j < offset/2; j++) {
		text.insert(micsRegionsBA[i], micsRegionsBA[i+1], doc);
		i += 2;
	    }
	    beforeResult = new MutableRegionSet();
	    beforeResult.insert(new FuzzyRegion
				(beforeMicsRegionSet[k],
				 beforeMicsRegionSet[k+1],
				 beforeMicsRegionSet[k+2],
				 beforeMicsRegionSet[k+3],
					 doc)
				);
	    assertTrue( (text.before()).slowEquals(beforeResult) );
	    k += 4;
	}
	for (int i = 0; i < doubleFuzzyRegions.length; i += 8) {
	    text = new MutableRegionSet();
	    text.insert(new FuzzyRegion
			(doubleFuzzyRegions[i],
			 doubleFuzzyRegions[i+1],
			 doubleFuzzyRegions[i+2],
			 doubleFuzzyRegions[i+3],
					 doc)
			);
	    text.insert(new FuzzyRegion
			(doubleFuzzyRegions[i+4],
			 doubleFuzzyRegions[i+5],
			 doubleFuzzyRegions[i+6],
			 doubleFuzzyRegions[i+7],
					 doc)
			);
	    beforeResult = new MutableRegionSet();
	    beforeResult.insert(new FuzzyRegion
				(beforeMicsRegionSet[k],
				 beforeMicsRegionSet[k+1],
				 beforeMicsRegionSet[k+2],
				 beforeMicsRegionSet[k+3],
					 doc)
				);
	    assertTrue( (text.before()).slowEquals(beforeResult) );
	    k += 4;
	}
    }
    	
    public void testMicsAfter() {
	int k = 0;
	for (int i = 0; i < micsRegionsBA.length; ) {
	    text = new MutableRegionSet();
	    int offset = micsRegionsBA[i];
	    i++;
	    for (int j = 0; j < offset/2; j++) {
		text.insert(micsRegionsBA[i], micsRegionsBA[i+1], doc);
		i += 2;
	    }
	    afterResult = new MutableRegionSet();
	    afterResult.insert(new FuzzyRegion
				(afterMicsRegionSet[k],
				 afterMicsRegionSet[k+1],
				 afterMicsRegionSet[k+2],
				 afterMicsRegionSet[k+3],
					 doc)
				);
	    assertTrue( (text.after()).slowEquals(afterResult) );
	    k += 4;
	}
	for (int i = 0; i < doubleFuzzyRegions.length; i += 8) {
	    text = new MutableRegionSet();
	    text.insert(new FuzzyRegion
			(doubleFuzzyRegions[i],
			 doubleFuzzyRegions[i+1],
			 doubleFuzzyRegions[i+2],
			 doubleFuzzyRegions[i+3],
					 doc)
			);
	    text.insert(new FuzzyRegion
			(doubleFuzzyRegions[i+4],
			 doubleFuzzyRegions[i+5],
			 doubleFuzzyRegions[i+6],
			 doubleFuzzyRegions[i+7],
					 doc)
			);
	    afterResult = new MutableRegionSet();
	    afterResult.insert(new FuzzyRegion
				(afterMicsRegionSet[k],
				 afterMicsRegionSet[k+1],
				 afterMicsRegionSet[k+2],
				 afterMicsRegionSet[k+3],
					 doc)
				);
	    assertTrue( (text.after()).slowEquals(afterResult) );
	    k += 4;
	}
    }

    public void testPointContains() {
	text = new MutableRegionSet();
	for (int i = 0; i < pointRegionsCI.length; ) {
	    int offset = pointRegionsCI[i];
	    i++;
	    for (int j = 0; j < offset/2; j++) {
		text.insert(pointRegionsCI[i], pointRegionsCI[i+1], doc);
		i += 2;
	    }
	}
	containsResult = new MutableRegionSet();
	for (int i = 0; i < containsPointRegionSet.length; ) {
	    int offset = containsPointRegionSet[i];
	    i++;
	    for (int j = 0; j < offset/4; j++) {
		containsResult.insert(new FuzzyRegion
					(containsPointRegionSet[i],
					 containsPointRegionSet[i+1],
					 containsPointRegionSet[i+2],
					 containsPointRegionSet[i+3],
					 doc)
					);
		i += 4;
	    }
	}
	assertTrue( (text.contains()).slowEquals(containsResult) );
    }

    public void testPointIn() {
	text = new MutableRegionSet();
	for (int i = 0; i < pointRegionsCI.length; ) {
	    int offset = pointRegionsCI[i];
	    i++;
	    for (int j = 0; j < offset/2; j++) {
		text.insert(pointRegionsCI[i], pointRegionsCI[i+1], doc);
		i += 2;
	    }
	}
	inResult = new MutableRegionSet();
	for (int i = 0; i < inPointRegionSet.length; ) {
	    int offset = inPointRegionSet[i];
	    i++;
	    for (int j = 0; j < offset/4; j++) {
		inResult.insert(new FuzzyRegion
					(inPointRegionSet[i],
					 inPointRegionSet[i+1],
					 inPointRegionSet[i+2],
					 inPointRegionSet[i+3],
					 doc)
					);
		i += 4;
	    }
	}
	assertTrue( (text.in()).slowEquals(inResult) );
    }

    public void testPointContains2() {
	int j = 0;
	for (int i = 0; i < pointRegionsCI2.length; i += 2) {
	    text = new MutableRegionSet();
	    text.insert(pointRegionsCI2[i], pointRegionsCI2[i+1], doc);
	    containsResult = new MutableRegionSet();
	    int j0 = containsPointRegionSet2[j];
	    int j1 = containsPointRegionSet2[j+1];
	    int j2 = containsPointRegionSet2[j+2];
	    int j3 = containsPointRegionSet2[j+3];
	    if (j0==j1 && j2==j3)
		containsResult.insert(j0, j2, doc);
	    else 
		containsResult.insert(new FuzzyRegion(j0, j1, j2, j3,
					 doc));

	    assertTrue( (text.contains()).slowEquals(containsResult) );
   	    j += 4;
	}
    }

    public void testPointIn2() {
	int j = 0;
	for (int i = 0; i < pointRegionsCI2.length; i += 2) {
	    text = new MutableRegionSet();
	    text.insert(pointRegionsCI2[i], pointRegionsCI2[i+1], doc);
	    inResult = new MutableRegionSet();
	    int j0 = inPointRegionSet2[j];
	    int j1 = inPointRegionSet2[j+1];
	    int j2 = inPointRegionSet2[j+2];
	    int j3 = inPointRegionSet2[j+3];
	    if (j0==j1 && j2==j3)
		inResult.insert(j0, j2, doc);
	    else 
		inResult.insert(new FuzzyRegion(j0, j1, j2, j3,
					 doc));

	    assertTrue( (text.in()).slowEquals(inResult) );
   	    j += 4;
	}
    }
    
    public void testFuzzyContains() {
	text = new MutableRegionSet();
	for (int i = 0; i < fuzzyRegionsCI.length; i += 4)
	    text.insert(new FuzzyRegion
			(fuzzyRegionsCI[i],
			 fuzzyRegionsCI[i+1],
			 fuzzyRegionsCI[i+2],
			 fuzzyRegionsCI[i+3],
					 doc)
			);
	containsResult = new MutableRegionSet();
	for (int i = 0; i < containsFuzzyRegionSet.length; i += 4)
	    containsResult.insert(new FuzzyRegion
			      (containsFuzzyRegionSet[i],
			       containsFuzzyRegionSet[i+1],
			       containsFuzzyRegionSet[i+2],
			       containsFuzzyRegionSet[i+3],
					 doc)
			      );

	assertTrue( (text.contains()).slowEquals(containsResult) );
    }

    public void testFuzzyIn() {
	text = new MutableRegionSet();
	for (int i = 0; i < fuzzyRegionsCI.length; i += 4)
	    text.insert(new FuzzyRegion
			(fuzzyRegionsCI[i],
			 fuzzyRegionsCI[i+1],
			 fuzzyRegionsCI[i+2],
			 fuzzyRegionsCI[i+3],
					 doc)
			);
	inResult = new MutableRegionSet();
	for (int i = 0; i < inFuzzyRegionSet.length; i += 4)
	    inResult.insert(new FuzzyRegion
			      (inFuzzyRegionSet[i],
			       inFuzzyRegionSet[i+1],
			       inFuzzyRegionSet[i+2],
			       inFuzzyRegionSet[i+3],
					 doc)
			      );
	assertTrue( (text.in()).slowEquals(inResult) );
    }
    
    public void testFuzzyContains2() {
	int j = 0;
	for (int i = 0; i < fuzzyRegionsCI2.length; i += 4) {
	    text = new MutableRegionSet();
	    text.insert(new FuzzyRegion
			(fuzzyRegionsCI2[i], 
			 fuzzyRegionsCI2[i+1],
			 fuzzyRegionsCI2[i+2],
			 fuzzyRegionsCI2[i+3],
					 doc)
			);
	    containsResult = new MutableRegionSet();
	    containsResult.insert(new FuzzyRegion
				  (containsFuzzyRegionSet2[j],
				   containsFuzzyRegionSet2[j+1],
				   containsFuzzyRegionSet2[i+2],
				   containsFuzzyRegionSet2[i+3],
					 doc)
				  );

	    assertTrue( (text.contains()).slowEquals(containsResult) );
   	    j += 4;
	}
    }
    
    public void testFuzzyIn2() {
	int j = 0;
	for (int i = 0; i < fuzzyRegionsCI2.length; i += 4) {
	    text = new MutableRegionSet();
	    text.insert(new FuzzyRegion
			(fuzzyRegionsCI2[i], 
			 fuzzyRegionsCI2[i+1],
			 fuzzyRegionsCI2[i+2],
			 fuzzyRegionsCI2[i+3],
					 doc)
			);
	    inResult = new MutableRegionSet();
	    inResult.insert(new FuzzyRegion
				  (inFuzzyRegionSet2[j],
				   inFuzzyRegionSet2[j+1],
				   inFuzzyRegionSet2[i+2],
				   inFuzzyRegionSet2[i+3],
					 doc)
				  );

	    assertTrue( (text.in()).slowEquals(inResult) );
   	    j += 4;
	}
    }
    
    private void printRegionSet(RegionSet rs) {
	//System.out.println(rs);
	//System.out.println(rs.getSize());
	RegionEnumeration re = rs.regions();
	for (Region r = re.firstFast(); r != null; r = re.nextFast())
	    System.out.println(r);
    }
}
