/*
 * LAPIS lightweight structured text processing system
 *
 * Copyright (C) 1998-2002 Carnegie Mellon University,
 * Copyright (C) 2003 Massachusetts Institute of Technology.
 * All rights reserved.
 *
 * This library is free software; you can redistribute it
 * and/or modify it under the terms of the GNU General
 * Public License as published by the Free Software
 * Foundation, version 2.
 *
 * LAPIS homepage: http://graphics.lcs.mit.edu/lapis/
 */

package lapis;

import java.util.Iterator;
import lapisx.util.Debug;

/**
 * SingleDocVersions represents Versions from single document.
 */
public class SingleDocVersions implements Versions {
    public static Debug debug = Debug.QUIET;

    DocumentVersion version;

    /**
     * @param ver is not null
     */
    public SingleDocVersions(DocumentVersion ver) {
        debug.assertion(ver != null);
        this.version = ver;
    }

	public Iterator versions() {
        return new Iterator () {
            public boolean hasNext() {
                return version != null;
            }
            public Object next() {
                if (version != null) {
                    DocumentVersion v = version;
                    version = null;
                    return v;
                } else
                    return null;
            }
            public void remove() {
            }
        };
	}

	public Iterator documents() {
        return new Iterator () {
            public boolean hasNext() {
                return version != null;
            }
            public Object next() {
                if (version != null) {
                    Document d = version.getDocument();
                    version = null;
                    return d;
                } else 
                    return null;
            }
            public void remove() {
            }
        };
	}

	public int getSize() {
		return 1;
	}

	public boolean contains(DocumentVersion ver) {
		return version.equals(ver);
	}

	public boolean contains(Document doc) {
		return (version.getDocument() == doc);
	}

	public DocumentVersion getVersion(Document doc) {
        return this.contains(doc) ? version : null;
	}

	public boolean compatible(Versions vs) {
        Document sourceDoc = version.getDocument();
        DocumentVersion targetVer = vs.getVersion(sourceDoc);
        return (targetVer == null || targetVer.equals(version));
	}

    public boolean equals (Object obj) {
        if (obj instanceof Versions) {
            Versions vs = (Versions)obj;
            if (vs.getSize() == 1 && vs.contains(version))
                return true;
            else
                return false;
        } else 
            return false;
    }
}
