/*
 * LAPIS lightweight structured text processing system
 *
 * Copyright (C) 1998-2002 Carnegie Mellon University,
 * Copyright (C) 2003 Massachusetts Institute of Technology.
 * All rights reserved.
 *
 * This library is free software; you can redistribute it
 * and/or modify it under the terms of the GNU General
 * Public License as published by the Free Software
 * Foundation, version 2.
 *
 * LAPIS homepage: http://graphics.lcs.mit.edu/lapis/
 */


package lapis;

import junit.framework.*;
import java.util.*;

public class StandardRectanglesTest extends TestCase {
    private final int MIN = RegionSet.MIN_INDEX;
    private final int MAX = RegionSet.MAX_INDEX;

    private int[] test1Input;
    private int[] test1Output;
    private int[] test2Input;
    private int[] test2Output;
    private int[] test3Input;
    private int[] test3Output;
    private int[] test4Input;
    private int[] test4Output;
    private int[] test5Input;
    private int[] test5Output;
    private int[] test6Input;
    private int[] test6Output;
    private int[] test7Input;
    private int[] test7Output;
    private int[] test8Input;
    private int[] test8Output;
    private int[] test9Input;
    private int[] test9Output;
    private int[] test10Input;
    private int[] test10Output;
    private int[] test11Input;
    private int[] test11Output;
    private int[] test12Input;
    private int[] test12Output;
    private int[] test13Input;
    private int[] test13Output;
    private int[] test14Input;
    private int[] test14Output;
    private int[] test15Input;
    private int[] test15Output;
    private int[] test16Input;
    private int[] test16Output;
    private int[] test17Input;
    private int[] test17Output;
    private int[] test18Input;
    private int[] test18Output;
    private int[] test19Input;
    private int[] test19Output;

	static Document doc = BasicDocument.defaultFactory.make ("");

    public static void main(String args[]) {
	junit.textui.TestRunner.run(StandardRectanglesTest.class);
    }

    protected void setUp() {
	test1Input = new int[] {
	    10, 30, 60, 70,
	    20, 40, 50, 80
	};

	test1Output = new int[] {
	    10, 19, 60, 70,
	    20, 40, 50, 80
	};

	test2Input = new int[] {
	    10, 40, 60, 80,
	    20, 30, 50, 70
	};

	test2Output = new int[] {
	    10, 19, 60, 80,
	    20, 30, 50, 80,
	    31, 40, 60, 80
	};

	test3Input = new int[] {
	    10, 40, 50, 80,
	    40, 40, 60, 90
	};

	test3Output = new int[] {
	    10, 39, 50, 80,
	    40, 40, 50, 90
	};

	test4Input = new int[] {
	    10, 40, 50, 80,
	    41, 41, 60, 90
	};

	test4Output = new int[] {
	    10, 40, 50, 80,
	    41, 41, 60, 90
	};

	test5Input = new int[] {
	    10, 40, 50, 80,
	    10, 10, 40, 60,
	    40, 40, 70, 90
	};

	test5Output = new int[] {
	    10, 10, 40, 80,
	    11, 39, 50, 80,
	    40, 40, 50, 90
	};

	test6Input = new int[] {
	    10, 40, 50, 80,
	    9, 9, 40, 60,
	    40, 40, 70, 90
	};

	test6Output = new int[] {
	    9, 9, 40, 60,
	    10, 39, 50, 80,
	    40, 40, 50, 90
	};

	test7Input = new int[] {
	    10, 40, 50, 80,
	    9, 9, 40, 60,
	    20, 20, 70, 90
	};
	
	test7Output = new int[] {
	    9, 9, 40, 60,
	    10, 19, 50, 80,
	    20, 20, 50, 90,
	    21, 40, 50, 80
	};

	test8Input = new int[] {
	    10, 40, 50, 80,
	    5, 20, 50, 50
	};

	test8Output = new int[] {
	    5, 9, 50, 50,
	    10, 40, 50, 80
	};

	test9Input = new int[] {
	    10, 40, 50, 80,
	    5, 20, 49, 49
	};

	test9Output = new int[] {
	    5, 9, 49, 49,
	    10, 20, 49, 80,
	    21, 40, 50, 80
	};

	test10Input = new int[] {
	    10, 40, 50, 80,
	    20, 30, 49, 49
	};

	test10Output = new int[] {
	    10, 19, 50, 80,
	    20, 30, 49, 80,
	    31, 40, 50, 80
	};

	test11Input = new int[] {
	    10, 40, 50, 80,
	    20, 30, 60, 60
	};

	test11Output = new int[] {
	    10, 40, 50, 80
	};

	test12Input = new int[] {
	    10, 40, 50, 80,
	    5, 50, 60, 60
	};

	test12Output = new int[] {
	    5, 9, 60, 60,
	    10, 40, 50, 80,
	    41, 50, 60, 60
	};

	test13Input = new int[] {
	    10, 40, 50, 70,
	    20, 60, 80, 100,
	    30,30, 60, 90
	};

	test13Output = new int[] {
	    10, 19, 50, 70,
	    20, 29, 50, 70,
	    20, 29, 80, 100,
	    30, 30, 50, 100,
	    31, 40, 50, 70,
	    31, 40, 80, 100,
	    41, 60, 80, 100
	};

	test14Input = new int[] {
	    10, 30, 50, 80,
	    40, 50, 60, 100,
	    20, 45, 70, 70
	};

	test14Output = new int[] {
	    10, 30, 50, 80,
	    31, 39, 70, 70,
	    40, 50, 60, 100
	};

	test15Input = new int[] {
	    10, 30, 50, 80,
	    31, 40, 50, 80
	};

	test15Output = new int[] {
	    10, 40, 50, 80
	};

	test16Input = new int[] {
	    50, 50, 50, 69,
	    51, 70, 51, 70
	};

	test17Input = new int[] {
	    50, 69, 50, 69,
	    51, 70, 70, 70
	};

	test16Output = new int[] {
	    50, 50, 0, 69,
	    51, 70, 0, 70
	};
	
	test17Output = test16Output;

	test18Input = new int[] {
	    MIN, 49, 50, 50,
	    MIN, 50, 51, MAX
	};

	test19Input = new int[] {
	    MIN, 49, 50, MAX,
	    50, 50, 51, MAX
	};

	test18Output = new int[] {
	    0, 49, 50, MAX,
	    50, 50, 51, MAX
	};
	
	test19Output = test18Output;
     }

    public void testStandardize() {
	//System.out.println("test1");
	assertTrue(isStandard(test1Input, test1Output));
	//System.out.println("test2");
	assertTrue(isStandard(test2Input, test2Output));
	//System.out.println("test3");
	assertTrue(isStandard(test3Input, test3Output));
	//System.out.println("test4");
	assertTrue(isStandard(test4Input, test4Output));
	//System.out.println("test5");
	assertTrue(isStandard(test5Input, test5Output));
	//System.out.println("test6");
	assertTrue(isStandard(test6Input, test6Output));
	//System.out.println("test7");
	assertTrue(isStandard(test7Input, test7Output));
	//System.out.println("test8");
	assertTrue(isStandard(test8Input, test8Output));
	//System.out.println("test9");
	assertTrue(isStandard(test9Input, test9Output));
	//System.out.println("test10");
	assertTrue(isStandard(test10Input, test10Output));
	//System.out.println("test11");
	assertTrue(isStandard(test11Input, test11Output));
	//System.out.println("test12");
	assertTrue(isStandard(test12Input, test12Output));
	//System.out.println("test13");
	assertTrue(isStandard(test13Input, test13Output));
	//System.out.println("test14");
	assertTrue(isStandard(test14Input, test14Output));
	//System.out.println("test15");
	assertTrue(isStandard(test15Input, test15Output));
	//System.out.println("test16");
	assertTrue(isStandard(test16Input, test16Output));
	//System.out.println("test17");
	assertTrue(isStandard(test17Input, test17Output));
	//System.out.println("test18");
	assertTrue(isStandard(test18Input, test18Output));
	//System.out.println("test19");
	assertTrue(isStandard(test19Input, test19Output));
    }

    private boolean isStandard(int[] input, int[] output) {
	MutableRegionSet rs = new MutableRegionSet();
	for (int i = 0; i < input.length; i += 4)
	    rs.insert(new FuzzyRegion(input[i], input[i+1], input[i+2], input[i+3], doc));
	StandardRectangles srs = new StandardRectangles(rs);
	ArrayList result = srs.standardize();
	ArrayList outputList = new ArrayList();
	for (int i = 0; i < output.length; i +=4)
	    outputList.add(srs.new Rect(output[i], output[i+1], output[i+2], output[i+3]));

	return standardEquals(result, outputList);
    }

    private boolean standardEquals(ArrayList l1, ArrayList l2) {
	int size = l1.size();
	if (size != l2.size())
	    return false;
	for (int i = 0; i < size; i++)
	    if ( ! ((StandardRectangles.Rect)l1.get(i)).equals((StandardRectangles.Rect)l2.get(i)) )
		return false;
	return true;
    }
}
