/*
 * LAPIS lightweight structured text processing system
 *
 * Copyright (C) 1998-2002 Carnegie Mellon University,
 * Copyright (C) 2003 Massachusetts Institute of Technology.
 * All rights reserved.
 *
 * This library is free software; you can redistribute it
 * and/or modify it under the terms of the GNU General
 * Public License as published by the Free Software
 * Foundation, version 2.
 *
 * LAPIS homepage: http://graphics.lcs.mit.edu/lapis/
 */



package lapis;

/**
 * Enumerates a partition of a RegionSet.
 * The partition depends on the RegionSet implementation.  For example,
 * RBTree enumerates the children of the root of the tree.
 * <P>
 * The RegionSet returned by firstFast() or nextFast() may be
 * internal object which is overwritten by the next call to
 * firstFast() or nextFast().  As a result, if you want to save
 * the enumerated subset across iterations, you should copy it
 * by calling freeze() on it. 
 * <P>
 * Here is the standard idiom for using this class:
 * <pre>
 * RegionSet set; // initialized somehow
 * RegionSet last;
 * SubsetEnumeration e = set.subsets ();
 * for (RegionSet r = e.firstFast (); r != null; r = e.nextFast ()) {
 *    // use r
 * 
 *    // If you need to save r for the next iteration, call freeze ():
 *    last = r.freeze ();
 * }
 * </pre>
 */
public interface SubsetEnumeration {
    public abstract RegionSet firstFast ();
    public abstract RegionSet nextFast ();
}
