/*
 * LAPIS lightweight structured text processing system
 *
 * Copyright (C) 1998-2002 Carnegie Mellon University,
 * Copyright (C) 2003 Massachusetts Institute of Technology.
 * All rights reserved.
 *
 * This library is free software; you can redistribute it
 * and/or modify it under the terms of the GNU General
 * Public License as published by the Free Software
 * Foundation, version 2.
 *
 * LAPIS homepage: http://graphics.lcs.mit.edu/lapis/
 */

package lapis;

import lapis.tools.*;
import junit.framework.*;

public class ToolboxTest extends TestCase {

    protected Toolbox toolbox;
    protected Tool tool1;
    protected Tool tool2;
    protected Tool tool3;
    protected String name1;
    protected String name2;
    protected String name3;
    protected String name4;

    public ToolboxTest (String name) {
        super(name);
    }
    protected void setUp() {
	toolbox = new Toolbox();
	tool1 = new Back();
	tool2 = new Calc();
	tool3 = new Prefix();
	name1 = "name1";
	name2 = "name2";
	name3 = "name1";
	name4 = "name4";
    }

    public void testAddTools() {
	assertFalse(toolbox.contains(new Toolbox.Info(null, name1, null, null, true, true)));
	assertFalse(toolbox.contains(new Toolbox.Info(null, name2, null, null, true, true)));
	assertFalse(toolbox.contains(new Toolbox.Info(null, name3, null, null, true, true)));
	assertFalse(toolbox.contains(new Toolbox.Info(null, name4, null, null, true, true)));
	toolbox.add(name1, tool1);
	assertTrue(toolbox.contains(new Toolbox.Info(null, name1, null, null, true, true)));
	assertFalse(toolbox.contains(new Toolbox.Info(null, name2, null, null, true, true)));
	assertTrue(toolbox.contains(new Toolbox.Info(null, name3, null, null, true, true)));
	assertFalse(toolbox.contains(new Toolbox.Info(null, name4, null, null, true, true)));
	toolbox.add(name2, tool1);
	assertTrue(toolbox.contains(new Toolbox.Info(null, name1, null, null, true, true)));
	assertTrue(toolbox.contains(new Toolbox.Info(null, name2, null, null, true, true)));
	assertTrue(toolbox.contains(new Toolbox.Info(null, name3, null, null, true, true)));
	assertFalse(toolbox.contains(new Toolbox.Info(null, name4, null, null, true, true)));
	toolbox.add(name4, tool2);
	assertTrue(toolbox.contains(new Toolbox.Info(null, name1, null, null, true, true)));
	assertTrue(toolbox.contains(new Toolbox.Info(null, name2, null, null, true, true)));
	assertTrue(toolbox.contains(new Toolbox.Info(null, name3, null, null, true, true)));
	assertTrue(toolbox.contains(new Toolbox.Info(null, name4, null, null, true, true)));

    }
    public void testRemoveTools(){
	assertFalse(toolbox.contains(new Toolbox.Info(null, name1, null, null, true, true)));
	assertFalse(toolbox.contains(new Toolbox.Info(null, name2, null, null, true, true)));
	assertFalse(toolbox.contains(new Toolbox.Info(null, name3, null, null, true, true)));
	toolbox.add(name1, tool1);
	assertTrue(toolbox.contains(new Toolbox.Info(null, name1, null, null, true, true)));
	toolbox.add(name2, tool1);
	assertTrue(toolbox.contains(new Toolbox.Info(null, name1, null, null, true, true)));
	assertTrue(toolbox.contains(new Toolbox.Info(null, name2, null, null, true, true)));
	assertTrue(toolbox.contains(new Toolbox.Info(null, name3, null, null, true, true)));
	toolbox.remove(name1);
	assertFalse(toolbox.contains(new Toolbox.Info(null, name1, null, null, true, true)));
	assertTrue(toolbox.contains(new Toolbox.Info(null, name2, null, null, true, true)));
    }
    public void testAddRemoveTools(){
	assertFalse(toolbox.contains(new Toolbox.Info(null, name1, null, null, true, true)));
	assertFalse(toolbox.contains(new Toolbox.Info(null, name2, null, null, true, true)));
	assertFalse(toolbox.contains(new Toolbox.Info(null, name3, null, null, true, true)));
	toolbox.add(name1, tool1);
	assertTrue(toolbox.contains(new Toolbox.Info(null, name1, null, null, true, true)));
	toolbox.add(name2, tool1);
	assertTrue(toolbox.contains(new Toolbox.Info(null, name1, null, null, true, true)));
	assertTrue(toolbox.contains(new Toolbox.Info(null, name2, null, null, true, true)));
	assertTrue(toolbox.contains(new Toolbox.Info(null, name3, null, null, true, true)));
	toolbox.remove(name1);
	assertFalse(toolbox.contains(new Toolbox.Info(null, name1, null, null, true, true)));
	assertTrue(toolbox.contains(new Toolbox.Info(null, name2, null, null, true, true)));
	toolbox.add(name1, tool1);
	assertTrue(toolbox.contains(new Toolbox.Info(null, name1, null, null, true, true)));
	assertTrue(toolbox.contains(new Toolbox.Info(null, name2, null, null, true, true)));
    }



    public static Test suite () {        
        return new TestSuite (ToolboxTest.class);
    }

}
