/*
 * LAPIS lightweight structured text processing system
 *
 * Copyright (C) 1998-2002 Carnegie Mellon University,
 * Copyright (C) 2003 Massachusetts Institute of Technology.
 * All rights reserved.
 *
 * This library is free software; you can redistribute it
 * and/or modify it under the terms of the GNU General
 * Public License as published by the Free Software
 * Foundation, version 2.
 *
 * LAPIS homepage: http://graphics.lcs.mit.edu/lapis/
 */

package lapis;

import java.util.*;

/**
 * Versions is a set of document versions from which a region set is derived.  Contains
 * at most one version per document (i.e., if v1!=v2 are in the set, then v1.doc != v2.doc).
 * Versions is immutable.
 */
public interface Versions {
    /**
     * @return an iterator over the set of document versions
     */
    public Iterator versions();
    
    /**
     * @return an iterator over the set of documents
     */
    public Iterator documents();
    
    /**
     * @return the number of versions (or equivalently, the number of documents) that Versions contains
     */
    public int getSize();
    
    /**
     * @param ver a document version
     * @return true if ver is in Versions, false otherwise.
     */
    public boolean contains (DocumentVersion ver);
    
    /**
     * @param doc a document
     * @return true if doc is in Versions, false otherwise.
     */
    public boolean contains (Document doc);
    
    /**
     * get doc's version, which is stored in Versions
     * @param doc a document
     * @return doc's version, which is stored in Versions, if doc is in Versions. null otherwise.
     */
    public DocumentVersion getVersion (Document doc);
    
    /**
     * @return true if obj is an instance of Versions and obj contains the same set of DocumentVersion as this.
     * false otherwise.
     */
    public boolean equals (Object obj);
    
    /**
     * Test whether two Versions are compatible -- i.e., whether two region sets with those Versions can be
     * safely combined without coordinate conversion. 
     * @param vs a Versions
     * @return true if and only if for every document doc shared by this and vs,  this.getVersion(doc) == vs.getVersion(doc).
     */
    public boolean compatible (Versions vs);
}
