/*
 * LAPIS lightweight structured text processing system
 *
 * Copyright (C) 1998-2002 Carnegie Mellon University,
 * Copyright (C) 2003 Massachusetts Institute of Technology.
 * All rights reserved.
 *
 * This library is free software; you can redistribute it
 * and/or modify it under the terms of the GNU General
 * Public License as published by the Free Software
 * Foundation, version 2.
 *
 * LAPIS homepage: http://graphics.lcs.mit.edu/lapis/
 */


package lapis.maps;

import lapis.*;

public class CompositeCoordinateMap implements CoordinateMap {
    CoordinateMap m1;
    CoordinateMap m2;
    CoordinateMap myInverse;

    public CompositeCoordinateMap (CoordinateMap m1, CoordinateMap m2) {
        this (m1, m2, null);
    }

    CompositeCoordinateMap (CoordinateMap m1, CoordinateMap m2,
                            CompositeCoordinateMap myInverse) {
        this.m1 = m1;
        this.m2 = m2;
        this.myInverse = (myInverse != null) 
            ? myInverse
            : new CompositeCoordinateMap (m2.invert (), m1.invert (), this);
    }

    public int mapStart (int x) {
        return m1 .mapStart (m2.mapStart (x));
    }

    public int mapEnd (int x) {
        return m1 .mapEnd (m2.mapEnd (x));
    }
        
    public CoordinateMap invert () {
        return myInverse;
    }

}
