/*
 * LAPIS lightweight structured text processing system
 *
 * Copyright (C) 1998-2002 Carnegie Mellon University,
 * Copyright (C) 2003 Massachusetts Institute of Technology.
 * All rights reserved.
 *
 * This library is free software; you can redistribute it
 * and/or modify it under the terms of the GNU General
 * Public License as published by the Free Software
 * Foundation, version 2.
 *
 * LAPIS homepage: http://graphics.lcs.mit.edu/lapis/
 */


package lapis.maps;

import lapis.*;

public abstract class EditCoordinateMap {

    public static class Insertion implements CoordinateMap {
        int a;
        int b1, b2;

        public Insertion (int a, int b1, int b2) {
            this.a = a;
            this.b1 = b1;
            this.b2 = b2;
        }

        public int mapStart (int x) {
            if (x < a)
                return x;
            else
                return (x - a) + b2;
        }
        
        public int mapEnd (int x) {
            if (x <= a)
                return x;
            else
                return (x - a) + b2;
        }
        
        public CoordinateMap invert () {
            return new Deletion (b1, b2, a);
        }
    }

    public static class Deletion implements CoordinateMap {
        int a1, a2;
        int b;

        public Deletion (int a1, int a2, int b) {
            this.a1 = a1;
            this.a2 = a2;
            this.b = b;
        }

        public int mapStart (int x) {
            if (x < a1)
                return x;
            else if (x < a2)
                return b;
            else
                return (x - a2) + b;
        }
        
        public int mapEnd (int x) {
            if (x < a1)
                return x;
            else if (x < a2)
                return b;
            else
                return (x - a2) + b;
        }
        
        public CoordinateMap invert () {
            return new Insertion (b, a1, a2);
        }
    }
}

