/*
 * LAPIS lightweight structured text processing system
 *
 * Copyright (C) 1998-2002 Carnegie Mellon University,
 * Copyright (C) 2003 Massachusetts Institute of Technology.
 * All rights reserved.
 *
 * This library is free software; you can redistribute it
 * and/or modify it under the terms of the GNU General
 * Public License as published by the Free Software
 * Foundation, version 2.
 *
 * LAPIS homepage: http://graphics.lcs.mit.edu/lapis/
 */


package lapis.maps;

import lapis.*;

public class SlicedCoordinateMap implements CoordinateMap {
    CoordinateMap base;
    int a1;
    int a2;
    int b1;
    int b2;
    CoordinateMap myInverse;

    public SlicedCoordinateMap (CoordinateMap base, 
                                int a1, int a2, int b1, int b2) {
        this (base, a1, a2, b1, b2, null);
    }

    SlicedCoordinateMap (CoordinateMap base, 
                         int a1, int a2, int b1, int b2,
                         SlicedCoordinateMap myInverse) {
        this.base = base;
        this.a1 = a1;
        this.a2 = a2;
        this.b1 = b1;
        this.b2 = b2;
        this.myInverse = (myInverse != null) 
            ? myInverse
            : new SlicedCoordinateMap (base.invert (), 
                                       b1, b2,
                                       a1, a2,
                                       this);
    }

    public int mapStart (int x) {
        if (x < a1)
            return base.mapStart (x);
        else 
            return base.mapStart (x + (a2 - a1)) - (b2 - b1);
    }

    public int mapEnd (int x) {
        if (x < a1)
            return base.mapEnd (x);
        else
            return base.mapEnd (x + (a2 - a1)) - (b2 - b1);
    }
        
    public CoordinateMap invert () {
        return myInverse;
    }

}
