/*
 * LAPIS lightweight structured text processing system
 *
 * Copyright (C) 1998-2002 Carnegie Mellon University,
 * Copyright (C) 2003 Massachusetts Institute of Technology.
 * All rights reserved.
 *
 * This library is free software; you can redistribute it
 * and/or modify it under the terms of the GNU General
 * Public License as published by the Free Software
 * Foundation, version 2.
 *
 * LAPIS homepage: http://graphics.lcs.mit.edu/lapis/
 */


package lapis.maps;

import lapis.*;

public class SplicedCoordinateMap implements CoordinateMap {
    CoordinateMap base;
    CoordinateMap splice;
    int a1;
    int a2;
    int b1;
    int b2;
    CoordinateMap myInverse;

    public SplicedCoordinateMap (CoordinateMap base, 
                                 CoordinateMap splice,
                                 int a1, int a2, int b1, int b2) {
        this (base, splice, a1, a2, b1, b2, null);
    }

    SplicedCoordinateMap (CoordinateMap base, 
                          CoordinateMap splice,
                          int a1, int a2, int b1, int b2,
                          SplicedCoordinateMap myInverse) {
        this.base = base;
        this.splice = splice;
        this.a1 = a1;
        this.a2 = a2;
        this.b1 = b1;
        this.b2 = b2;
        this.myInverse = (myInverse != null) 
            ? myInverse
            : new SplicedCoordinateMap (base.invert (), 
                                        splice.invert (), 
                                        b1, b2,
                                        a1, a2,
                                        this);
    }

    public int mapStart (int x) {
        if (x <= a1)
            return base.mapStart (x);
        else if (x >= a2)
            return (b2 - b1) + base.mapStart (x - (a2 - a1));
        else
            return b1 + splice.mapStart (x - a1);
    }

    public int mapEnd (int x) {
        if (x <= a1)
            return base.mapEnd (x);
        else if (x >= a2)
            return (b2 - b1) + base.mapEnd (x - (a2 - a1));
        else
            return b1 + splice.mapEnd (x - a1);
    }
        
    public CoordinateMap invert () {
        return myInverse;
    }

}
