/*
 * LAPIS lightweight structured text processing system
 *
 * Copyright (C) 1998-2002 Carnegie Mellon University,
 * Copyright (C) 2003 Massachusetts Institute of Technology.
 * All rights reserved.
 *
 * This library is free software; you can redistribute it
 * and/or modify it under the terms of the GNU General
 * Public License as published by the Free Software
 * Foundation, version 2.
 *
 * LAPIS homepage: http://graphics.lcs.mit.edu/lapis/
 */


package lapis.ml;

public class CategoryUtilityMetric extends DistanceMetric {
    public static lapisx.util.Debug debug = lapisx.util.Debug.QUIET; 

    public CategoryUtilityMetric (DataSet pos, DataSet neg) {
        int n = pos.features.length;
        weight = new double[n];
        double nPos = pos.getSize ();
        double nNeg = neg.getSize ();
        double nTot = nPos + nNeg;
        for (int i = 0; i < n; ++i) {
            debug.println ("computing utility for " + pos.features[i]);
            double nPosF = pos.sum[i];
            double nPosNotF = nPos - nPosF;
            double nF = nPosF + neg.sum[i];
            double nNotF = nTot - nF;

            double pF = nTot > 0 ? nF / nTot : 1;
            double pFGivenPos = nPos > 0 ? nPosF / nPos : 1;
            double pPosGivenF = nF > 0 ? nPosF / nF : 1;

            double pNotF = nTot > 0 ? nNotF / nTot : 1;
            double pNotFGivenPos = nPos > 0 ? nPosNotF / nPos : 1;
            double pPosGivenNotF = nNotF > 0 ? nPosNotF / nNotF : 1;

            debug.println ("pF=" + pF);
            debug.println ("pFGivenPos=" + pFGivenPos);
            debug.println ("pPosGivenF=" + pPosGivenF);
            debug.println ("pNotF=" + pNotF);
            debug.println ("pNotFGivenPos=" + pNotFGivenPos);
            debug.println ("pPosGivenNotF=" + pPosGivenNotF);

            // compute utilities of F and not-F
            double uF = pFGivenPos * pPosGivenF;
            double uNotF = pFGivenPos * pPosGivenF;

            // keep the larger of the two utilities, and
            // recenter around P(+) (the utility of
            // a useless feature that all examples share)
            double u = Math.max (uF, uNotF) - (nPos / nTot);

            // clip negative weights to 0
            weight[i] = Math.max (u, 0);
        }

        pruneWeights (weight, pos.features);
    }
}
