/*
 * LAPIS lightweight structured text processing system
 *
 * Copyright (C) 1998-2002 Carnegie Mellon University,
 * Copyright (C) 2003 Massachusetts Institute of Technology.
 * All rights reserved.
 *
 * This library is free software; you can redistribute it
 * and/or modify it under the terms of the GNU General
 * Public License as published by the Free Software
 * Foundation, version 2.
 *
 * LAPIS homepage: http://graphics.lcs.mit.edu/lapis/
 */


package lapis.ml;

import lapis.*;
import lapis.tc.*;
import java.util.*;
import lapisx.enum.*;

public class Feature extends NamedRegionSet {
    Feature base;
    Vector equivalents; // vector of features 

	public Feature (RegionSet regions, TC pattern) {
		super (regions, pattern);
	}
    
	public Feature (RegionSet regions, String description) {
		super (regions, description);
	}

	public Feature (Feature base, RegionSet regions, TC pattern) {
	   	super (regions, pattern);
		this.base = base;
	}

	public Feature (Feature base, RegionSet regions, String description) {
		super (regions, description);
		this.base = base;
	}
	
    public Feature (Feature base, String description) {
        super (base, description);
        this.base = base;
    }

    public Feature getBaseFeature () {
        return base != null ? base : this;
    }

    void clearEquivalentFeatures () {
        equivalents = null;
    }

    void addEquivalentFeature (Feature f) {
        if (equivalents == null)
            equivalents = new Vector ();
        equivalents.addElement (f);
    }

    public Enumeration equivalentFeatures () {
        if (equivalents == null)
            return new EmptyEnumeration ();
        else
            return equivalents.elements ();
    }

}
