/*
 * LAPIS lightweight structured text processing system
 *
 * Copyright (C) 1998-2002 Carnegie Mellon University,
 * Copyright (C) 2003 Massachusetts Institute of Technology.
 * All rights reserved.
 *
 * This library is free software; you can redistribute it
 * and/or modify it under the terms of the GNU General
 * Public License as published by the Free Software
 * Foundation, version 2.
 *
 * LAPIS homepage: http://graphics.lcs.mit.edu/lapis/
 */


package lapis.ml;

import lapis.*;
import lapis.tc.*;
import java.util.*;
import lapisx.util.*;
import lapisx.enum.*;

public class LibraryGenerator extends FilteredEnumeration {
    public static lapisx.util.Debug debug = lapisx.util.Debug.QUIET;
    
    Document doc;
    PatternLibrary lib;
    static Set skip = new HashSet ();

    public LibraryGenerator  (Document doc) {
        super (PatternLibrary.getDocumentLibrary (doc).visibleNames ());
        this.doc = doc;
        this.lib = PatternLibrary.getDocumentLibrary (doc);
    }

    public void transform (Object o) {
        Thr.check ();

        String name = o.toString ();
        debug.println (name);

        // skip names matching skip list
        for (Iterator g = skip.iterator (); g.hasNext (); ) {
            if (matches (name, ((String) g.next ()))) {
                debug.println ("skipping " + name);
                return;
            }
        }
        
        String shortName = lib.getShortestName (name);
        RegionSet matches = lib.get (name).match (doc);
        Main.getProgress ().fireAddProgress (1);
        
        if (!matches.isEmpty ()) {
            //yield (new Feature (doc, matches, new TC (new TC.Id (shortName), shortName)));
			yield (new Feature (matches, new TC (new TC.Id (shortName), shortName)));
        }
    }


    /**
     * Register a name or set of names that should not be used as an
     * inference feature.
     * @param wildcard either a full canonical name, like
     * "Business.Date.Month", or a namespace followed by an asterisk,
     * like "Business.Date.*".  
     * @effects If wildcard is a full name, then that named pattern is
     * not used for inference.  If wildcard is a namespace, then all
     * named patterns in that namespace are not used for inference.
     */
    public static void skipNamesMatching (String wildcard) {
        skip.add (wildcard);
    }

    static boolean matches (String name, String wildcard) {
        if (wildcard.endsWith ("*"))
            return name.startsWith (wildcard.substring (0, wildcard.length ()-1));
        else
            return name.equals (wildcard);
    }

}
