/*
 * LAPIS lightweight structured text processing system
 *
 * Copyright (C) 1998-2002 Carnegie Mellon University,
 * Copyright (C) 2003 Massachusetts Institute of Technology.
 * All rights reserved.
 *
 * This library is free software; you can redistribute it
 * and/or modify it under the terms of the GNU General
 * Public License as published by the Free Software
 * Foundation, version 2.
 *
 * LAPIS homepage: http://graphics.lcs.mit.edu/lapis/
 */


package lapis.ml;

public class MutualInformationMetric extends DistanceMetric {
    static final double THRESHOLD = 0.05;
    public MutualInformationMetric (DataSet pos, DataSet neg) {
        int n = pos.features.length;
        int nPos = pos.getSize ();
        int nNeg = neg.getSize ();
        double maxMI = mutualInformation (nPos, 0, 0, nNeg);
        weight = new double[n];
        for (int i = 0; i < n; ++i) {
            double mi = mutualInformation ((int)pos.sum[i], 
                                           (int)neg.sum[i],
                                           (int)(nPos - pos.sum[i]),
                                           (int)(nNeg - neg.sum[i]));
            weight[i] = mi / maxMI;
            if (weight[i] < THRESHOLD)
                weight[i] = 0.0;
        }

        pruneWeights (weight, pos.features);
    }

    static double mutualInformation (int AB, int aB,
                                               int Ab, int ab) {
        double n = AB + aB + Ab + ab;
        return 
            info ((AB + aB)/n) 
            + info ((Ab + ab)/n)
            + info ((AB + Ab)/n)
            + info ((aB + ab)/n)
            - info (AB/n) 
            - info (aB/n) 
            - info (Ab/n) 
            - info (ab/n);
    }

    static final double LOG2 = Math.log(2);
    static double info (double p) {
        return (p > 0.0) ? -p * Math.log(p)/LOG2 : 0.0;
    }
}
