/*
 * LAPIS lightweight structured text processing system
 *
 * Copyright (C) 1998-2002 Carnegie Mellon University,
 * Copyright (C) 2003 Massachusetts Institute of Technology.
 * All rights reserved.
 *
 * This library is free software; you can redistribute it
 * and/or modify it under the terms of the GNU General
 * Public License as published by the Free Software
 * Foundation, version 2.
 *
 * LAPIS homepage: http://graphics.lcs.mit.edu/lapis/
 */


package lapis.ml;

import lapis.*;
import lapis.tc.*;
import java.util.*;
import lapisx.util.*;
import lapisx.enum.*;
import java.lang.reflect.*;

public class RelopGenerator extends FilteredEnumeration {
    public static Debug debug = Debug.QUIET;

    Constructor[] ctors;
    String[] names;
    TC.Node[] args;

    public RelopGenerator (Class[] relops, Enumeration features) {
        super (features);

        try {
            // Find the constructor for each class in relops
            ctors = new Constructor[relops.length];
            names = new String[relops.length];
            for (int i = 0; i < relops.length; ++i) {
                ctors[i] = relops[i].getConstructor 
                    (new Class[] { TC.Node.class });
                if (relops[i] == TC.Starting.class)
                    names[i] = "starting";
                else if (relops[i] == TC.Ending.class)
                    names[i] = "ending";
                else if (relops[i] == TC.JustBefore.class)
                    names[i] = "just before";
                else if (relops[i] == TC.JustAfter.class)
                    names[i] = "just after";
                else if (relops[i] == TC.Contains.class)
                    names[i] = "contains";
                else if (relops[i] == TC.In.class)
                    names[i] = "in";
                else if (relops[i] == TC.Equals.class)
                    names[i] = "equals";
                else
                    names[i] = relops[i].getName ();
            }

            // Prepare an array for constructor arguments
            args = new TC.Node[1];
        } catch (NoSuchMethodException e) {
            debug.report (e);
        }
    }

    public void transform (Object o) {
        try {
            Feature f = (Feature) o;
            args[0] = new TC.Constant (f);
            for (int i = 0; i < ctors.length; ++i) {
                TC pattern = new TC ((TC.Node) ctors[i].newInstance (args), 
                                     names[i] + " " + f);
				// TODO: support multiple documents
                debug.assertion(f.getVersions().getSize() == 1);
                Iterator idoc = f.getDocuments();
                RegionSet matches = RegionSet.EMPTY;
                while (idoc.hasNext())
                    matches = pattern.match((Document)idoc.next());
                
                if (!matches.isEmpty ()) {
                    // create a feature
                    yield (new Feature (f, matches, pattern));
                }
            }
        } catch (InvocationTargetException e) {
            debug.report (e);
        } catch (IllegalAccessException e) {
            debug.report (e);
        } catch (InstantiationException e) {
            debug.report (e);
        }
    }
}
