/*
 * LAPIS lightweight structured text processing system
 *
 * Copyright (C) 1998-2002 Carnegie Mellon University,
 * Copyright (C) 2003 Massachusetts Institute of Technology.
 * All rights reserved.
 *
 * This library is free software; you can redistribute it
 * and/or modify it under the terms of the GNU General
 * Public License as published by the Free Software
 * Foundation, version 2.
 *
 * LAPIS homepage: http://graphics.lcs.mit.edu/lapis/
 */

 
package lapis.parsers;

import lapis.*;
import java.io.*;
import java.util.*;

/**
 * Checks spelling of a document using an external program (ispell).
 *
 */
public class SpellingParser implements Parser, Pattern {
    
    public static lapisx.util.Debug debug = lapisx.util.Debug.QUIET;

    public static String PATTERN_NAME = "English.Dictionary.Misspelling";

    private static ExternalParser.Command ispellCommand = 
        new ExternalParser.Command 
        ( new String[] { "ispell", "-l" } );

    public SpellingParser () {
    }

    public void bind(PatternLibrary lib) {
        lib.put (PATTERN_NAME, this);
    }

    public void bind (PatternLibrary lib, Document doc) {
        // no doc-specific patterns for this parser
    }

    public RegionSet match (Document doc) {
        PatternCache cache = doc.getPatternCache();
        if (!cache.wasParsedBy (PATTERN_NAME))
            parse (doc);
        return cache.get (PATTERN_NAME);
    }

    public void parse (Document doc) {
        InputStream ispellStream = ispellCommand.exec (doc.getCookedView().getText());
        
        if (ispellStream == null) {
            doc.getPatternCache ()
                .put (PATTERN_NAME, new ErrorRegionSet ("can't run ispell"));
            return;
        }

        BufferedReader in = 
            new BufferedReader (new InputStreamReader (ispellStream));
        try {
            Set words = new HashSet ();
            for (String word = in.readLine (); 
                 word != null;
                 word = in.readLine ())
                words.add (word.toLowerCase ());
            debug.println ("ispell found these words:\n" + words);

            if (words.isEmpty ())
                doc.getPatternCache ()
                    .put (PATTERN_NAME, RegionSet.EMPTY);
            else {
                ListParser scanner = new ListParser (PATTERN_NAME, words,
                                                 false, true);
                scanner.parse (doc);
            }

        } catch (IOException e) {
            debug.report (e);
        }
    }
}
