/*
 * LAPIS lightweight structured text processing system
 *
 * Copyright (C) 1998-2002 Carnegie Mellon University,
 * Copyright (C) 2003 Massachusetts Institute of Technology.
 * All rights reserved.
 *
 * This library is free software; you can redistribute it
 * and/or modify it under the terms of the GNU General
 * Public License as published by the Free Software
 * Foundation, version 2.
 *
 * LAPIS homepage: http://graphics.lcs.mit.edu/lapis/
 */



package lapis.swing;

import lapis.*;
import java.util.*;
import javax.swing.*;
import lapisx.progress.*;

public class BackgroundThreads {
    public static lapisx.util.Debug debug = lapisx.util.Debug.QUIET; 

    private Browser browser;
    private BasicProgressGenerator progress;
    private List threads = Collections.synchronizedList (new LinkedList ());

    public BackgroundThreads (Browser browser, BasicProgressGenerator progress) {
        this.browser = browser;
        this.progress = progress;
    }

    public void run (RunnableWithExceptions r) {
        Worker w = new Worker (r);
        threads.add (w);
        w.start ();
    }

    public void stop () {
        for (Iterator g = threads.iterator (); g.hasNext (); )
            ((Thread) g.next ()).interrupt ();
        threads.clear ();
    }

    private class Worker extends Thread {
        RunnableWithExceptions r;

        public Worker (RunnableWithExceptions r) {
	    super ("BackgroundThreads/" + r.getClass ().getName ());
            this.r = r;
            setPriority (4);
        }

        public void run () {
            try {
                Main.addProgress (progress);
                setBusy (true);
                r.run ();
                setBusy (false);
            } catch (final Exception e) {
                reportException (e);
            } catch (final StackOverflowError e) {
                reportException (e);
            } finally {
                Main.removeProgress (progress);
            }
        }
    }

    void setBusy (final boolean enabled) {
        SwingUtilities.invokeLater (new Runnable () {
                public void run () {
                    browser.setBusy (enabled);
                }
            });
    }

    void reportException (final Throwable e) {
        debug.report (e);
        SwingUtilities.invokeLater (new Runnable () {
                public void run () {
                    browser.clearBusy ();
                    browser.clearHourglass ();
                    browser.clearStatus ();
                    FeedbackForm.showExceptionDialog (browser, e);
                }
            });
    }

}
