/*
 * LAPIS lightweight structured text processing system
 *
 * Copyright (C) 1998-2002 Carnegie Mellon University,
 * Copyright (C) 2003 Massachusetts Institute of Technology.
 * All rights reserved.
 *
 * This library is free software; you can redistribute it
 * and/or modify it under the terms of the GNU General
 * Public License as published by the Free Software
 * Foundation, version 2.
 *
 * LAPIS homepage: http://graphics.lcs.mit.edu/lapis/
 */
package lapis.swing;

/**
 * Listener, attached to a browser, that receives events when the
 * browser is changing documents.
 */
public interface BrowserListener {

    /**
     * Called when a document is about to be loaded.  The document has
     * not necessarily been fully downloaded yet, so its content is
     * unavailable, but its URL and content type are available.
     * Always called from event-handling thread.
     * @param browser Browser which is loading the document
     * @param doc Document being loaded
     */
    public void loadingDocument (Browser browser, SwingDocument doc);

    /**
     * Called after the current document has been fully loaded.
     * Always called from event-handling thread.
     * @param browser Browser which is loading the document
     * @param doc Document loaded
     */
    public void loadedDocument (Browser browser, SwingDocument doc);
}
