/*
 * LAPIS lightweight structured text processing system
 *
 * Copyright (C) 1998-2002 Carnegie Mellon University,
 * Copyright (C) 2003 Massachusetts Institute of Technology.
 * All rights reserved.
 *
 * This library is free software; you can redistribute it
 * and/or modify it under the terms of the GNU General
 * Public License as published by the Free Software
 * Foundation, version 2.
 *
 * LAPIS homepage: http://graphics.lcs.mit.edu/lapis/
 */


package lapis.swing;

import java.awt.*;
import javax.swing.*;
import javax.swing.border.*;
import lapisx.swing.*;

public class BrowserScrollPane extends HighlightingScrollPane {
    private Border defaultBorder;
    private Border titledBorder;

    private Color defaultBackground;
    private Color activeBackground;

    public BrowserScrollPane (BrowserPane pane, String title) {
        super (pane);

        setVerticalScrollBarPolicy (VERTICAL_SCROLLBAR_ALWAYS);
        setMinimumSize (new Dimension (0, 0));
        setVerticalHighlighter ((ScrollBarHighlighter) pane.getScrollBarHighlighter ());

        defaultBorder = getBorder ();
        titledBorder = makeTitledBorder (title);

        defaultBackground = getBackground ();
        activeBackground = Color.orange;
    }

    private Border makeTitledBorder (String title) {
        Border negativePadding = 
            BorderFactory.createEmptyBorder (-2, -4, -4, -4);
        return
            BorderFactory.createTitledBorder  (negativePadding, title);
    }

    public void setTitled (boolean t) {
        setBorder (t ? titledBorder : defaultBorder);
    }

    public void setActivated (boolean t) {
        setBackground (t ? activeBackground : defaultBackground);
    }

}

