/*
 * LAPIS lightweight structured text processing system
 *
 * Copyright (C) 1998-2002 Carnegie Mellon University,
 * Copyright (C) 2003 Massachusetts Institute of Technology.
 * All rights reserved.
 *
 * This library is free software; you can redistribute it
 * and/or modify it under the terms of the GNU General
 * Public License as published by the Free Software
 * Foundation, version 2.
 *
 * LAPIS homepage: http://graphics.lcs.mit.edu/lapis/
 */


package lapis.swing;

import javax.swing.text.*;
import java.awt.*;
import lapis.*;

/**
 * A collection of text styles for rendering syntax-highlighted
 * region sets in a document model. Because the rendering styles
 * are based on view preferences, the views need convenient access
 * to style settings. This convenience justifies implementing the
 * factory interface along with the style storage.
 *
 */

public class ColoringContext extends StyleContext implements ViewFactory {
	
  public static lapisx.util.Debug debug = lapisx.util.Debug.QUIET;

  public static RegionSetStyle DEFAULT;
  
  // TODO: support a set of regionset-style mappings in the future
  // HashSet styleSpecifications; // set of RegionSetStyles

  private boolean colored = false;

  public ColoringContext() {
    super();
    
    // should be a static initialization block - but gives problems in
    // creating a StyleContext.NamedStyle
    Style s = new StyleContext.NamedStyle("GREEN", null);
    StyleConstants.setForeground(s, Color.green);
    StyleConstants.setBold(s, true); 
//    DEFAULT = new RegionSetStyle(RegionSet.ANY, s);
	// same as ColoringView class. need debug.assertion
	DEFAULT = new RegionSetStyle((Region)RegionSet.getUniversal(lapis.Document.DEFAULT), s);

  }

  // --- ViewFactory methods ------------------------------------------
  /** Specified by ViewFactory.create() */
  public View create(Element element) {
    ColoringView cv = new ColoringView(element, colored);
    cv.applyStyle(DEFAULT);
    return cv;
  }

  /**
   * Specifies whether syntax highlighting is turned on or off. 
   */
  public void setColoring(boolean renderColor) {
    colored = renderColor;
  }

  /**
   * Adds a RegionSet-Style mapping to this style context.
   */
  public boolean addRegionSetStyle(RegionSetStyle rs) {
    // return styleSpecifications.add(rs);
    return true;
  }
}
