/*
 * LAPIS lightweight structured text processing system
 *
 * Copyright (C) 1998-2002 Carnegie Mellon University,
 * Copyright (C) 2003 Massachusetts Institute of Technology.
 * All rights reserved.
 *
 * This library is free software; you can redistribute it
 * and/or modify it under the terms of the GNU General
 * Public License as published by the Free Software
 * Foundation, version 2.
 *
 * LAPIS homepage: http://graphics.lcs.mit.edu/lapis/
 */


package lapis.swing;

import lapis.*;
import java.util.*;
import javax.swing.*;
import javax.swing.table.*;
import lapisx.sort.*;
import lapisx.swing.Layout;

public class DocumentProperties extends JFrame implements BrowserListener {
    Document doc;
    Dictionary props;
    Vector propertyNames;
    JTable table;
    PropertyTableModel model;

    public DocumentProperties () {
        super ("Document Properties");

        props = new Hashtable ();
        propertyNames = new Vector ();

        Layout.vertical (getContentPane ())
            .add (new JScrollPane (table = 
                                   new JTable (model = new PropertyTableModel ())))
            ;
        pack ();

        table.getTableHeader ().setReorderingAllowed (false);
    }

    public void setDocument (Document doc) {
        this.doc = doc;
        if (doc == null) {
            props = new Hashtable ();
            propertyNames.removeAllElements ();
        } else {
            props = doc.getProperties ();
            propertyNames.removeAllElements ();
            for (Enumeration e = props.keys (); e.hasMoreElements (); )
                propertyNames.addElement (e.nextElement ());
        }
            
        Quicksort.sort (new SortableVector (propertyNames));

        model.fireTableDataChanged ();
    }

    //
    // BrowserListener interface
    //

    public void loadingDocument (Browser browser, SwingDocument doc) {
    }

    public void loadedDocument (Browser browser, SwingDocument doc) {
        if (isVisible ())
            setDocument (doc);
    }

    class PropertyTableModel extends AbstractTableModel {
        public String getColumnName(int col) { 
            switch (col) {
            case 0:
                return "Name";
            case 1:
                return "Value";
            default:
                return "";
            }
        }

        public int getRowCount() { 
            return props.size ();
        }

        public int getColumnCount() { 
            return 2;
        }

        public Object getValueAt(int row, int col) {
            Object key = propertyNames.elementAt (row); 
            switch (col) {
            case 0:
                return key;
            case 1:
                return props.get (key);
            default:
                return "";
            }
        }
    }                
}
