/*
 * LAPIS lightweight structured text processing system
 *
 * Copyright (C) 1998-2002 Carnegie Mellon University,
 * Copyright (C) 2003 Massachusetts Institute of Technology.
 * All rights reserved.
 *
 * This library is free software; you can redistribute it
 * and/or modify it under the terms of the GNU General
 * Public License as published by the Free Software
 * Foundation, version 2.
 *
 * LAPIS homepage: http://graphics.lcs.mit.edu/lapis/
 */

package lapis.swing;

import lapis.*;
import lapis.tc.*;
import javax.swing.JOptionPane;

public class HighlightReplacements implements Tool {
    Browser browser;

    public HighlightReplacements (Browser browser) {
        this.browser = browser;
    }

    public Document invoke (Arguments args) throws Exception {
        TC pat = null;
        boolean add = false;
        boolean remove = false;
        
        args.setUsage (
                       "Usage:\n"
                       + "   highlight-replacements <pattern>      highlights regions matching <pattern> in green\n"
                       + "\n"
                       + "Options:\n"
                       + "   -add         Add <pattern> to green highlights\n"
                       + "   -remove      Remove <pattern> from green highlights\n"
                       + "   -help        Display this message\n"
                       );
        while (args.hasMoreElements ()) {
            String name = args.nextName ();
            if ("query".equals (name)
                || (name == null && pat == null))
                pat = args.nextPattern ();
            else if ("add".equals (name))
                add = true;
            else if ("remove".equals (name))
                remove = true;
            else
                args.consume (name);
        }

        if (pat == null || (add && remove))
            args.usage ();

        BrowserPane bp = browser.getActivePane ();
        
        Document doc = args.getInput ();
        RegionSet s = pat.match (doc);

        if (add || remove) {
            NamedRegionSet currSel = bp.getFindAndReplaceHighlighter().getSelection ();
            RegionSet curr = 
                currSel != null
                ? currSel.convertToLatest ()
                : RegionSet.EMPTY;
            s = add ? curr.or (s) : curr.butnot (s);
        }

        //NamedRegionSet sel = new NamedRegionSet (doc, s);
		NamedRegionSet sel = new NamedRegionSet (s);
        bp.getFindAndReplaceHighlighter().setSelection (sel);

        JOptionPane.showMessageDialog
            (browser,
             sel.getSize () + " regions highlighted in green.",
             "Highlight Replacements",
             JOptionPane.PLAIN_MESSAGE,
             null);
        return doc;
    }
}
