/*
 * LAPIS lightweight structured text processing system
 *
 * Copyright (C) 1998-2002 Carnegie Mellon University,
 * Copyright (C) 2003 Massachusetts Institute of Technology.
 * All rights reserved.
 *
 * This library is free software; you can redistribute it
 * and/or modify it under the terms of the GNU General
 * Public License as published by the Free Software
 * Foundation, version 2.
 *
 * LAPIS homepage: http://graphics.lcs.mit.edu/lapis/
 */

package lapis.swing;

import lapis.*;
import lapisx.swing.*;
import java.awt.event.*;
import java.util.*;

public class ManualMode implements SelectionMode {
    public static lapisx.util.Debug debug = lapisx.util.Debug.QUIET; 

    Browser browser;

    public ManualMode (Browser browser) {
        this.browser = browser;
    }

    public void enteringMode (SelectionMode oldMode) {
    }

    public void leavingMode (SelectionMode newMode) {
    }
    
    public void startMouseSelection () {
    }

    public void stopMouseSelection () {
    }

	public void selectRegion (RegionSet rs) {
		Document doc = browser.getDocument ();
		Region r = rs.getSingleDocRegionSet(doc).getBoundingBox();

		if (debug.printEnabled ())
			debug.print ("select " + r.toStringWithContent ());

		NamedRegionSet sel = browser.getSelection ();
		NamedRegionSet newSel = mergeSelection (sel, r);
		browser.setSelection (newSel);
	}

	public void unselectRegion (RegionSet rs) {
		Document doc = browser.getDocument ();
		Region r = rs.getSingleDocRegionSet(doc).getBoundingBox();

		if (debug.printEnabled ())
			debug.print ("unselect " + r.toStringWithContent ());
        
		NamedRegionSet sel = browser.getSelection ();
		browser.setSelection (new NamedRegionSet (sel.butnot (r)));
	}
	
    public void replaced (NamedRegionSet selection,  NamedRegionSet newSelection, 
                          TransferableSelection mss, String content) {
    }

    public void copied (NamedRegionSet selection) {
    }

    public void undidTo (DocumentVersion oldVersion) {
    }

    public boolean showExampleHighlight () {
        return false;
    }

    public boolean clearSelectionOnClick () {
        return true;
    }

    public NamedRegionSet mergeSelection (NamedRegionSet selection, Region r) {
        Document doc = browser.getDocument ();
        if (selection == null)
			return new NamedRegionSet (r);

		// TODO: support multiple documents
        
        // minwu
		//HashSet vers = new HashSet();
		//vers.add(doc.getVersion());
        
		DocumentVersion selVer = selection.getSingleDocRegionSet(doc).getVersion();
		if (selVer != doc.getVersion())
			selection = (NamedRegionSet)selection.convert(new SingleDocVersions(doc.getVersion()));

        // Don't allow r to overlap any regions in resulting set.
        // To do this, we find all regions in selection that overlap r,
        // remove them, and use them to expand r's boundaries.
        // Then we add r.
        int s = r.getStart ();
        int e = r.getEnd ();

        MutableRegionSet deletions = new MutableRegionSet ();
        RegionEnumeration re = selection.regions ((Region) r.overlaps ());
        for (Region k = re.firstFast (); k != null; k = re.nextFast ()) {
            if (s < k.getEndHigh () && k.getStartLow () < e) {
                debug.println ("deleting overlapping region " + k);
                s = Math.min (s, k.getStartLow ());
                e = Math.max (e, k.getEndHigh ());
                deletions.insert (k);
            }
        }
        
        return 
			new NamedRegionSet (selection.butnot (deletions).or (new Region (s, e, doc.getVersion())));
    }

    /**
     * Action that enters Manual NamedRegionSet mode.
     */
    public static class ManualAction extends AcceleratedAction {
        Browser browser;

        public ManualAction (Browser browser) {
            super ("&Manual",
                   SwingConfig.makeIcon ("stop-simuledit.gif"),
                   'M', KeyEvent.CTRL_MASK,
                   "Manual selection mode");
            this.browser = browser;
        }

        public void actionPerformed (ActionEvent event) {
            browser.setSelectionMode (browser.getManualSelectionMode ());
        }
    }

}

