/*
 * LAPIS lightweight structured text processing system
 *
 * Copyright (C) 1998-2002 Carnegie Mellon University,
 * Copyright (C) 2003 Massachusetts Institute of Technology.
 * All rights reserved.
 *
 * This library is free software; you can redistribute it
 * and/or modify it under the terms of the GNU General
 * Public License as published by the Free Software
 * Foundation, version 2.
 *
 * LAPIS homepage: http://graphics.lcs.mit.edu/lapis/
 */

package lapis.swing;
import java.awt.*;
import java.awt.image.*;
import javax.swing.text.*;

public class OutlierHighlighter extends RegionHighlighter {

    final static Color DEFAULT_SQUIGGLE_COLOR = new Color (244, 0, 0); // red    
    Color squiggleColor;
    Image squiggle;

    public OutlierHighlighter () {
        super ();
        setSquiggleColor (DEFAULT_SQUIGGLE_COLOR);
    }

    public OutlierHighlighter (Highlighter h) {
        super (h);
        setSquiggleColor (DEFAULT_SQUIGGLE_COLOR);
    }



    static int squiggleWidth = 4;
    static int squiggleHeight = 4;
    static int BLANK = 0x00ffffff;
    static int COLOR = 0xfff40000;
    static int[] squiggleData = {
        COLOR, BLANK, BLANK, BLANK,
        COLOR, COLOR, BLANK, COLOR,
        BLANK, COLOR, COLOR, COLOR,
        BLANK, BLANK, COLOR, BLANK,
    };

    public void setSquiggleColor (Color color) {
        squiggleColor = color;

        int argb = 0xff000000 | color.getRGB ();
        int[] recoloredData = replace (squiggleData, 
                                       COLOR,
                                       argb);

        Toolkit tkit = Toolkit.getDefaultToolkit ();
        squiggle = tkit.createImage (
            new MemoryImageSource (squiggleWidth, squiggleHeight, 
                                   recoloredData, 
                                   0, squiggleWidth));
    }

    protected void drawRegionRect (Graphics g, int x, int y, int w, int h) {
        y += h - squiggleHeight;
        w -= endHandleWidth + 2;

        for (; w >= squiggleWidth; x += squiggleWidth, w -= squiggleWidth)
            g.drawImage (squiggle, x, y, null);
    }

    
}
