/*
 * LAPIS lightweight structured text processing system
 *
 * Copyright (C) 1998-2002 Carnegie Mellon University,
 * Copyright (C) 2003 Massachusetts Institute of Technology.
 * All rights reserved.
 *
 * This library is free software; you can redistribute it
 * and/or modify it under the terms of the GNU General
 * Public License as published by the Free Software
 * Foundation, version 2.
 *
 * LAPIS homepage: http://graphics.lcs.mit.edu/lapis/
 */

package lapis.swing;

import java.awt.event.*;
import lapis.*;
import java.util.*;

public class PreserveCase extends TransformAction {
	Browser browser;
    
	String unchangedReplacement;
        String lowerCaseReplacement;
        String upperCaseReplacement;
        String sentenceCaseReplacement;
    
        
	public PreserveCase(Browser browser, String replaceString) {
		super(browser, "PreserveCase");
		this.browser = browser;
		
                unchangedReplacement = replaceString;
                lowerCaseReplacement = replaceString.toLowerCase ();
                upperCaseReplacement = replaceString.toUpperCase ();
                sentenceCaseReplacement = new TransformAction.SentenceCase(browser).transform (replaceString);
	}

	protected String transform(String s) {
            if (s.equals(s.toUpperCase())) {
                //count chars to check number of Letters if 1 -> sentence Case, else UpperCase
                if (countLetters(s) < 2)
                    return sentenceCaseReplacement;
                else
                    return upperCaseReplacement;
            }
            else {
                // if removed word is only lowercased and no special case in replace string
                if (s.equals(s.toLowerCase()))
                    return lowerCaseReplacement;
                // removed word has some special capitalization
                else {
                    int j = 0;
                    while ((Character.isWhitespace(s.charAt(j))) && j < s.length())
                        j++;
                    if (j == s.length())
                        j = 0;
                    //                  // only pay attention if first word is capitalized
                    if (Character.isUpperCase(s.charAt(j)))
                        return sentenceCaseReplacement;
                    else if (!Character.isUpperCase(s.charAt(j)))
                        return lowerCaseReplacement;
                }
            }
            return unchangedReplacement;
	}
	
	protected static int countLetters(String s){
		int count = 0;
		for  (int j = 0; j < s.length(); j++){
			if ((Character.isUpperCase(s.charAt(j))) || (Character.isLowerCase(s.charAt(j))))
				count++;
		}
		return count;
		
	}
}
