/*
 * LAPIS lightweight structured text processing system
 *
 * Copyright (C) 1998-2002 Carnegie Mellon University,
 * Copyright (C) 2003 Massachusetts Institute of Technology.
 * All rights reserved.
 *
 * This library is free software; you can redistribute it
 * and/or modify it under the terms of the GNU General
 * Public License as published by the Free Software
 * Foundation, version 2.
 *
 * LAPIS homepage: http://graphics.lcs.mit.edu/lapis/
 */


package lapis.swing;

import javax.swing.text.*;
import lapis.*;

/**
 * RegionSetStyle: A container for mappings between
 * an arbitrary RegionSet and an associated Style
 *
 * Objects of this class are immutable.
 *
*/
public class RegionSetStyle {
  
  RegionSet r;
  Style s;

  ///////////////////////////////////
  /// Constructors
  //////////////////////////////////

  public RegionSetStyle(RegionSet r, Style s) {
    this.r = r;
    this.s = s;
  }

  public RegionSetStyle(RegionSet r) {
    this(r, new StyleContext().getStyle(StyleContext.DEFAULT_STYLE));
  }
  

  //////////////////////////////////
  /// Accessors
  //////////////////////////////////

  /**
   * Returns the style embedded in this RegionSetStyle.
   */
  public Style getStyle() {
    return s;
  }

  /**
   * Returns the RegionSet associated with this RegionSetStyle.
   */
  public RegionSet getRegionSet() {
    return r;
  }


  /**
   * Tests for equality of two RegionSetStyles.
   */
  public boolean equals(Object o) {
    if(o instanceof RegionSetStyle) {
      return equals((RegionSetStyle)o);
    }
    return false;
  }

  /**
   * Tests for equality of two RegionSetStyles.
   */
  public boolean equals(RegionSetStyle rs) {
    return (this.r.equals(rs.r) &&
	    this.s.equals(rs.s));
  }

  /**
   * Returns a hashcode value for the RegionSetStyle.
   */
  public int hashCode() {
    return(r.hashCode() * s.hashCode());
  }
}
