/*
 * LAPIS lightweight structured text processing system
 *
 * Copyright (C) 1998-2002 Carnegie Mellon University,
 * Copyright (C) 2003 Massachusetts Institute of Technology.
 * All rights reserved.
 *
 * This library is free software; you can redistribute it
 * and/or modify it under the terms of the GNU General
 * Public License as published by the Free Software
 * Foundation, version 2.
 *
 * LAPIS homepage: http://graphics.lcs.mit.edu/lapis/
 */

package lapis.swing;

import lapis.*;
import java.io.*;
import javax.swing.JFileChooser;

public class SaveClusters extends lapis.tools.SaveRegionSet {
    Browser browser;

    public SaveClusters (Browser browser) {
        this.browser = browser;
    }

    public Document invoke (Arguments args) throws Exception {
        File file = null;
        
        args.setUsage (
                       "Usage:\n"
                       + "   save-region-set [filename]      save highlighted region set to filename\n"
                       + "\n"
                       + "Options:\n"
                       + "   -help        Display this message\n"
                       );
        while (args.hasMoreElements ()) {
            String name = args.nextName ();
            if ("filename".equals (name)
                || (name == null && file == null))
                file = new File (args.nextString ());
            else
                args.consume (name);
        }
        
        if (file == null) {
            JFileChooser chooser = FileAction.makeFileChooser (browser, null);
            if (chooser.showSaveDialog (browser) != JFileChooser.APPROVE_OPTION)
                return null;

            file = chooser.getSelectedFile ();
        }

        RegionHighlighter h = browser.getActivePane ().getFinderHighlighter();
        RegionSet r = h.getSelection ().convertToLatest ();

        super.save (file, r);

        browser.setStatus ("Region set saved.");

        return null;
    }
}
