/*
 * LAPIS lightweight structured text processing system
 *
 * Copyright (C) 1998-2002 Carnegie Mellon University,
 * Copyright (C) 2003 Massachusetts Institute of Technology.
 * All rights reserved.
 *
 * This library is free software; you can redistribute it
 * and/or modify it under the terms of the GNU General
 * Public License as published by the Free Software
 * Foundation, version 2.
 *
 * LAPIS homepage: http://graphics.lcs.mit.edu/lapis/
 */

package lapis.swing;

import lapis.*;
import lapis.tc.*;
import javax.swing.*;

public class ScrollTo implements Tool {
    Browser browser;

    public ScrollTo (Browser browser) {
        this.browser = browser;
    }

    public Document invoke (Arguments args) throws Exception {
        TC pat = null;

        args.setUsage (
                       "Usage:\n"
                       + "   scrollto <pattern>     scroll window to make a match to <pattern>\n"
                       + "                          visible\n"
                       + "\n"
                       + "Options:\n"
                       + "   -help        Display this message\n"
                       );
        while (args.hasMoreElements ()) {
            String name = args.nextName ();
            if ("query".equals (name)
                || (name == null && pat == null))
                pat = args.nextPattern ();
            else
                args.consume (name);
        }

        if (pat == null)
            args.usage ();

        RegionSet s = pat.match (browser.getDocument ());
        final Region r = s.regions ().first ();

        if (r != null)
            SwingUtilities.invokeLater (new Runnable () {
                    public void run () {
                        browser.getActivePane ().scrollRegionToVisible (r);
                    }
                });
        return null;
    }
}
