/*
 * LAPIS lightweight structured text processing system
 *
 * Copyright (C) 1998-2002 Carnegie Mellon University,
 * Copyright (C) 2003 Massachusetts Institute of Technology.
 * All rights reserved.
 *
 * This library is free software; you can redistribute it
 * and/or modify it under the terms of the GNU General
 * Public License as published by the Free Software
 * Foundation, version 2.
 *
 * LAPIS homepage: http://graphics.lcs.mit.edu/lapis/
 */

package lapis.swing;

import lapis.*;

/**
 * NamedRegionSet behavior for Browser.  The selection mode determines what
 * happens when the user adds or removes regions from the selection.
 * Normal mode does nothing beyond the add/remove, but inference modes
 * use the added or removed region as an example to change the inferred
 * selection.
 */
public interface SelectionMode {

    /**
     * Called by a browser when the browser enters this selection mode.
     * @param oldMode browser's previous selection mode
     */
    public void enteringMode (SelectionMode oldMode);

    /**
     * Called by a browser when browser leaves this selection mode.
     * @param newMode selection mode that browser is entering
     */
    public void leavingMode (SelectionMode newMode);

    public void startMouseSelection ();
    public void stopMouseSelection ();

    //public void selectRegion (Region r);
    //public void unselectRegion (Region r);
	public void selectRegion (RegionSet rs);
	public void unselectRegion (RegionSet rs);

    public void replaced (NamedRegionSet selection, NamedRegionSet newSelection, 
                          TransferableSelection mss,
                          String content);
    public void copied (NamedRegionSet selection);
    public void undidTo (DocumentVersion oldVersion);

    public boolean showExampleHighlight ();
    public boolean clearSelectionOnClick ();
}
