/*
 * LAPIS lightweight structured text processing system
 *
 * Copyright (C) 1998-2002 Carnegie Mellon University,
 * Copyright (C) 2003 Massachusetts Institute of Technology.
 * All rights reserved.
 *
 * This library is free software; you can redistribute it
 * and/or modify it under the terms of the GNU General
 * Public License as published by the Free Software
 * Foundation, version 2.
 *
 * LAPIS homepage: http://graphics.lcs.mit.edu/lapis/
 */

package lapis.swing;

import lapis.*;
import java.io.*;
import javax.swing.text.*;

/**
 * A SwingDocument is both a LAPIS document and a Swing JEditorPane document.
 */
public interface SwingDocument extends javax.swing.text.Document, lapis.Document {

    /**
     * Property name for read-only documents (HTML pages that have a
     * &lt;META name="read-only" content=""&gt; tag; used for tutorial
     * and help pages).
     */
    public final static String ReadOnlyProperty = "read-only";

    /**
      * Incrementally load document from its stream.
      */
    public boolean load (EditorKit kit);

    public boolean isLoaded ();

    /**
      * Factory for creating SwingDocuments.
      */

    public static class Factory extends DocumentFactory {
        public lapis.Document make (Reader in, String contentType) throws IOException {
            return ("text/html".equals (contentType))
                ? (SwingDocument)new HTMLDocument (this, in)
                : (SwingDocument)new PlainDocument (this, in);
        }
        
        public lapis.Document make (String content, String contentType) {
            try {
                return make (new StringReader (content), contentType);
            } catch (IOException e) {
                throw new RuntimeException (e.toString ()); // shouldn't happen
            }
        }
        
        public lapis.Document make (lapis.Document src, String contentType) {
            if (contentType == null)
                contentType = (String) src.getProperty (src.MIMEProperty);
            return ("text/html".equals (contentType))
                ? (SwingDocument)new HTMLDocument (this, src)
                : (SwingDocument)new PlainDocument (this, src, contentType);
        }
    }


    /**
     * Factory for creating SwingDocuments.
     */
    public static final DocumentFactory defaultFactory = new Factory ();

	//public DocumentView getCookedView ();

}
