/*
 * LAPIS lightweight structured text processing system
 *
 * Copyright (C) 1998-2002 Carnegie Mellon University,
 * Copyright (C) 2003 Massachusetts Institute of Technology.
 * All rights reserved.
 *
 * This library is free software; you can redistribute it
 * and/or modify it under the terms of the GNU General
 * Public License as published by the Free Software
 * Foundation, version 2.
 *
 * LAPIS homepage: http://graphics.lcs.mit.edu/lapis/
 */

package lapis.swing;
import java.awt.*;
import java.awt.event.*;
import javax.swing.*;
import javax.swing.border.*;
import javax.swing.plaf.*;
import javax.swing.plaf.metal.*;
import lapisx.swing.*;
import javax.swing.undo.*;

public class TCComboBox extends JComboBox {
    public static lapisx.util.Debug debug = lapisx.util.Debug.QUIET;

    public TCComboBox (boolean editable, boolean scrollable) {
        init (editable, scrollable);
    }

    public TCComboBox (ComboBoxModel model, boolean editable, boolean scrollable) {
        super (model);
        init (editable, scrollable);
    }

    void init (boolean editable, boolean scrollable) {
        setEditable (true);

        Editor editor = new Editor (editable, scrollable);
        setEditor (editor);
        setRenderer (new Renderer ());
        setFont (new Font ("Monospaced", Font.PLAIN, 12));
        setMinimumSize (new Dimension (0, 0));
        setMaximumSize (new Dimension (Integer.MAX_VALUE, Integer.MAX_VALUE));

        if (editable)
            CoalescingUndo.setUndoableEditListener 
                (editor.getDocument (), new UndoManager ());
    }

    public void setUI (ComboBoxUI newUI) {
        super.setUI (new TCComboBoxUI ());
    }

    static Border noFocusBorder = new EmptyBorder(1, 1, 1, 1); 

    static class Renderer extends TCEditor implements ListCellRenderer {
        public Renderer () {
            super (true, false);
            super.setEditable (false);
        }
        public Component getListCellRendererComponent(JList list,
                                                      Object value,
                                                      int index,
                                                      boolean isSelected,
                                                      boolean hasFocus) {
            TCComboBox.debug.println ("rendering " + value);
            setText (value != null ? value.toString () : "");
            
            if (isSelected) {
                super.setForeground(list.getSelectionForeground());
                super.setBackground(list.getSelectionBackground());
            }
            else {
                super.setForeground(list.getForeground());
                super.setBackground(list.getBackground());
            }
	
            if (hasFocus) {
                setBorder(UIManager.getBorder("List.focusCellHighlightBorder"));
            } else {
                setBorder(noFocusBorder);
            }

            return this;
        }
    }

    static class Editor extends TCEditor implements ComboBoxEditor {
        Component component;
        
        public Editor (boolean editable, boolean scrollable) {
            super (true);
            super.setEditable (editable);

            component = (scrollable) 
                ? (Component) new JScrollPane (this)
                : (Component) this;
        }

        // ComboBoxEditor interface
        Object value;

        public void addActionListener (ActionListener l) {
        }

        public void removeActionListener (ActionListener l) {
        }

        public Component getEditorComponent () {
            return component;
        }

        public Object getItem () {
            return value;
        }

        public void setItem (Object value) {
            this.value = value;
            if (value != null)
                setText (value.toString ());
        }
    }
}

class TCComboBoxUI extends MetalComboBoxUI {

    protected LayoutManager createLayoutManager() {
        return new TCComboBoxLayoutManager();
    }

    public void doLayoutContainer(Container parent) {
        JComboBox cb = (JComboBox)parent;
        int width = cb.getWidth();
        int height = cb.getHeight();
        Insets insets = cb.getInsets();
        int buttonHeight = height - (insets.top + insets.bottom);
        int buttonWidth = Math.min (buttonHeight, 50);
        Rectangle cvb;

        if ( arrowButton != null ) {
            arrowButton.setBounds( width - (insets.right + buttonWidth),
                                   insets.top,
                                   buttonWidth, buttonHeight);
        }
        if ( editor != null ) {
            cvb = rectangleForCurrentValue();
            editor.setBounds(cvb);
        }
    }
            
    class TCComboBoxLayoutManager extends MetalComboBoxLayoutManager {
        public void layoutContainer(Container parent) {
            doLayoutContainer (parent);
        }
    }
}


