/*
 * LAPIS lightweight structured text processing system
 *
 * Copyright (C) 1998-2002 Carnegie Mellon University,
 * Copyright (C) 2003 Massachusetts Institute of Technology.
 * All rights reserved.
 *
 * This library is free software; you can redistribute it
 * and/or modify it under the terms of the GNU General
 * Public License as published by the Free Software
 * Foundation, version 2.
 *
 * LAPIS homepage: http://graphics.lcs.mit.edu/lapis/
 */

package lapis.swing;

import lapis.*;
import lapis.tc.*;
import java.awt.event.*;
import java.io.*;
import javax.swing.*;
import javax.swing.filechooser.FileFilter;
import lapisx.swing.*;
import lapisx.util.Str;


public class TCFileEditor extends FileEditorPanel {
    Browser browser;    // browser where TC patterns should be evaluated

    public TCFileEditor (Browser browser) {
	super(new TCEditor (false));

        this.browser = browser;
        
	// set the font
        try {
            FontUtil.resizeFont (getEditor (), SwingConfig.getFontSize ());
        } catch (NumberFormatException e) {}

        // Extend the toolbar to include a file "menu" (actually a 
	// combo box), a Go button, a Close button, and a Select Color
	// button
        JToolBar toolbar = getToolBar ();
	addFileMenu();
        toolbar.add (goAction);
	toolbar.add (closeAction);
    }


    protected FileChooser makeFileChooser () {
        FileChooser chooser = super.makeFileChooser ();
        chooser.addChoosableFileFilter (tcFileFilter);
        chooser.setFileFilter (tcFileFilter);
        return chooser;
   }

    static final FileFilter tcFileFilter = new FileFilter () {
            public boolean accept (File f) {
                return f.isDirectory() || f.toString().endsWith (".tc");
            }
            public String getDescription () {
                return "Text constraint files (*.tc)";
            }
        };


    protected void handleInteractiveException (Exception e) {
        FeedbackForm.showExceptionDialog (browser, e);
    }


    /**
     * Get browser with which this TCFileEditor is associated.
     * @return browser 
     */
    public Browser getBrowser () {
        return browser;
    }


    /**
     * Set the editor contents.
     */
    public void setText (String text) {
        super.setText (Str.untabify (text, 8));
    }


    /**
     * Interpret the editor contents as a TC system.  Pops up a 
     * dialog box if an error occurs.
     * @return TC parsed from editor contents
     */
    public TC getTC () throws TCParseException {
        TC sys = PatternPane.makeTCFromTextComponent (getEditor (), false);
        return sys;
    }


    /**
     * Action invoked by Go command.  Parses the associated
     * browser using the editor's contents as a TC.
     */
    Action goAction = new AcceleratedAction ("&Go", KeyEvent.VK_ENTER, 
					     KeyEvent.CTRL_MASK) {
        public void actionPerformed (ActionEvent evt) {
            Browser browser = getBrowser ();
            if (browser == null)
                return;
                
            try {
                Parser parser = getTC ();
                parser.bind (browser.getPatternLibrary ());
            } catch (TCParseException e) {
                FeedbackForm.showExceptionDialog (browser, e);
            }
        }
    };


    /**
     * Action invoked by the Close command.  Closes the sidebar tab 
     * containing this.
     */
    public Action closeAction = new AcceleratedAction ("&Close") {
        public void actionPerformed (ActionEvent evt) {
            Browser browser = getBrowser ();

            if (browser == null)
                return;

	    browser.closeTCEditor();
        }
    };
}

