/*
 * LAPIS lightweight structured text processing system
 *
 * Copyright (C) 1998-2002 Carnegie Mellon University,
 * Copyright (C) 2003 Massachusetts Institute of Technology.
 * All rights reserved.
 *
 * This library is free software; you can redistribute it
 * and/or modify it under the terms of the GNU General
 * Public License as published by the Free Software
 * Foundation, version 2.
 *
 * LAPIS homepage: http://graphics.lcs.mit.edu/lapis/
 */

package lapis.swing;

import java.awt.event.*;
import java.io.*;
import javax.swing.*;
import javax.swing.filechooser.FileFilter;
import lapisx.swing.*;


public class TclFileEditor extends FileEditorPanel {
    Browser browser;    // browser where TC patterns should be evaluated

    public TclFileEditor (Browser browser) {
        super ();

        this.browser = browser;

        // Set the font
        try {
            FontUtil.resizeFont (getEditor (), SwingConfig.getFontSize ());
        } catch (NumberFormatException e) {}

        // Extend the toolbar to include a file "menu" (actually a 
	// combo box), a Run button, and a Close button
        JToolBar toolbar = getToolBar ();
	addFileMenu();
        toolbar.add (runNowAction);
	toolbar.add (closeAction);
    }


    protected FileChooser makeFileChooser () {
        FileChooser chooser = super.makeFileChooser ();
        chooser.addChoosableFileFilter (tclFileFilter);
        chooser.setFileFilter (tclFileFilter);
        return chooser;
    }


    static final FileFilter tclFileFilter = new FileFilter () {
            public boolean accept (File f) {
                return f.isDirectory() || f.toString().endsWith (".tcl");
            }
            public String getDescription () {
                return "Tcl scripts (*.tcl)";
            }
        };


    /**
     * Get browser with which this TclFileEditor is associated.
     * @return browser 
     */
    public Browser getBrowser () {
        return browser;
    }


    /**
     * Set editor contents from a string.  Sets dirty flag if 
     * new contents are not "".
     */
    public void setText (String contents) {
        super.setText (contents);
        if (contents.length () > 0)
            setDirty (false);
    }


    /**
     * Action invoked by Run Now command.  Evaluates the
     * script in the associated browser.
     */
    public Action runNowAction = new AcceleratedAction ("&Run") {
        public void actionPerformed (ActionEvent evt) {
            Browser browser = getBrowser ();
            if (browser == null)
                return;
            browser.eval (getText ());
        }
    };


    /**
     * Action invoked by the Close command.  Closes the sidebar tab 
     * containing this.
     */
    public Action closeAction = new AcceleratedAction ("&Close") {
        public void actionPerformed (ActionEvent evt) {
            Browser browser = getBrowser ();

            if (browser == null)
                return;

	    browser.closeTclEditor();
        }
    };


    /**
     * Action invoked by Optimize command.  Eliminates dead
     * commands from the script.
     */
    public Action optimizeAction = new AcceleratedAction ("&Optimize") {
        public void actionPerformed (ActionEvent evt) {
            String script = getText ();
            script = lapis.tcl.Optimizer.optimizeDeadURLs (script);
            script = lapis.tcl.Optimizer.optimizeFormSubmits (script);
            setText (script);
        }
    };
}
