/*
 * LAPIS lightweight structured text processing system
 *
 * Copyright (C) 1998-2002 Carnegie Mellon University,
 * Copyright (C) 2003 Massachusetts Institute of Technology.
 * All rights reserved.
 *
 * This library is free software; you can redistribute it
 * and/or modify it under the terms of the GNU General
 * Public License as published by the Free Software
 * Foundation, version 2.
 *
 * LAPIS homepage: http://graphics.lcs.mit.edu/lapis/
 */

package lapis.swing;

import lapis.*;
import java.io.*;
import java.util.*;
import java.awt.datatransfer.*;

class TransferableSelection extends NamedRegionSet implements Transferable {

    Vector v = new Vector ();
    DataFlavor[] flavors;

    public static final DataFlavor multiStringFlavor = 
        new DataFlavor ("application/x-vector-of-strings", "strings");

    static final DataFlavor[] STRING_FLAVORS = {
        DataFlavor.stringFlavor,
        multiStringFlavor
    };
    static final DataFlavor[] MULTI_FLAVORS = {
        multiStringFlavor
    };

	public TransferableSelection (NamedRegionSet sel) {
		super (sel);
        Iterator idoc = sel.getDocuments();
		while (idoc.hasNext()) {
			Document doc = (Document)idoc.next();
			DocumentView view = doc.getCookedView();
			RegionSet s = view.getVersion().convert(sel.getSingleDocRegionSet(doc));
		
			RegionEnumeration re = s.regions ();
			for (Region r = re.firstFast (); r != null; r = re.nextFast ())
				v.addElement (view.getText(r));
		}

		flavors = (v.size () <= 1) ? STRING_FLAVORS : MULTI_FLAVORS;
	}

    public Object getTransferData (DataFlavor flavor) throws UnsupportedFlavorException, IOException {
        if (flavor.equals (DataFlavor.stringFlavor))
            switch (v.size ()) {
            case 0:
                return "";
            case 1:
                return (String) v.elementAt (0);
            default:
                throw new UnsupportedFlavorException (flavor);
            }
        else if (flavor.equals (multiStringFlavor))
            return this;
        else
            throw new UnsupportedFlavorException (flavor);
    }

    public DataFlavor[] getTransferDataFlavors () {
        return flavors;
    }

    public boolean isDataFlavorSupported (DataFlavor flavor) {
        for (int i = 0; i < flavors.length; ++i)
            if (flavor.equals (flavors[i]))
                return true;
        return false;
    }

    public Vector getStrings () {
        return v;
    }
}

    
