/*
 * LAPIS lightweight structured text processing system
 *
 * Copyright (C) 1998-2002 Carnegie Mellon University,
 * Copyright (C) 2003 Massachusetts Institute of Technology.
 * All rights reserved.
 *
 * This library is free software; you can redistribute it
 * and/or modify it under the terms of the GNU General
 * Public License as published by the Free Software
 * Foundation, version 2.
 *
 * LAPIS homepage: http://graphics.lcs.mit.edu/lapis/
 */
package lapis.swing.cluster;
import javax.swing.tree.*;
import javax.swing.event.*;
import lapis.swing.cluster.MatchNodeCreator.Node;

public abstract class AbstractTreeTableModel
	extends DefaultTreeModel
	implements TreeTableModel {
	protected Object root;
	protected EventListenerList listenerList = new EventListenerList();
	public static lapisx.util.Debug debug = lapisx.util.Debug.QUIET;

	public AbstractTreeTableModel(Node root) {
		super(root);
		this.root = root;
	}

	//
	// Default implmentations for methods in the TreeModel interface. 
	//

	public Object getRoot() {
		return root;
	}

	public void setRoot(Node node) {
		super.setRoot(node);
		root = node;
	}
	public boolean isLeaf(Object node) {
		return getChildCount(node) == 0;
	}

	public void valueForPathChanged(TreePath path, Object newValue) {
	}

	// This is not called in the JTree's default mode: use a naive implementation. 
	public int getIndexOfChild(Object parent, Object child) {
		for (int i = 0; i < getChildCount(parent); i++) {
			if (getChild(parent, i).equals(child)) {
				return i;
			}
		}
		return -1;
	}

	public void addTreeModelListener(TreeModelListener l) {
		listenerList.add(TreeModelListener.class, l);
	}

	public void removeTreeModelListener(TreeModelListener l) {
		listenerList.remove(TreeModelListener.class, l);
	}
	/*
	 * Notify all listeners that have registered interest for
	 * notification on this event type.  The event instance 
	 * is lazily created using the parameters passed into 
	 * the fire method.
	 * @see EventListenerList
	 */
	public void fireTreeNodesChanged(
		Object source,
		Object[] path,
		int[] childIndices,
		Object[] children) {
		debug.println("nodes changed");
		// Guaranteed to return a non-null array
		Object[] listeners = listenerList.getListenerList();
		TreeModelEvent e = null;
		// Process the listeners last to first, notifying
		// those that are interested in this event
		for (int i = listeners.length - 2; i >= 0; i -= 2) {
			if (listeners[i] == TreeModelListener.class) {
				// Lazily create the event:
				if (e == null)
					e =
						new TreeModelEvent(
							source,
							path,
							childIndices,
							children);
				((TreeModelListener) listeners[i + 1]).treeNodesChanged(e);
			}
		}
	}

	/*
	 * Notify all listeners that have registered interest for
	 * notification on this event type.  The event instance 
	 * is lazily created using the parameters passed into 
	 * the fire method.
	 * @see EventListenerList
	 */
	public void fireTreeNodesInserted(
		Object source,
		Object[] path,
		int[] childIndices,
		Object[] children) {
		debug.println("nodes inserted");
		// Guaranteed to return a non-null array
		Object[] listeners = listenerList.getListenerList();
		TreeModelEvent e = null;
		// Process the listeners last to first, notifying
		// those that are interested in this event
		for (int i = listeners.length - 2; i >= 0; i -= 2) {
			if (listeners[i] == TreeModelListener.class) {
				// Lazily create the event:
				if (e == null)
					e =
						new TreeModelEvent(
							source,
							path,
							childIndices,
							children);
				((TreeModelListener) listeners[i + 1]).treeNodesInserted(e);
			}
		}
	}

	/*
	 * Notify all listeners that have registered interest for
	 * notification on this event type.  The event instance 
	 * is lazily created using the parameters passed into 
	 * the fire method.
	 * @see EventListenerList
	 */
	public void fireTreeNodesRemoved(
		Object source,
		Object[] path,
		int[] childIndices,
		Object[] children) {
		debug.println("nodes removed");
		// Guaranteed to return a non-null array
		Object[] listeners = listenerList.getListenerList();
		TreeModelEvent e = null;
		// Process the listeners last to first, notifying
		// those that are interested in this event
		for (int i = listeners.length - 2; i >= 0; i -= 2) {
			if (listeners[i] == TreeModelListener.class) {
				// Lazily create the event:
				if (e == null)
					e =
						new TreeModelEvent(
							source,
							path,
							childIndices,
							children);
				((TreeModelListener) listeners[i + 1]).treeNodesRemoved(e);
			}
		}
	}

	/*
	 * Notify all listeners that have registered interest for
	 * notification on this event type.  The event instance 
	 * is lazily created using the parameters passed into 
	 * the fire method.
	 * @see EventListenerList
	 */
	public void fireTreeStructureChanged(
		Object source,
		Object[] path,
		int[] childIndices,
		Object[] children) {
		debug.println("structure changed");
		// Guaranteed to return a non-null array
		Object[] listeners = listenerList.getListenerList();
		TreeModelEvent e = null;
		// Process the listeners last to first, notifying
		// those that are interested in this event
		for (int i = listeners.length - 2; i >= 0; i -= 2) {
			if (listeners[i] == TreeModelListener.class) {
				// Lazily create the event:
				if (e == null)
					e =
						new TreeModelEvent(
							source,
							path,
							childIndices,
							children);
				((TreeModelListener) listeners[i + 1]).treeStructureChanged(e);
			}
		}
	}

	//
	// Default impelmentations for methods in the TreeTableModel interface. 
	//

	public Class getColumnClass(int column) {
		return Object.class;
	}

	/** By default, make the column with the Tree in it the only editable one. 
	 *  Making this column editable causes the JTable to forward mouse 
	 *  and keyboard events in the Tree column to the underlying JTree. 
	 */
	public boolean isCellEditable(Object node, int column) {
		return getColumnClass(column) == TreeTableModel.class;
	}

	public void setValueAt(Object aValue, Object node, int column) {
	}



	/* 
	 *   public Object getChild(Object parent, int index)
	 *   public int getChildCount(Object parent) 
	 *   public int getColumnCount() 
	 *   public String getColumnName(Object node, int column)  
	 *   public Object getValueAt(Object node, int column) 
	 */

}
