/*
 * LAPIS lightweight structured text processing system
 *
 * Copyright (C) 1998-2002 Carnegie Mellon University,
 * Copyright (C) 2003 Massachusetts Institute of Technology.
 * All rights reserved.
 *
 * This library is free software; you can redistribute it
 * and/or modify it under the terms of the GNU General
 * Public License as published by the Free Software
 * Foundation, version 2.
 *
 * LAPIS homepage: http://graphics.lcs.mit.edu/lapis/
 */

package lapis.swing.cluster;

import lapis.*;
import lapis.tc.*;
import lapis.swing.*;
import java.awt.*;
import java.awt.event.*;
import java.util.*;
import javax.swing.*;
import javax.swing.event.*;
import lapisx.swing.*;
import javax.swing.undo.*;

/**
 * A Cluster-Based Find and Replace Pane a side panel in LAPIS
 *
 * <p>
 *
 **/

public class ClusterFindReplacePane extends JPanel implements StateEditable {

    public static lapisx.util.Debug debug = lapisx.util.Debug.QUIET;
    Browser browser;
    private JButton closeButton,
        findAllButton,
        replaceButton,
        undoButton,
        selectButton,
        unselectButton;
    private JTextField findText, replaceText;
    private JCheckBox matchCase, wholeWord, clusterBox;
    private ButtonGroup matchDisplayFormat;
    private JRadioButton tableFormat, treeFormat;
    private MatchDisplayPanel matchDisplayPanel;
    private JPanel matchPanel;
    private boolean caseSensitive = false;
    private boolean wordMatch = false;
    static public boolean cluster = true;
    private boolean showProp = false;
    static public boolean tree = true;
    private JLabel replacementsSelected, replacementsHighlighted, replaceWith;
    private int highlighted;
    private UndoManager undoManager;

    //private JButton lexParseButton;

    /** 
     * 
     * @effects constructs a new blank Find and Replace Dialog with all buttons, except for the 
     * close button, disabled
     **/

    public ClusterFindReplacePane(Browser browser) {
        super();
        this.browser = browser;
        undoManager = new UndoManager();

        highlighted = 0;
        Document doc = browser.getDocument();
        NamedRegionSet sel = browser.getSelection();
        Region r;
        RegionEnumeration findEnumerator = sel.regions();
        r = findEnumerator.first();
        String textToFind = "";
        if (r != null) {
            textToFind = doc.getText(r);
        }

        matchDisplayFormat = new ButtonGroup();
        matchDisplayPanel = new MatchTreePanel();
        matchPanel = new JPanel();
        clusterBox = ActionAdapters.toCheckBox(clusterAction);
        treeFormat =
            ActionAdapters.toRadioButton(treeFormatAction, matchDisplayFormat);
        tableFormat =
            ActionAdapters.toRadioButton(tableFormatAction, matchDisplayFormat);
        undoButton = ActionAdapters.toButton(undoAction);

        Layout.vertical(this)
            .setContainerInsets(5, 5, 5, 5)
            .add(Layout.horizontal()
                    .setContainerInsets(0, 0, 2, 0)
                    .setAlignment(Layout.NORTH)
                    .add(new JLabel("Find What: "), Layout.FIXED_SIZE)
                    .add(Layout.vertical()
                            .setAlignment(Layout.WEST)
                            .add(findText = new JTextField(textToFind), Layout.FIXED_HEIGHT)
                        .add(Layout.horizontal()
                                .add(
                                    matchCase =
                                        ActionAdapters.toCheckBox(caseAction))
                                .add(
                                    wholeWord =
                                        ActionAdapters.toCheckBox(wordAction))
                                .done())
                        .add(
                            Layout
                            .horizontal()
                            .add(
                                findAllButton =
                                    ActionAdapters.toButton(findAllAction),
                                Layout.FIXED_SIZE)
                    //.add(lexParseButton = ActionAdapters.toButton(lexParseAction), Layout.FIXED_SIZE)
                        // 			   .add(properties = ActionAdapters.toTinyButton(propertiesAction), Layout.FIXED_SIZE)
                        // 			   .add(clusterBox = ActionAdapters.toCheckBox (clusterAction))
                        // 			   .add(Layout.vertical()
                        // 				.add(treeFormat = ActionAdapters.toRadioButton(treeFormatAction, matchDisplayFormat))
                        // 				.add(tableFormat = ActionAdapters.toRadioButton(tableFormatAction, matchDisplayFormat))
                        // 				.done())
                    .done()).done(),
                        Layout.FIXED_HEIGHT).done(),
                        Layout
                            .FIXED_HEIGHT)
                            .add(
                                Layout
                                    .horizontal()
                                    .setContainerInsets(2, 0, 2, 0)
                                    .setAlignment(Layout.CENTER)
                                    .add(
                                        Layout
                                            .vertical()
                                            .setAlignment(Layout.EAST)
                                            .setContainerInsets(10, 0, 0, 0)
                                            .add(
                                                Layout
                                                    .horizontal()
                                                    .add(
                                                        replacementsHighlighted =
                                                            new JLabel("total matches shown"))
                                                    .addGlue ()
                                                    .add(
                                                        Layout
                                                            .horizontal()
                                                            .setContainerInsets(
                                                                2,
                                                                5,
                                                                2,
                                                                0)
                                                            .setAlignment(
                                                                Layout.CENTER)
                                                            .setSize(
                                                                Layout
                                                                    .FIXED_SIZE)
                                                            .addGlue()
                                                            .add(
                                                                selectButton =
                                                                    ActionAdapters
                                                                        .toTinyButton(
                                                                        selectAction),
                                                                Layout
                                                                    .FIXED_HEIGHT)
                                                            .add(
                                                                unselectButton =
                                                                    ActionAdapters
                                                                        .toTinyButton(
                                                                        unselectAction),
                                                                Layout
                                                                    .FIXED_HEIGHT)
                                                            .addGlue()
                                                            .done(),
                                                        Layout.FIXED_WIDTH,
                                                        Layout.CENTER)
                                                    .done())
                                            .add(matchPanel)
                                            .done())
                                    .done())
                            .add(
                                Layout.gridbag ()
                                    .setContainerInsets(2, 0, 2, 0)
                                    .setAlignment(Layout.NORTH)
                                    .nextColumn ()
                                    .add(replacementsSelected =
                                                    new JLabel("matches selected for replacement"))
                                    .nextRow ()
                                    .add(replaceWith = new JLabel("Replace With: "),
                                            Layout.FIXED_SIZE)
                                    .add(Layout.vertical()
                                            .add(replaceText = new JTextField(),
                                                    Layout.FIXED_HEIGHT)
                                            .add(Layout.horizontal()
                                                    .setContainerInsets(2, 0, 2, 0)
                                                    .setAlignment(Layout.NORTHWEST)
                                                    .setSize(Layout.FIXED_SIZE)
                                                    .add(replaceButton = ActionAdapters.toButton (replaceAction))
                                                    .add(undoButton = ActionAdapters.toButton(undoAction))
                                                    .addGlue()
                                                    .done(),
                                                    Layout.FIXED_HEIGHT)
                                            .done(),
                                            Layout.FIXED_HEIGHT)
                                    .done())
                            .addGlue()
                            .add(
                                Layout
                                    .horizontal()
                                    .setContainerInsets(2, 0, 0, 0)
                                    .setAlignment(Layout.NORTHEAST)
                                    .addGlue()
                                    .add(
                                        closeButton =
                                            ActionAdapters.toButton(
                                                closeAction),
                                        Layout.FIXED_SIZE)
                                    .done(),
                                Layout.FIXED_HEIGHT)
                            .done();

                replacementsHighlighted.setVisible(false);
                replacementsSelected.setVisible(false);
                matchPanel.setVisible(false);
                selectButton.setVisible(false);
                unselectButton.setVisible(false);
                replaceWith.setVisible(false);
                replaceText.setVisible(false);
                replaceButton.setVisible(false);
                undoButton.setVisible(false);
                treeFormat.setSelected(tree);
                tableFormat.setSelected(!tree);
                clusterBox.setVisible(showProp);
                treeFormat.setVisible(showProp);
                tableFormat.setVisible(showProp);

                findText.getDocument().addDocumentListener(
            new JTextListener(findAllButton));

        if (findText.getText().equals("")) {
            findAllButton.setEnabled(false);
        }
        findText.getInputMap().put(KeyStroke.getKeyStroke("ENTER"), "FindAll");
        findText.getActionMap().put("FindAll", findAllAction);
        replaceText.getInputMap().put(
            KeyStroke.getKeyStroke("ENTER"),
            "Replace");
        replaceText.getActionMap().put("Replace", replaceAction);

        setupListeners();
        if (!undoManager.canUndo())
            undoButton.setEnabled(false);
    }

    private void setupListeners() {
        // NamedRegionSet Listener

        browser.addSelectionListener(new SelectionListener() {
            public void changedSelection(Browser browser, NamedRegionSet sel) {
                debug.println("*** selection changed");
                setSelectedText(sel.getSize());
                if (!ClusterFindReplacePane.this.componentHasFocus())
                    if (matchDisplayPanel.findNodeMatch(sel) == null)
                        replaceButton.setEnabled(false);
            }
        });

        // Browser Listener
        browser.addBrowserListener(new BrowserListener() {

            public void loadedDocument(Browser browser, SwingDocument doc) {
                debug.println("*** loaded document");
            }

            public void loadingDocument(Browser browser, SwingDocument doc) {
                debug.println("*** loading document");
                resetState();
            }
        });
        //		browser.addFocusListener(new FocusListener() {
        //			public void focusGained(FocusEvent e) {
        //				debug.println("gained focus");
        //				replaceButton.setEnabled(false);
        //			}
        //			public void focusLost(FocusEvent e) {
        //				debug.println("focus lost");
        //			}
        //		});
    }

    /** 
     * Listener attached to a JTextField
     * 
     **/
    private class JTextListener implements DocumentListener {
        JButton b;
        Action a;

        public JTextListener(Action a, JButton b) {
            this.b = b;
            this.a = a;
        }
        public JTextListener(JButton b) {
            this.b = b;
        }

        public void changedUpdate(DocumentEvent e) {
            debug.println("action performed on Find text");

        }
        public void insertUpdate(DocumentEvent e) {
            //	     debug.println(findText.getText()+":");
            b.setEnabled(true);
        }
        public void removeUpdate(DocumentEvent e) {
            //	     debug.println(findText.getText()+".");
            if (e.getDocument().getLength() == 0) {
                b.setEnabled(false);
            }
        }
    }

    //undoable stuff

    public void restoreState(Hashtable state) {
        debug.println("savedState: " + state.toString());
        if (state.get("replacementsHighlighted") != null)
            highlighted =
                ((Integer) state.get("replacementsHighlighted")).intValue();
        setHighlightedText(highlighted);

    }
    public void storeState(Hashtable state) {
        state.put("replacementsHighlighted", new Integer(highlighted));
    }

    /**
     * returns true if some component within this panel has focus
     **/

    public boolean componentHasFocus() {
        return (
            closeButton.hasFocus()
                || findAllButton.hasFocus()
                || replaceButton.hasFocus()
                || undoButton.hasFocus()
                || selectButton.hasFocus()
                || unselectButton.hasFocus()
                || findText.hasFocus()
                || replaceText.hasFocus()
                || matchCase.hasFocus()
                || wholeWord.hasFocus()
                || clusterBox.hasFocus()
                || tableFormat.hasFocus()
                || treeFormat.hasFocus()
                || matchDisplayPanel.componentHasFocus());
    }

    static public void setProperties(boolean treeB, boolean clusterB) {
        tree = treeB;
        cluster = clusterB;
    }

    public Action caseAction = new AcceleratedAction("&Match Case") {
        public void actionPerformed(ActionEvent evt) {
            caseSensitive = !caseSensitive;
            debug.println("case sensitive " + caseSensitive);

        }
    };

    public Action lexParseAction =
        new AcceleratedAction("&Lexical Attraction Parse") {
        public void actionPerformed(ActionEvent evt) {
            LexicalAttractionParser.run(browser.getDocument());

        }
    };

    public Action propertiesAction = new AcceleratedAction("&Change Prop") {
        public void actionPerformed(ActionEvent evt) {
            showProp = !showProp;
            clusterBox.setVisible(showProp);
            treeFormat.setVisible(showProp);
            tableFormat.setVisible(showProp);
        }
    };

    public Action wordAction =
        new AcceleratedAction("&Find Whole Words Only") {
        public void actionPerformed(ActionEvent evt) {
            wordMatch = !wordMatch;
            debug.println("matchWord " + wordMatch);
        }
    };
    public Action clusterAction = new AcceleratedAction("&Cluster Results") {
        public void actionPerformed(ActionEvent evt) {
            cluster = !cluster;
            debug.println("cluster " + cluster);
        }
    };
    /**
     * finds and highlights all matches to search pattern. 
     * populates Match/Description pane
     **/

    public Action findAllAction = new AcceleratedAction("&Find All") {
        public void actionPerformed(ActionEvent evt) {

            if (!findAllButton.isEnabled())
                return;
            Cursor bCurrent = browser.getCursor();
            Cursor fCurrent = findText.getCursor();
            browser.setCursor(new Cursor(Cursor.WAIT_CURSOR));
            findText.setCursor(new Cursor(Cursor.WAIT_CURSOR));
            Document doc = browser.getDocument();
            browser.clearSelection();
            NamedRegionSet sel = browser.getSelection();

            TC pat =
                new TC(
                    new TC.CaseSensitivity(
                        caseSensitive,
                        new TC.Literal(findText.getText())));

            if (wordMatch) {
                TC.Literal word = new TC.Literal(findText.getText());
                TC.Ending endingWord = new TC.Ending(new TC.Id("word"));
                TC.Starting startingWord = new TC.Starting(new TC.Id("word"));

                pat =
                    new TC(
                        new TC.CaseSensitivity(
                            caseSensitive,
                            new TC.And(
                                endingWord,
                                new TC.And(startingWord, word))));

            }

            RegionSet matches = ((TC) pat).match(doc);
            //sel = new NamedRegionSet(browser.getSelection(), matches);
            sel = new NamedRegionSet(matches);
            if (sel.isEmpty()) {
                browser.getToolkit().beep();
                browser.setStatus("No matches were found");
                JOptionPane.showMessageDialog(
                    ClusterFindReplacePane.this,
                    "Cannot Find '" + findText.getText() + "'",
                    null,
                    JOptionPane.INFORMATION_MESSAGE);
                browser.clearSelection();
                browser.setCursor(bCurrent);
                findText.setCursor(fCurrent);
                resetState();
                return;
            }

            debug.println("setting selection in findNextMatch()");
            // 		browser.setSelection (new NamedRegionSet (sel, matches));
            // 		sel =  browser.getSelection ();
            //browser.getActivePane ().findAndReplaceHighlighter.setSelection (sel);

            debug.println("selection : " + browser.getSelection().getSize());

            debug.println("scrolling in findnext");

            highlighted = sel.getSize();
            setHighlightedText(highlighted);
            //replacementsHighlighted.setText(sel.getSize() + " total matches shown");
            //yellowText.setVisible(true);
            //replacementsHighlighted.setVisible(true);
            setSelectedText(0);
            replacementsSelected.setVisible(true);
            selectButton.setVisible(true);
            unselectButton.setVisible(true);
            replaceWith.setVisible(true);
            replaceText.setVisible(true);
            replaceButton.setVisible(true);
            undoButton.setVisible(true);
            matchPanel.setVisible(false);
            if (tree) {
                matchPanel.removeAll();
                matchDisplayPanel =
                    new MatchTreePanel(
                        ClusterFindReplacePane.this,
                        browser,
                        sel,
                        cluster);
            } else {
                matchPanel.removeAll();
                matchDisplayPanel =
                    new MatchTable(
                        ClusterFindReplacePane.this,
                        browser,
                        sel,
                        cluster);
            }

            browser.setCursor(bCurrent);
            findText.setCursor(fCurrent);
            Layout
                .vertical(matchPanel)
                .add((Component) matchDisplayPanel)
                .done();
            matchPanel.setVisible(true);
            //browser.getActivePane ().findAndReplaceHighlighter.setSelection (sel);
        }
    };

    public Action replaceAction = new AcceleratedAction("&Replace") {
        public void actionPerformed(ActionEvent evt) {
            StateEdit newEdit = new StateEdit(ClusterFindReplacePane.this);

            NamedRegionSet sel = browser.getSelection();
            if (sel.isEmpty()) {
                return;
            }
            Cursor bCurrent = browser.getCursor();
            Cursor rCurrent = replaceText.getCursor();
            browser.setCursor(new Cursor(Cursor.WAIT_CURSOR));
            replaceText.setCursor(new Cursor(Cursor.WAIT_CURSOR));
            if (caseSensitive
                || !replaceText.getText().equals(
                    replaceText.getText().toLowerCase()))
                browser.getActivePane().replaceSelection(replaceText.getText());
            else {
                PreserveCase transform =
                    new PreserveCase(browser, replaceText.getText());
                transform.actionPerformed(evt);
            }

            browser.clearSelection();
            highlighted = highlighted - sel.getSize();
            matchDisplayPanel.deleteSelection();
            setHighlightedText(highlighted);
            setSelectedText(0);
            browser.setCursor(bCurrent);
            replaceText.setCursor(rCurrent);
            newEdit.end();
            undoManager.addEdit(newEdit);
            if (undoManager.canUndo())
                undoButton.setEnabled(true);
        }
    };
    public Action undoAction = new AcceleratedAction("&Undo") {
        public void actionPerformed(ActionEvent evt) {
            browser.undo(
                new ActionEvent(
                    browser.getActivePane(),
                    evt.getID(),
                    evt.getActionCommand(),
                    evt.getModifiers()));
            matchDisplayPanel.undo();
            try {
                undoManager.undo();
            } catch (CannotUndoException cue) {
            }
            browser.clearSelection();
            replaceButton.setEnabled(false);
            if (!undoManager.canUndo())
                undoButton.setEnabled(false);
        }

    };
    public Action selectAction = new AcceleratedAction("&Select All") {
        public void actionPerformed(ActionEvent evt) {
            matchDisplayPanel.selectAll();
        }
    };
    public Action unselectAction = new AcceleratedAction("&Unselect All") {
        public void actionPerformed(ActionEvent evt) {
            matchDisplayPanel.clearSelection();
        }
    };
    public Action closeAction = new AcceleratedAction("&Close") {
        public void actionPerformed(ActionEvent evt) {
            browser.clearSelection();
            browser
                .getActivePane()
                .getFindAndReplaceHighlighter()
                .setSelection(
                null);
            browser.removeSidebarTab(ClusterFindReplacePane.this);
        }
    };

    public Action treeFormatAction = new AcceleratedAction("&Tree Format") {
        public void actionPerformed(ActionEvent evt) {
            tree = true;
            findAllAction.actionPerformed(evt);
        }
    };
    public Action tableFormatAction = new AcceleratedAction("&Table Format") {
        public void actionPerformed(ActionEvent evt) {
            tree = false;
            findAllAction.actionPerformed(evt);
        }
    };
    public static class ClusterFindReplaceAction extends AcceleratedAction {
        Browser browser;

        public ClusterFindReplaceAction(Browser browser) {
            super("&Clustering Find & Replace", 'J', KeyEvent.CTRL_MASK);
            this.browser = browser;

        }
        public void actionPerformed(ActionEvent evt) {
            browser.addSidebarTab(
                "Clustering Find and Replace",
                new ClusterFindReplacePane(browser));

        }
    }

    public void setHighlightedText(int highlighted) {
        String text = highlighted + " total match";
        if (highlighted == 1)
            text = text + " shown";
        else
            text = text + "es shown";
        replacementsHighlighted.setText(text);
        //yellowText.setVisible(true);
        replacementsHighlighted.setVisible(true);

    }
    public void setSelectedText(int selected) {
        String text = selected + " match";
        if (selected == 1)
            text = text + " selected for replacement";
        else
            text = text + "es selected for replacement";
        replacementsSelected.setText(text);
        //replacementsSelected.setVisible(true);
        //blueText.setVisible(true);
        if (selected > 0)
            replaceButton.setEnabled(true);
        else
            replaceButton.setEnabled(false);
    }
    private void resetState() {
        replacementsHighlighted.setVisible(false);

        selectButton.setVisible(false);
        unselectButton.setVisible(false);
        replaceWith.setVisible(false);
        replaceText.setVisible(false);
        replaceText.setText("");
        replaceButton.setVisible(false);
        matchPanel.setVisible(false);
        if (matchDisplayPanel != null)
            matchDisplayPanel.clearSelection();
        browser.clearSelection();
        browser.getActivePane().getFindAndReplaceHighlighter().setSelection(
            null);
        replacementsSelected.setVisible(false);
    }

    /**
     * All instances of Cluster Find and Replace Panes for each browser are the
     * same
     **/

    public boolean equals(Object obj) {

        if (obj instanceof ClusterFindReplacePane) {
            debug.println("another ClusterFindReplacePane");
            if (((ClusterFindReplacePane) obj).browser.equals(this.browser))
                return true;
        }
        return false;

    }

    /**
     * All instances of Cluster Find and Replace Panes for each browser are the
     * same
     **/

    public int hashCode() {
        return this.browser.hashCode() + 92549085;
    }

}
