/*
 * LAPIS lightweight structured text processing system
 *
 * Copyright (C) 1998-2002 Carnegie Mellon University,
 * Copyright (C) 2003 Massachusetts Institute of Technology.
 * All rights reserved.
 *
 * This library is free software; you can redistribute it
 * and/or modify it under the terms of the GNU General
 * Public License as published by the Free Software
 * Foundation, version 2.
 *
 * LAPIS homepage: http://graphics.lcs.mit.edu/lapis/
 */

package lapis.swing.cluster;

import lapis.*;
import lapis.swing.*;
import java.awt.*;
import java.awt.image.*;
import java.util.*;
import java.awt.event.*;
import javax.swing.*;
import lapisx.swing.*;
import javax.swing.text.BadLocationException;
import java.awt.Dimension;
import javax.swing.border.LineBorder;
import lapis.swing.cluster.MatchNodeCreator.Node;

public class ClusterRenderer {

	public ClusterRenderer() {}

	public JComponent getTopLevelClip(Browser browser, Node n, boolean expanded, boolean sel, boolean hasFocus) {
		TopLevelClip tp = new TopLevelClip(browser, n, expanded, sel, hasFocus);
		JPanel jp = new JPanel();
		Layout.vertical(jp).add(tp).done();
		if (!expanded) {
			jp.setBorder(new LineBorder(new Color(220,220,220), 3));
		}
		return jp;

	}
	public JComponent getTopSingleClip(Browser browser, Node n, boolean expanded, boolean sel, boolean hasFocus) {
		TopSingleClip tp = new TopSingleClip(browser, n, expanded, sel, hasFocus);
		JPanel jp = new JPanel();
		Layout.vertical(jp).add(tp).done();
		if (!expanded) {
			jp.setBorder(new LineBorder(new Color(220,220,220), 3));
		}
		return jp;

	}
	public JComponent getTopOverlayClip(Browser browser, Node n, boolean expanded, boolean sel, boolean hasFocus) {
		TopOverlayClip tp = new TopOverlayClip(browser, n, expanded, sel, hasFocus);
		JPanel jp = new JPanel();

		Layout.vertical(jp).add(tp).done();
		if (!expanded) {
			jp.setBorder(new LineBorder(new Color(220,220,220), 3));
		}
		return jp;

	}

	public JComponent getSingleClip(Browser browser, Node n, Region r, boolean sel, boolean hasFocus) {
		return new SingleClip(browser, n, r, sel, hasFocus);
	}
	public static lapisx.util.Debug debug = lapisx.util.Debug.QUIET;

	public class TopSingleClip extends JPanel {

		RegionSet rs;
		Region r1 = null;

		Rectangle rect = null;
		Rectangle rect1 = new Rectangle(0, 0, 0, 0);
		Browser browser;
		boolean expanded;
		Rectangle regionRec1;
		Node node;
		JButton explanationButton;
		JTextArea explanationText;
		boolean sel;

		public TopSingleClip(Browser browser, Node n, boolean expanded, boolean sel, boolean hasFocus) {
			//			debug.printStackTrace();
			setBackground(Color.white);
			this.rs = n.getMatch();
			this.sel = sel;
			RegionEnumeration e = rs.regions();

			this.node = n;
			for (Region r = e.first(); r != null; r = e.next()) {
				if (!(r.getStart() == r.getEnd())) {
					if (r1 == null) {
						r1 = r;

					}
				}
			}

			this.browser = browser;
			this.expanded = expanded;
			setRegion(r1);

			Component b1 = null;
			JLabel textLabel = new JLabel();

			if (r1 != null)
				if (!(r1.getStart() == r1.getEnd())) {
					// 		    Node drawn = new Node (browser, "head.sub", new NamedRegionSet (browser.getDocument(), r1));
					// 		    debug.println("drawn image: " + drawn.getImage());
					b1 = new SingleClip(browser, n, r1, false, false);
				}
			if (b1 != null)
				debug.println("browserClip not null");
			else {
				Node child = null;
				if (n.getChildCount() >0)
					 child = (Node)n.children.get(0);
				
				if (child != null){
				
					b1 = new SingleClip(browser, child, child.getMatch().regions().first(), sel, hasFocus);
				    n.setImage(((SingleClip)b1).getClip());
				}
			}
			String text = n.getLabel();

			if ((!expanded) && (b1 != null)) {
				Layout.horizontal(this)
					.add(textLabel = new JLabel(text), Layout.FIXED_SIZE, Layout.WEST)
					.add(b1)
					.done();
			}
			if ((!expanded) && (b1 == null)) {
				Layout.vertical(this).add(Layout.horizontal().addGlue()
				// 			 .add(explanationButton = ActionAdapters.toTinyButton(explainAction),  Layout.FIXED_SIZE)
				.done()).done();
			}
			if (expanded) {
				Layout.vertical(this).add(Layout.horizontal().add(textLabel = new JLabel(text), Layout.FIXED_SIZE, Layout.WEST).addGlue()
					// 			 .add(explanationButton = ActionAdapters.toTinyButton(explainAction),  Layout.FIXED_SIZE)
				.done()).done();
			}
			setBorder(new LineBorder(new Color(220,220,220), 1));
			if (hasFocus) {
				setBorder(new LineBorder(Color.blue, 1));
			}

			setToolTipText(n.getExplanationText());
			setOpaque(true);
			textLabel.setBackground(Color.white);
			textLabel.setOpaque(true);
		}

		public void setRegion(Region r1) {

			if (r1 != null) {
				if (!(r1.getStart() == r1.getEnd())) {
					try {
						regionRec1 = browser.getActivePane().regionToExpandedRectangle(r1);
						rect1 =
							new Rectangle(
								regionRec1.x,
								regionRec1.y,
								Math.min(regionRec1.width + 200, browser.getActivePane().getWidth()),
								regionRec1.height + 10);
					}
					catch (BadLocationException ble) {
						ble.printStackTrace();
					}
				}
			}
			rect = new Rectangle(0, 0, rect1.width + 6, rect1.height + 30);

		}

		public Action explainAction = new AcceleratedAction("&?") {
			public void actionPerformed(ActionEvent evt) {}
		};

		public void paint(Graphics g) {
			super.paint(g);
			debug.println("painting toplevel " + node.toString());
			g.setPaintMode();
			g.setColor(new Color(102, 102, 255, 100));
			if (sel) {
				debug.println("selected");
				//g.setClip(0,0,getPreferredSize().width,getPreferredSize().height);
				//g.fillRect(0,0,getPreferredSize().width,getPreferredSize().height);
				g.fillRect(g.getClipBounds().x, g.getClipBounds().y, g.getClipBounds().width, g.getClipBounds().height);
				debug.println("bounds: " + g.getClipBounds().toString());
			}

		}
	}

	public class TopLevelClip extends JPanel {

		RegionSet rs;
		Region r1 = null;

		Rectangle rect = null;
		Rectangle rect1 = new Rectangle(0, 0, 0, 0);
		Rectangle rect2 = new Rectangle(0, 0, 0, 0);
		Rectangle rect3 = new Rectangle(0, 0, 0, 0);
		Browser browser;
		boolean expanded;
		Rectangle regionRec1;
		Rectangle regionRec2;
		Rectangle regionRec3;
		Node node;
		JButton explanationButton;
		JTextArea explanationText;
		boolean sel;

		public TopLevelClip(Browser browser, Node n, boolean expanded, boolean sel, boolean hasFocus) {
			this.rs = n.getMatch();
			this.sel = sel;
			RegionEnumeration e = rs.regions();

			this.node = n;
			for (Region r = e.first(); r != null; r = e.next()) {
				if (!(r.getStart() == r.getEnd())) {
					if (r1 == null) {
						r1 = r;

					}
				}
			}

			this.browser = browser;
			this.expanded = expanded;
			setRegion(r1);

			SingleClip b1 = null;

			if (r1 != null)
				if (!(r1.getStart() == r1.getEnd())) {
					// 		    Node drawn = new Node (browser, "head.sub", new NamedRegionSet (browser.getDocument(), r1));
					// 		    debug.println("drawn image: " + drawn.getImage());
					b1 = new SingleClip(browser, n, r1, false, false);
				}
			if (b1 != null)
				debug.println("browserClip not null");
			String text = n.getLabel();
			JLabel textLabel = new JLabel();
			JLabel select = new JLabel(" (  selected)");
			select.setVisible(false);
			if ((n.getSelectedChildren().size() != 0) && (n.getSelectedChildren().size() < n.getChildCount())) {
				select.setText(" (" + n.getSelectedChildren().size() + " selected)");
				select.setVisible(true);
			}
			select.setOpaque(false);

			if ((!expanded) && (b1 != null)) {
				Layout.vertical(
					this)
						.add(
							Layout
							.horizontal()
							.add(textLabel = new JLabel(text), Layout.FIXED_SIZE, Layout.WEST)
							.add(select, Layout.FIXED_SIZE)
							.addGlue()
					// 			 .add(explanationButton = ActionAdapters.toTinyButton(explainAction),  Layout.FIXED_SIZE)
	.done()).add(b1).done();
			}
			if ((!expanded) && (b1 == null)) {
				Layout.vertical(
					this)
						.add(
							Layout
							.horizontal()
							.add(textLabel = new JLabel(text), Layout.FIXED_SIZE, Layout.WEST)
							.add(select, Layout.FIXED_SIZE)
							.addGlue()
					// 			 .add(explanationButton = ActionAdapters.toTinyButton(explainAction),  Layout.FIXED_SIZE)
	.done()).done();
			}
			if (expanded) {
				Layout.vertical(
					this)
						.add(
							Layout
							.horizontal()
							.add(textLabel = new JLabel(text), Layout.FIXED_SIZE, Layout.WEST)
							.add(select, Layout.FIXED_SIZE)
							.addGlue()
					// 			 .add(explanationButton = ActionAdapters.toTinyButton(explainAction),  Layout.FIXED_SIZE)
	.done())

					// .add(explanationText = new JTextArea(n.getExplanationText()))
	.done();

				// 		explanationText.getDocument().putProperty(DefaultEditorKit.EndOfLineStringProperty, "\n");
				// 		explanationText.setSize(explanationText.getPreferredSize());
			}
			setBorder(new LineBorder(Color.black, 1));
			if (hasFocus) {
				setBorder(new LineBorder(Color.blue, 1));
			}

			setToolTipText(n.getExplanationText());
			setOpaque(true);

		}

		public void setRegion(Region r1) {

			if (r1 != null) {
				if (!(r1.getStart() == r1.getEnd())) {
					try {
						regionRec1 = browser.getActivePane().regionToExpandedRectangle(r1);
						rect1 =
							new Rectangle(
								regionRec1.x,
								regionRec1.y,
								Math.min(regionRec1.width + 200, browser.getActivePane().getWidth()),
								regionRec1.height + 10);
					}
					catch (BadLocationException ble) {
						ble.printStackTrace();
					}
				}
			}
			rect = new Rectangle(0, 0, rect1.width + 6, rect1.height + 30);

		}

		public Action explainAction = new AcceleratedAction("&?") {
			public void actionPerformed(ActionEvent evt) {}
		};
		public void paint(Graphics g) {
			super.paint(g);
			debug.println("painting toplevel");
			g.setPaintMode();
			g.setColor(new Color(102, 102, 255, 100));
			if (sel) {
				debug.println("selected");
				//g.fillRect(0,0,getPreferredSize().width,getPreferredSize().height);
				g.fillRect(g.getClipBounds().x, g.getClipBounds().y, g.getClipBounds().width, g.getClipBounds().height);
				debug.println("bounds: " + g.getClipBounds().toString());
			}

		}
	}

	public class TopOverlayClip extends JPanel {
		boolean sel;

		public TopOverlayClip(Browser browser, Node n, boolean expanded, boolean sel, boolean hasFocus) {

			this.sel = sel;
			OverlayClip o1 = new OverlayClip(browser, n, expanded, sel, hasFocus);
			String text = n.getLabel();
			JLabel textLabel = new JLabel();
			JLabel select = new JLabel(" (  selected)");
			select.setVisible(false);
			if ((n.getSelectedChildren().size() != 0) && (n.getSelectedChildren().size() < n.getChildCount())) {
				select.setText(" (" + n.getSelectedChildren().size() + " selected)");
				select.setVisible(true);
			}
			select.setOpaque(false);

			if ((!expanded) && (o1 != null)) {
				Layout.vertical(this).add(Layout.horizontal().add(select, Layout.FIXED_SIZE).addGlue()
				// 			 .add(explanationButton = ActionAdapters.toTinyButton(explainAction),  Layout.FIXED_SIZE)
				.done()).add(o1).done();
			}
			if ((!expanded) && (o1 == null)) {
				Layout.vertical(this).add(Layout.horizontal().add(select, Layout.FIXED_SIZE).addGlue()
				// 			 .add(explanationButton = ActionAdapters.toTinyButton(explainAction),  Layout.FIXED_SIZE)
				.done()).done();
			}
			if (expanded) {
				Layout.vertical(
					this)
						.add(
							Layout
							.horizontal()
							.add(textLabel = new JLabel(text), Layout.FIXED_SIZE, Layout.WEST)
							.add(select, Layout.FIXED_SIZE)
							.addGlue()
					// 			 .add(explanationButton = ActionAdapters.toTinyButton(explainAction),  Layout.FIXED_SIZE)
	.done())

					// .add(explanationText = new JTextArea(n.getExplanationText()))
	.done();

				// 		explanationText.getDocument().putProperty(DefaultEditorKit.EndOfLineStringProperty, "\n");
				// 		explanationText.setSize(explanationText.getPreferredSize());
			}
			setBorder(new LineBorder(new Color(220,220,220), 1));
			if (hasFocus) {
				setBorder(new LineBorder(Color.blue, 1));
			}

			setToolTipText(n.getExplanationText());
			setOpaque(true);
			setSize(getPreferredSize());

		}

		public void paint(Graphics g) {
			super.paint(g);
			debug.println("painting toplevel");
			g.setPaintMode();
			g.setColor(new Color(102, 102, 255, 100));
			if (sel) {
				debug.println("selected");
				//g.fillRect(0,0,getPreferredSize().width,getPreferredSize().height);
				g.fillRect(g.getClipBounds().x, g.getClipBounds().y, g.getClipBounds().width, g.getClipBounds().height);
				debug.println("bounds: " + g.getClipBounds().toString());
			}

		}

	}
	public class OverlayClip extends JPanel {
		RegionSet rs;
		Browser browser;
		boolean expanded;
		Rectangle rect = null;
		Node node;
		Vector images = new Vector();
		boolean selected;
		int height = 0;
		int width = 0;

		public OverlayClip(Browser browser, Node n, boolean expanded, boolean sel, boolean hasFocus) {
			this.selected = sel;
			this.rs = n.getMatch();
			this.node = n;

			debug.println("creating overlay image: " + n.toString() + " " + n.getChildCount());
			for (Enumeration e = n.children(); e.hasMoreElements();) {
				Node child = (Node)e.nextElement();
				//				MiniBrowser mb = new MiniBrowser(child.getImage());
				//				mb.show();
				if (child.getImage() != null) {
					//debug.println(child.getImage().toString());
					images.add(child.getImage());
					height = Math.max(height, ((BufferedImage)child.getImage()).getHeight());
					width = Math.max(width, ((BufferedImage)child.getImage()).getWidth());
					//debug.println("w: " + width + " h: " + height);
				}
			}
			setPreferredSize(new Dimension(width, height));
		}

		public void paintComponent(Graphics g) {

			setBackground(Color.white);

			//			revalidate();
			//			setSize(getPreferredSize());

			super.paintComponent(g);

			g.setPaintMode();
			g.setColor(Color.white);
			g.fillRect(g.getClipBounds().x, g.getClipBounds().y, g.getClipBounds().width, g.getClipBounds().height);

			for (Enumeration e = images.elements(); e.hasMoreElements();) {
				BufferedImage img = (BufferedImage)e.nextElement();
				int rgbColourSpec = 0xffffff;
				// filter the supplied image 
				Image image = createImage(new FilteredImageSource(img.getSource(), new ImageTransparencyFilter(rgbColourSpec)));

				g.drawImage(image, 0, 0, this);
			}

			g.setPaintMode();
			g.setColor(new Color(102, 102, 255, 100));
			if (selected) {

				//g.fillRect(0,0,getPreferredSize().width,getPreferredSize().height);
				g.fillRect(g.getClipBounds().x, g.getClipBounds().y, g.getClipBounds().width, g.getClipBounds().height);
			}

		}
		public BufferedImage getClip() {
			return (BufferedImage)this.createImage(width, height);
		}

	}

	public class MultiClip extends JPanel {
		RegionSet rs;
		Region r1 = null;
		Region r2 = null;
		Region r3 = null;
		Region r4 = null;
		Rectangle rect = null;
		Rectangle rect1 = new Rectangle(0, 0, 0, 0);
		Rectangle rect2 = new Rectangle(0, 0, 0, 0);
		Rectangle rect3 = new Rectangle(0, 0, 0, 0);
		Browser browser;
		boolean expanded;
		Rectangle regionRec1;
		Rectangle regionRec2;
		Rectangle regionRec3;
		Node node;

		public MultiClip(Browser browser, Node n, boolean expanded, boolean sel) {
			RegionSet rs = n.getMatch();
			RegionEnumeration e = rs.regions();
			this.node = n;

			for (Region r = e.first(); r != null; r = e.next()) {
				if (!(r.getStart() == r.getEnd())) {
					if (r1 == null)
						r1 = r;
					else
						if (r2 == null)
							r2 = r;
						else
							if (r3 == null)
								r3 = r;
							else
								if (r4 == null)
									r4 = r;
								else
									break;
				}
			}

			this.browser = browser;
			this.expanded = expanded;
			setRegions(r1, r2, r3);
			//	    setPreferredSize(new Dimension((int)rect.getWidth(),(int)rect.getHeight()));
			SingleClip b1 = null;
			SingleClip b2 = null;
			SingleClip b3 = null;

			if (r1 != null)
				if (!(r1.getStart() == r1.getEnd()))
					b1 = new SingleClip(browser, n, r1, false, false);
			if (r2 != null)
				if (!(r2.getStart() == r2.getEnd()))
					b2 = new SingleClip(browser, n, r2, false, false);
			if (r3 != null)
				if (!(r3.getStart() == r3.getEnd()))
					b3 = new SingleClip(browser, n, r3, false, false);
			String text = n.getLabel();
			if ((n.getSelectedChildren().size() != 0) && (n.getSelectedChildren().size() < n.getChildCount())) {
				text = text + " (" + n.getSelectedChildren().size() + " selected)";
			}
			Layout.vertical(this).add(new JLabel(text)).done();

			if (!expanded) {
				// 		setPreferredSize(new Dimension((int)rect.getWidth(),(int)rect.getHeight()));
				if (b1 != null)
					Layout.vertical(this).add(b1).done();
				if (b2 != null)
					Layout.vertical(this).add(b2).done();
				if (b3 != null)
					Layout.vertical(this).add(b3).done();
				if (r4 != null)
					if (!(r4.getStart() == r4.getEnd()))
						Layout.vertical(this).add(new JLabel("(more)")).done();
			}
			setBorder(new LineBorder(Color.red, 2));
			if (sel) {
				setBorder(new LineBorder(Color.black, 2));
				setBackground(new Color(102, 102, 255, 100));
				//debug.println(n.toString() + " " + n.getExplanationText());
			}

			setToolTipText(n.getExplanationText());
			setOpaque(true);

		}

		public void setRegions(Region r1, Region r2, Region r3) {

			if (r1 != null) {
				if (!(r1.getStart() == r1.getEnd())) {
					try {
						regionRec1 = browser.getActivePane().regionToExpandedRectangle(r1);
						rect1 =
							new Rectangle(
								regionRec1.x,
								regionRec1.y,
								Math.min(regionRec1.width + 200, browser.getActivePane().getWidth()),
								regionRec1.height + 10);
					}
					catch (BadLocationException ble) {
						ble.printStackTrace();
					}
				}
				if (r2 != null) {
					if (!(r2.getStart() == r2.getEnd())) {
						try {
							regionRec2 = browser.getActivePane().regionToExpandedRectangle(r2);
							rect2 =
								new Rectangle(
									regionRec2.x,
									regionRec2.y,
									Math.min(regionRec2.width + 200, browser.getActivePane().getWidth()),
									regionRec2.height + 10);
						}
						catch (BadLocationException ble) {
							ble.printStackTrace();
						}
					}

					if (r3 != null) {
						if (!(r3.getStart() == r3.getEnd())) {
							try {
								regionRec3 = browser.getActivePane().regionToExpandedRectangle(r3);
								rect3 =
									new Rectangle(
										regionRec3.x,
										regionRec3.y,
										Math.min(regionRec3.width + 200, browser.getActivePane().getWidth()),
										regionRec3.height + 10);
							}
							catch (BadLocationException ble) {
								ble.printStackTrace();
							}
						}
					}
				}
			}
			int width = Math.max(rect1.width, Math.max(rect2.width, rect3.width)) + 6;
			int height = rect1.height + rect2.height + rect3.height + 30;
			rect = new Rectangle(0, 0, width, height);

		}

	}

	public class SingleClip extends JPanel {
		int height = 0;
		int width = 0;
		public SingleClip(Browser browser, Node n, Region r, boolean selected, boolean hasFocus) {
			BrowserClip b = new BrowserClip(browser, n, r, selected);
			Layout.vertical(this).setContainerInsets(5, 0, 5, 0).add(b).done();
			//setPreferredSize(new Dimension((int)b.getPreferredSize().width, (int) b.getPreferredSize().height+10));
			//setBackground(Color.white);
			setSize(getPreferredSize());
			//	    debug.println("S preferred: " + getPreferredSize().toString());
			//	    debug.println("S size: " + getSize().toString());
			if (hasFocus) {
				setBorder(new LineBorder(Color.blue, 1));
			}
			else
				setBorder(new LineBorder(new Color(220,220,220), 1));
			if (n.getImage() != null){
				height = ((BufferedImage)n.getImage()).getHeight();
				width = ((BufferedImage)n.getImage()).getWidth();
			}
		}
		public BufferedImage getClip() {
			return (BufferedImage)this.createImage(width, height);
		}

	}

	public class BrowserClip extends JComponent {
		Region r;
		Rectangle rect;
		Browser browser;
		boolean selected;
		Rectangle regionRec;
		Node node;

		public BrowserClip(Browser browser, Node n, Region r, boolean selected) {
			this.r = r;
			this.browser = browser;
			this.selected = selected;
			this.node = n;
			if (r != null) {
				setRegion(r);
				setPreferredSize(new Dimension((int)rect.getWidth(), (int)rect.getHeight()));
			}
			// setMaximumSize(getPreferredSize());
			setBackground(Color.white);
			setOpaque(true);
		}

		// 	public void setBounds(int x, int y, int w, int h) {
		// 	    super.setBounds(x, 0, w, MatchTree.this.getHeight());
		// 	}

		public void setRegion(Region r) {
			this.r = r;

			try {
				if (r != null) {
					regionRec = browser.getActivePane().regionToExpandedRectangle(r);
					//					rect =
					//						new Rectangle(
					//							regionRec.x,
					//							regionRec.y,
					//							Math.min(regionRec.width + 200, browser.getActivePane().getWidth()),
					//							regionRec.height);
					//				}
					rect = new Rectangle(regionRec.x, regionRec.y, regionRec.width + 200, regionRec.height);
				}
				// 		debug.println("regionRec:  " + regionRec.toString() );
				// 		debug.println("boundingRec: " + rect.toString());
				// 		debug.println("region: " + r.toString());
			}
			catch (BadLocationException ble) {
				ble.printStackTrace();
			}

		}

		public void paintComponent(Graphics g) {

			setBackground(Color.white);

			revalidate();
			setSize(getPreferredSize());

			super.paintComponent(g);
			if (r != null) {

				g.setPaintMode();
				g.setColor(Color.white);
				g.fillRect(g.getClipBounds().x, g.getClipBounds().y, g.getClipBounds().width, g.getClipBounds().height);

				if (node.getImage() != null)
					g.drawImage(node.getImage(), 0, 0, this);
				debug.println("painted browserClip");

				g.setPaintMode();
				g.setColor(new Color(102, 102, 255, 100));
				if (selected) {

					//	g.fillRect(0,0,getPreferredSize().width,getPreferredSize().height);
					g.fillRect(g.getClipBounds().x, g.getClipBounds().y, g.getClipBounds().width, g.getClipBounds().height);
				}
			}
		}

	}

	//	ImageTransparencyFilter.java - filter to create a transparent background 
	//		 Copyright (c) 1995, Optimation Software Engineering Pty. Ltd.,     
	//							 Melbourne, Australia.                          

	//	$Id: ClusterRenderer.java,v 1.12 2003/08/07 05:45:35 minwu Exp $ 
	/* 
	
	 Revision 3.1  1996/08/12 06:27:41  ronm 
	 Moved to rev 3 
	
	# Revision 1.1  1996/07/15  05:29:39  grege 
	# Initial revision 
	# 
	 */

	public class ImageTransparencyFilter extends RGBImageFilter {

		/** 
		 * Default dimensions 
		 */
		//		public static final int WIDTH = 100;
		//		public static final int HEIGHT = 100;
		//		public static final int EDGE = 10;

		/** 
		 * RGB value (24 bit) of the colour targetted for transparency 
		 */
		protected int transTargetColour;

		/** 
		 * Construct an ImageTransparencyFilter for `targetColour` 
		 */
		public ImageTransparencyFilter(int targetColour) {

			transTargetColour = targetColour;
			canFilterIndexColorModel = true;

		}

		/** 
		 * @return a filtered RGB 
		 */
		public int filterRGB(int x, int y, int rgb) {

			if ((rgb & 0xffffff) == transTargetColour) {
				// pull out the rgb values (ignore alpha) 
				return 0; // alpha == 0   
			}
			else {
				// nothing to filter 
				return rgb;
			}

		}

	}

}
