/*
 * LAPIS lightweight structured text processing system
 *
 * Copyright (C) 1998-2002 Carnegie Mellon University,
 * Copyright (C) 2003 Massachusetts Institute of Technology.
 * All rights reserved.
 *
 * This library is free software; you can redistribute it
 * and/or modify it under the terms of the GNU General
 * Public License as published by the Free Software
 * Foundation, version 2.
 *
 * LAPIS homepage: http://graphics.lcs.mit.edu/lapis/
 */
package lapis.swing.cluster;

import javax.swing.tree.TreeModel;

import lapis.RegionSet;
import lapis.NamedRegionSet;
import lapis.swing.*;
import lapis.swing.cluster.MatchNodeCreator.*;
import javax.swing.tree.*;
import javax.swing.*;
import java.awt.*;
import lapis.Region;


/**
 * @author alisa_m
 *
 * Like Match Tree  but for Lexical Attraction
 */
public class LexicalTree extends MatchTree {
	/**
	 * @param clusterPane
	 * @param browser
	 * @param sel
	 * @param cluster
	 */

	public LexicalTree(ClusterFindReplacePane clusterPane, Browser browser, NamedRegionSet sel, boolean cluster) {
		//super(clusterPane, browser, sel, cluster);
		TreeModel tm;

			tm = new DefaultTreeModel(new LexicalClusterCreator(browser, sel).getRoot());

		setModel(tm);
		root = (Node)tm.getRoot();
		this.cluster = cluster;
		this.browser = browser;
		this.clusterPane = clusterPane;
		setProperties();
		
		setupListeners();
		this.setCellRenderer(new Renderer(browser));
		//undoManager = new UndoManager();
		addSelectionRow(0);
		expandAll();
		ToolTipManager.sharedInstance().registerComponent(this);
		
	}
	/**
	 * @param clusterPane
	 * @param browser
	 * @param matches
	 * @param cluster
	 */
	public LexicalTree(ClusterFindReplacePane clusterPane, Browser browser, RegionSet matches, boolean cluster) {
		//this(clusterPane, browser, new NamedRegionSet(browser.getDocument(), matches), cluster);
		this(clusterPane, browser, new NamedRegionSet(matches), cluster);
	}
	/**
	 * @param clusterPane
	 * @param browser
	 * @param sel
	 * @param cluster
	 * @param tm
	 */
	public LexicalTree(
		ClusterFindReplacePane clusterPane,
		Browser browser,
		NamedRegionSet sel,
		boolean cluster,
		TreeModel tm) {
		super(clusterPane, browser, sel, cluster, tm);
	}
	
	class Renderer extends DefaultTreeCellRenderer {
		Browser browser;

		public Renderer(Browser browser) {
			super();
			this.browser = browser;

		}

		public Component getTreeCellRendererComponent(
			JTree tree,
			Object value,
			boolean sel,
			boolean expanded,
			boolean leaf,
			int row,
			boolean hasFocus) {
			Node n = (Node)value;
			//	    debug.println(n.toString());
			ClusterRenderer renderer = new ClusterRenderer();
			if (n.getAllowsChildren()) {
				JComponent m = renderer.getTopSingleClip(browser, n, expanded, sel, hasFocus);
				//tree.setRowHeight(m.getHeight());
				m.setToolTipText(n.getExplanationText());
				height = m.getPreferredSize().height;
				return m;
			}

			RegionSet rs = n.getMatch();
			Region r = rs.regions().first();
			JComponent c = renderer.getSingleClip(browser, n, r, sel, hasFocus);
			c.setToolTipText(n.getExplanationText());
			height = c.getPreferredSize().height;
			return c;

		}

	}
	
}
