/*
 * LAPIS lightweight structured text processing system
 *
 * Copyright (C) 1998-2002 Carnegie Mellon University,
 * Copyright (C) 2003 Massachusetts Institute of Technology.
 * All rights reserved.
 *
 * This library is free software; you can redistribute it
 * and/or modify it under the terms of the GNU General
 * Public License as published by the Free Software
 * Foundation, version 2.
 *
 * LAPIS homepage: http://graphics.lcs.mit.edu/lapis/
 */

package lapis.swing.cluster;

import javax.swing.plaf.basic.BasicListUI;
import javax.swing.event.*;
import java.awt.event.*;
import javax.swing.SwingUtilities;
import java.awt.*;
/**
 * @author alisa_m
 *
 * a different ListUI  that allows click on click off capability
 */
public class MatchListUI extends BasicListUI {

	public static lapisx.util.Debug debug = lapisx.util.Debug.QUIET;

	protected MouseInputListener createMouseInputListener() {
		return new ClickonInputHandler();
	}

	public class ClickonInputHandler extends MouseInputHandler {
		private boolean selectedOnPress;
		public void mousePressed(MouseEvent e) {
			if (e.isConsumed()) {
				selectedOnPress = false;
				return;
			}
			selectedOnPress = true;
			myadjustFocusAndSelection(e);
		}
		public void mouseReleased(MouseEvent e) {
			if (selectedOnPress) {
				if (!SwingUtilities.isLeftMouseButton(e)) {
					return;
				}

				list.setValueIsAdjusting(false);
			}
			else {
				myadjustFocusAndSelection(e);
			}
		}
		void myadjustFocusAndSelection(MouseEvent e) {
			if (!SwingUtilities.isLeftMouseButton(e)) {
				return;
			}

			if (!list.isEnabled()) {
				return;
			}

			/* Request focus before updating the list selection.  This implies
			 * that the current focus owner will see a focusLost() event
			 * before the lists selection is updated IF requestFocus() is
			 * synchronous (it is on Windows).  See bug 4122345
			 */
			if (!list.hasFocus() && list.isRequestFocusEnabled()) {
				list.requestFocus();
			}

			int row = locationToIndex(list, new Point(e.getX(), e.getY()));
			if (row != -1) {
				boolean adjusting = (e.getID() == MouseEvent.MOUSE_PRESSED) ? true : false;
				list.setValueIsAdjusting(adjusting);
				int anchorIndex = list.getAnchorSelectionIndex();
				if (e.isShiftDown() && (anchorIndex != -1)) {
					list.setSelectionInterval(anchorIndex, row);
				}
				else
					if (list.isSelectedIndex(row)) {
						list.removeSelectionInterval(row, row);
						debug.println("removing row: " + row);
					}
					else {
						list.addSelectionInterval(row, row);
					}
			}

		}
	}

}

