package lapis.swing.cluster;
import lapis.*;
import lapis.maps.*;
import lapis.ml.*;
import lapis.swing.*;
import java.awt.*;
import java.awt.image.*;
import java.util.*;
import lapisx.sort.*;
import javax.swing.text.BadLocationException;
import javax.swing.tree.*;
/**
 * Class that contains all Node creation for results to a find or higlighted matches in a browser. 
 **/
public class MatchNodeCreator {
	public static lapisx.util.Debug debug = lapisx.util.Debug.QUIET;
	/**
	 * returns a node cluster
	 * Parameters cluster, if true the results are clustered by simularity, else all results are returned as one cluster. 
	 **/
	public static NodeCreator createNodes(Browser browser, RegionSet rs, boolean cluster) {
		if (cluster)
			return new ClusterCreator(browser, rs);
		return new SingleGroupNodeCreator(browser, rs);
	}
	public static NodeCreator createLexicalNodes(Browser browser, RegionSet rs, boolean cluster) {
		if (cluster)
			return new LexicalClusterCreator(browser, rs);
		return new SingleGroupNodeCreator(browser, rs);
	}
	public static NodeCreator createNodes(Browser browser, NamedRegionSet sel, boolean cluster) {
		if (cluster)
			return new ClusterCreator(browser, sel);
		return new SingleGroupNodeCreator(browser, sel);
	}
	public static NodeCreator createLexicalNodes(Browser browser, NamedRegionSet sel, boolean cluster) {
		if (cluster)
			return new LexicalClusterCreator(browser, sel);
		return new SingleGroupNodeCreator(browser, sel);
	}
	public static NodeTableCreator createTable(Browser browser, RegionSet rs, boolean cluster) {
		if (cluster)
			return new ClusterTableCreator(browser, rs);
		return new SingleGroupNodeTableCreator(browser, rs);
	}
	public static NodeTableCreator createTable(Browser browser, NamedRegionSet sel, boolean cluster) {
		if (cluster)
			return new ClusterTableCreator(browser, sel);
		return new SingleGroupNodeTableCreator(browser, sel);
	}
	public static TreeTableModel createTableModel(Browser browser, NamedRegionSet sel, boolean cluster) {
		if (cluster)
			return new ClusterNodeTableModel(browser, sel);
		return new SingleNodeTableModel(browser, sel);
	}
	public static TreeTableModel createTableModel(Browser browser, RegionSet rs, boolean cluster) {
		if (cluster)
			return new ClusterNodeTableModel(browser, rs);
		return new SingleNodeTableModel(browser, rs);
	}
	public static RegionSet filteredEmptyRegions(RegionSet regionSet) {
		debug.println("rs size: " + regionSet.getSize());
		RegionEnumeration e = regionSet.regions();
		RegionSet filtered = new EmptyRegionSet();
		for (Region r = e.first(); r != null; r = e.next()) {
			debug.println("r: " + r.getStart() + " " + r.getEnd());
			if (!r.isPoint())
				filtered = filtered.or(r);
		}
		return filtered;
	}
	interface NodeCreator {
		public Node getRoot();
	}
	interface NodeTableCreator {
		public Vector getData();
		public Vector getColumn();
		public Node getRoot();
	}
	static class ClusterTableCreator implements NodeTableCreator {
		Vector data = new Vector();
		Vector column = new Vector();
		Node root;
		public ClusterTableCreator(Browser browser, RegionSet rs) {
			//this(browser, new NamedRegionSet(browser.getDocument(), rs));
			this(browser, new NamedRegionSet(rs));
		}
		public ClusterTableCreator(Browser browser, NamedRegionSet sel) {
			ClusterCreator cc = new ClusterCreator(browser, sel);
			this.root = cc.getRoot();
			for (Enumeration e = root.children(); e.hasMoreElements();) {
				Node child = (Node) e.nextElement();
				Vector v = new Vector();
				v.add(child);
				v.add(new Integer(child.getChildCount()));
				data.add(v);
			}
			column.add("description");
			column.add("size");
		}
		public Vector getData() {
			return data;
		}
		public Vector getColumn() {
			return column;
		}
		public Node getRoot() {
			return root;
		}
	}
	static class SingleGroupNodeTableCreator implements NodeTableCreator {
		Node root;
		Vector data = new Vector();
		Vector column = new Vector();
		//public SingleGroupNodeTableCreator(Browser browser, NamedRegionSet sel) {
		//	this(browser, sel.getRegions());
		//}
		public SingleGroupNodeTableCreator(Browser browser, RegionSet matches) {
			SingleGroupNodeCreator sgnc = new SingleGroupNodeCreator(browser, matches);
			this.root = sgnc.getRoot();
			for (Enumeration e = root.children(); e.hasMoreElements();) {
				Node child = (Node) e.nextElement();
				Vector v = new Vector();
				v.add(child);
				v.add(new Integer(child.getChildCount()));
				data.add(v);
			}
			column.add("description");
			column.add("size");
		}
		public SingleGroupNodeTableCreator(Node root) {
			this.root = root;
			for (Enumeration e = root.children(); e.hasMoreElements();) {
				Node child = (Node) e.nextElement();
				Vector v = new Vector();
				v.add(child);
				v.add(new Integer(child.getChildCount()));
				data.add(v);
			}
			column.add("description");
			column.add("size");
		}
		public Vector getData() {
			return data;
		}
		public Vector getColumn() {
			return column;
		}
		public Node getRoot() {
			return root;
		}
	}
	static class LexicalClusterCreator extends ClusterCreator {
		public LexicalClusterCreator(Browser browser, RegionSet rs) {
			super(browser, new NamedRegionSet(rs));
			//TODO go through clusters and create nodes based on explaination text. put into hashMap based upon that.
		}
		public LexicalClusterCreator(Browser browser, NamedRegionSet sel) {
			super(browser, sel);
		}
		protected void handleClusters(Browser browser) {
			debug.println("" + clusters.length + " clusters found");
//			int[] clusterSizeArray = new int[clusters.length];
//						TreeSet treeSet = new TreeSet(new Comparator() {
//							public int compare(Object o1, Object o2) {
//								Node n1 = (Node) o1;
//								Node n2 = (Node) o2;
//								if (n1.getExplanationText().compareTo(n2.getExplanationText()) == 0) {
//									if (n1.getMatch().regions().first().getStart()
//										== n1.getMatch().regions().first().getStart()) {
//										if (n1.getMatch().regions().first().getEnd()
//											== n1.getMatch().regions().first().getEnd()) {
//										}
//									}
//								}
//								return n1.getExplanationText().compareTo(n2.getExplanationText());
//							}
//							public boolean equals(Object obj) {
//								return false;
//							}
//						});
			HashMap lexattracMap = new HashMap();
			boolean singletons = true;
			for (int j = 0; j < clusters.length; j++) {
				if (clusters[j].getSize() > 1) {
					singletons = false;
					//return ClusterCreator.makeFromClusters(clusters[j]);
				}
			}
			debug.println("all singletons? : " + singletons); 
//			Node unclusterable =
//				new Node(browser, "miscellaneous", new NamedRegionSet(browser.getDocument(), new EmptyRegion()));
			for (int j = 0; j < clusters.length; j++) {
				if (clusters[j].getSize() < 2) {
					RegionEnumeration e = clusters[j].regions();
					int k = 0;
					for (Region r = e.first(); r != null; r = e.next()) {
						Node match = null;
						NamedRegionSet rs = new NamedRegionSet(r);
						match = new Node(browser, "Unclusterable.match #" + k + " " + r.toString(), rs);
						match.setExplanation(clusters[j].getExplanation());
						if (lexattracMap.get(match.getExplanationText()) != null) {
							((Vector) lexattracMap.get(match.getExplanationText())).add(match);
						}
						else {
							Vector v = new Vector();
							v.add(match);
							lexattracMap.put(match.getExplanationText(), v);
						}
						k++;
					}
				}
				else {
					Node header = new Node(browser, "cluster #" + j, new NamedRegionSet(clusters[j]));
					header.setExplanation(clusters[j].getExplanation());
					root.add(header);
					int i = 0;
					RegionEnumeration e = clusters[j].regions();
					for (Region r = e.first(); r != null; r = e.next()) {
						Node match = null;
						NamedRegionSet rs = new NamedRegionSet(r);
						match = new Node(browser, header.fullname + "." + "match #" + i + " " + r.toString(), rs);
						header.add(match);
						i++;
					}
				}
			}
//			String currentExplanation = null;
			Node currentHeader = null;
			int j = 0;
			for (Iterator i = lexattracMap.keySet().iterator(); i.hasNext(); j++) {
				// get explanations
				// make new head
				// get vector
				// add all vector elements to head
				// add head to root
				String explanation = (String) i.next();
				debug.println(explanation);
				Vector children = (Vector) lexattracMap.get(explanation);
				currentHeader = new Node(browser, "cluster #" + j, new NamedRegionSet(RegionSet.EMPTY));
				for (Enumeration e = children.elements(); e.hasMoreElements();) {
					currentHeader.add((Node) e.nextElement());
				}
				RegionSet rs = RegionSet.EMPTY;
				for (Enumeration e = currentHeader.children(); e.hasMoreElements();) {
					rs.or(((Node) e.nextElement()).getMatch());
				}
				//Node oldHeader = new Node(browser, "cluster #" + j, new NamedRegionSet(browser.getDocument(), rs));
				Node oldHeader = new Node(browser, "cluster #" + j, new NamedRegionSet(rs));
				for (Enumeration e = currentHeader.children(); e.hasMoreElements();) {
					oldHeader.add((Node) e.nextElement());
				}
				root.addSorted(oldHeader);
				//				
				//				Node singleton = (Node)i.next();
				//				debug.println(singleton.toString() + " " + singleton.getExplanationText());
				//				if (singleton.getExplanationText() == currentExplanation){
				//					debug.println("same as the last one");
				//					currentHeader.add(singleton);
				//				}
				//				else{
				//					debug.println("new save curent and make a new current");
				//					if (currentHeader != null){
				//					//get the matches from current header and make a new node with the correct matches
				//					RegionSet rs = RegionSet.EMPTY;
				//					for (Enumeration e = currentHeader.children(); e.hasMoreElements();){
				//						rs.or(((Node)e.nextElement()).getMatch());
				//					}
				//					Node oldHeader =  new Node(browser, "cluster #" + j, new NamedRegionSet(browser.getDocument(), rs));
				//					root.add(oldHeader);
				//					}
				//					currentHeader = new Node(browser, "cluster #" + j, new NamedRegionSet(browser.getDocument(), singleton.getMatch()));
				//					currentHeader.add(singleton);
				//					currentHeader.setExplanationText(singleton.getExplanationText());
				j++;
			}
			//root.add(unclusterable);
		}
		protected void setExamples(NamedRegionSet positive, NamedRegionSet negative) {
			LexicalAttractionParser lexParse = new LexicalAttractionParser();

			if (positive == null && negative == null) {
				sim = null;
				clusters = new Similarity.Cluster[0];
				debug.println("pos and neg examples null");
				return;
			}
            
            // TODO: support multiple documents
            debug.assertion(positive.getVersions().getSize() == 1);
            Iterator idoc = positive.getDocuments();
            while (idoc.hasNext())
                lexParse.parse((Document)idoc.next());
             
			LexMap lm = lexParse.getLexicalMap();
			sim = new LexicalSimilarity(positive, negative, lm);
			debug.println("getting clusters");
			clusters = sim.getClusters();
		}
	}
	static class ClusterCreator implements NodeCreator {
		Node root;
		Similarity sim;
		Similarity.Cluster[] clusters;
		Browser browser;
		NamedRegionSet sel;
		public ClusterCreator(Browser browser, RegionSet rs) {
			this(browser, new NamedRegionSet(rs));
		}
		public ClusterCreator(Browser browser, NamedRegionSet sel) {
			this.sel = sel;
			this.browser = browser;
			debug.println("getting Pos/Neg");
			int sucess = getPosNeg();
			debug.println("setting root");
			root = new Node(browser, "**root**", new NamedRegionSet(Region.EMPTY));
			if (sucess == 1) {
				Region r = sel.regions().first();
				NamedRegionSet rs = new NamedRegionSet(r);
				Node match = new Node(browser, "**root**." + "match #1 " + r.toString(), rs);
				root.add(match);
			}
			else {
				handleClusters(browser);
			}
		}
		protected void handleClusters(Browser browser) {
			debug.println("" + clusters.length + " clusters found");
			int[] clusterSizeArray = new int[clusters.length];
			for (int j = 0; j < clusters.length; j++) {
				clusterSizeArray[j] = clusters[j].getSize();
			}
			PointerSort pointerArray = new PointerSort(clusterSizeArray);
			pointerArray.sort();
			int[] pArray = pointerArray.pointerArray();
			Node unclusterable = new Node(browser, "miscellaneous", new NamedRegionSet(Region.EMPTY));
			for (int j = 0; j < clusters.length; j++) {
				if (clusters[pArray[pArray.length - j - 1]].getSize() < 2) {
					RegionEnumeration e = clusters[pArray[pArray.length - j - 1]].regions();
					int k = 0;
					for (Region r = e.first(); r != null; r = e.next()) {
						Node match = null;
						NamedRegionSet rs = new NamedRegionSet(r);
						match = new Node(browser, "Unclusterable match #" + k + " " + r.toString(), rs);
						match.setExplanation(clusters[pArray[pArray.length - j - 1]].getExplanation());
						unclusterable.add(match);
						k++;
					}
				}
				else {
					Node header = new Node(browser, "cluster #" + j, new NamedRegionSet(clusters[pArray[pArray.length - j - 1]]));
					header.setExplanation(clusters[pArray[pArray.length - j - 1]].getExplanation());
					root.add(header);
					int i = 0;
					RegionEnumeration e = clusters[pArray[pArray.length - j - 1]].regions();
					for (Region r = e.first(); r != null; r = e.next()) {
						Node match = null;
						NamedRegionSet rs = new NamedRegionSet(r);
						match = new Node(browser, header.fullname + "." + "match #" + i + " " + r.toString(), rs);
						header.add(match);
						i++;
					}
				}
			}
			root.add(unclusterable);
		}
		protected int getPosNeg() {
			if (sel.getVersions().getSize() == 0 || sel == null) {
				setExamples(null, null);
				debug.println("doc null or posExamples null");
				return 0;
			}
			if (sel.getSize() <= 1) {
				setExamples(null, null);
				debug.println("too small posExamples");
				return 1;
			}
			debug.println("setting examples");
			setExamples(sel, new NamedRegionSet(RegionSet.EMPTY));
			return 100;
		}
		protected void setExamples(NamedRegionSet positive, NamedRegionSet negative) {
			if (positive == null && negative == null) {
				sim = null;
				clusters = new Similarity.Cluster[0];
				debug.println("pos and neg examples null");
				return;
			}
			sim = new Similarity(positive, negative);
			debug.println("getting clusters");
			clusters = sim.getClusters();
		}
		public Node getRoot() {
			return root;
		}
	}
	static class SingleGroupNodeCreator implements NodeCreator {
		Node root;
		//public SingleGroupNodeCreator(Browser browser, NamedRegionSet sel) {
		//	this(browser, sel.getRegions());
		//}
		public SingleGroupNodeCreator(Browser browser, RegionSet matches) {
			int i = 0;
			root = new Node(browser, "**root**", new NamedRegionSet(Region.EMPTY));
			Node header = new Node(browser, "", new NamedRegionSet(matches));
			RegionEnumeration e = matches.regions();
			for (Region r = e.first(); r != null; r = e.next()) {
				Node match = null;
				NamedRegionSet rs = new NamedRegionSet(r);
				match = new Node(browser, header.fullname + "." + "match #" + i + " " + r.toString(), rs);
				root.add(match);
				i++;
			}
		}
		public Node getRoot() {
			return root;
		}
	}
	/**
	 * Node contains all the information about a match 
	 */
	static class Node implements MutableTreeNode {
		boolean isTopLevel; // true iff child of root or is root
		String fullname;
		String label; // label shown in tree,
		Vector children;
		NamedRegionSet smatch;
		RegionSet rs;
		Node parent;
		Vector selectedChildren;
		Similarity.Explanation[] explanation;
		boolean selected;
		BufferedImage image;
		String exp = null;
		
		public Node() {
		}
		public Node(Browser browser, String fullname, NamedRegionSet match) {
			this.smatch = match;
			this.selected = false;
			this.fullname = fullname;
			this.children = new Vector();
			int i = fullname.lastIndexOf('.');
			if (i == -1) {
				isTopLevel = true;
				label = "" + children.size();
				this.rs = match;
				debug.println(this.toString() + " size " + rs.getSize());
				browser.getActivePane().getFindAndReplaceHighlighter().setSelection(match);
				image = createImage(browser, rs.regions().first());
				browser.getActivePane().getFindAndReplaceHighlighter().setSelection(null);
			}
			else {
				isTopLevel = false;
				label = fullname.substring(i + 1);
				this.rs = match;
				browser.getActivePane().getFindAndReplaceHighlighter().setSelection(match);
				if (rs != null)
					image = createImage(browser, rs.regions().first());
				browser.getActivePane().getFindAndReplaceHighlighter().setSelection(null);
			}
			this.children = new Vector();
			parent = null;
			selectedChildren = new Vector();
		}
		public Node copy() {
			Node copy = new Node();
			copy.smatch = this.smatch;
			copy.selected = false;
			copy.fullname = this.fullname;
			copy.children = new Vector();
			copy.isTopLevel = this.isTopLevel;
			copy.label = this.label;
			copy.rs = this.rs;
			copy.parent = this.parent;
			copy.selectedChildren = new Vector();
			copy.explanation = this.explanation;
			copy.image = this.image;
			copy.exp = this.exp;
			//debug.println("adding children");
			if (!isTopLevel) {
			}
			else {
				for (Enumeration e = this.children.elements(); e.hasMoreElements();) {
					Node o = (Node) e.nextElement();
					//debug.println("adding: " + o.fullname);
					Node p = o.copy();
					//debug.println(p.toString());
					copy.add(p);
				}
			}
			return copy;
		}
		public void setImage(BufferedImage img) {
			image = img;
		}
		private BufferedImage createImage(Browser browser, Region r) {
			Rectangle rect;
			Rectangle regionRec;
			BufferedImage img = null;
			try {
				if (r != null) {
					regionRec = browser.getActivePane().regionToExpandedRectangle(r);
					rect =
						new Rectangle(
							regionRec.x - 50,
							regionRec.y,
							Math.min(regionRec.width + 200, browser.getActivePane().getWidth()),
							regionRec.height);
					img = (BufferedImage) browser.createImage(rect.width, rect.height);
					// make a Graphics that will draw into the image
					Graphics g = img.getGraphics();
					// tell b to draw itself through the graphics
					g.translate(-1 * (int) rect.getX(), -1 * (int) rect.getY());
					g.setPaintMode();
					g.setColor(Color.white);
					g.fillRect(rect.x, rect.y, rect.width, rect.height);
					g.setClip(rect);
					browser.getActivePane().paint(g);
				}
			}
			catch (BadLocationException ble) {
				ble.printStackTrace();
			}
			return img;
		}
		public Image getImage() {
			if (image == null)
				debug.println("null image");
			return image;
		}
		public void setSelected(boolean sel) {
			this.selected = sel;
			if (parent != null) {
				if (!sel) {
					parent.selectedChildren.remove(this);
				}
				else
					if (!parent.selectedChildren.contains(this))
						parent.selectedChildren.add(this);
			}
			if (parent != null)
				debug.println(
					this.toString()
						+ " sel? "
						+ sel
						+ " sel sib "
						+ this.parent.getSelectedChildrenCount()
						+ " sib "
						+ this.parent.getChildCount());
		}
		public void setExplanation(Similarity.Explanation[] exp) {
			explanation = exp;
		}
		public void setExplanationText(String exp) {
			this.exp = exp;
		}
		public String getExplanationText() {
			if (this.exp == null) {
				if (explanation != null) {
					exp = "";
					for (int i = 0; i < explanation.length - 1; i++)
						exp = exp + explanation[i].feature + "\n";
					if (explanation.length - 1 >= 0)
						exp = exp + explanation[explanation.length - 1].feature;
				}
			}
			return exp;
		}
		public int getExplanationWidth() {
			int width = 0;
			if (explanation != null) {
				for (int i = 0; i < explanation.length; i++)
					width = Math.max(explanation[i].feature.length(), width);
			}
			return (int) (width * .75);
		}
		public int getExplanationHeight() {
			int height = 0;
			if (explanation != null) {
				height = explanation.length;
			}
			return height;
		}
//		private void setSelectedChildren(Vector sel) {
//			if (isTopLevel)
//				selectedChildren = new Vector(sel);
//			for (Enumeration e = selectedChildren.elements(); e.hasMoreElements();)
//				 ((Node) e.nextElement()).setSelected(true);
//		}
		// sets all children to unselected
		public void resetSelectedChildren() {
			for (Enumeration e = children.elements(); e.hasMoreElements();)
				 ((Node) e.nextElement()).setSelected(false);
			selectedChildren = new Vector();
		}
		public void selectAllChildren() {
			for (Enumeration e = children.elements(); e.hasMoreElements();)
				 ((Node) e.nextElement()).setSelected(true);
		}
		public Vector getSelectedChildren() {
			return selectedChildren;
		}
		public int getSelectedChildrenCount() {
			return selectedChildren.size();
		}
		public Vector getSelectedDecendents() {
			Vector selectedDecendents = new Vector();
			if (!isTopLevel) {
			}
			else {
				for (Enumeration e = this.children.elements(); e.hasMoreElements();) {
					Node o = (Node) e.nextElement();
					if (o.selected) {
						//debug.println("adding: " + o.fullname);
						selectedDecendents.add(o);
					}
					selectedDecendents.addAll(o.getSelectedDecendents());
				}
			}
			return selectedDecendents;
		}
		public int getDescendantsCount() {
			int count = 0;
			if (!isTopLevel)
				return count;
			for (Enumeration e = children.elements(); e.hasMoreElements();) {
				Node n = (Node) e.nextElement();
				if (n.isTopLevel) {
					count += n.getDescendantsCount();
				}
				else
					count++;
			}
			//			debug.println("total count " + count);
			return count;
		}
		public void add(Node node) {
			if (!children.contains(node))
				children.add(node);
			node.parent = this;
			resetText();
		}
		public void addSorted(Node node) {
			debug.println("*********************Adding sorted node  of size " + node.getChildCount()+ "*********************");
			if (!children.contains(node)) {
				int i = 0;
				while ( i < getChildCount()) {
					if (((Node) children.elementAt(i)).getChildCount() > node.getChildCount())
						i++;
					else
						break;
				}
				children.add(i, node);
				for (Enumeration e = children.elements(); e.hasMoreElements();)
					debug.print(((Node)e.nextElement()).getChildCount() +" " );
				debug.println("");
			}
			node.parent = this;
			resetText();
		}
		public void remove(Node node) {
			children.remove(node);
			selectedChildren.remove(node);
			debug.println(" rs size: " + rs.getSize());
			rs = filteredEmptyRegions(rs);
		}
		public NamedRegionSet getSelection() {
			return smatch;
		}
		public void resetText() {
			if (isTopLevel) {
				label = fullname + " " + children.size() + " match";
				if (children.size() > 1)
					label = label + "es";
			}
		}
		public String toString() {
			if (isTopLevel) {
				String str = fullname + " " + children.size() + " match";
				if (children.size() > 1)
					str = str + "es:   ";
				else
					label = label + ":   ";
				return str;
			}
			return label;
		}
		public String getLabel() {
			if (isTopLevel) {
				if (fullname != "miscellaneous") {
					label = "" + children.size() + " related match";
					if (children.size() > 1)
						label = label + "es:   ";
					else
						label = label + ":   ";
					return label;
				}
				else {
					label = "" + children.size() + " miscellaneous match";
					if (children.size() > 1)
						label = label + "es:   ";
					else
						label = label + ":   ";
					return label;
				}
			}
			return label;
		}
		public RegionSet getMatch() {
			return filteredEmptyRegions(smatch.convertToLatest());
		}
		public boolean equals(Object obj) {
			return (obj instanceof Node)
				&& fullname.equals(((Node) obj).fullname)
				&& children.size() == ((Node) obj).getChildCount()
				&& getDescendantsCount() == ((Node) obj).getDescendantsCount();
		}
		/**
		 * Returns the children of the receiver as an Enumeration.  
		 **/
		public Enumeration children() {
			return children.elements();
		}
		/**
		 * Returns true if the receiver allows children.
		 **/
		public boolean getAllowsChildren() {
			return isTopLevel;
		}
		/**
		 * Returns the child TreeNode at index childIndex. 
		 **/
		public TreeNode getChildAt(int childIndex) {
			return (TreeNode) children.elementAt(childIndex);
		}
		/**
		 * Returns the number of children TreeNodes the receiver contains. 
		 **/
		public int getChildCount() {
			return children.size();
		}
		/**
		 * Returns the index of node in the receivers children.
		 **/
		public int getIndex(TreeNode node) {
			return children.indexOf(node);
		}
		/**
		 * Returns the parent TreeNode of the receiver.  
		 **/
		public TreeNode getParent() {
			return parent;
		}
		public Node[] getAncestors() {
			Vector v = new Vector();
			v.add(this);
			Node p = (Node) getParent();
			while (p != null) {
				v.add(p);
				p = (Node) p.getParent();
			}
			Node[] ancestors = new Node[v.size()];
			int i = v.size() - 1;
			for (Enumeration e = v.elements(); e.hasMoreElements(); i--) {
				ancestors[i] = (Node) e.nextElement();
			}
			return ancestors;
		}
		/**
		 * Returns true if the receiver is a leaf.
		 **/
		public boolean isLeaf() {
			return getChildCount() == 0;
		}
		/**
		 * Adds child to the receiver at index.
		 **/
		public void insert(MutableTreeNode child, int index) {
			children.remove(child);
			children.add(index, child);
		}
		/**
		 * Removes the child at index from the receiver. 
		 **/
		public void remove(int index) {
			Object removed = children.remove(index);
			((Node) removed).setParent(null);
			selectedChildren.remove(removed);
			debug.println(
				"removed int: " + removed.toString() + " rs size: " + this.rs.getSize() + " " + this.getChildCount());
			rs = filteredEmptyRegions(rs);
		}
		/**
		 * Removes node from the receiver.  
		 **/
		public void remove(MutableTreeNode node) {
			boolean removed = children.remove(node);
			if (removed)
				selectedChildren.remove(node);
			debug.println("removed node: " + removed + " rs size: " + rs.getSize());
			rs = filteredEmptyRegions(rs);
		}
		/**
		 * Removes the receiver from its parent.  
		 **/
		public void removeFromParent() {
			if (parent != null) {
				parent.remove(this);
				parent = null;
			}
		}
		/**
		 * Sets the parent of the receiver to newParent. 
		 **/
		public void setParent(MutableTreeNode newParent) {
			this.parent = (Node) newParent;
		}
		/**
		 *  Resets the user object of the receiver to object.
		 **/
		public void setUserObject(Object object) {
		}
	}
}
