/*
 * LAPIS lightweight structured text processing system
 *
 * Copyright (C) 1998-2002 Carnegie Mellon University,
 * Copyright (C) 2003 Massachusetts Institute of Technology.
 * All rights reserved.
 *
 * This library is free software; you can redistribute it
 * and/or modify it under the terms of the GNU General
 * Public License as published by the Free Software
 * Foundation, version 2.
 *
 * LAPIS homepage: http://graphics.lcs.mit.edu/lapis/
 */

package lapis.swing.cluster;

import lapis.*;
import lapis.swing.*;
import java.awt.*;
import java.awt.event.*;
import java.util.*;
import javax.swing.*;
import javax.swing.event.*;
import lapisx.swing.*;
import lapis.swing.cluster.MatchNodeCreator.Node;
import javax.swing.undo.*;
/**
 * A dual table representation of the matches within a document
 **/

public class MatchTable extends JPanel implements MatchDisplayPanel, StateEditable {
	public static lapisx.util.Debug debug = lapisx.util.Debug.QUIET;
	Browser browser;
	ClusterFindReplacePane clusterPane;
	HeaderList clusters;
	ChildrenList matches;
	JScrollPane matchesPane;
	Node root;
	boolean cluster;
	UndoManager undoManager;

	//JEditorPane explanationText;
	public MatchTable(ClusterFindReplacePane clusterPane, Browser browser, NamedRegionSet sel, boolean cluster) {
		this(MatchNodeCreator.createNodes(browser, sel, cluster));
		this.cluster = cluster;
		this.browser = browser;
		this.clusterPane = clusterPane;

//		JSplitPane sub;

		JPanel clusterPanel = new JPanel();

		Layout
			.vertical(clusterPanel)
			.setAlignment(Layout.WEST)
			.add(new JLabel("Clusters"))
			.add(new JScrollPane(clusters = new HeaderList(root.children, browser)))
			.done();
		//		JPanel descriptionPanel = new JPanel();
		//		Layout
		//			.vertical(descriptionPanel)
		//			.setAlignment(Layout.WEST)
		//			.add(new JLabel("Description"))
		//			.add(new JScrollPane(explanationText = new JEditorPane()))
		//			.done();
		JPanel matchesPanel = new JPanel();
		Layout
			.vertical(matchesPanel)
			.setAlignment(Layout.WEST)
			.add(new JLabel("Matches"))
			.add(matchesPane = new JScrollPane(matches = new ChildrenList()))
			.done();
		//		JSplitPane main =
		//			new JSplitPane(
		//				JSplitPane.VERTICAL_SPLIT,
		//				sub = new JSplitPane(JSplitPane.HORIZONTAL_SPLIT, clusterPanel, descriptionPanel),
		//				matchesPanel);
		JSplitPane main = new JSplitPane(JSplitPane.VERTICAL_SPLIT, clusterPanel, matchesPanel);
		Layout.horizontal(this).add(main).done();

		main.setDividerLocation(100);
		//		sub.setDividerLocation(300);

		setupListeners();
		setProperties();
		clusters.setSelectedIndex(0);
		undoManager = new UndoManager();
	}

	public MatchTable(ClusterFindReplacePane clusterPane, Browser browser, RegionSet matches, boolean cluster) {
		//this(clusterPane, browser, new NamedRegionSet(browser.getDocument(), matches), cluster);
		this(clusterPane, browser, new NamedRegionSet(matches), cluster);
	}

	public MatchTable(MatchNodeCreator.NodeCreator nc) {
		root = nc.getRoot();

	}

	public boolean componentHasFocus() {
		return (clusters.hasFocus() || matches.hasFocus() || matchesPane.hasFocus()); // || explanationText.hasFocus());
	}

	public Node findNodeMatch(NamedRegionSet sel) {

		debug.println("do something");
		if (sel.getSize() == 1) {
			debug.println("one selection");
			// try to highlight the corresponding node
			// if it exists, else do nothing
			//RegionSet rs = sel.getRegions();
			for (Enumeration e = root.children.elements(); e.hasMoreElements();) {
				Node n = (Node)e.nextElement();
				if (n.isTopLevel) {
					for (Enumeration f = n.children.elements(); f.hasMoreElements();) {
						Node child = (Node)f.nextElement();
						//debug.println("testing " + child.getMatch().toString() + " vs. " + rs.toString());
						if (child.getMatch().equals((RegionSet)sel)) {
							debug.println("Match found");
							return child;
						} // if
					} //for
				} //if
				else {
					//check singletons
				} //else
			} //for
		} //if
		else {
			//MatchTree.this.clearSelection();
		}
		return null;
	}

	private void setupListeners() {

		addFocusListener(new FocusListener() {
			public void focusGained(FocusEvent e) {
				debug.println("gained focus");
				// rehighlight selected nodes

				highlightSelectedNodes();
			}
			public void focusLost(FocusEvent e) {
				debug.println("focus lost");
			}
		});

		browser.addSelectionListener(new SelectionListener() {
			public void changedSelection(Browser browser, NamedRegionSet sel) {
				if (MatchTable.this.hasFocus() || MatchTable.this.componentHasFocus() || clusterPane.componentHasFocus()) {}
				else {
					Node child = findNodeMatch(sel);
					if (child != null) {

						Vector selectedChild = new Vector();
						selectedChild.add(child);
						child.setSelected(true);
						Node n = (Node)child.getParent();
						if (n == (Node)clusters.getSelectedValue()) {
							//highlight the single match
							matches.setSelectedValue(child, true);
						}
						else {
							//go to that node and set scroll bar to view
							clusters.setSelectedValue(n, true);
							matches.setSelectedValue(child, true);
						}
					}
				} //else
			}

		});

	}

	private void setProperties() {

		//		explanationText.getDocument().putProperty(DefaultEditorKit.EndOfLineStringProperty, "\n");
		//		explanationText.setEditable(false);
	}

	/**
	 * selects all matches displayed
	 **/
	public void selectAll() {
		if (matches != null)
			matches.selectAll();
	}

	/**
	 * highlights in browser all matches displayed
	 **/
	public void highlightAll() {
		if (matches != null)
			matches.highlightAll();

	}
	/**
	 * unselects all matches found
	 **/
	public void clearSelection() {
		if (matches != null)
			matches.clearSelection();
		highlight(new Vector());
	}

	/**
	 * deletes the selection from the display
	 **/
	public void deleteSelection() {
		StateEdit newEdit = new StateEdit(this);
		matches.remove(matches.getSelectedValues());
		if (((Node)clusters.getSelectedValue()).getChildCount() == 0)
			clusters.remove(clusters.getSelectedValues());
		// "end" the edit when you are done modifying the object
		newEdit.end();
		// debug.println("before " + newEdit.preState + " after: " + newEdit.postState);
		debug.println("can undo? " + newEdit.canUndo());
		undoManager.addEdit(newEdit);
	}

	public void undo() {
		try {
			undoManager.undo();
		}
		catch (CannotUndoException cue) {}
	}

	public void restoreState(Hashtable state) {
		debug.println("savedState: " + state.toString());

		Node root2 = (Node)state.get("root");
		if (root2 == null)
			return;
		DefaultListModel dlm = new DefaultListModel();
		for (Enumeration e = root2.children(); e.hasMoreElements();)
			dlm.addElement(e.nextElement());
		clusters.setModel(dlm);
		setupListeners();

		//int selected = clusters.getSelectedIndex();
		clusters.clearSelection();
		DefaultListModel dlm2 = new DefaultListModel();
		matches.setModel(dlm2);
		this.root = root2;

		this.setVisible(false);
		this.setVisible(true);

		this.repaint();
	}
	public void storeState(Hashtable state) {
		Node root2 = root.copy();
		state.put("root", root2);

	}

	public void highlight(Vector nodes) {
		RegionSet rs = RegionSet.EMPTY;
		for (Enumeration e = nodes.elements(); e.hasMoreElements();) {
			Object o = e.nextElement();
			if (o instanceof Node) {
				rs = rs.or(((Node)o).getMatch());

			}
		}
		browser.setSelection(new NamedRegionSet(rs));
		browser.getActivePane().scrollRegionsToVisible(rs);

	}

	public void highlightSelectedNodes() {
		RegionSet rs = RegionSet.EMPTY;
		for (Enumeration e = root.children.elements(); e.hasMoreElements();) {
			Object o = e.nextElement();
			if (o instanceof Node) {
				Node p = (Node)o;
				if (p.isTopLevel) {
					for (Enumeration f = p.getSelectedChildren().elements(); f.hasMoreElements();) {
						Object n = f.nextElement();
						rs = rs.or(((Node)n).getMatch());
					}
				}
			}
		}
		browser.setSelection(new NamedRegionSet(rs));
		browser.getActivePane().scrollRegionsToVisible(rs);

	}

	class HeaderList extends JList {
		Browser browser;
		Vector headers;
		Rectangle highlighted= null;
		
		public HeaderList(Vector v, Browser b) {
			super(v);
			setModel(new DefaultListModel());
			for (Enumeration e = v.elements(); e.hasMoreElements();)
				 ((DefaultListModel)getModel()).addElement(e.nextElement());
			browser = b;
			setupListeners();
			setSelectionMode(ListSelectionModel.SINGLE_SELECTION);
			setCellRenderer(new Renderer(b));
		}
		
		protected void paintComponent(Graphics g) {

			super.paintComponent(g);
			if (highlighted != null) {
				g.setColor(new Color(150, 150, 150, 50));
				g.fill3DRect(highlighted.x, highlighted.y, highlighted.width, highlighted.height, true);
				debug.println("want to paint: " + highlighted.toString());
			}
		}
		
		
		private void setupListeners() {
			
			addMouseMotionListener(new MouseMotionAdapter() {
				public void mouseMoved(MouseEvent me) {
					//		    debug.println("mouse moved");
					int row = locationToIndex(new Point(me.getX(), me.getY()));
					if (HeaderList.this.getCellBounds(row, row) != highlighted) {
						highlighted = HeaderList.this.getCellBounds(row, row);
						repaint();
					}
				}
			});
			addMouseListener(new MouseInputAdapter() {
				public void mouseExited(MouseEvent me) {
					highlighted = null;
					repaint();
				}
			});
			addListSelectionListener(new ListSelectionListener() {
				public void valueChanged(ListSelectionEvent e) {
					if (getModel().getSize() > 0) {

						Node selected = (Node)getSelectedValue();

						if (selected != null) {
							debug.println("selected: " + selected.toString() + " children: " + selected.children.size());
							matchesPane.setViewportView(matches = new ChildrenList(selected.children, browser, selected));
							matches.selectAll();
						}
						else {
							debug.println("nothing Selected");
							matches.clearSelection();

						}
					}
				}
			});
		}
		public void remove(Object node) {
			if (node instanceof Node)
				 ((DefaultListModel)getModel()).removeElement(node);

		}

		public void remove(Object[] nodes) {
			for (int i = 0; i < nodes.length; i++) {
				if (nodes[i] instanceof Node) {
					((DefaultListModel)getModel()).removeElement(nodes[i]);
					root.remove((Node)nodes[i]);
				}
			}
		}

	}

	class ChildrenList extends JList {
		Node parent;
		Rectangle highlighted;
		public ChildrenList() {
			super();
		}
		public ChildrenList(Vector v, Browser b, Node parent) {
			super(v);
			setModel(new DefaultListModel());
			setUI(new MatchListUI());
			for (Enumeration e = v.elements(); e.hasMoreElements();)
				 ((DefaultListModel)getModel()).addElement(e.nextElement());
			this.parent = parent;
			setupListeners();
			setSelectionMode(ListSelectionModel.MULTIPLE_INTERVAL_SELECTION);

			if (parent.getSelectedChildren() != null) {
				int[] selectedIndices = new int[parent.getSelectedChildren().size()];
				int i = 0;
				for (Enumeration e = parent.getSelectedChildren().elements(); e.hasMoreElements(); i++) {
					selectedIndices[i] = ((DefaultListModel)getModel()).indexOf(e.nextElement());
				}
				setSelectedIndices(selectedIndices);
			}
			else
				b.clearSelection();

			setCellRenderer(new Renderer(b));
		}
		protected void paintComponent(Graphics g) {

			super.paintComponent(g);
			if (highlighted != null) {
				g.setColor(new Color(150, 150, 150, 50));
				g.fill3DRect(highlighted.x, highlighted.y, highlighted.width, highlighted.height, true);
				debug.println("want to paint: " + highlighted.toString());
			}
		}
		private void setupListeners() {

			addMouseMotionListener(new MouseMotionAdapter() {
				public void mouseMoved(MouseEvent me) {
					//		    debug.println("mouse moved");
					int row = locationToIndex(new Point(me.getX(), me.getY()));
					if (ChildrenList.this.getCellBounds(row, row) != highlighted) {
						highlighted = ChildrenList.this.getCellBounds(row, row);
						repaint();
					}
				}
			});
			addMouseListener(new MouseInputAdapter() {
				public void mouseExited(MouseEvent me) {
					highlighted = null;
					repaint();
				}
			});
			addListSelectionListener(new ListSelectionListener() {
				public void valueChanged(ListSelectionEvent e) {

					Object[] selected = getSelectedValues();
					Vector nodes = new Vector();
					if (selected != null) {
						for (int i = 0; i < selected.length; i++) {
							if (selected[i] instanceof Node) {
								Node node = (Node)selected[i];
								node.setSelected(true);
								nodes.add(node);
							}
						}
					}
					MatchTable.this.highlight(nodes);

				}
			});
		}
		public void clearSelection() {
			super.clearSelection();
			if (parent != null)
				parent.resetSelectedChildren();
		}

		public void highlightAll() {
			parent.selectAllChildren();
			MatchTable.this.highlightSelectedNodes();

		}
		public void selectAll() {
			setSelectionInterval(0, getModel().getSize() - 1);
			parent.selectAllChildren();
			debug.println(
				"sel size: "
					+ getModel().getSize()
					+ "par.chil size: "
					+ parent.children.size()
					+ " selChil size: "
					+ parent.getSelectedChildren().size());

		}
		public void remove(Object node) {
			if (node instanceof Node) {
				parent.remove((Node)node);
				((DefaultListModel)getModel()).removeElement(node);
			}
		}
		public void remove(Object[] nodes) {
			for (int i = 0; i < nodes.length; i++) {
				if (nodes[i] instanceof Node) {
					parent.remove((Node)nodes[i]);
					((DefaultListModel)getModel()).removeElement(nodes[i]);
				}
			}
		}

		public void remove(Vector nodes) {
			for (Enumeration e = nodes.elements(); e.hasMoreElements();) {
				Node n = (Node)e.nextElement();
				parent.remove(n);
				((DefaultListModel)getModel()).removeElement(n);
			}
		}

	}

	class Renderer implements ListCellRenderer {
		Browser browser;

		public Renderer(Browser browser) {
			super();
			this.browser = browser;

		}

		public Component getListCellRendererComponent(JList list, Object value, int index, boolean sel, boolean cellHasFocus) {
			Node n = (Node)value;
			//	    debug.println(n.toString());
			ClusterRenderer renderer = new ClusterRenderer();
			if (n.getAllowsChildren()) {
				JComponent m = renderer.getTopSingleClip(browser, n, false, sel, cellHasFocus);
				return m;
			}

			RegionSet rs = n.getMatch();
			Region r = rs.regions().first();
			JComponent c = renderer.getSingleClip(browser, n, r, sel, cellHasFocus);
			//c.setToolTipText(n.getExplanationText());
			return c;

		}

	}

}
