/*
 * LAPIS lightweight structured text processing system
 *
 * Copyright (C) 1998-2002 Carnegie Mellon University,
 * Copyright (C) 2003 Massachusetts Institute of Technology.
 * All rights reserved.
 *
 * This library is free software; you can redistribute it
 * and/or modify it under the terms of the GNU General
 * Public License as published by the Free Software
 * Foundation, version 2.
 *
 * LAPIS homepage: http://graphics.lcs.mit.edu/lapis/
 */

package lapis.swing.cluster;

import lapis.*;
import lapis.swing.*;
import java.awt.*;
import javax.swing.*;
import lapis.swing.cluster.MatchNodeCreator.Node;



/**
 * A tree representation of the matches within a document
 **/

public class MatchTreePanel extends JScrollPane implements MatchDisplayPanel {
	public static lapisx.util.Debug debug = lapisx.util.Debug.QUIET;
	MatchTree matchTree;
	ClusterFindReplacePane clusterPane;

	public MatchTreePanel(
		ClusterFindReplacePane clusterPane,
		Browser browser,
		NamedRegionSet sel,
		boolean cluster) {
		super();

		matchTree = new MatchTree(clusterPane, browser, sel, cluster);
		setViewportView((Component) matchTree);
		this.clusterPane = clusterPane;
		
	}
	public MatchTreePanel() {
		super();
		matchTree = null;
	}

//	public void undo(ActionEvent e) {
//		matchTree.undo();
//	}
	public void undo() {
		matchTree.undo();
	}

	/**
	 * selects all matches displayed
	 **/
	public void selectAll() {
		if (matchTree != null)
			matchTree.selectAll();
	}

	/**
	 * highlights in browser all matches displayed
	 **/
	public void highlightAll() {
		if (matchTree != null)
			matchTree.highlightAll();
	}
	/**
	 * unselects all matches found
	 **/
	public void clearSelection() {
		if (matchTree != null)
			matchTree.clearSelection();
	}

	/**
	 * deletes the selection from the display
	 **/
	public void deleteSelection() {
		if (matchTree != null)
			matchTree.deleteSelection();
	}
	public Node findNodeMatch(NamedRegionSet sel) {
		if (matchTree != null)
			return matchTree.findNodeMatch(sel);
		return null;
	}
	
	public boolean componentHasFocus() {
		if (matchTree != null)
			return matchTree.hasFocus();
		return false;
	}
}
