/*
 * LAPIS lightweight structured text processing system
 *
 * Copyright (C) 1998-2002 Carnegie Mellon University,
 * Copyright (C) 2003 Massachusetts Institute of Technology.
 * All rights reserved.
 *
 * This library is free software; you can redistribute it
 * and/or modify it under the terms of the GNU General
 * Public License as published by the Free Software
 * Foundation, version 2.
 *
 * LAPIS homepage: http://graphics.lcs.mit.edu/lapis/
 */

package lapis.swing.cluster;

import lapis.*;
import lapis.swing.*;
import java.awt.*;
import javax.swing.*;
import javax.swing.undo.*;
import lapis.swing.cluster.MatchNodeCreator.Node;

/**
 * A Tabletree representation of the matches within a document
 **/
public class MatchTreeTablePanel extends JScrollPane implements MatchDisplayPanel {
	public static lapisx.util.Debug debug = lapisx.util.Debug.QUIET;
	MatchTreeTable matchTreeTable;
	UndoManager undoManager;

	public MatchTreeTablePanel(ClusterFindReplacePane clusterPane, Browser browser, NamedRegionSet sel, boolean cluster) {

		super();
		TreeTableModel tm;
		if (cluster)
			tm = new ClusterNodeTableModel(browser, sel);
		else
			tm = new SingleNodeTableModel(browser, sel);

		matchTreeTable = new MatchTreeTable(clusterPane, browser, sel, cluster, tm);

		setViewportView((Component)matchTreeTable);
		undoManager = new UndoManager();

	}
	public MatchTreeTablePanel() {
		super();
		matchTreeTable = null;
	}

	public void undo() {
		matchTreeTable.getTree().undo();
		matchTreeTable.undo();
		setVisible(false);
		setVisible(true);
	}

	/**
	 * selects all matches displayed
	 **/
	public void selectAll() {
		if (matchTreeTable != null)
			matchTreeTable.getTree().selectAll();
	}

	/**
	 * highlights in browser all matches displayed
	 **/
	public void highlightAll() {
		if (matchTreeTable != null)
			matchTreeTable.getTree().highlightAll();
		matchTreeTable.setVisible(false);
		matchTreeTable.setVisible(true);
		revalidate();
		setVisible(false);
		setVisible(true);
		repaint(0);
	}
	/**
	 * unselects all matches found
	 **/
	public void clearSelection() {
		if (matchTreeTable != null)
			matchTreeTable.getTree().clearSelection();
		setVisible(false);
		setVisible(true);
		revalidate();
	}

	/**
	 * deletes the selection from the display
	 **/
	public void deleteSelection() {
		if (matchTreeTable != null) {
			matchTreeTable.getTree().deleteSelection();
		}
	}
	
	public Node findNodeMatch(NamedRegionSet sel) {
		if (matchTreeTable != null)
			return matchTreeTable.getTree().findNodeMatch(sel);
		return null;
	}
	
	public boolean componentHasFocus() {
		if (matchTreeTable != null)
			return (matchTreeTable.getTree().hasFocus() || matchTreeTable.hasFocus());
		return false;
	}
	
}
