/*
 * LAPIS lightweight structured text processing system
 *
 * Copyright (C) 1998-2002 Carnegie Mellon University,
 * Copyright (C) 2003 Massachusetts Institute of Technology.
 * All rights reserved.
 *
 * This library is free software; you can redistribute it
 * and/or modify it under the terms of the GNU General
 * Public License as published by the Free Software
 * Foundation, version 2.
 *
 * LAPIS homepage: http://graphics.lcs.mit.edu/lapis/
 */

package lapis.swing.cluster;

import lapis.*;
import lapis.swing.*;
import java.util.*;
import lapis.swing.cluster.MatchNodeCreator.*;

public  class SingleNodeTableModel extends AbstractTreeTableModel implements TreeTableModel{
	Vector data;
	Vector column;

	public SingleNodeTableModel(Browser browser, RegionSet rs) {
		//this(browser, new NamedRegionSet(browser.getDocument(), rs));
		this(browser, new NamedRegionSet(rs));
	}

	public SingleNodeTableModel(Browser browser, NamedRegionSet sel) {
		this(new SingleGroupNodeTableCreator(browser, sel));
	}
	public SingleNodeTableModel(SingleGroupNodeTableCreator sgntc) {
		super(null);
		root = sgntc.getRoot();
		data = sgntc.getData();
		column = sgntc.getColumn();
	}
	public SingleNodeTableModel(Node root) {
		this(new SingleGroupNodeTableCreator(root));
	}


	//
	// The TreeModel interface
	//

	/**
	 * Returns the number of children of <code>node</code>.
	 */
	public int getChildCount(Object node) {
		return ((Node) node).getChildCount();
	}

	/**
	 * Returns the child of <code>node</code> at index <code>i</code>.
	 */
	public Object getChild(Object node, int i) {
		return ((Node) node).children.get(i);
	}

	/**
	 * Returns true if the passed in object represents a leaf, false
	 * otherwise.
	 */
	public boolean isLeaf(Object node) {
		return ((Node) node).isLeaf();
	}

	//
	//  The TreeTableNode interface. 
	//

	/**
	 * Returns the number of columns.
	 */
	public int getColumnCount() {
		return column.size();
	}

	/**
	 * Returns the name for a particular column.
	 */
	public String getColumnName(int column) {
		return (String) this.column.get(column);
	}

	/**
	 * Returns the class for the particular column.
	 */
	public Class getColumnClass(int column) {
		switch (column) {
			case 0 :
				return TreeTableModel.class;
			case 1 :
				return String.class;

		}
		return null;
	}

	/**
	 * Returns the value of the particular column.
	 */
	public Object getValueAt(Object node, int column) {
		Node n = (Node) node;

		switch (column) {
			case 0 :
				return n;
			case 1 :
			if (n.getChildCount()>0)
				return new Integer(n.getChildCount());
			return new String("1");	
		}
		return null;
	}
}
