/*
 * LAPIS lightweight structured text processing system
 *
 * Copyright (C) 1998-2002 Carnegie Mellon University,
 * Copyright (C) 2003 Massachusetts Institute of Technology.
 * All rights reserved.
 *
 * This library is free software; you can redistribute it
 * and/or modify it under the terms of the GNU General
 * Public License as published by the Free Software
 * Foundation, version 2.
 *
 * LAPIS homepage: http://graphics.lcs.mit.edu/lapis/
 */
 package lapis.swing.cluster;
import javax.swing.tree.TreeModel;
import javax.swing.tree.MutableTreeNode;
import lapis.swing.cluster.MatchNodeCreator.Node;

public interface TreeTableModel extends TreeModel {

	public void setRoot(Node node);

	/**
	 * Returns the number ofs availible column.
	 */
	public int getColumnCount();

	/**
	 * Returns the name for column number <code>column</code>.
	 */
	public String getColumnName(int column);

	/**
	 * Returns the type for column number <code>column</code>.
	 */
	public Class getColumnClass(int column);

	/**
	 * Returns the value to be displayed for node <code>node</code>, 
	 * at column number <code>column</code>.
	 */
	public Object getValueAt(Object node, int column);

	/**
	 * Indicates whether the the value for node <code>node</code>, 
	 * at column number <code>column</code> is editable.
	 */
	public boolean isCellEditable(Object node, int column);

	/**
	 * Sets the value for node <code>node</code>, 
	 * at column number <code>column</code>.
	 */
	public void setValueAt(Object aValue, Object node, int column);

	public void fireTreeNodesChanged(
		Object source,
		Object[] path,
		int[] childIndices,
		Object[] children);

	/*
	 * Notify all listeners that have registered interest for
	 * notification on this event type.  The event instance 
	 * is lazily created using the parameters passed into 
	 * the fire method.
	 * @see EventListenerList
	 */
	public void fireTreeNodesInserted(
		Object source,
		Object[] path,
		int[] childIndices,
		Object[] children);

	/*
	 * Notify all listeners that have registered interest for
	 * notification on this event type.  The event instance 
	 * is lazily created using the parameters passed into 
	 * the fire method.
	 * @see EventListenerList
	 */
	public void fireTreeNodesRemoved(
		Object source,
		Object[] path,
		int[] childIndices,
		Object[] children);

	/*
	 * Notify all listeners that have registered interest for
	 * notification on this event type.  The event instance 
	 * is lazily created using the parameters passed into 
	 * the fire method.
	 * @see EventListenerList
	 */
	public void fireTreeStructureChanged(
		Object source,
		Object[] path,
		int[] childIndices,
		Object[] children);

	public void removeNodeFromParent(MutableTreeNode node);

}
