/*
 * LAPIS lightweight structured text processing system
 *
 * Copyright (C) 1998-2002 Carnegie Mellon University,
 * Copyright (C) 2003 Massachusetts Institute of Technology.
 * All rights reserved.
 *
 * This library is free software; you can redistribute it
 * and/or modify it under the terms of the GNU General
 * Public License as published by the Free Software
 * Foundation, version 2.
 *
 * LAPIS homepage: http://graphics.lcs.mit.edu/lapis/
 */
package lapis.swing.cluster;
import javax.swing.JTree;
import javax.swing.SwingUtilities;
import javax.swing.table.AbstractTableModel;
import javax.swing.tree.TreePath;
import javax.swing.event.TreeExpansionEvent;
import javax.swing.event.TreeExpansionListener;
import javax.swing.event.TreeModelEvent;
import javax.swing.event.TreeModelListener;

public class TreeTableModelAdapter extends AbstractTableModel {
	JTree tree;
	TreeTableModel treeTableModel;
	boolean expanding;
	public static lapisx.util.Debug debug = lapisx.util.Debug.QUIET;

	public TreeTableModelAdapter(TreeTableModel treeTableModel, JTree tree) {
		this.tree = tree;
		this.treeTableModel = treeTableModel;

		tree.addTreeExpansionListener(new TreeExpansionListener() {
			// Don't use fireTableRowsInserted() here; the selection model
			// would get updated twice. 
			public void treeExpanded(TreeExpansionEvent event) {
				expanding = true;
				debug.println("tree expanded");
				try {
					fireTableDataChanged();
				}
				finally {
					expanding = false;
				}
				
			}
			public void treeCollapsed(TreeExpansionEvent event) {
				expanding = true;
				debug.println("tree Collapsed");
				try {
					fireTableDataChanged();
				}
				finally {
					expanding = false;
				}
			}
		});

		
		

		// Install a TreeModelListener that can update the table when
		// tree changes. We use delayedFireTableDataChanged as we can
		// not be guaranteed the tree will have finished processing
		// the event before us.
		treeTableModel.addTreeModelListener(new TreeModelListener() {
			public void treeNodesChanged(TreeModelEvent e) {
				debug.println("nodes changed");
				delayedFireTableDataChanged();
			}

			public void treeNodesInserted(TreeModelEvent e) {
				debug.println("nodes inserted");
				delayedFireTableDataChanged();
			}

			public void treeNodesRemoved(TreeModelEvent e) {
				debug.println("nodes removed");
				delayedFireTableDataChanged();
			}

			public void treeStructureChanged(TreeModelEvent e) {
				debug.println("structure changed");
				delayedFireTableDataChanged();
			}
		});
	}

	// Wrappers, implementing TableModel interface. 

	public int getColumnCount() {
		return treeTableModel.getColumnCount();
	}

	public String getColumnName(int column) {
		return treeTableModel.getColumnName(column);
	}

	public Class getColumnClass(int column) {
		return treeTableModel.getColumnClass(column);
	}

	public int getRowCount() {
		return tree.getRowCount();
	}

	protected Object nodeForRow(int row) {
		TreePath treePath = tree.getPathForRow(row);
		return treePath.getLastPathComponent();
	}

	public Object getValueAt(int row, int column) {
		return treeTableModel.getValueAt(nodeForRow(row), column);
	}

	public boolean isCellEditable(int row, int column) {
		return treeTableModel.isCellEditable(nodeForRow(row), column);
	}

	public void setValueAt(Object value, int row, int column) {
		treeTableModel.setValueAt(value, nodeForRow(row), column);
	}
	public boolean getExpanding(){
		return expanding;
	}
	/**
	 * Invokes fireTableDataChanged after all the pending events have been
	 * processed. SwingUtilities.invokeLater is used to handle this.
	 */
	protected void delayedFireTableDataChanged() {
		SwingUtilities.invokeLater(new Runnable() {
			public void run() {
				fireTableDataChanged();
				debug.println("fired TableDataChanged");
			}
		});
	}
//	public void fireTableChanged(TableModelEvent e) {
//		debug.println("table changed");
//	// Guaranteed to return a non-null array
//	Object[] listeners = listenerList.getListenerList();
//	// Process the listeners last to first, notifying
//	// those that are interested in this event
//	for (int i = 0; i<=listeners.length-2; i+=2) {
//		debug.println("listener: " + i);
//		if (listeners[i]==TableModelListener.class) {
//		((TableModelListener)listeners[i+1]).tableChanged(e);
//		}
//	}
//	}
}
