/*
 * LAPIS lightweight structured text processing system
 *
 * Copyright (C) 1998-2002 Carnegie Mellon University,
 * Copyright (C) 2003 Massachusetts Institute of Technology.
 * All rights reserved.
 *
 * This library is free software; you can redistribute it
 * and/or modify it under the terms of the GNU General
 * Public License as published by the Free Software
 * Foundation, version 2.
 *
 * LAPIS homepage: http://graphics.lcs.mit.edu/lapis/
 */

package lapis.tc;

public class Cloner implements Visitor {
    public Object forAnd (TC.And n) {
        return new TC.And ((TC.Node) n.getArg1 ().accept (this),
                        (TC.Node) n.getArg2 ().accept (this));
    }
    public Object forOr (TC.Or n) {
        return new TC.Or ((TC.Node) n.getArg1 ().accept (this),
                       (TC.Node) n.getArg2 ().accept (this));
    }
    public Object forButNot (TC.ButNot n) {
        return new TC.ButNot ((TC.Node) n.getArg1 ().accept (this),
                           (TC.Node) n.getArg2 ().accept (this));
    }
    public Object forOrButNot (TC.OrButNot n){
        return new TC.OrButNot ((TC.Node) n.getArg1 ().accept (this),
                             (TC.Node) n.getArg2 ().accept (this),
                             (TC.Node) n.getArg3 ().accept (this));
    }
    public Object forEquals (TC.Equals n) {
        return new TC.Equals ((TC.Node) n.getArg ().accept (this));
    }
    public Object forBefore (TC.Before n) {
        return new TC.Before ((TC.Node) n.getArg ().accept (this));
    }
    public Object forAfter (TC.After n) {
        return new TC.After ((TC.Node) n.getArg ().accept (this));
    }
    public Object forJustBefore (TC.JustBefore n) {
        return new TC.JustBefore ((TC.Node) n.getArg ().accept (this));
    }
    public Object forJustAfter (TC.JustAfter n) {
        return new TC.JustAfter ((TC.Node) n.getArg ().accept (this));
    }
    public Object forBeforeDelimited (TC.BeforeDelimited n) {
        return new TC.BeforeDelimited ((TC.Node) n.getArg ().accept (this));
    }
    public Object forAfterDelimited (TC.AfterDelimited n) {
        return new TC.AfterDelimited ((TC.Node) n.getArg ().accept (this));
    }
    public Object forJustBeforeDelimited (TC.JustBeforeDelimited n) {
        return new TC.JustBeforeDelimited ((TC.Node) n.getArg ().accept (this));
    }
    public Object forJustAfterDelimited (TC.JustAfterDelimited n) {
        return new TC.JustAfterDelimited ((TC.Node) n.getArg ().accept (this));
    }

    public Object forIn (TC.In n) {
        return new TC.In ((TC.Node) n.getArg ().accept (this));
    }
    public Object forContains (TC.Contains n) {
        return new TC.Contains ((TC.Node) n.getArg ().accept (this));
    }

    public Object forDescendant (TC.Descendant n) {
	return new TC.Descendant ((TC.Node) n.getArg ().accept (this));
    }
    public Object forAncestor (TC.Ancestor n) {
	return new TC.Ancestor ((TC.Node) n.getArg ().accept (this));
    }

    public Object forStarting (TC.Starting n) {
        return new TC.Starting ((TC.Node) n.getArg ().accept (this));
    }
    public Object forEnding (TC.Ending n) {
        return new TC.Ending ((TC.Node) n.getArg ().accept (this));
    }
    public Object forStartingDelimited (TC.StartingDelimited n) {
        return new TC.StartingDelimited ((TC.Node) n.getArg ().accept (this));
    }
    public Object forEndingDelimited (TC.EndingDelimited n) {
        return new TC.EndingDelimited ((TC.Node) n.getArg ().accept (this));
    }
    public Object forOverlapsStart (TC.OverlapsStart n) {
        return new TC.OverlapsStart ((TC.Node) n.getArg ().accept (this));
    }
    public Object forOverlapsEnd (TC.OverlapsEnd n) {
        return new TC.OverlapsEnd ((TC.Node) n.getArg ().accept (this));
    }
    public Object forOverlaps (TC.Overlaps n) {
        return new TC.Overlaps ((TC.Node) n.getArg ().accept (this));
    }
    public Object forSeparatedBy (TC.SeparatedBy n) {
        return new TC.SeparatedBy ((TC.Node) n.getArg ().accept (this));
    }
    public Object forStartOf (TC.StartOf n) {
        return new TC.StartOf ((TC.Node) n.getArg ().accept (this));
    }
    public Object forEndOf (TC.EndOf n) {
        return new TC.EndOf ((TC.Node) n.getArg ().accept (this));
    }
    public Object forBalancedUnary (TC.BalancedUnary n) {
        return new TC.BalancedUnary ((TC.Node) n.getArg ().accept (this));
    }
    public Object forBalancedBinary (TC.BalancedBinary n){
        return new TC.BalancedBinary ((TC.Node) n.getArg1 ().accept (this),
                                   (TC.Node) n.getArg2 ().accept (this));
    }
    public Object forFromTo (TC.FromTo n){
        return new TC.FromTo ((TC.Node) n.getArg1 ().accept (this),
                              (TC.Node) n.getArg2 ().accept (this));
    }
    public Object forConstant (TC.Constant n) {
        return n;
    }
    public Object forExternalPattern (TC.ExternalPattern n) {
        return n;
    }
    public Object forLiteral (TC.Literal n) {
        return n;
    }
    public Object forRegexp (TC.Regexp n) {
        return n;
    }
    public Object forId (TC.Id n) {
        return n;
    }
    public Object forAny (TC.Any n) {
        return n;
    }
    public Object forNothing (TC.Nothing n) {
        return n;
    }
    public Object forNextTo (TC.NextTo n) {
        return new TC.NextTo ((TC.Node) n.getArg1 ().accept (this),
                           (TC.Node) n.getArg2 ().accept (this));
    }
    public Object forTrim (TC.Trim n) {
        return new TC.Trim ((TC.Node) n.getArg1 ().accept (this),
                         (TC.Node) n.getArg2 ().accept (this));
    }
    public Object forInclude (TC.Include n) {
        return new TC.Include ((TC.Node) n.getArg1 ().accept (this),
                         (TC.Node) n.getArg2 ().accept (this));
    }
    public Object forAssign (TC.Assign n) {
        return new TC.Assign (n.getString (),
                              (TC.Node) n.getArg ().accept (this));
    }
    public Object forSeq (TC.Seq n) {
        return new TC.Seq ((TC.Node) n.getArg1 ().accept (this),
                        (TC.Node) n.getArg2 ().accept (this));
    }
    public Object forIgnoreBinary (TC.IgnoreBinary n) {
        return new TC.IgnoreBinary ((TC.Node) n.getArg1 ().accept (this),
                                 (TC.Node) n.getArg2 ().accept (this));
    }
    public Object forNth (TC.Nth n){
        return new TC.Nth (n.getCount (),
                        (TC.Node) n.getCounter ().accept (this),
                        (TC.Node) n.getContext ().accept (this));
    }
    public Object forFlatten (TC.Flatten n) {
        return new TC.Flatten ((TC.Node) n.getArg ().accept (this));
    }
    public Object forUnbind (TC.Unbind n) {
        return new TC.Unbind ((TC.Node) n.getArg ().accept (this));
    }
    public Object forMelt (TC.Melt n) {
        return new TC.Melt ((TC.Node) n.getArg ().accept (this));
    }
    public Object forCrispen (TC.Crispen n) {
        return new TC.Crispen ((TC.Node) n.getArg ().accept (this));
    }
    public Object forNonempty (TC.Nonempty n) {
        return new TC.Nonempty ((TC.Node) n.getArg ().accept (this));
    }
    public Object forPrefix (TC.Prefix n) {
        return new TC.Prefix (n.getPrefix (), 
                              (TC.Node) n.getArg ().accept (this));
    }
    public Object forCaseSensitivity (TC.CaseSensitivity n) {
        return new TC.CaseSensitivity (n.getCaseSensitive (), 
                                       (TC.Node) n.getArg ().accept (this));
    }
    public Object forView (TC.View n) {
        return new TC.View (n.getView (), 
                            (TC.Node) n.getArg ().accept (this));
    }
}
