/*
 * LAPIS lightweight structured text processing system
 *
 * Copyright (C) 1998-2002 Carnegie Mellon University,
 * Copyright (C) 2003 Massachusetts Institute of Technology.
 * All rights reserved.
 *
 * This library is free software; you can redistribute it
 * and/or modify it under the terms of the GNU General
 * Public License as published by the Free Software
 * Foundation, version 2.
 *
 * LAPIS homepage: http://graphics.lcs.mit.edu/lapis/
 */
package lapis.tc;
import java.io.*;
import lapisx.util.Str;


public class TCLexer implements TCSymbols {
	private final int YY_BUFFER_SIZE = 512;
	private final int YY_F = -1;
	private final int YY_NO_STATE = -1;
	private final int YY_NOT_ACCEPT = 0;
	private final int YY_START = 1;
	private final int YY_END = 2;
	private final int YY_NO_ANCHOR = 4;
	private final int YY_BOL = 256;
	private final int YY_EOF = 257;

public static lapisx.util.Debug debug = lapisx.util.Debug.QUIET; 
int col = 0;
TCParseException errors;
int TABSIZE = 0; // initialized in increaseColumn ()
private void increaseColumn (String text) {
    if (TABSIZE == 0)
        TABSIZE =
            Integer.parseInt (lapis.Main.getConfig ()
                              .getProperty ("tc.tabsize"));
    // skip through text looking for tab characters
    int i = 0;
    int tab;
    while ((tab = text.indexOf ('\t', i)) != -1) {
        // account for characters up to tab
        col += tab - i;
        // account for tab itself
        col = (col/TABSIZE + 1) * TABSIZE;
        i = tab + 1;
    }
    // account for characters after last tab
    col += text.length() - i;
}
private TCToken makeToken (int sym) {
    return makeToken (sym, yytext ());
}
private TCToken makeToken (int sym, String value) {
    String text = yytext ();
    int colStart = col;
    increaseColumn (text);
    int colEnd = col;
    return new TCToken (sym, value, 
                        yyline, colStart, colEnd,
                        yychar, yychar+text.length ());
}
private static boolean isPedantic () {
    String ped = lapis.Main.getConfig ()
                 .getProperty ("tc.pedantic");
    return Boolean.valueOf (ped).booleanValue ();
}
public TCToken recordError (TCToken tok, String message) {
    errors.addError (tok, message);
    return tok;
}
public void setErrorHolder (TCParseException errors) {
    this.errors = errors;
}
// Test main.
public static void main (String[] argv) throws IOException {
    TCLexer lexer = new TCLexer (new InputStreamReader (System.in));
    lexer.setErrorHolder (new TCParseException ());
    TCToken tok;
    while ((tok = lexer.nextToken ()) != null)
        System.err.println (tok);
    lexer.errors.printErrors (new PrintWriter (System.err));
}
	private java.io.BufferedReader yy_reader;
	private int yy_buffer_index;
	private int yy_buffer_read;
	private int yy_buffer_start;
	private int yy_buffer_end;
	private char yy_buffer[];
	private int yychar;
	private int yyline;
	private boolean yy_at_bol;
	private int yy_lexical_state;

	public TCLexer (java.io.Reader reader) {
		this ();
		if (null == reader) {
			throw (new Error("Error: Bad input stream initializer."));
		}
		yy_reader = new java.io.BufferedReader(reader);
	}

	public TCLexer (java.io.InputStream instream) {
		this ();
		if (null == instream) {
			throw (new Error("Error: Bad input stream initializer."));
		}
		yy_reader = new java.io.BufferedReader(new java.io.InputStreamReader(instream));
	}

	private TCLexer () {
		yy_buffer = new char[YY_BUFFER_SIZE];
		yy_buffer_read = 0;
		yy_buffer_index = 0;
		yy_buffer_start = 0;
		yy_buffer_end = 0;
		yychar = 0;
		yyline = 0;
		yy_at_bol = true;
		yy_lexical_state = YYINITIAL;
	}

	private boolean yy_eof_done = false;
	private final int YYINITIAL = 0;
	private final int yy_state_dtrans[] = {
		0
	};
	private void yybegin (int state) {
		yy_lexical_state = state;
	}
	private int yy_advance ()
		throws java.io.IOException {
		int next_read;
		int i;
		int j;

		if (yy_buffer_index < yy_buffer_read) {
			return yy_buffer[yy_buffer_index++];
		}

		if (0 != yy_buffer_start) {
			i = yy_buffer_start;
			j = 0;
			while (i < yy_buffer_read) {
				yy_buffer[j] = yy_buffer[i];
				++i;
				++j;
			}
			yy_buffer_end = yy_buffer_end - yy_buffer_start;
			yy_buffer_start = 0;
			yy_buffer_read = j;
			yy_buffer_index = j;
			next_read = yy_reader.read(yy_buffer,
					yy_buffer_read,
					yy_buffer.length - yy_buffer_read);
			if (-1 == next_read) {
				return YY_EOF;
			}
			yy_buffer_read = yy_buffer_read + next_read;
		}

		while (yy_buffer_index >= yy_buffer_read) {
			if (yy_buffer_index >= yy_buffer.length) {
				yy_buffer = yy_double(yy_buffer);
			}
			next_read = yy_reader.read(yy_buffer,
					yy_buffer_read,
					yy_buffer.length - yy_buffer_read);
			if (-1 == next_read) {
				return YY_EOF;
			}
			yy_buffer_read = yy_buffer_read + next_read;
		}
		return yy_buffer[yy_buffer_index++];
	}
	private void yy_move_end () {
		if (yy_buffer_end > yy_buffer_start &&
		    '\n' == yy_buffer[yy_buffer_end-1])
			yy_buffer_end--;
		if (yy_buffer_end > yy_buffer_start &&
		    '\r' == yy_buffer[yy_buffer_end-1])
			yy_buffer_end--;
	}
	private boolean yy_last_was_cr=false;
	private void yy_mark_start () {
		int i;
		for (i = yy_buffer_start; i < yy_buffer_index; ++i) {
			if ('\n' == yy_buffer[i] && !yy_last_was_cr) {
				++yyline;
			}
			if ('\r' == yy_buffer[i]) {
				++yyline;
				yy_last_was_cr=true;
			} else yy_last_was_cr=false;
		}
		yychar = yychar
			+ yy_buffer_index - yy_buffer_start;
		yy_buffer_start = yy_buffer_index;
	}
	private void yy_mark_end () {
		yy_buffer_end = yy_buffer_index;
	}
	private void yy_to_mark () {
		yy_buffer_index = yy_buffer_end;
		yy_at_bol = (yy_buffer_end > yy_buffer_start) &&
		            ('\r' == yy_buffer[yy_buffer_end-1] ||
		             '\n' == yy_buffer[yy_buffer_end-1] ||
		             2028/*LS*/ == yy_buffer[yy_buffer_end-1] ||
		             2029/*PS*/ == yy_buffer[yy_buffer_end-1]);
	}
	private java.lang.String yytext () {
		return (new java.lang.String(yy_buffer,
			yy_buffer_start,
			yy_buffer_end - yy_buffer_start));
	}
	private int yylength () {
		return yy_buffer_end - yy_buffer_start;
	}
	private char[] yy_double (char buf[]) {
		int i;
		char newbuf[];
		newbuf = new char[2*buf.length];
		for (i = 0; i < buf.length; ++i) {
			newbuf[i] = buf[i];
		}
		return newbuf;
	}
	private final int YY_E_INTERNAL = 0;
	private final int YY_E_MATCH = 1;
	private java.lang.String yy_error_string[] = {
		"Error: Internal error.\n",
		"Error: Unmatched input.\n"
	};
	private void yy_error (int code,boolean fatal) {
		java.lang.System.out.print(yy_error_string[code]);
		java.lang.System.out.flush();
		if (fatal) {
			throw new Error("Fatal Error.\n");
		}
	}
	private int[][] unpackFromString(int size1, int size2, String st) {
		int colonIndex = -1;
		String lengthString;
		int sequenceLength = 0;
		int sequenceInteger = 0;

		int commaIndex;
		String workString;

		int res[][] = new int[size1][size2];
		for (int i= 0; i < size1; i++) {
			for (int j= 0; j < size2; j++) {
				if (sequenceLength != 0) {
					res[i][j] = sequenceInteger;
					sequenceLength--;
					continue;
				}
				commaIndex = st.indexOf(',');
				workString = (commaIndex==-1) ? st :
					st.substring(0, commaIndex);
				st = st.substring(commaIndex+1);
				colonIndex = workString.indexOf(':');
				if (colonIndex == -1) {
					res[i][j]=Integer.parseInt(workString);
					continue;
				}
				lengthString =
					workString.substring(colonIndex+1);
				sequenceLength=Integer.parseInt(lengthString);
				workString=workString.substring(0,colonIndex);
				sequenceInteger=Integer.parseInt(workString);
				res[i][j] = sequenceInteger;
				sequenceLength--;
			}
		}
		return res;
	}
	private int yy_acpt[] = {
		/* 0 */ YY_NOT_ACCEPT,
		/* 1 */ YY_NO_ANCHOR,
		/* 2 */ YY_NO_ANCHOR,
		/* 3 */ YY_NO_ANCHOR,
		/* 4 */ YY_NO_ANCHOR,
		/* 5 */ YY_NO_ANCHOR,
		/* 6 */ YY_NO_ANCHOR,
		/* 7 */ YY_NO_ANCHOR,
		/* 8 */ YY_NO_ANCHOR,
		/* 9 */ YY_NO_ANCHOR,
		/* 10 */ YY_NO_ANCHOR,
		/* 11 */ YY_NO_ANCHOR,
		/* 12 */ YY_NO_ANCHOR,
		/* 13 */ YY_NO_ANCHOR,
		/* 14 */ YY_NO_ANCHOR,
		/* 15 */ YY_NO_ANCHOR,
		/* 16 */ YY_NO_ANCHOR,
		/* 17 */ YY_NO_ANCHOR,
		/* 18 */ YY_NO_ANCHOR,
		/* 19 */ YY_NO_ANCHOR,
		/* 20 */ YY_NO_ANCHOR,
		/* 21 */ YY_NO_ANCHOR,
		/* 22 */ YY_NO_ANCHOR,
		/* 23 */ YY_NO_ANCHOR,
		/* 24 */ YY_NO_ANCHOR,
		/* 25 */ YY_NO_ANCHOR,
		/* 26 */ YY_NO_ANCHOR,
		/* 27 */ YY_NO_ANCHOR,
		/* 28 */ YY_NO_ANCHOR,
		/* 29 */ YY_NO_ANCHOR,
		/* 30 */ YY_NO_ANCHOR,
		/* 31 */ YY_NO_ANCHOR,
		/* 32 */ YY_NO_ANCHOR,
		/* 33 */ YY_NO_ANCHOR,
		/* 34 */ YY_NO_ANCHOR,
		/* 35 */ YY_NO_ANCHOR,
		/* 36 */ YY_NO_ANCHOR,
		/* 37 */ YY_NO_ANCHOR,
		/* 38 */ YY_NO_ANCHOR,
		/* 39 */ YY_NO_ANCHOR,
		/* 40 */ YY_NO_ANCHOR,
		/* 41 */ YY_NO_ANCHOR,
		/* 42 */ YY_NO_ANCHOR,
		/* 43 */ YY_NO_ANCHOR,
		/* 44 */ YY_NO_ANCHOR,
		/* 45 */ YY_NO_ANCHOR,
		/* 46 */ YY_NO_ANCHOR,
		/* 47 */ YY_NO_ANCHOR,
		/* 48 */ YY_NO_ANCHOR,
		/* 49 */ YY_NO_ANCHOR,
		/* 50 */ YY_NO_ANCHOR,
		/* 51 */ YY_NO_ANCHOR,
		/* 52 */ YY_NO_ANCHOR,
		/* 53 */ YY_NO_ANCHOR,
		/* 54 */ YY_NO_ANCHOR,
		/* 55 */ YY_NO_ANCHOR,
		/* 56 */ YY_NO_ANCHOR,
		/* 57 */ YY_NO_ANCHOR,
		/* 58 */ YY_NO_ANCHOR,
		/* 59 */ YY_NO_ANCHOR,
		/* 60 */ YY_NO_ANCHOR,
		/* 61 */ YY_NO_ANCHOR,
		/* 62 */ YY_NO_ANCHOR,
		/* 63 */ YY_NO_ANCHOR,
		/* 64 */ YY_NO_ANCHOR,
		/* 65 */ YY_NO_ANCHOR,
		/* 66 */ YY_NO_ANCHOR,
		/* 67 */ YY_NO_ANCHOR,
		/* 68 */ YY_NO_ANCHOR,
		/* 69 */ YY_NO_ANCHOR,
		/* 70 */ YY_NO_ANCHOR,
		/* 71 */ YY_NO_ANCHOR,
		/* 72 */ YY_NO_ANCHOR,
		/* 73 */ YY_NO_ANCHOR,
		/* 74 */ YY_NO_ANCHOR,
		/* 75 */ YY_NO_ANCHOR,
		/* 76 */ YY_NO_ANCHOR,
		/* 77 */ YY_NO_ANCHOR,
		/* 78 */ YY_NOT_ACCEPT,
		/* 79 */ YY_NO_ANCHOR,
		/* 80 */ YY_NO_ANCHOR,
		/* 81 */ YY_NO_ANCHOR,
		/* 82 */ YY_NO_ANCHOR,
		/* 83 */ YY_NO_ANCHOR,
		/* 84 */ YY_NO_ANCHOR,
		/* 85 */ YY_NO_ANCHOR,
		/* 86 */ YY_NO_ANCHOR,
		/* 87 */ YY_NO_ANCHOR,
		/* 88 */ YY_NO_ANCHOR,
		/* 89 */ YY_NO_ANCHOR,
		/* 90 */ YY_NO_ANCHOR,
		/* 91 */ YY_NO_ANCHOR,
		/* 92 */ YY_NO_ANCHOR,
		/* 93 */ YY_NO_ANCHOR,
		/* 94 */ YY_NO_ANCHOR,
		/* 95 */ YY_NO_ANCHOR,
		/* 96 */ YY_NO_ANCHOR,
		/* 97 */ YY_NO_ANCHOR,
		/* 98 */ YY_NO_ANCHOR,
		/* 99 */ YY_NO_ANCHOR,
		/* 100 */ YY_NO_ANCHOR,
		/* 101 */ YY_NO_ANCHOR,
		/* 102 */ YY_NO_ANCHOR,
		/* 103 */ YY_NO_ANCHOR,
		/* 104 */ YY_NO_ANCHOR,
		/* 105 */ YY_NO_ANCHOR,
		/* 106 */ YY_NO_ANCHOR,
		/* 107 */ YY_NO_ANCHOR,
		/* 108 */ YY_NO_ANCHOR,
		/* 109 */ YY_NO_ANCHOR,
		/* 110 */ YY_NO_ANCHOR,
		/* 111 */ YY_NO_ANCHOR,
		/* 112 */ YY_NO_ANCHOR,
		/* 113 */ YY_NO_ANCHOR,
		/* 114 */ YY_NO_ANCHOR,
		/* 115 */ YY_NO_ANCHOR,
		/* 116 */ YY_NOT_ACCEPT,
		/* 117 */ YY_NO_ANCHOR,
		/* 118 */ YY_NO_ANCHOR,
		/* 119 */ YY_NO_ANCHOR,
		/* 120 */ YY_NO_ANCHOR,
		/* 121 */ YY_NO_ANCHOR,
		/* 122 */ YY_NO_ANCHOR,
		/* 123 */ YY_NO_ANCHOR,
		/* 124 */ YY_NO_ANCHOR,
		/* 125 */ YY_NO_ANCHOR,
		/* 126 */ YY_NO_ANCHOR,
		/* 127 */ YY_NOT_ACCEPT,
		/* 128 */ YY_NO_ANCHOR,
		/* 129 */ YY_NO_ANCHOR,
		/* 130 */ YY_NO_ANCHOR,
		/* 131 */ YY_NO_ANCHOR,
		/* 132 */ YY_NO_ANCHOR,
		/* 133 */ YY_NO_ANCHOR,
		/* 134 */ YY_NO_ANCHOR,
		/* 135 */ YY_NOT_ACCEPT,
		/* 136 */ YY_NO_ANCHOR,
		/* 137 */ YY_NO_ANCHOR,
		/* 138 */ YY_NOT_ACCEPT,
		/* 139 */ YY_NO_ANCHOR,
		/* 140 */ YY_NOT_ACCEPT,
		/* 141 */ YY_NO_ANCHOR,
		/* 142 */ YY_NOT_ACCEPT,
		/* 143 */ YY_NO_ANCHOR,
		/* 144 */ YY_NOT_ACCEPT,
		/* 145 */ YY_NO_ANCHOR,
		/* 146 */ YY_NOT_ACCEPT,
		/* 147 */ YY_NO_ANCHOR,
		/* 148 */ YY_NOT_ACCEPT,
		/* 149 */ YY_NO_ANCHOR,
		/* 150 */ YY_NOT_ACCEPT,
		/* 151 */ YY_NO_ANCHOR,
		/* 152 */ YY_NOT_ACCEPT,
		/* 153 */ YY_NO_ANCHOR,
		/* 154 */ YY_NOT_ACCEPT,
		/* 155 */ YY_NO_ANCHOR,
		/* 156 */ YY_NOT_ACCEPT,
		/* 157 */ YY_NO_ANCHOR,
		/* 158 */ YY_NOT_ACCEPT,
		/* 159 */ YY_NO_ANCHOR,
		/* 160 */ YY_NOT_ACCEPT,
		/* 161 */ YY_NO_ANCHOR,
		/* 162 */ YY_NOT_ACCEPT,
		/* 163 */ YY_NO_ANCHOR,
		/* 164 */ YY_NOT_ACCEPT,
		/* 165 */ YY_NO_ANCHOR,
		/* 166 */ YY_NOT_ACCEPT,
		/* 167 */ YY_NO_ANCHOR,
		/* 168 */ YY_NOT_ACCEPT,
		/* 169 */ YY_NO_ANCHOR,
		/* 170 */ YY_NOT_ACCEPT,
		/* 171 */ YY_NO_ANCHOR,
		/* 172 */ YY_NOT_ACCEPT,
		/* 173 */ YY_NO_ANCHOR,
		/* 174 */ YY_NOT_ACCEPT,
		/* 175 */ YY_NO_ANCHOR,
		/* 176 */ YY_NOT_ACCEPT,
		/* 177 */ YY_NO_ANCHOR,
		/* 178 */ YY_NOT_ACCEPT,
		/* 179 */ YY_NO_ANCHOR,
		/* 180 */ YY_NOT_ACCEPT,
		/* 181 */ YY_NO_ANCHOR,
		/* 182 */ YY_NOT_ACCEPT,
		/* 183 */ YY_NO_ANCHOR,
		/* 184 */ YY_NOT_ACCEPT,
		/* 185 */ YY_NO_ANCHOR,
		/* 186 */ YY_NOT_ACCEPT,
		/* 187 */ YY_NO_ANCHOR,
		/* 188 */ YY_NOT_ACCEPT,
		/* 189 */ YY_NO_ANCHOR,
		/* 190 */ YY_NOT_ACCEPT,
		/* 191 */ YY_NO_ANCHOR,
		/* 192 */ YY_NOT_ACCEPT,
		/* 193 */ YY_NO_ANCHOR,
		/* 194 */ YY_NOT_ACCEPT,
		/* 195 */ YY_NO_ANCHOR,
		/* 196 */ YY_NOT_ACCEPT,
		/* 197 */ YY_NO_ANCHOR,
		/* 198 */ YY_NOT_ACCEPT,
		/* 199 */ YY_NO_ANCHOR,
		/* 200 */ YY_NOT_ACCEPT,
		/* 201 */ YY_NO_ANCHOR,
		/* 202 */ YY_NOT_ACCEPT,
		/* 203 */ YY_NO_ANCHOR,
		/* 204 */ YY_NOT_ACCEPT,
		/* 205 */ YY_NO_ANCHOR,
		/* 206 */ YY_NOT_ACCEPT,
		/* 207 */ YY_NO_ANCHOR,
		/* 208 */ YY_NOT_ACCEPT,
		/* 209 */ YY_NO_ANCHOR,
		/* 210 */ YY_NOT_ACCEPT,
		/* 211 */ YY_NO_ANCHOR,
		/* 212 */ YY_NOT_ACCEPT,
		/* 213 */ YY_NO_ANCHOR,
		/* 214 */ YY_NOT_ACCEPT,
		/* 215 */ YY_NO_ANCHOR,
		/* 216 */ YY_NOT_ACCEPT,
		/* 217 */ YY_NO_ANCHOR,
		/* 218 */ YY_NOT_ACCEPT,
		/* 219 */ YY_NO_ANCHOR,
		/* 220 */ YY_NOT_ACCEPT,
		/* 221 */ YY_NO_ANCHOR,
		/* 222 */ YY_NOT_ACCEPT,
		/* 223 */ YY_NO_ANCHOR,
		/* 224 */ YY_NOT_ACCEPT,
		/* 225 */ YY_NO_ANCHOR,
		/* 226 */ YY_NOT_ACCEPT,
		/* 227 */ YY_NO_ANCHOR,
		/* 228 */ YY_NOT_ACCEPT,
		/* 229 */ YY_NO_ANCHOR,
		/* 230 */ YY_NOT_ACCEPT,
		/* 231 */ YY_NO_ANCHOR,
		/* 232 */ YY_NOT_ACCEPT,
		/* 233 */ YY_NO_ANCHOR,
		/* 234 */ YY_NOT_ACCEPT,
		/* 235 */ YY_NO_ANCHOR,
		/* 236 */ YY_NOT_ACCEPT,
		/* 237 */ YY_NO_ANCHOR,
		/* 238 */ YY_NOT_ACCEPT,
		/* 239 */ YY_NO_ANCHOR,
		/* 240 */ YY_NOT_ACCEPT,
		/* 241 */ YY_NO_ANCHOR,
		/* 242 */ YY_NOT_ACCEPT,
		/* 243 */ YY_NO_ANCHOR,
		/* 244 */ YY_NOT_ACCEPT,
		/* 245 */ YY_NO_ANCHOR,
		/* 246 */ YY_NOT_ACCEPT,
		/* 247 */ YY_NO_ANCHOR,
		/* 248 */ YY_NOT_ACCEPT,
		/* 249 */ YY_NO_ANCHOR,
		/* 250 */ YY_NOT_ACCEPT,
		/* 251 */ YY_NO_ANCHOR,
		/* 252 */ YY_NOT_ACCEPT,
		/* 253 */ YY_NO_ANCHOR,
		/* 254 */ YY_NOT_ACCEPT,
		/* 255 */ YY_NO_ANCHOR,
		/* 256 */ YY_NOT_ACCEPT,
		/* 257 */ YY_NO_ANCHOR,
		/* 258 */ YY_NOT_ACCEPT,
		/* 259 */ YY_NO_ANCHOR,
		/* 260 */ YY_NOT_ACCEPT,
		/* 261 */ YY_NO_ANCHOR,
		/* 262 */ YY_NOT_ACCEPT,
		/* 263 */ YY_NO_ANCHOR,
		/* 264 */ YY_NOT_ACCEPT,
		/* 265 */ YY_NO_ANCHOR,
		/* 266 */ YY_NOT_ACCEPT,
		/* 267 */ YY_NO_ANCHOR,
		/* 268 */ YY_NOT_ACCEPT,
		/* 269 */ YY_NO_ANCHOR,
		/* 270 */ YY_NOT_ACCEPT,
		/* 271 */ YY_NO_ANCHOR,
		/* 272 */ YY_NOT_ACCEPT,
		/* 273 */ YY_NO_ANCHOR,
		/* 274 */ YY_NOT_ACCEPT,
		/* 275 */ YY_NO_ANCHOR,
		/* 276 */ YY_NOT_ACCEPT,
		/* 277 */ YY_NO_ANCHOR,
		/* 278 */ YY_NOT_ACCEPT,
		/* 279 */ YY_NO_ANCHOR,
		/* 280 */ YY_NOT_ACCEPT,
		/* 281 */ YY_NO_ANCHOR,
		/* 282 */ YY_NOT_ACCEPT,
		/* 283 */ YY_NO_ANCHOR,
		/* 284 */ YY_NOT_ACCEPT,
		/* 285 */ YY_NO_ANCHOR,
		/* 286 */ YY_NOT_ACCEPT,
		/* 287 */ YY_NO_ANCHOR,
		/* 288 */ YY_NOT_ACCEPT,
		/* 289 */ YY_NO_ANCHOR,
		/* 290 */ YY_NOT_ACCEPT,
		/* 291 */ YY_NO_ANCHOR,
		/* 292 */ YY_NOT_ACCEPT,
		/* 293 */ YY_NO_ANCHOR,
		/* 294 */ YY_NOT_ACCEPT,
		/* 295 */ YY_NO_ANCHOR,
		/* 296 */ YY_NOT_ACCEPT,
		/* 297 */ YY_NO_ANCHOR,
		/* 298 */ YY_NOT_ACCEPT,
		/* 299 */ YY_NO_ANCHOR,
		/* 300 */ YY_NOT_ACCEPT,
		/* 301 */ YY_NO_ANCHOR,
		/* 302 */ YY_NOT_ACCEPT,
		/* 303 */ YY_NO_ANCHOR,
		/* 304 */ YY_NOT_ACCEPT,
		/* 305 */ YY_NO_ANCHOR,
		/* 306 */ YY_NOT_ACCEPT,
		/* 307 */ YY_NO_ANCHOR,
		/* 308 */ YY_NOT_ACCEPT,
		/* 309 */ YY_NO_ANCHOR,
		/* 310 */ YY_NOT_ACCEPT,
		/* 311 */ YY_NO_ANCHOR,
		/* 312 */ YY_NOT_ACCEPT,
		/* 313 */ YY_NO_ANCHOR,
		/* 314 */ YY_NOT_ACCEPT,
		/* 315 */ YY_NO_ANCHOR,
		/* 316 */ YY_NOT_ACCEPT,
		/* 317 */ YY_NO_ANCHOR,
		/* 318 */ YY_NOT_ACCEPT,
		/* 319 */ YY_NO_ANCHOR,
		/* 320 */ YY_NOT_ACCEPT,
		/* 321 */ YY_NO_ANCHOR,
		/* 322 */ YY_NOT_ACCEPT,
		/* 323 */ YY_NO_ANCHOR,
		/* 324 */ YY_NOT_ACCEPT,
		/* 325 */ YY_NO_ANCHOR,
		/* 326 */ YY_NOT_ACCEPT,
		/* 327 */ YY_NO_ANCHOR,
		/* 328 */ YY_NOT_ACCEPT,
		/* 329 */ YY_NO_ANCHOR,
		/* 330 */ YY_NOT_ACCEPT,
		/* 331 */ YY_NO_ANCHOR,
		/* 332 */ YY_NOT_ACCEPT,
		/* 333 */ YY_NO_ANCHOR,
		/* 334 */ YY_NOT_ACCEPT,
		/* 335 */ YY_NO_ANCHOR,
		/* 336 */ YY_NOT_ACCEPT,
		/* 337 */ YY_NO_ANCHOR,
		/* 338 */ YY_NOT_ACCEPT,
		/* 339 */ YY_NO_ANCHOR,
		/* 340 */ YY_NOT_ACCEPT,
		/* 341 */ YY_NO_ANCHOR,
		/* 342 */ YY_NOT_ACCEPT,
		/* 343 */ YY_NO_ANCHOR,
		/* 344 */ YY_NOT_ACCEPT,
		/* 345 */ YY_NO_ANCHOR,
		/* 346 */ YY_NOT_ACCEPT,
		/* 347 */ YY_NO_ANCHOR,
		/* 348 */ YY_NOT_ACCEPT,
		/* 349 */ YY_NO_ANCHOR,
		/* 350 */ YY_NOT_ACCEPT,
		/* 351 */ YY_NO_ANCHOR,
		/* 352 */ YY_NOT_ACCEPT,
		/* 353 */ YY_NO_ANCHOR,
		/* 354 */ YY_NOT_ACCEPT,
		/* 355 */ YY_NO_ANCHOR,
		/* 356 */ YY_NOT_ACCEPT,
		/* 357 */ YY_NO_ANCHOR,
		/* 358 */ YY_NOT_ACCEPT,
		/* 359 */ YY_NO_ANCHOR,
		/* 360 */ YY_NOT_ACCEPT,
		/* 361 */ YY_NO_ANCHOR,
		/* 362 */ YY_NOT_ACCEPT,
		/* 363 */ YY_NO_ANCHOR,
		/* 364 */ YY_NOT_ACCEPT,
		/* 365 */ YY_NO_ANCHOR,
		/* 366 */ YY_NOT_ACCEPT,
		/* 367 */ YY_NO_ANCHOR,
		/* 368 */ YY_NOT_ACCEPT,
		/* 369 */ YY_NO_ANCHOR,
		/* 370 */ YY_NOT_ACCEPT,
		/* 371 */ YY_NO_ANCHOR,
		/* 372 */ YY_NOT_ACCEPT,
		/* 373 */ YY_NO_ANCHOR,
		/* 374 */ YY_NOT_ACCEPT,
		/* 375 */ YY_NO_ANCHOR,
		/* 376 */ YY_NOT_ACCEPT,
		/* 377 */ YY_NOT_ACCEPT,
		/* 378 */ YY_NOT_ACCEPT,
		/* 379 */ YY_NOT_ACCEPT,
		/* 380 */ YY_NOT_ACCEPT,
		/* 381 */ YY_NOT_ACCEPT,
		/* 382 */ YY_NOT_ACCEPT,
		/* 383 */ YY_NOT_ACCEPT,
		/* 384 */ YY_NOT_ACCEPT,
		/* 385 */ YY_NOT_ACCEPT,
		/* 386 */ YY_NOT_ACCEPT,
		/* 387 */ YY_NOT_ACCEPT,
		/* 388 */ YY_NOT_ACCEPT,
		/* 389 */ YY_NOT_ACCEPT,
		/* 390 */ YY_NOT_ACCEPT,
		/* 391 */ YY_NOT_ACCEPT,
		/* 392 */ YY_NOT_ACCEPT,
		/* 393 */ YY_NOT_ACCEPT,
		/* 394 */ YY_NOT_ACCEPT,
		/* 395 */ YY_NOT_ACCEPT,
		/* 396 */ YY_NOT_ACCEPT,
		/* 397 */ YY_NOT_ACCEPT,
		/* 398 */ YY_NOT_ACCEPT,
		/* 399 */ YY_NOT_ACCEPT,
		/* 400 */ YY_NOT_ACCEPT,
		/* 401 */ YY_NOT_ACCEPT,
		/* 402 */ YY_NOT_ACCEPT,
		/* 403 */ YY_NOT_ACCEPT,
		/* 404 */ YY_NOT_ACCEPT,
		/* 405 */ YY_NOT_ACCEPT,
		/* 406 */ YY_NOT_ACCEPT,
		/* 407 */ YY_NOT_ACCEPT,
		/* 408 */ YY_NOT_ACCEPT,
		/* 409 */ YY_NOT_ACCEPT,
		/* 410 */ YY_NOT_ACCEPT,
		/* 411 */ YY_NOT_ACCEPT,
		/* 412 */ YY_NOT_ACCEPT,
		/* 413 */ YY_NOT_ACCEPT,
		/* 414 */ YY_NOT_ACCEPT,
		/* 415 */ YY_NOT_ACCEPT,
		/* 416 */ YY_NOT_ACCEPT,
		/* 417 */ YY_NOT_ACCEPT,
		/* 418 */ YY_NOT_ACCEPT,
		/* 419 */ YY_NOT_ACCEPT,
		/* 420 */ YY_NOT_ACCEPT,
		/* 421 */ YY_NOT_ACCEPT,
		/* 422 */ YY_NOT_ACCEPT,
		/* 423 */ YY_NOT_ACCEPT,
		/* 424 */ YY_NOT_ACCEPT,
		/* 425 */ YY_NOT_ACCEPT,
		/* 426 */ YY_NOT_ACCEPT,
		/* 427 */ YY_NOT_ACCEPT,
		/* 428 */ YY_NOT_ACCEPT,
		/* 429 */ YY_NOT_ACCEPT,
		/* 430 */ YY_NOT_ACCEPT,
		/* 431 */ YY_NOT_ACCEPT,
		/* 432 */ YY_NOT_ACCEPT,
		/* 433 */ YY_NO_ANCHOR,
		/* 434 */ YY_NO_ANCHOR,
		/* 435 */ YY_NO_ANCHOR,
		/* 436 */ YY_NO_ANCHOR,
		/* 437 */ YY_NOT_ACCEPT,
		/* 438 */ YY_NOT_ACCEPT,
		/* 439 */ YY_NOT_ACCEPT,
		/* 440 */ YY_NOT_ACCEPT,
		/* 441 */ YY_NOT_ACCEPT,
		/* 442 */ YY_NOT_ACCEPT,
		/* 443 */ YY_NOT_ACCEPT,
		/* 444 */ YY_NOT_ACCEPT,
		/* 445 */ YY_NOT_ACCEPT,
		/* 446 */ YY_NOT_ACCEPT,
		/* 447 */ YY_NOT_ACCEPT,
		/* 448 */ YY_NOT_ACCEPT,
		/* 449 */ YY_NOT_ACCEPT,
		/* 450 */ YY_NOT_ACCEPT,
		/* 451 */ YY_NOT_ACCEPT,
		/* 452 */ YY_NOT_ACCEPT,
		/* 453 */ YY_NOT_ACCEPT,
		/* 454 */ YY_NOT_ACCEPT,
		/* 455 */ YY_NOT_ACCEPT,
		/* 456 */ YY_NOT_ACCEPT,
		/* 457 */ YY_NOT_ACCEPT,
		/* 458 */ YY_NOT_ACCEPT,
		/* 459 */ YY_NOT_ACCEPT,
		/* 460 */ YY_NOT_ACCEPT,
		/* 461 */ YY_NOT_ACCEPT,
		/* 462 */ YY_NO_ANCHOR,
		/* 463 */ YY_NOT_ACCEPT,
		/* 464 */ YY_NO_ANCHOR,
		/* 465 */ YY_NOT_ACCEPT,
		/* 466 */ YY_NOT_ACCEPT,
		/* 467 */ YY_NO_ANCHOR,
		/* 468 */ YY_NOT_ACCEPT,
		/* 469 */ YY_NOT_ACCEPT,
		/* 470 */ YY_NOT_ACCEPT,
		/* 471 */ YY_NOT_ACCEPT,
		/* 472 */ YY_NOT_ACCEPT,
		/* 473 */ YY_NOT_ACCEPT,
		/* 474 */ YY_NOT_ACCEPT,
		/* 475 */ YY_NOT_ACCEPT,
		/* 476 */ YY_NOT_ACCEPT,
		/* 477 */ YY_NOT_ACCEPT,
		/* 478 */ YY_NOT_ACCEPT,
		/* 479 */ YY_NOT_ACCEPT,
		/* 480 */ YY_NO_ANCHOR,
		/* 481 */ YY_NOT_ACCEPT,
		/* 482 */ YY_NOT_ACCEPT,
		/* 483 */ YY_NOT_ACCEPT,
		/* 484 */ YY_NOT_ACCEPT,
		/* 485 */ YY_NOT_ACCEPT,
		/* 486 */ YY_NOT_ACCEPT,
		/* 487 */ YY_NOT_ACCEPT,
		/* 488 */ YY_NOT_ACCEPT,
		/* 489 */ YY_NOT_ACCEPT,
		/* 490 */ YY_NOT_ACCEPT,
		/* 491 */ YY_NOT_ACCEPT,
		/* 492 */ YY_NOT_ACCEPT,
		/* 493 */ YY_NOT_ACCEPT,
		/* 494 */ YY_NOT_ACCEPT,
		/* 495 */ YY_NOT_ACCEPT,
		/* 496 */ YY_NOT_ACCEPT,
		/* 497 */ YY_NO_ANCHOR,
		/* 498 */ YY_NOT_ACCEPT,
		/* 499 */ YY_NOT_ACCEPT,
		/* 500 */ YY_NOT_ACCEPT,
		/* 501 */ YY_NOT_ACCEPT,
		/* 502 */ YY_NOT_ACCEPT,
		/* 503 */ YY_NO_ANCHOR,
		/* 504 */ YY_NOT_ACCEPT,
		/* 505 */ YY_NOT_ACCEPT,
		/* 506 */ YY_NO_ANCHOR,
		/* 507 */ YY_NOT_ACCEPT,
		/* 508 */ YY_NO_ANCHOR,
		/* 509 */ YY_NOT_ACCEPT,
		/* 510 */ YY_NO_ANCHOR,
		/* 511 */ YY_NO_ANCHOR,
		/* 512 */ YY_NO_ANCHOR,
		/* 513 */ YY_NO_ANCHOR,
		/* 514 */ YY_NO_ANCHOR,
		/* 515 */ YY_NO_ANCHOR,
		/* 516 */ YY_NO_ANCHOR,
		/* 517 */ YY_NO_ANCHOR,
		/* 518 */ YY_NO_ANCHOR,
		/* 519 */ YY_NO_ANCHOR,
		/* 520 */ YY_NO_ANCHOR,
		/* 521 */ YY_NO_ANCHOR,
		/* 522 */ YY_NO_ANCHOR,
		/* 523 */ YY_NO_ANCHOR,
		/* 524 */ YY_NO_ANCHOR,
		/* 525 */ YY_NO_ANCHOR,
		/* 526 */ YY_NO_ANCHOR,
		/* 527 */ YY_NO_ANCHOR,
		/* 528 */ YY_NO_ANCHOR,
		/* 529 */ YY_NO_ANCHOR,
		/* 530 */ YY_NO_ANCHOR,
		/* 531 */ YY_NO_ANCHOR,
		/* 532 */ YY_NO_ANCHOR,
		/* 533 */ YY_NO_ANCHOR,
		/* 534 */ YY_NO_ANCHOR,
		/* 535 */ YY_NO_ANCHOR,
		/* 536 */ YY_NO_ANCHOR,
		/* 537 */ YY_NO_ANCHOR,
		/* 538 */ YY_NO_ANCHOR,
		/* 539 */ YY_NO_ANCHOR,
		/* 540 */ YY_NO_ANCHOR,
		/* 541 */ YY_NO_ANCHOR,
		/* 542 */ YY_NO_ANCHOR,
		/* 543 */ YY_NO_ANCHOR,
		/* 544 */ YY_NO_ANCHOR,
		/* 545 */ YY_NO_ANCHOR,
		/* 546 */ YY_NO_ANCHOR,
		/* 547 */ YY_NO_ANCHOR,
		/* 548 */ YY_NO_ANCHOR,
		/* 549 */ YY_NO_ANCHOR,
		/* 550 */ YY_NO_ANCHOR,
		/* 551 */ YY_NO_ANCHOR,
		/* 552 */ YY_NO_ANCHOR,
		/* 553 */ YY_NO_ANCHOR,
		/* 554 */ YY_NO_ANCHOR,
		/* 555 */ YY_NO_ANCHOR,
		/* 556 */ YY_NO_ANCHOR,
		/* 557 */ YY_NO_ANCHOR,
		/* 558 */ YY_NO_ANCHOR,
		/* 559 */ YY_NO_ANCHOR,
		/* 560 */ YY_NO_ANCHOR,
		/* 561 */ YY_NO_ANCHOR,
		/* 562 */ YY_NO_ANCHOR,
		/* 563 */ YY_NO_ANCHOR,
		/* 564 */ YY_NO_ANCHOR,
		/* 565 */ YY_NO_ANCHOR,
		/* 566 */ YY_NO_ANCHOR,
		/* 567 */ YY_NO_ANCHOR,
		/* 568 */ YY_NO_ANCHOR,
		/* 569 */ YY_NO_ANCHOR,
		/* 570 */ YY_NO_ANCHOR,
		/* 571 */ YY_NO_ANCHOR,
		/* 572 */ YY_NO_ANCHOR,
		/* 573 */ YY_NO_ANCHOR,
		/* 574 */ YY_NO_ANCHOR,
		/* 575 */ YY_NO_ANCHOR,
		/* 576 */ YY_NO_ANCHOR,
		/* 577 */ YY_NO_ANCHOR,
		/* 578 */ YY_NO_ANCHOR,
		/* 579 */ YY_NO_ANCHOR,
		/* 580 */ YY_NO_ANCHOR,
		/* 581 */ YY_NO_ANCHOR,
		/* 582 */ YY_NO_ANCHOR,
		/* 583 */ YY_NO_ANCHOR,
		/* 584 */ YY_NO_ANCHOR,
		/* 585 */ YY_NO_ANCHOR,
		/* 586 */ YY_NO_ANCHOR,
		/* 587 */ YY_NO_ANCHOR,
		/* 588 */ YY_NO_ANCHOR,
		/* 589 */ YY_NO_ANCHOR,
		/* 590 */ YY_NO_ANCHOR,
		/* 591 */ YY_NO_ANCHOR,
		/* 592 */ YY_NO_ANCHOR,
		/* 593 */ YY_NO_ANCHOR,
		/* 594 */ YY_NO_ANCHOR,
		/* 595 */ YY_NO_ANCHOR,
		/* 596 */ YY_NO_ANCHOR,
		/* 597 */ YY_NO_ANCHOR,
		/* 598 */ YY_NO_ANCHOR,
		/* 599 */ YY_NO_ANCHOR,
		/* 600 */ YY_NO_ANCHOR,
		/* 601 */ YY_NO_ANCHOR,
		/* 602 */ YY_NO_ANCHOR,
		/* 603 */ YY_NO_ANCHOR,
		/* 604 */ YY_NO_ANCHOR,
		/* 605 */ YY_NO_ANCHOR,
		/* 606 */ YY_NO_ANCHOR,
		/* 607 */ YY_NO_ANCHOR,
		/* 608 */ YY_NO_ANCHOR,
		/* 609 */ YY_NO_ANCHOR,
		/* 610 */ YY_NO_ANCHOR,
		/* 611 */ YY_NO_ANCHOR,
		/* 612 */ YY_NOT_ACCEPT,
		/* 613 */ YY_NO_ANCHOR,
		/* 614 */ YY_NOT_ACCEPT,
		/* 615 */ YY_NOT_ACCEPT,
		/* 616 */ YY_NOT_ACCEPT,
		/* 617 */ YY_NOT_ACCEPT,
		/* 618 */ YY_NOT_ACCEPT,
		/* 619 */ YY_NO_ANCHOR,
		/* 620 */ YY_NO_ANCHOR,
		/* 621 */ YY_NOT_ACCEPT,
		/* 622 */ YY_NO_ANCHOR,
		/* 623 */ YY_NO_ANCHOR,
		/* 624 */ YY_NO_ANCHOR,
		/* 625 */ YY_NO_ANCHOR,
		/* 626 */ YY_NO_ANCHOR,
		/* 627 */ YY_NO_ANCHOR,
		/* 628 */ YY_NO_ANCHOR,
		/* 629 */ YY_NO_ANCHOR,
		/* 630 */ YY_NO_ANCHOR,
		/* 631 */ YY_NO_ANCHOR,
		/* 632 */ YY_NO_ANCHOR,
		/* 633 */ YY_NO_ANCHOR,
		/* 634 */ YY_NO_ANCHOR,
		/* 635 */ YY_NO_ANCHOR,
		/* 636 */ YY_NO_ANCHOR,
		/* 637 */ YY_NO_ANCHOR,
		/* 638 */ YY_NO_ANCHOR,
		/* 639 */ YY_NO_ANCHOR,
		/* 640 */ YY_NO_ANCHOR,
		/* 641 */ YY_NO_ANCHOR,
		/* 642 */ YY_NO_ANCHOR,
		/* 643 */ YY_NO_ANCHOR,
		/* 644 */ YY_NO_ANCHOR,
		/* 645 */ YY_NO_ANCHOR,
		/* 646 */ YY_NO_ANCHOR,
		/* 647 */ YY_NO_ANCHOR,
		/* 648 */ YY_NO_ANCHOR,
		/* 649 */ YY_NO_ANCHOR,
		/* 650 */ YY_NO_ANCHOR,
		/* 651 */ YY_NO_ANCHOR,
		/* 652 */ YY_NO_ANCHOR,
		/* 653 */ YY_NO_ANCHOR,
		/* 654 */ YY_NO_ANCHOR,
		/* 655 */ YY_NO_ANCHOR,
		/* 656 */ YY_NO_ANCHOR,
		/* 657 */ YY_NO_ANCHOR,
		/* 658 */ YY_NO_ANCHOR,
		/* 659 */ YY_NO_ANCHOR,
		/* 660 */ YY_NO_ANCHOR,
		/* 661 */ YY_NO_ANCHOR,
		/* 662 */ YY_NO_ANCHOR,
		/* 663 */ YY_NO_ANCHOR,
		/* 664 */ YY_NO_ANCHOR,
		/* 665 */ YY_NO_ANCHOR,
		/* 666 */ YY_NO_ANCHOR,
		/* 667 */ YY_NO_ANCHOR,
		/* 668 */ YY_NO_ANCHOR,
		/* 669 */ YY_NO_ANCHOR,
		/* 670 */ YY_NO_ANCHOR,
		/* 671 */ YY_NO_ANCHOR,
		/* 672 */ YY_NO_ANCHOR,
		/* 673 */ YY_NO_ANCHOR,
		/* 674 */ YY_NO_ANCHOR,
		/* 675 */ YY_NO_ANCHOR,
		/* 676 */ YY_NO_ANCHOR,
		/* 677 */ YY_NO_ANCHOR,
		/* 678 */ YY_NO_ANCHOR,
		/* 679 */ YY_NO_ANCHOR,
		/* 680 */ YY_NO_ANCHOR,
		/* 681 */ YY_NO_ANCHOR,
		/* 682 */ YY_NO_ANCHOR,
		/* 683 */ YY_NO_ANCHOR,
		/* 684 */ YY_NO_ANCHOR,
		/* 685 */ YY_NO_ANCHOR,
		/* 686 */ YY_NO_ANCHOR,
		/* 687 */ YY_NO_ANCHOR,
		/* 688 */ YY_NO_ANCHOR,
		/* 689 */ YY_NO_ANCHOR,
		/* 690 */ YY_NO_ANCHOR,
		/* 691 */ YY_NO_ANCHOR,
		/* 692 */ YY_NO_ANCHOR,
		/* 693 */ YY_NO_ANCHOR,
		/* 694 */ YY_NO_ANCHOR,
		/* 695 */ YY_NO_ANCHOR,
		/* 696 */ YY_NO_ANCHOR,
		/* 697 */ YY_NO_ANCHOR,
		/* 698 */ YY_NO_ANCHOR,
		/* 699 */ YY_NO_ANCHOR,
		/* 700 */ YY_NO_ANCHOR,
		/* 701 */ YY_NO_ANCHOR,
		/* 702 */ YY_NO_ANCHOR,
		/* 703 */ YY_NO_ANCHOR,
		/* 704 */ YY_NO_ANCHOR,
		/* 705 */ YY_NO_ANCHOR,
		/* 706 */ YY_NO_ANCHOR,
		/* 707 */ YY_NOT_ACCEPT,
		/* 708 */ YY_NOT_ACCEPT,
		/* 709 */ YY_NO_ANCHOR,
		/* 710 */ YY_NO_ANCHOR,
		/* 711 */ YY_NO_ANCHOR,
		/* 712 */ YY_NO_ANCHOR,
		/* 713 */ YY_NO_ANCHOR,
		/* 714 */ YY_NO_ANCHOR,
		/* 715 */ YY_NO_ANCHOR,
		/* 716 */ YY_NO_ANCHOR,
		/* 717 */ YY_NO_ANCHOR,
		/* 718 */ YY_NO_ANCHOR,
		/* 719 */ YY_NO_ANCHOR,
		/* 720 */ YY_NO_ANCHOR,
		/* 721 */ YY_NO_ANCHOR,
		/* 722 */ YY_NO_ANCHOR,
		/* 723 */ YY_NO_ANCHOR,
		/* 724 */ YY_NO_ANCHOR,
		/* 725 */ YY_NO_ANCHOR,
		/* 726 */ YY_NO_ANCHOR,
		/* 727 */ YY_NO_ANCHOR,
		/* 728 */ YY_NO_ANCHOR,
		/* 729 */ YY_NO_ANCHOR,
		/* 730 */ YY_NO_ANCHOR,
		/* 731 */ YY_NO_ANCHOR,
		/* 732 */ YY_NO_ANCHOR,
		/* 733 */ YY_NO_ANCHOR,
		/* 734 */ YY_NO_ANCHOR,
		/* 735 */ YY_NO_ANCHOR,
		/* 736 */ YY_NO_ANCHOR,
		/* 737 */ YY_NO_ANCHOR,
		/* 738 */ YY_NO_ANCHOR,
		/* 739 */ YY_NO_ANCHOR,
		/* 740 */ YY_NO_ANCHOR,
		/* 741 */ YY_NO_ANCHOR,
		/* 742 */ YY_NO_ANCHOR,
		/* 743 */ YY_NO_ANCHOR,
		/* 744 */ YY_NO_ANCHOR,
		/* 745 */ YY_NO_ANCHOR,
		/* 746 */ YY_NO_ANCHOR,
		/* 747 */ YY_NO_ANCHOR,
		/* 748 */ YY_NO_ANCHOR,
		/* 749 */ YY_NO_ANCHOR,
		/* 750 */ YY_NO_ANCHOR,
		/* 751 */ YY_NO_ANCHOR,
		/* 752 */ YY_NO_ANCHOR,
		/* 753 */ YY_NO_ANCHOR,
		/* 754 */ YY_NO_ANCHOR,
		/* 755 */ YY_NO_ANCHOR,
		/* 756 */ YY_NO_ANCHOR,
		/* 757 */ YY_NO_ANCHOR,
		/* 758 */ YY_NO_ANCHOR,
		/* 759 */ YY_NO_ANCHOR,
		/* 760 */ YY_NO_ANCHOR,
		/* 761 */ YY_NO_ANCHOR,
		/* 762 */ YY_NO_ANCHOR,
		/* 763 */ YY_NO_ANCHOR,
		/* 764 */ YY_NO_ANCHOR,
		/* 765 */ YY_NO_ANCHOR,
		/* 766 */ YY_NO_ANCHOR,
		/* 767 */ YY_NO_ANCHOR,
		/* 768 */ YY_NO_ANCHOR,
		/* 769 */ YY_NO_ANCHOR,
		/* 770 */ YY_NO_ANCHOR,
		/* 771 */ YY_NO_ANCHOR,
		/* 772 */ YY_NO_ANCHOR,
		/* 773 */ YY_NO_ANCHOR,
		/* 774 */ YY_NO_ANCHOR,
		/* 775 */ YY_NO_ANCHOR,
		/* 776 */ YY_NO_ANCHOR,
		/* 777 */ YY_NO_ANCHOR,
		/* 778 */ YY_NO_ANCHOR,
		/* 779 */ YY_NO_ANCHOR,
		/* 780 */ YY_NO_ANCHOR,
		/* 781 */ YY_NO_ANCHOR,
		/* 782 */ YY_NO_ANCHOR,
		/* 783 */ YY_NO_ANCHOR,
		/* 784 */ YY_NO_ANCHOR,
		/* 785 */ YY_NO_ANCHOR,
		/* 786 */ YY_NO_ANCHOR,
		/* 787 */ YY_NO_ANCHOR,
		/* 788 */ YY_NO_ANCHOR,
		/* 789 */ YY_NO_ANCHOR,
		/* 790 */ YY_NO_ANCHOR,
		/* 791 */ YY_NO_ANCHOR,
		/* 792 */ YY_NO_ANCHOR,
		/* 793 */ YY_NO_ANCHOR,
		/* 794 */ YY_NO_ANCHOR,
		/* 795 */ YY_NO_ANCHOR,
		/* 796 */ YY_NO_ANCHOR,
		/* 797 */ YY_NO_ANCHOR,
		/* 798 */ YY_NO_ANCHOR,
		/* 799 */ YY_NO_ANCHOR,
		/* 800 */ YY_NO_ANCHOR,
		/* 801 */ YY_NO_ANCHOR,
		/* 802 */ YY_NO_ANCHOR,
		/* 803 */ YY_NO_ANCHOR,
		/* 804 */ YY_NO_ANCHOR,
		/* 805 */ YY_NO_ANCHOR,
		/* 806 */ YY_NO_ANCHOR,
		/* 807 */ YY_NO_ANCHOR,
		/* 808 */ YY_NO_ANCHOR,
		/* 809 */ YY_NO_ANCHOR,
		/* 810 */ YY_NO_ANCHOR,
		/* 811 */ YY_NO_ANCHOR,
		/* 812 */ YY_NO_ANCHOR,
		/* 813 */ YY_NO_ANCHOR,
		/* 814 */ YY_NO_ANCHOR,
		/* 815 */ YY_NO_ANCHOR,
		/* 816 */ YY_NO_ANCHOR,
		/* 817 */ YY_NO_ANCHOR,
		/* 818 */ YY_NO_ANCHOR,
		/* 819 */ YY_NO_ANCHOR,
		/* 820 */ YY_NO_ANCHOR,
		/* 821 */ YY_NO_ANCHOR,
		/* 822 */ YY_NO_ANCHOR,
		/* 823 */ YY_NO_ANCHOR,
		/* 824 */ YY_NO_ANCHOR,
		/* 825 */ YY_NO_ANCHOR,
		/* 826 */ YY_NO_ANCHOR,
		/* 827 */ YY_NO_ANCHOR,
		/* 828 */ YY_NO_ANCHOR,
		/* 829 */ YY_NO_ANCHOR,
		/* 830 */ YY_NO_ANCHOR,
		/* 831 */ YY_NO_ANCHOR,
		/* 832 */ YY_NO_ANCHOR,
		/* 833 */ YY_NO_ANCHOR,
		/* 834 */ YY_NO_ANCHOR,
		/* 835 */ YY_NO_ANCHOR,
		/* 836 */ YY_NO_ANCHOR,
		/* 837 */ YY_NO_ANCHOR,
		/* 838 */ YY_NO_ANCHOR,
		/* 839 */ YY_NO_ANCHOR,
		/* 840 */ YY_NO_ANCHOR,
		/* 841 */ YY_NO_ANCHOR,
		/* 842 */ YY_NO_ANCHOR,
		/* 843 */ YY_NO_ANCHOR,
		/* 844 */ YY_NO_ANCHOR,
		/* 845 */ YY_NO_ANCHOR,
		/* 846 */ YY_NO_ANCHOR,
		/* 847 */ YY_NO_ANCHOR,
		/* 848 */ YY_NO_ANCHOR,
		/* 849 */ YY_NO_ANCHOR,
		/* 850 */ YY_NO_ANCHOR,
		/* 851 */ YY_NO_ANCHOR
	};
	private int yy_cmap[] = unpackFromString(1,258,
"38:8,4:2,1,38,4,1,38:18,4,38,5,2,38:3,6,39,40,38,21,38,27,38,7,37,36:9,38:3" +
",22,38:3,25,29,34,28,13,14,20,19,9,33,38,26,32,16,17,11,23,12,10,18,24,35,3" +
"1,15,30,38:2,3,38:4,25,29,34,28,13,14,20,19,9,33,38,26,32,16,17,11,23,12,10" +
",18,24,35,31,15,30,38,41,38,8,38:130,0:2")[0];

	private int yy_rmap[] = unpackFromString(1,852,
"0,1,2,3,4,5,6,1:6,7,8,3:2,9,3,10,11,1:2,12,3,13,3,14,3:2,15,16,17,18,3:8,19" +
",3,20,3:12,21,3:10,22,3,23,3:7,24,25,26,27,28,3:2,1,3:6,29,1,3:2,1:10,30,1," +
"31,1:7,32,33,1:4,34,35,36,1,37,38,39,40,41,1,42,43,44,45,46,1,47,48,49,50,5" +
"1,52,53,54,55,56,57,58,59,60,61,62,63,64,65,66,67,68,69,70,71,72,73,74,75,7" +
"6,77,78,79,80,81,82,83,84,85,86,87,88,89,90,91,92,93,94,95,96,97,98,99,100," +
"101,102,103,104,105,106,107,108,109,110,111,112,113,114,115,116,117,118,119" +
",120,121,122,123,124,125,126,127,128,129,130,131,132,133,134,135,136,137,13" +
"8,139,140,141,142,143,144,145,146,147,148,149,150,151,152,153,154,155,156,1" +
"57,158,159,160,161,162,163,164,165,166,167,168,169,170,171,172,173,174,175," +
"176,177,178,179,180,181,182,183,184,185,186,187,188,189,190,191,192,193,194" +
",195,196,197,198,199,200,201,202,203,204,205,206,207,208,209,210,211,212,21" +
"3,214,215,216,217,218,219,220,221,222,223,224,225,226,227,228,229,230,231,2" +
"32,233,234,235,236,237,238,239,240,241,242,243,244,245,246,247,248,249,250," +
"251,252,253,254,255,256,257,258,259,260,261,262,263,264,265,266,267,268,269" +
",270,271,272,273,274,275,276,277,278,279,280,281,282,283,284,285,286,287,28" +
"8,289,290,291,292,293,294,295,296,297,298,299,300,301,302,303,304,305,306,3" +
"07,308,309,310,311,312,313,314,315,316,317,318,319,320,321,322,323,324,325," +
"326,327,328,329,330,331,332,333,334,335,336,337,338,339,340,341,342,343,3,3" +
"44,345,346,347,348,349,350,351,352,353,354,355,356,357,358,359,360,361,362," +
"363,364,365,366,367,368,369,370,371,372,373,374,375,376,377,378,379,380,381" +
",382,383,384,385,386,387,388,389,390,391,392,393,394,395,396,397,398,399,40" +
"0,401,402,403,404,405,406,407,408,409,410,411,412,413,414,415,416,417,418,4" +
"19,420,421,422,423,424,425,426,427,428,429,430,431,432,433,434,435,436,437," +
"438,439,440,441,442,443,444,445,446,447,448,449,450,451,452,453,454,455,456" +
",457,458,459,460,461,462,463,464,465,466,467,468,469,470,471,472,473,474,47" +
"5,476,477,478,479,480,481,482,483,16,484,485,486,487,488,489,490,491,492,49" +
"3,494,495,496,497,498,499,500,501,502,503,504,505,506,507,508,509,510,511,5" +
"12,513,514,515,3,516,3,517,518,519,520,521,522,523,524,525,526,527,528,529," +
"530,531,532,533,534,535,536,537,538,539,540,541,542,543,544,545,546,547,548" +
",549,550,551,552,553,554,555,556,557,558,559,560,561,562,563,564,565,566,56" +
"7,568,569,570,571,572,573,574,575,576,577,578,579,580,581,582,583,584,585,5" +
"86,587,588,17,589,590,591,592,593,594,595,596,597,598,599,600,601,602,603,6" +
"04,605,606,607,608,609,610,611,612,613,614,615,616,617,618,619,620,621,622," +
"623,624,625,626,627,628,629,630,631,632,633,634,635,636,637,638,639,640,641" +
",642,643,644,645,646,647,648,649,650,651,652,653,654,655,656,657,658,659,66" +
"0,661,662,663,664,665,666,667,668,669,670,671,672,673,674,675,676,677,678,6" +
"79,680,681,682,683,684,685,686,687,688,689,690,691,692,693,694,695,696,697," +
"698,699,700,701,702,703,704,705,706,707,708,709,710,711,712,713,714,715,716" +
",717,718,719,720,721,722,723,724,725,726,727,728,729,730,731,732,733,734,73" +
"5,736,737,738,739,740,741,742,743,744,745,746,747,748,749,750,751,752,753,7" +
"54,755")[0];

	private int yy_nxt[][] = unpackFromString(756,42,
"1,2,79,3,4,5,81,6,7,80,706,768,769,608,620,3,433,117,128,3:2,8,9,3,770,480," +
"622,3,831,623,3,624,625,626,627,709,136,3:2,10,11,12,-1:43,2,79,-1:42,3,-1:" +
"3,3,-1,3:12,-1:2,3:16,-1:7,4,-1:39,13:3,-1,13:36,-1:2,82,139,82:3,15,82,6:1" +
"2,82:2,6:16,82:3,-1:2,13:3,21,13:36,-1:2,14:4,22,14:35,-1:3,3,-1:3,3,-1,3,6" +
"36,3:10,-1:2,3:11,722,3:4,-1:6,3,116,-1:2,3,-1,3:7,648,3:4,-1:2,3:4,649,3:1" +
"1,-1:6,3,135,-1:2,3,-1,3:5,725,3:6,-1:2,3:4,726,3:11,-1:6,3,140,-1:2,3,-1,3" +
":10,657,3,-1:2,3:4,776,3:6,728,3:4,-1:6,3,154,-1:2,3,-1,3:12,-1:2,3:4,732,8" +
"34,3:2,659,3:7,-1:6,3,158,-1:2,3,-1,3:8,549,3:3,-1:2,3:4,550,3:4,663,3:6,-1" +
":6,3,-1:3,3,-1,3:4,231,3:7,-1:2,3:16,-1:6,3,-1:3,3,-1,3:4,233,3:7,-1:2,3:16" +
",-1:6,3,-1:3,3,-1,3:8,551,3:3,-1:2,3:16,-1:6,3,-1:3,3,-1,3:12,-1:2,3:2,666," +
"3:13,-1:6,3,-1:3,3,-1,3,94,3:10,-1:2,3:16,-1:6,3,200,-1:2,3,-1,3:12,-1:2,3:" +
"4,744,837,3:2,673,3:7,-1:6,3,266,-1:2,3,-1,3,792,3:2,687,3:7,-1:2,3:4,688,3" +
":11,-1:6,3,399,-1:2,3,-1,3:12,-1:2,3:4,850,844,3:10,-1:6,3,409,-1:2,3,-1,3:" +
"12,-1:2,3:4,851,845,3:10,-1:4,82:41,-1,2,79:40,-1:3,3,-1:3,3,-1,3,16,3:5,17" +
",3:3,710,-1:2,3:16,-1:5,14:4,-1,14:35,-1:2,82,78,82:3,85,82:34,-1:3,3,354,-" +
"1:2,3,-1,3:12,-1:2,3:4,849,843,3:10,-1:7,399,-1:22,407,408,-1:17,409,-1:22," +
"413,414,-1:17,116,-1:11,142,-1:28,3,-1:3,3,-1,3:3,18,3,609,3:6,-1:2,3:12,80" +
"1,3:3,-1:6,3,308,-1:2,3,-1,3:12,-1:2,3:4,848,841,3:10,-1:7,354,-1:22,377,49" +
"5,-1:16,3,294,-1:2,3,-1,3:12,-1:2,3:4,755,3:3,690,3:7,-1:6,3,362,-1:2,3,-1," +
"3:12,-1:2,3:4,762,3:3,699,3:7,-1:7,127,-1:5,144,-1:2,146,-1:31,3,-1:3,3,-1," +
"3:3,506,631,3:3,19,3,508,3,-1:2,3:16,-1:7,264,-1:22,439,174,-1:17,308,-1:22" +
",352,469,-1:17,294,-1:22,326,-1:3,328,-1:14,318,-1:22,481,448,-1:17,362,-1:" +
"22,382,-1:3,473,-1:14,135,-1:9,150,-1:30,3,-1:3,3,-1,3,147,3,149,3:3,149,3," +
"151,3:2,-1:2,3:5,20,3:7,136:2,3,-1:7,138,-1:12,152,-1:25,82:2,6,82:3,6,82,6" +
":12,82:2,6:16,82:3,-1:4,140,-1:29,156,-1:10,3,-1:3,3,-1,3:7,772,3,23,3:2,-1" +
":2,3:16,-1:16,160,-1:31,3,-1:3,3,-1,3:12,-1:2,3:5,24,3,803,3:3,804,3:4,-1:2" +
"1,437,-1:26,3,127,-1:2,3,-1,3,774,3:2,651,3:7,-1:2,3:4,652,3:11,-1:19,162,-" +
"1:28,3,-1:3,3,-1,3:9,20,3:2,-1:2,3:16,-1:7,148,-1:11,164,-1:28,3,-1:3,3,-1," +
"3:12,-1:2,3:5,20,3:10,-1:15,440,-1:32,3,-1:3,3,-1,3:10,20,3,-1:2,3:16,-1:17" +
",93,-1:30,3,138,-1:2,3,-1,536,25,3:6,177,3:3,-1:2,3:4,179,3:11,-1:7,154,-1:" +
"23,174,-1:2,176,-1:13,3,-1:3,3,-1,3:12,-1:2,3:9,26,3:6,-1:28,180,-1:19,3,-1" +
":3,3,-1,3:12,-1:2,3:9,27,3:6,-1:7,158,-1:12,182,-1:27,3,-1:3,3,-1,3:7,83,3:" +
"4,-1:2,3:16,-1:18,184,-1:29,3,-1:3,3,-1,3:9,28,3:2,-1:2,3:16,-1:31,188,-1:1" +
"6,3,148,-1:2,3,-1,3:7,543,3:4,-1:2,3:4,544,3:11,-1:20,192,-1:27,3,-1:3,3,-1" +
",3:10,29,3,-1:2,3:16,-1:7,166,-1:20,443,-1:3,441,-1:15,3,-1:3,3,-1,3:9,30,3" +
":2,-1:2,3:16,-1:7,168,-1:5,483,-1:34,3,-1:3,3,-1,3:9,31,3:2,-1:2,3:16,-1:7," +
"170,-1:5,194,-1,499,-1:32,3,-1:3,3,-1,3:5,32,3:6,-1:2,3:16,-1:7,172,-1:5,20" +
"2,-1:2,204,-1:11,444,-1:7,206,-1:11,3,-1:3,3,-1,3:9,33,3:2,-1:2,3:16,-1:16," +
"208,-1:31,3,-1:3,3,-1,3:10,34,3,-1:2,3:16,-1:12,485,-1:35,3,-1:3,3,-1,3:5,3" +
"5,3:6,-1:2,3:16,-1:7,178,-1:13,210,-1:26,3,-1:3,3,-1,3:8,177,3:3,-1:2,3:16," +
"-1:13,212,-1:34,3,-1:3,3,-1,3:9,36,3:2,-1:2,3:16,-1:17,214,-1:30,3,-1:3,3,-" +
"1,3:10,37,3,-1:2,3:16,-1:21,118,-1:26,3,-1:3,3,-1,3:10,38,3,-1:2,3:16,-1:15" +
",500,-1:32,3,-1:3,3,-1,3:10,39,3,-1:2,3:16,-1:7,190,-1:12,216,-1:9,482,-1:1" +
"7,3,-1:3,3,-1,3:12,-1:2,3:5,40,3:10,-1:7,190,-1:12,216,-1:27,3,-1:3,3,-1,3:" +
"3,41,3:8,-1:2,3:16,-1:21,119,-1:26,3,166,-1:2,3,-1,3:12,-1:2,3:2,736,3,737," +
"3,781,3:9,-1:20,446,-1:27,3,168,-1:2,3,-1,3,835,3:10,-1:2,3:4,836,3:11,-1:3" +
"5,220,-1:12,3,170,-1:2,3,-1,3,782,3,822,3:8,-1:2,3:4,783,3:11,-1:17,96,-1:3" +
"0,3,-1:3,3,-1,3:4,609,3:7,-1:2,3:16,-1:7,200,-1:23,448,-1:2,224,-1:13,3,-1:" +
"3,3,-1,553,3:3,42,3:7,-1:2,3:16,-1:21,226,-1:26,3,-1:3,3,-1,3:12,-1:2,3:5,4" +
"3,3:10,-1:19,228,-1:28,3,438,-1:2,3,-1,554,44,3:6,239,3:3,-1:2,3:4,241,3:11" +
",-1:27,232,-1:20,3,-1:3,3,-1,3:6,45,3:5,-1:2,3:16,-1:29,449,-1:18,3,172,-1:" +
"2,3,-1,3,785,3:2,667,3:7,-1:2,3:2,555,3,556,3:5,739,3:5,-1:20,9,-1:27,3,-1:" +
"3,3,-1,3:3,46,3:8,-1:2,3:16,-1:16,240,-1:31,3,-1:3,3,-1,3:10,47,3,-1:2,3:16" +
",-1:17,121,-1:30,3,-1:3,3,-1,3:9,87,3:2,-1:2,3:16,-1:17,120,-1:30,3,-1:3,3," +
"-1,3:11,25,-1:2,3:16,-1:17,250,-1:30,3,178,-1:2,3,-1,558,84,3:7,243,3:2,-1:" +
"2,3:3,559,245,3:11,-1:7,222,-1:21,450,447,-1:17,3,-1:3,3,-1,3:10,48,3,-1:2," +
"3:16,-1:7,222,-1:21,450,-1:18,3,-1:3,3,-1,3:9,86,3:2,-1:2,3:16,-1:12,453,-1" +
":35,3,-1:3,3,-1,3:12,-1:2,3:5,49,3:10,-1:28,457,-1:19,3,190,-1:2,3,-1,3:8,2" +
"53,3:3,-1:2,3:4,255,3:11,-1:31,256,-1:16,3,-1:3,3,-1,3:4,50,3:7,-1:2,3:16,-" +
"1:7,234,-1:5,486,-1:2,258,-1:13,260,-1:17,3,-1:3,3,-1,3:12,-1:2,3:5,90,3:10" +
",-1:13,501,-1:34,3,-1:3,3,-1,3:3,91,3:8,-1:2,3:16,-1:7,234,-1:5,486,-1:2,25" +
"8,-1:31,3,-1:3,3,-1,3:4,51,3:7,-1:2,3:16,-1:21,455,-1:26,3,-1:3,3,-1,3:10,5" +
"2,3,-1:2,3:16,-1:22,129,-1:25,3,-1:3,3,-1,3:5,53,3:6,-1:2,3:16,-1:7,242,-1:" +
"5,487,-1:16,442,-1:17,3,-1:3,3,-1,3:8,239,3:3,-1:2,3:16,-1:7,242,-1:5,487,-" +
"1:34,3,-1:3,3,-1,3:8,84,3:3,-1:2,3:16,-1:7,246,-1:12,270,-1:9,498,-1:17,3,-" +
"1:3,3,-1,3:9,243,3:2,-1:2,3:16,-1:7,246,-1:12,270,-1:27,3,-1:3,3,-1,3:7,54," +
"3:4,-1:2,3:16,-1:16,272,-1:31,3,-1:3,3,-1,3:11,55,-1:2,3:16,-1:20,488,-1:27" +
",3,-1:3,3,-1,3:5,89,3:6,-1:2,3:16,-1:15,276,-1:32,3,-1:3,3,-1,3:5,88,3:6,-1" +
":2,3:16,-1:29,460,-1:18,3,-1:3,3,-1,3:8,253,3:3,-1:2,3:16,-1:12,458,132,-1:" +
"34,3,-1:3,3,-1,3:4,435,3:7,-1:2,3:16,-1:19,290,-1:28,3,222,-1:2,3,-1,3:12,-" +
"1:2,3:3,678,679,3:11,-1:13,486,-1:2,258,-1:31,3,-1:3,3,-1,3:11,94,-1:2,3:16" +
",-1:35,489,-1:12,3,-1:3,3,-1,3:11,44,-1:2,3:16,-1:7,264,-1:23,174,-1:16,3,2" +
"34,-1:2,3,-1,3,789,3:2,682,3:7,-1:2,3:4,683,3:11,-1:7,266,-1:5,463,-1:2,466" +
",-1:31,3,-1:3,3,-1,3:10,434,3,-1:2,3:16,-1:7,268,-1:20,302,-1:3,461,-1:15,3" +
",-1:3,3,-1,3:11,84,-1:2,3:16,-1:17,125,-1:30,3,-1:3,3,-1,3:12,-1:2,3:7,56,3" +
":8,-1:15,130,-1:32,3,242,-1:2,3,-1,3,838,3:10,-1:2,3:4,839,3:11,-1:12,490,-" +
"1:35,3,-1:3,3,-1,3,57,685,3:9,-1:2,3:16,-1:37,310,-1:10,3,-1:3,3,-1,3:11,61" +
"0,-1:2,3:16,-1:16,465,-1:31,3,246,-1:2,3,-1,3:8,289,3:3,-1:2,3:4,291,3:11,-" +
"1:13,312,-1:34,3,-1:3,3,-1,3,58,3:10,-1:2,3:5,58,3:10,-1:7,282,-1:24,314,-1" +
":15,3,-1:3,3,-1,578,611,3:9,611,-1:2,3:16,-1:22,133,-1:25,3,-1:3,3,-1,583,1" +
"24,3:10,-1:2,3:16,-1:21,322,-1:26,3,268,-1:2,3,-1,3:12,-1:2,3:2,752,3,753,3" +
",793,3:9,-1:28,491,-1:19,3,-1:3,3,-1,3:5,95,3:6,-1:2,3:16,-1:31,330,-1:16,3" +
",-1:3,3,-1,3:8,289,3:3,-1:2,3:16,-1:7,459,-1:20,707,-1,332,-1,334,-1:15,3,-" +
"1:3,3,-1,3:11,58,-1:2,3:16,-1:7,294,-1:26,328,-1:13,3,-1:3,3,-1,3:3,122,3:8" +
",-1:2,3:16,-1:15,137,-1:32,3,282,-1:2,3,-1,3:12,-1:2,3:4,587,3,313,3:9,-1:1" +
"5,338,-1:32,3,-1:3,3,-1,3:10,436,3,-1:2,3:16,-1:19,342,-1:28,3,-1:3,3,-1,3:" +
"5,59,3:6,-1:2,3:16,-1:17,616,-1:30,3,-1:3,3,-1,3:8,301,3:3,-1:2,3:16,-1:17," +
"97,-1:30,3,-1:3,3,-1,3:4,92,3:7,-1:2,3:16,-1:16,123,-1:31,3,-1:3,3,-1,3:11," +
"611,-1:2,3:16,-1:7,308,-1:23,469,-1:16,3,-1:3,3,-1,3:4,60,3:7,-1:2,3:16,-1:" +
"16,98,-1:31,3,-1:3,3,-1,3:9,61,3:2,-1:2,3:16,-1:21,99,-1:26,3,-1:3,3,-1,3:1" +
"2,-1:2,3:7,62,3:8,-1:33,100,-1:14,3,320,-1:2,3,-1,3:12,-1:2,3:4,590,3,327,3" +
":9,-1:35,492,-1:12,3,-1:3,3,-1,591,126,3:10,-1:2,3:16,-1:7,318,-1:23,448,-1" +
":16,3,-1:3,3,-1,3:11,124,-1:2,3:16,-1:7,320,-1:24,356,-1:15,3,336,-1:2,3,-1" +
",3:8,177,3:3,-1:2,3:4,179,3:11,-1:12,358,134,-1:34,3,-1:3,3,-1,3:11,57,-1:2" +
",3:16,-1:23,132,-1:24,3,350,-1:2,3,-1,3:8,329,3:3,-1:2,3:4,331,3:11,-1:34,3" +
"28,-1:13,3,-1:3,3,-1,3:12,-1:2,3:7,63,3:8,-1:12,470,-1:35,3,-1:3,3,-1,3:5,6" +
"4,3:6,-1:2,3:16,-1:7,336,-1:12,152,-1:9,360,-1:17,3,-1:3,3,-1,3:8,329,3:3,-" +
"1:2,3:16,-1:28,707,-1:3,334,-1:15,3,-1:3,3,-1,3:12,-1:2,3:5,65,3:10,-1:16,7" +
"08,-1:31,3,-1:3,3,-1,3:11,126,-1:2,3:16,-1:7,336,-1:12,152,-1:27,3,-1:3,3,-" +
"1,3:10,35,3,-1:2,3:16,-1:16,131,-1:31,3,385,-1:2,3,-1,3:8,239,3:3,-1:2,3:4," +
"241,3:11,-1:21,364,-1:26,3,-1:3,3,-1,3:3,66,3:8,-1:2,3:5,66,3:10,-1:13,366," +
"-1:34,3,-1:3,3,-1,3:5,67,3:6,-1:2,3:16,-1:28,368,-1:19,3,-1:3,3,-1,3:8,343," +
"3:3,-1:2,3:16,-1:31,370,-1:16,3,-1:3,3,-1,3:3,68,3:8,-1:2,3:16,-1:17,372,-1" +
":30,3,-1:3,3,-1,3:4,69,3:7,-1:2,3:16,-1:7,350,-1:12,374,-1:27,3,-1:3,3,-1,3" +
":3,35,3:8,-1:2,3:16,-1:31,469,-1:16,3,397,-1:2,3,-1,3:8,363,3:3,-1:2,3:4,36" +
"5,3:11,-1:7,354,-1:23,495,-1:16,3,-1:3,3,-1,3:4,70,3:7,-1:2,3:16,-1:33,101," +
"-1:14,3,-1:3,3,-1,3:3,71,3:8,-1:2,3:5,71,3:10,-1:19,381,-1:28,3,-1:3,3,-1,3" +
":10,53,3,-1:2,3:16,-1:20,152,-1:27,3,-1:3,3,-1,3:4,53,3:7,-1:2,3:16,-1:7,36" +
"2,-1:26,473,-1:13,3,-1:3,3,-1,3:5,72,3:6,-1:2,3:16,-1:16,386,-1:31,3,-1:3,3" +
",-1,3:8,363,3:3,-1:2,3:16,-1:12,474,-1:35,3,-1:3,3,-1,3:4,73,3:7,-1:2,3:16," +
"-1:15,496,-1:32,3,-1:3,3,-1,3:3,74,3:8,-1:2,3:5,74,3:10,-1:7,471,-1:12,387," +
"-1:9,504,-1:17,3,-1:3,3,-1,3:3,75,3:8,-1:2,3:5,75,3:10,-1:20,389,-1:27,3,-1" +
":3,3,-1,3:3,76,3:8,-1:2,3:5,76,3:10,-1:17,102,-1:30,3,-1:3,3,-1,3:3,77,3:8," +
"-1:2,3:5,77,3:10,-1:29,390,-1:43,495,-1:48,392,-1:34,103,-1:31,393,-1:43,13" +
"4,-1:52,473,-1:29,93,-1:26,385,-1:12,198,-1:9,507,-1:18,385,-1:12,198,-1:36" +
",104,-1:15,104,-1:27,105,-1:39,106,-1:41,398,-1:38,400,-1:58,401,-1:28,107," +
"-1:41,402,-1:46,403,-1:35,93,-1:33,397,-1:12,406,-1:9,509,-1:18,397,-1:12,4" +
"06,-1:37,108,-1:32,399,-1:23,408,-1:45,477,-1:18,410,-1:44,109,-1:15,109,-1" +
":32,96,-1:35,96,-1:63,411,-1:20,110,-1:55,408,-1:26,412,-1:32,409,-1:23,414" +
",-1:45,416,-1:22,111,-1:54,478,-1:43,414,-1:26,417,-1:46,418,-1:32,419,-1:5" +
"8,421,-1:28,422,-1:46,423,-1:55,479,-1:18,424,-1:44,112,-1:15,112,-1:26,425" +
",-1:60,427,-1:21,113,-1:15,113,-1:31,428,-1:32,429,-1:45,430,-1:46,431,-1:3" +
"5,114,-1:15,114,-1:26,432,-1:40,115,-1:15,115,-1:16,3,-1:3,3,-1,630,3:7,141" +
",3:3,-1:2,3:16,-1:6,3,264,-1:2,3,-1,3:12,-1:2,3:4,840,834,3:10,-1:6,3,318,-" +
"1:2,3,-1,3:12,-1:2,3:4,842,837,3:10,-1:28,186,-1:20,438,-1:12,198,-1:52,174" +
",-1:30,196,-1:37,218,-1:38,487,-1:45,505,-1:45,230,-1:39,452,-1:49,252,-1:4" +
"3,450,-1:28,254,-1:37,262,-1:57,280,-1:44,278,-1:23,274,-1:49,284,-1:27,454" +
",-1:12,304,-1:37,296,-1:45,298,-1:36,286,-1:45,324,-1:29,459,-1:20,707,-1:3" +
",334,-1:21,316,-1:45,348,-1:31,3,454,-1:2,3,-1,3:8,301,3:3,-1:2,3:4,303,3:1" +
"1,-1:21,344,-1:26,3,459,-1:2,3,-1,3:12,-1:2,3:2,756,3,757,3,795,3:9,-1:15,4" +
"93,-1:45,346,-1:28,3,471,-1:2,3,-1,3:8,343,3:3,-1:2,3:4,345,3:11,-1:12,378," +
"-1:45,376,-1:46,383,-1:27,471,-1:12,387,-1:37,388,-1:37,394,-1:50,476,-1:35" +
",404,-1:38,405,-1:41,415,-1:41,420,-1:41,426,-1:35,3,-1:3,3,-1,3:5,632,3,14" +
"3,3,145,3:2,-1:2,3:16,-1:31,448,-1:30,216,-1:37,445,-1:42,236,-1:45,238,-1:" +
"41,288,-1:36,300,-1:40,306,-1:38,340,-1:50,468,-1:35,494,-1:38,380,-1:45,37" +
"9,-1:46,384,-1:36,391,-1:46,396,-1:26,3,-1:3,3,-1,3:12,-1:2,3:5,153,3:10,-1" +
":20,270,-1:37,614,-1:46,244,-1:41,292,-1:36,395,-1:31,3,-1:3,3,-1,3:8,155,3" +
":3,-1:2,3:16,-1:20,387,-1:42,248,-1:26,3,-1:3,3,-1,157,3:11,-1:2,3:16,-1:20" +
",198,-1:27,3,-1:3,3,-1,522,3:3,159,3:7,-1:2,3:16,-1:20,406,-1:27,3,-1:3,3,-" +
"1,3,161,3:10,-1:2,3:16,-1:6,3,-1:3,3,-1,3:9,163,3:2,-1:2,3:16,-1:6,3,-1:3,3" +
",-1,3:9,165,3:2,-1:2,3:16,-1:6,3,-1:3,3,-1,3:12,-1:2,3:3,167,3:12,-1:6,3,-1" +
":3,3,-1,3:5,169,3:6,-1:2,3:16,-1:6,3,-1:3,3,-1,3:4,171,3:7,-1:2,3:16,-1:6,3" +
",-1:3,3,-1,3:7,173,3:4,-1:2,3:16,-1:6,3,-1:3,3,-1,3:9,175,3:2,-1:2,3:16,-1:" +
"6,3,-1:3,3,-1,3,181,3:10,-1:2,3:16,-1:6,3,-1:3,3,-1,3:9,183,3:2,-1:2,3:16,-" +
"1:6,3,-1:3,3,-1,3:9,185,3:2,-1:2,3:16,-1:6,3,-1:3,3,-1,3:9,187,3:2,-1:2,3:1" +
"6,-1:6,3,-1:3,3,-1,3:3,189,3:8,-1:2,3:16,-1:6,3,-1:3,3,-1,3:4,191,3:7,-1:2," +
"3:16,-1:6,3,-1:3,3,-1,3:9,193,3:2,-1:2,3:16,-1:6,3,-1:3,3,-1,3:4,195,3:7,-1" +
":2,3:16,-1:6,3,-1:3,3,-1,3:12,-1:2,3:8,197,3:7,-1:6,3,-1:3,3,-1,3:12,-1:2,3" +
":5,199,3:10,-1:6,3,-1:3,3,-1,3:3,201,3:8,-1:2,3:16,-1:6,3,-1:3,3,-1,3:7,203" +
",3:4,-1:2,3:16,-1:6,3,-1:3,3,-1,3:9,205,3:2,-1:2,3:16,-1:6,3,-1:3,3,-1,207," +
"3:11,-1:2,3:16,-1:6,3,-1:3,3,-1,3:9,209,3:2,-1:2,3:16,-1:6,3,-1:3,3,-1,3:4," +
"211,3:7,-1:2,3:16,-1:6,3,-1:3,3,-1,3:9,213,3:2,-1:2,3:16,-1:6,3,-1:3,3,-1,3" +
":2,215,3:9,-1:2,3:16,-1:6,3,-1:3,3,-1,3:7,217,3:4,-1:2,3:16,-1:6,3,-1:3,3,-" +
"1,3:12,-1:2,3:3,219,3:12,-1:6,3,-1:3,3,-1,3:9,221,3:2,-1:2,3:16,-1:6,3,-1:3" +
",3,-1,3:6,223,3:5,-1:2,3:16,-1:6,3,-1:3,3,-1,3:7,225,3:4,-1:2,3:16,-1:6,3,-" +
"1:3,3,-1,3:12,-1:2,3:5,227,3:10,-1:6,3,-1:3,3,-1,3:3,229,3:8,-1:2,3:16,-1:6" +
",3,-1:3,3,-1,3:8,215,3:3,-1:2,3:16,-1:6,3,-1:3,3,-1,3:7,543,3:4,-1:2,3:16,-" +
"1:6,3,-1:3,3,-1,3:12,-1:2,3:5,235,3:10,-1:6,3,-1:3,3,-1,3:9,237,3:2,-1:2,3:" +
"16,-1:6,3,-1:3,3,-1,3:4,247,3:7,-1:2,3:16,-1:6,3,-1:3,3,-1,3:7,249,3:4,-1:2" +
",3:16,-1:6,3,-1:3,3,-1,3:5,251,3:6,-1:2,3:16,-1:6,3,-1:3,3,-1,3:8,549,3:3,-" +
"1:2,3:16,-1:6,3,-1:3,3,-1,3:3,257,3:8,-1:2,3:16,-1:6,3,-1:3,3,-1,3:12,-1:2," +
"3:9,259,3:6,-1:6,3,-1:3,3,-1,3:7,261,3:4,-1:2,3:16,-1:6,3,-1:3,3,-1,3:7,263" +
",3:4,-1:2,3:16,-1:6,3,-1:3,3,-1,3:9,265,3:2,-1:2,3:16,-1:6,3,-1:3,3,-1,3,78" +
"5,3:2,667,3:7,-1:2,3:2,555,3:7,739,3:5,-1:6,3,-1:3,3,-1,3:9,267,3:2,-1:2,3:" +
"16,-1:6,3,-1:3,3,-1,3:7,269,3:4,-1:2,3:16,-1:6,3,-1:3,3,-1,558,3:11,-1:2,3:" +
"16,-1:6,3,-1:3,3,-1,3:9,271,3:2,-1:2,3:16,-1:6,3,-1:3,3,-1,3:4,273,3:7,-1:2" +
",3:16,-1:6,3,-1:3,3,-1,3:2,275,3:9,-1:2,3:16,-1:6,3,-1:3,3,-1,3:7,277,3:4,-" +
"1:2,3:16,-1:6,3,-1:3,3,-1,3:9,279,3:2,-1:2,3:16,-1:6,3,-1:3,3,-1,571,3:3,28" +
"1,3:7,-1:2,3:16,-1:6,3,-1:3,3,-1,3:7,283,3:4,-1:2,3:16,-1:6,3,-1:3,3,-1,3:1" +
"2,-1:2,3:5,285,3:10,-1:6,3,-1:3,3,-1,3:4,287,3:7,-1:2,3:16,-1:6,3,-1:3,3,-1" +
",3:3,462,3:8,-1:2,3:16,-1:6,3,-1:3,3,-1,3:12,-1:2,3:7,613,3:8,-1:6,3,-1:3,3" +
",-1,3:7,293,3:4,-1:2,3:16,-1:6,3,-1:3,3,-1,3:4,295,3:7,-1:2,3:16,-1:6,3,-1:" +
"3,3,-1,3:12,-1:2,3:5,297,3:10,-1:6,3,-1:3,3,-1,3:9,299,3:2,-1:2,3:16,-1:6,3" +
",-1:3,3,-1,3:9,464,3:2,-1:2,3:16,-1:6,3,-1:3,3,-1,3:3,305,3:8,-1:2,3:16,-1:" +
"6,3,-1:3,3,-1,3:7,307,3:4,-1:2,3:16,-1:6,3,-1:3,3,-1,3:12,-1:2,3:11,309,3:4" +
",-1:6,3,-1:3,3,-1,3,311,3:10,-1:2,3:16,-1:6,3,-1:3,3,-1,3:12,-1:2,3:5,315,3" +
":10,-1:6,3,-1:3,3,-1,3:9,317,3:2,-1:2,3:16,-1:6,3,-1:3,3,-1,3:7,319,3:4,-1:" +
"2,3:16,-1:6,3,-1:3,3,-1,3:12,-1:2,3:5,321,3:10,-1:6,3,-1:3,3,-1,3:7,323,3:4" +
",-1:2,3:16,-1:6,3,-1:3,3,-1,3:9,325,3:2,-1:2,3:16,-1:6,3,-1:3,3,-1,3:12,-1:" +
"2,3:6,313,3:9,-1:6,3,-1:3,3,-1,3:12,-1:2,3:5,467,3:10,-1:6,3,-1:3,3,-1,3:4," +
"333,3:7,-1:2,3:16,-1:6,3,-1:3,3,-1,3:12,-1:2,3:6,327,3:9,-1:6,3,-1:3,3,-1,3" +
":7,335,3:4,-1:2,3:16,-1:6,3,-1:3,3,-1,3:9,337,3:2,-1:2,3:16,-1:6,3,-1:3,3,-" +
"1,3:9,339,3:2,-1:2,3:16,-1:6,3,-1:3,3,-1,3:4,341,3:7,-1:2,3:16,-1:6,3,-1:3," +
"3,-1,3:4,347,3:7,-1:2,3:16,-1:6,3,-1:3,3,-1,3:12,-1:2,3:12,349,3:3,-1:6,3,-" +
"1:3,3,-1,3:4,351,3:7,-1:2,3:16,-1:6,3,-1:3,3,-1,3:9,353,3:2,-1:2,3:16,-1:6," +
"3,-1:3,3,-1,3:3,355,3:8,-1:2,3:16,-1:6,3,-1:3,3,-1,3:4,357,3:7,-1:2,3:16,-1" +
":6,3,-1:3,3,-1,3:9,359,3:2,-1:2,3:16,-1:6,3,-1:3,3,-1,3:3,361,3:8,-1:2,3:16" +
",-1:6,3,-1:3,3,-1,3:12,-1:2,3:12,367,3:3,-1:6,3,-1:3,3,-1,3:4,369,3:7,-1:2," +
"3:16,-1:6,3,-1:3,3,-1,3:4,371,3:7,-1:2,3:16,-1:6,3,-1:3,3,-1,3:4,373,3:7,-1" +
":2,3:16,-1:6,3,-1:3,3,-1,3:4,375,3:7,-1:2,3:16,-1:6,3,-1:3,3,-1,716,3:5,717" +
",497,3:4,-1:2,718,3:15,-1:6,3,158,-1:2,3,-1,3:8,549,3:3,-1:2,3:4,550,3:11,-" +
"1:7,612,-1:20,484,-1:3,618,-1:15,3,612,-1:2,3,-1,3:12,-1:2,3:2,740,3,741,3," +
"786,3:9,-1:19,451,-1:39,456,-1:45,472,-1:40,475,-1:37,615,-1:31,3,-1:3,3,-1" +
",3:9,613,3:2,-1:2,3:16,-1:6,3,-1:3,3,-1,629,3:2,503,3:4,719,3:3,-1:2,3:3,77" +
"1,3:12,-1:21,502,-1:26,3,-1:3,3,-1,3:12,-1:2,3:2,510,3:13,-1:6,3,-1:3,3,-1," +
"3:4,721,3:7,-1:2,3,511,802,3:13,-1:6,3,-1:3,3,-1,512,3:11,-1:2,3:16,-1:6,3," +
"-1:3,3,-1,3:4,513,3:7,-1:2,3:16,-1:6,3,-1:3,3,-1,3:12,-1:2,3,633,514,3:3,51" +
"5,3:9,-1:6,3,-1:3,3,-1,3:8,516,3:3,-1:2,3:2,634,3:13,-1:6,3,-1:3,3,-1,3:6,5" +
"17,3:5,-1:2,3:16,-1:6,3,-1:3,3,-1,3:3,518,3,519,3:6,-1:2,3:16,-1:6,3,-1:3,3" +
",-1,3:7,520,3:4,-1:2,3:16,-1:6,3,-1:3,3,-1,3:7,521,3:4,-1:2,3:16,-1:6,3,-1:" +
"3,3,-1,3:9,523,3:2,-1:2,3:16,-1:6,3,-1:3,3,-1,3,524,3:10,-1:2,3:16,-1:6,3,-" +
"1:3,3,-1,3,525,3:10,-1:2,3:16,-1:6,3,-1:3,3,-1,3:4,526,3:7,-1:2,3:16,-1:6,3" +
",-1:3,3,-1,527,3:11,-1:2,3:16,-1:6,3,-1:3,3,-1,3:8,528,3:3,-1:2,3:16,-1:6,3" +
",-1:3,3,-1,3:8,529,3:3,-1:2,3:16,-1:6,3,-1:3,3,-1,3:3,530,3:8,-1:2,3:16,-1:" +
"6,3,-1:3,3,-1,3:5,531,3:6,-1:2,3:16,-1:6,3,-1:3,3,-1,3:7,532,3:4,-1:2,3:16," +
"-1:6,3,-1:3,3,-1,3:10,619,3,-1:2,3:16,-1:6,3,-1:3,3,-1,3:10,533,3,-1:2,3:16" +
",-1:6,3,-1:3,3,-1,3:10,534,3,-1:2,3:16,-1:6,3,-1:3,3,-1,3:4,535,3:7,-1:2,3:" +
"16,-1:6,3,-1:3,3,-1,3:12,-1:2,3:2,537,3:13,-1:6,3,-1:3,3,-1,3:3,538,3:8,-1:" +
"2,3:16,-1:6,3,-1:3,3,-1,3:4,539,3:7,-1:2,3:16,-1:6,3,-1:3,3,-1,3:7,648,3:4," +
"-1:2,3:16,-1:6,3,-1:3,3,-1,540,3:11,-1:2,3:16,-1:6,3,-1:3,3,-1,3:7,541,3:4," +
"-1:2,3:16,-1:6,3,-1:3,3,-1,3,774,3:2,651,3:7,-1:2,3:16,-1:6,3,-1:3,3,-1,3:8" +
",542,3:3,-1:2,3:16,-1:6,3,-1:3,3,-1,3:12,-1:2,3,545,3:14,-1:6,3,-1:3,3,-1,3" +
":7,546,3:4,-1:2,3:16,-1:6,3,-1:3,3,-1,3:9,547,3:2,-1:2,3:16,-1:6,3,-1:3,3,-" +
"1,548,3:11,-1:2,3:16,-1:6,3,-1:3,3,-1,3:8,552,3:3,-1:2,3:16,-1:6,3,-1:3,3,-" +
"1,557,3:11,-1:2,3:16,-1:6,3,-1:3,3,-1,3:2,560,3:9,-1:2,3:16,-1:6,3,-1:3,3,-" +
"1,3,561,3:10,-1:2,3:16,-1:6,3,-1:3,3,-1,3:12,-1:2,3:2,562,3:13,-1:6,3,-1:3," +
"3,-1,563,3:11,-1:2,3:16,-1:6,3,-1:3,3,-1,3:3,564,3:8,-1:2,3:16,-1:6,3,-1:3," +
"3,-1,3:12,-1:2,3:11,565,3:4,-1:6,3,-1:3,3,-1,566,3:11,-1:2,3:16,-1:6,3,-1:3" +
",3,-1,3:7,567,3:4,-1:2,3:16,-1:6,3,-1:3,3,-1,3:3,568,3:8,-1:2,3:16,-1:6,3,-" +
"1:3,3,-1,3:8,569,3:3,-1:2,3:16,-1:6,3,-1:3,3,-1,3:12,-1:2,3:3,570,3:12,-1:6" +
",3,-1:3,3,-1,3:9,572,3:2,-1:2,3:16,-1:6,3,-1:3,3,-1,3:4,573,3:7,-1:2,3:16,-" +
"1:6,3,-1:3,3,-1,574,3:11,-1:2,3:16,-1:6,3,-1:3,3,-1,3,575,3:10,-1:2,3:16,-1" +
":6,3,-1:3,3,-1,3:9,576,3:2,-1:2,3:16,-1:6,3,-1:3,3,-1,3:8,577,3:3,-1:2,3:16" +
",-1:6,3,-1:3,3,-1,3:3,579,3:8,-1:2,3:16,-1:6,3,-1:3,3,-1,3:12,-1:2,3:2,580," +
"3:13,-1:6,3,-1:3,3,-1,3:12,-1:2,3:3,678,3:12,-1:6,3,-1:3,3,-1,3:4,581,3:7,-" +
"1:2,3:16,-1:6,3,-1:3,3,-1,3:3,582,3:8,-1:2,3:16,-1:6,3,-1:3,3,-1,3:7,584,3:" +
"4,-1:2,3:16,-1:6,3,-1:3,3,-1,3,789,3:2,682,3:7,-1:2,3:16,-1:6,3,-1:3,3,-1,5" +
"85,3:11,-1:2,3:16,-1:6,3,-1:3,3,-1,3:7,586,3:4,-1:2,3:16,-1:6,3,-1:3,3,-1,3" +
":7,588,3:4,-1:2,3:16,-1:6,3,-1:3,3,-1,3,792,3:2,687,3:7,-1:2,3:16,-1:6,3,-1" +
":3,3,-1,3:3,589,3:8,-1:2,3:16,-1:6,3,-1:3,3,-1,592,3:11,-1:2,3:16,-1:6,3,-1" +
":3,3,-1,3:3,593,3:8,-1:2,3:16,-1:6,3,-1:3,3,-1,3:9,594,3:2,-1:2,3:16,-1:6,3" +
",-1:3,3,-1,3:9,595,3:2,-1:2,3:16,-1:6,3,-1:3,3,-1,596,3:11,-1:2,3:16,-1:6,3" +
",-1:3,3,-1,3:9,597,3:2,-1:2,3:16,-1:6,3,-1:3,3,-1,3:3,598,3:8,-1:2,3:16,-1:" +
"6,3,-1:3,3,-1,3:8,599,3:3,-1:2,3:16,-1:6,3,-1:3,3,-1,3:9,600,3:2,-1:2,3:16," +
"-1:6,3,-1:3,3,-1,601,3:11,-1:2,3:16,-1:6,3,-1:3,3,-1,3:8,602,3:3,-1:2,3:16," +
"-1:6,3,-1:3,3,-1,603,3:11,-1:2,3:16,-1:6,3,-1:3,3,-1,3:9,604,3:2,-1:2,3:16," +
"-1:6,3,-1:3,3,-1,3:9,605,3:2,-1:2,3:16,-1:6,3,-1:3,3,-1,3:9,606,3:2,-1:2,3:" +
"16,-1:6,3,-1:3,3,-1,3:9,607,3:2,-1:2,3:16,-1:6,3,-1:3,3,-1,628,3:3,711,3:4," +
"712,3:2,-1:2,3,846,3:14,-1:17,621,-1:41,617,-1:30,3,-1:3,3,-1,635,3:11,-1:2" +
",3:16,-1:6,3,-1:3,3,-1,3:7,637,3:4,-1:2,3:16,-1:6,3,-1:3,3,-1,3:2,819,3:9,-" +
"1:2,3:11,638,723,3:3,-1:6,3,-1:3,3,-1,3:12,-1:2,3:2,639,3:13,-1:6,3,-1:3,3," +
"-1,3:4,640,3:7,-1:2,3:16,-1:6,3,-1:3,3,-1,641,3:11,-1:2,3:16,-1:6,3,-1:3,3," +
"-1,3:11,642,-1:2,3:16,-1:6,3,-1:3,3,-1,3:9,643,3,644,-1:2,3:16,-1:6,3,-1:3," +
"3,-1,3:12,-1:2,3:11,645,3:4,-1:6,3,-1:3,3,-1,3:12,-1:2,3,646,3:14,-1:6,3,-1" +
":3,3,-1,3:12,-1:2,3,647,3:14,-1:6,3,-1:3,3,-1,3:12,-1:2,3:6,650,3:9,-1:6,3," +
"-1:3,3,-1,3:5,653,3:6,-1:2,3:16,-1:6,3,-1:3,3,-1,3:12,-1:2,3:3,654,3:12,-1:" +
"6,3,-1:3,3,-1,3:4,655,3:7,-1:2,3:16,-1:6,3,-1:3,3,-1,3:9,656,3:2,-1:2,3:16," +
"-1:6,3,-1:3,3,-1,3:3,658,3:8,-1:2,3:16,-1:6,3,-1:3,3,-1,3:5,725,3:6,-1:2,3:" +
"16,-1:6,3,-1:3,3,-1,3:12,-1:2,3:9,660,3:6,-1:6,3,-1:3,3,-1,3:12,-1:2,3:2,66" +
"1,3:13,-1:6,3,-1:3,3,-1,3:12,-1:2,3:3,662,3:12,-1:6,3,-1:3,3,-1,3:12,-1:2,3" +
":2,664,3:13,-1:6,3,-1:3,3,-1,3:7,665,3:4,-1:2,3:16,-1:6,3,-1:3,3,-1,3:12,-1" +
":2,3:5,834,3:2,659,3:7,-1:6,3,-1:3,3,-1,3:4,668,3:7,-1:2,3:16,-1:6,3,-1:3,3" +
",-1,3:9,669,3:2,-1:2,3:16,-1:6,3,-1:3,3,-1,3:9,670,3:2,-1:2,3:16,-1:6,3,-1:" +
"3,3,-1,3:5,671,3:6,-1:2,3:16,-1:6,3,-1:3,3,-1,3:12,-1:2,3:2,736,3:3,781,3:9" +
",-1:6,3,-1:3,3,-1,3:9,672,3:2,-1:2,3:16,-1:6,3,-1:3,3,-1,3:12,-1:2,3,674,3:" +
"14,-1:6,3,-1:3,3,-1,3:5,675,3:6,-1:2,3:16,-1:6,3,-1:3,3,-1,3:12,-1:2,3:2,74" +
"0,3:3,786,3:9,-1:6,3,-1:3,3,-1,3:5,676,3:6,-1:2,3:16,-1:6,3,-1:3,3,-1,3:12," +
"-1:2,3,677,3:14,-1:6,3,-1:3,3,-1,3:12,-1:2,3:5,837,3:2,673,3:7,-1:6,3,-1:3," +
"3,-1,3:12,-1:2,3:5,680,3:10,-1:6,3,-1:3,3,-1,3:12,-1:2,3:2,681,3:13,-1:6,3," +
"-1:3,3,-1,3:5,684,3:6,-1:2,3:16,-1:6,3,-1:3,3,-1,3:12,-1:2,3:2,686,3:13,-1:" +
"6,3,-1:3,3,-1,3:4,689,3:7,-1:2,3:16,-1:6,3,-1:3,3,-1,3:12,-1:2,3:2,691,3:13" +
",-1:6,3,-1:3,3,-1,692,3:11,-1:2,3:16,-1:6,3,-1:3,3,-1,3:5,693,3:6,-1:2,3:16" +
",-1:6,3,-1:3,3,-1,3:12,-1:2,3:2,752,3:3,793,3:9,-1:6,3,-1:3,3,-1,3:9,694,3:" +
"2,-1:2,3:16,-1:6,3,-1:3,3,-1,3:12,-1:2,3:8,690,3:7,-1:6,3,-1:3,3,-1,3:5,695" +
",3:6,-1:2,3:16,-1:6,3,-1:3,3,-1,3:12,-1:2,3:2,756,3:3,795,3:9,-1:6,3,-1:3,3" +
",-1,3:12,-1:2,3:2,696,3:13,-1:6,3,-1:3,3,-1,3:5,697,3:6,-1:2,3:16,-1:6,3,-1" +
":3,3,-1,698,3:11,-1:2,3:16,-1:6,3,-1:3,3,-1,3:5,700,3:6,-1:2,3:16,-1:6,3,-1" +
":3,3,-1,3:12,-1:2,3:8,699,3:7,-1:6,3,-1:3,3,-1,3:9,701,3:2,-1:2,3:16,-1:6,3" +
",-1:3,3,-1,702,3:11,-1:2,3:16,-1:6,3,-1:3,3,-1,703,3:11,-1:2,3:16,-1:6,3,-1" +
":3,3,-1,704,3:11,-1:2,3:16,-1:6,3,-1:3,3,-1,705,3:11,-1:2,3:16,-1:6,3,-1:3," +
"3,-1,3:3,713,3:4,714,3:3,-1:2,3:16,-1:6,3,-1:3,3,-1,715,3:11,-1:2,3:16,-1:6" +
",3,-1:3,3,-1,3:7,720,3:4,-1:2,3:16,-1:6,3,-1:3,3,-1,3:12,-1:2,3:2,724,3:13," +
"-1:6,3,-1:3,3,-1,3:4,727,3:7,-1:2,3:16,-1:6,3,-1:3,3,-1,3:3,729,3:8,-1:2,3:" +
"16,-1:6,3,-1:3,3,-1,3:9,730,3:2,-1:2,3:16,-1:6,3,-1:3,3,-1,3:12,-1:2,3:2,73" +
"1,3:13,-1:6,3,-1:3,3,-1,3:12,-1:2,3:11,728,3:4,-1:6,3,-1:3,3,-1,3:10,733,3," +
"-1:2,3:16,-1:6,3,-1:3,3,-1,3,734,3:10,-1:2,3:16,-1:6,3,-1:3,3,-1,3:12,-1:2," +
"3:11,735,3:4,-1:6,3,-1:3,3,-1,3:12,-1:2,3:2,738,3:13,-1:6,3,-1:3,3,-1,3:4,7" +
"42,3:7,-1:2,3:16,-1:6,3,-1:3,3,-1,3:8,743,3:3,-1:2,3:16,-1:6,3,-1:3,3,-1,3," +
"782,3,822,3:8,-1:2,3:16,-1:6,3,-1:3,3,-1,3:7,745,3:4,-1:2,3:16,-1:6,3,-1:3," +
"3,-1,3:9,746,3:2,-1:2,3:16,-1:6,3,-1:3,3,-1,3:4,747,3:7,-1:2,3:16,-1:6,3,-1" +
":3,3,-1,3:12,-1:2,3:5,748,3:10,-1:6,3,-1:3,3,-1,3:12,-1:2,3:5,749,3:10,-1:6" +
",3,-1:3,3,-1,3:9,750,3:2,-1:2,3:16,-1:6,3,-1:3,3,-1,3:12,-1:2,3:9,751,3:6,-" +
"1:6,3,-1:3,3,-1,754,3:11,-1:2,3:16,-1:6,3,-1:3,3,-1,3:9,758,3:2,-1:2,3:16,-" +
"1:6,3,-1:3,3,-1,3:4,759,3:7,-1:2,3:16,-1:6,3,-1:3,3,-1,3:12,-1:2,3:9,760,3:" +
"6,-1:6,3,-1:3,3,-1,3:4,761,3:7,-1:2,3:16,-1:6,3,-1:3,3,-1,763,3:11,-1:2,3:1" +
"6,-1:6,3,-1:3,3,-1,3:12,-1:2,3:9,764,3:6,-1:6,3,-1:3,3,-1,3:12,-1:2,3:9,765" +
",3:6,-1:6,3,-1:3,3,-1,3:12,-1:2,3:9,766,3:6,-1:6,3,-1:3,3,-1,3:12,-1:2,3:9," +
"767,3:6,-1:6,3,-1:3,3,-1,3:4,773,3:7,-1:2,3:16,-1:6,3,-1:3,3,-1,3:12,-1:2,3" +
":3,775,3:12,-1:6,3,-1:3,3,-1,3:12,-1:2,3:8,777,3:7,-1:6,3,-1:3,3,-1,3:4,778" +
",3:7,-1:2,3:16,-1:6,3,-1:3,3,-1,3:4,779,3:7,-1:2,3:16,-1:6,3,-1:3,3,-1,3:3," +
"780,3:8,-1:2,3:16,-1:6,3,-1:3,3,-1,3:12,-1:2,3,784,3:14,-1:6,3,-1:3,3,-1,3:" +
"7,787,3:4,-1:2,3:16,-1:6,3,-1:3,3,-1,3:7,788,3:4,-1:2,3:16,-1:6,3,-1:3,3,-1" +
",790,3:11,-1:2,3:16,-1:6,3,-1:3,3,-1,3,791,3:10,-1:2,3:16,-1:6,3,-1:3,3,-1," +
"794,3:11,-1:2,3:16,-1:6,3,-1:3,3,-1,3,796,3:10,-1:2,3:16,-1:6,3,-1:3,3,-1,7" +
"97,3:11,-1:2,3:16,-1:6,3,-1:3,3,-1,798,3:11,-1:2,3:16,-1:6,3,-1:3,3,-1,799," +
"3:11,-1:2,3:16,-1:6,3,-1:3,3,-1,800,3:11,-1:2,3:16,-1:6,3,-1:3,3,-1,3:3,805" +
",3:8,-1:2,3:16,-1:6,3,-1:3,3,-1,3:12,-1:2,3:2,806,3:13,-1:6,3,-1:3,3,-1,3:8" +
",807,3:3,-1:2,3:16,-1:6,3,-1:3,3,-1,3:4,808,3:7,-1:2,3:16,-1:6,3,-1:3,3,-1," +
"3:4,809,3:7,-1:2,3:16,-1:6,3,-1:3,3,-1,3:12,-1:2,3:3,810,3:12,-1:6,3,-1:3,3" +
",-1,3:7,811,3:4,-1:2,3:16,-1:6,3,-1:3,3,-1,3:12,-1:2,3:3,812,3:12,-1:6,3,-1" +
":3,3,-1,3:7,813,3:4,-1:2,3:16,-1:6,3,-1:3,3,-1,3:12,-1:2,3:3,814,3:12,-1:6," +
"3,-1:3,3,-1,3:12,-1:2,3:3,815,3:12,-1:6,3,-1:3,3,-1,3:12,-1:2,3:3,816,3:12," +
"-1:6,3,-1:3,3,-1,3:12,-1:2,3:3,817,3:12,-1:6,3,-1:3,3,-1,818,3:3,847,3:7,-1" +
":2,3:16,-1:6,3,-1:3,3,-1,3:3,820,3:8,-1:2,3:16,-1:6,3,-1:3,3,-1,3:12,-1:2,3" +
":11,821,3:4,-1:6,3,-1:3,3,-1,3:4,823,3:7,-1:2,3:16,-1:6,3,-1:3,3,-1,3:4,824" +
",3:7,-1:2,3:16,-1:6,3,-1:3,3,-1,3,835,3:10,-1:2,3:16,-1:6,3,-1:3,3,-1,3:4,8" +
"25,3:7,-1:2,3:16,-1:6,3,-1:3,3,-1,3:4,826,3:7,-1:2,3:16,-1:6,3,-1:3,3,-1,3," +
"838,3:10,-1:2,3:16,-1:6,3,-1:3,3,-1,3:12,-1:2,3:5,834,3:10,-1:6,3,-1:3,3,-1" +
",3:4,827,3:7,-1:2,3:16,-1:6,3,-1:3,3,-1,3:12,-1:2,3:5,837,3:10,-1:6,3,-1:3," +
"3,-1,3:4,828,3:7,-1:2,3:16,-1:6,3,-1:3,3,-1,3:4,829,3:7,-1:2,3:16,-1:6,3,-1" +
":3,3,-1,3:4,830,3:7,-1:2,3:16,-1:6,3,-1:3,3,-1,3:3,832,3:8,-1:2,3:16,-1:6,3" +
",-1:3,3,-1,3,833,3:10,-1:2,3:16,-1:6,3,-1:3,3,-1,3:12,-1:2,3:5,841,3:10,-1:" +
"6,3,-1:3,3,-1,3:12,-1:2,3:5,843,3:10,-1:6,3,-1:3,3,-1,3:12,-1:2,3:5,844,3:1" +
"0,-1:6,3,-1:3,3,-1,3:12,-1:2,3:5,845,3:10,-1:3");

	public TCToken nextToken ()
		throws java.io.IOException {
		int yy_lookahead;
		int yy_anchor = YY_NO_ANCHOR;
		int yy_state = yy_state_dtrans[yy_lexical_state];
		int yy_next_state = YY_NO_STATE;
		int yy_last_accept_state = YY_NO_STATE;
		boolean yy_initial = true;
		int yy_this_accept;

		yy_mark_start();
		yy_this_accept = yy_acpt[yy_state];
		if (YY_NOT_ACCEPT != yy_this_accept) {
			yy_last_accept_state = yy_state;
			yy_mark_end();
		}
		while (true) {
			if (yy_initial && yy_at_bol) yy_lookahead = YY_BOL;
			else yy_lookahead = yy_advance();
			yy_next_state = YY_F;
			yy_next_state = yy_nxt[yy_rmap[yy_state]][yy_cmap[yy_lookahead]];
			if (YY_EOF == yy_lookahead && true == yy_initial) {
				return null;
			}
			if (YY_F != yy_next_state) {
				yy_state = yy_next_state;
				yy_initial = false;
				yy_this_accept = yy_acpt[yy_state];
				if (YY_NOT_ACCEPT != yy_this_accept) {
					yy_last_accept_state = yy_state;
					yy_mark_end();
				}
			}
			else {
				if (YY_NO_STATE == yy_last_accept_state) {
					throw (new Error("Lexical Error: Unmatched Input."));
				}
				else {
					yy_anchor = yy_acpt[yy_last_accept_state];
					if (0 != (YY_END & yy_anchor)) {
						yy_move_end();
					}
					yy_to_mark();
					switch (yy_last_accept_state) {
					case 1:
						
					case -2:
						break;
					case 2:
						{
   col = 0;
}
					case -3:
						break;
					case 3:
						{ 
    return makeToken (ID); 
}
					case -4:
						break;
					case 4:
						{
   increaseColumn (yytext ());
}
					case -5:
						break;
					case 5:
						{
    return recordError (makeToken (ID), "unknown character");
}
					case -6:
						break;
					case 6:
						{
    String str =  yytext().substring(1);
    return recordError (makeToken (REGEXP, str), "unterminated regular expression");
}
					case -7:
						break;
					case 7:
						{
    return makeToken (RIGHTCURLY);
}
					case -8:
						break;
					case 8:
						{ 
    return makeToken (THEN); 
}
					case -9:
						break;
					case 9:
						{ 
    return makeToken (EQUALS); 
}
					case -10:
						break;
					case 10:
						{
    return makeToken (LEFTPAREN);
}
					case -11:
						break;
					case 11:
						{
    return makeToken (RIGHTPAREN);
}
					case -12:
						break;
					case 12:
						{
    return makeToken (LEFTCURLY);
}
					case -13:
						break;
					case 13:
						{
    String str =  yytext().substring(1);
    return recordError (makeToken (LIT, str), "unterminated string");
}
					case -14:
						break;
					case 14:
						{
    String str =  yytext().substring(1);
    return recordError (makeToken (LIT, str), "unterminated string");
}
					case -15:
						break;
					case 15:
						{
    String str = yytext().substring(1, yytext().length() - 1);
    return makeToken (REGEXP, str);
}
					case -16:
						break;
					case 16:
						{ 
    return makeToken (IS); 
}
					case -17:
						break;
					case 17:
						{ 
    return makeToken (IN); 
}
					case -18:
						break;
					case 18:
						{ 
    return makeToken (OR); 
}
					case -19:
						break;
					case 19:
						{ 
    return makeToken (TO);
}
					case -20:
						break;
					case 20:
						{ 
    return makeToken (NTH);
}
					case -21:
						break;
					case 21:
						{
    String str =  yytext().substring(1,yytext().length() - 1);
    return makeToken (LIT, str);
}
					case -22:
						break;
					case 22:
						{
    String str =  yytext().substring(1,yytext().length() - 1);
    return makeToken (LIT, str);
}
					case -23:
						break;
					case 23:
						{ 
    return makeToken (NOT); 
}
					case -24:
						break;
					case 24:
						{ 
    if (isPedantic ())
        return recordError (makeToken (ID), 
"AND is ambiguous.  Do you mean one of the following instead?\n" +
"\n" + 
"Boolean interpretation: if you want to put multiple constraints on a\n"+
"pattern, (e.g., words that start with s AND end with e), then you can\n"+
"put each constraint on a new line, indenting far enough to link it to\n"+
"the overall pattern:\n"+
"    word starting s\n"+
"         ending e\n"+
"\n"+
"Aggregate interpretation: if you want to select several patterns at\n"+
"the same time (e.g., words AND punctuation), use EITHER/OR instead:\n"+
"    EITHER word OR punctuation\n"+
"\n"+
"Sequential interpretation: if you want to combine adjacent patterns into\n"+
"a single selection (e.g., first name AND last name), use THEN instead:\n"+
"    firstname THEN lastname\n");
    else
        return makeToken (AND);
}
					case -25:
						break;
					case 25:
						{
    return makeToken (ENDING); 
}
					case -26:
						break;
					case 26:
						{ 
    return makeToken (FROM);
}
					case -27:
						break;
					case 27:
						{ 
    return makeToken (TRIM); 
}
					case -28:
						break;
					case 28:
						{ 
    return makeToken (NTH); 
}
					case -29:
						break;
					case 29:
						{ 
    return makeToken (WITH); 
}
					case -30:
						break;
					case 30:
						{
    return makeToken (MELT);
}
					case -31:
						break;
					case 31:
						{ 
    return makeToken (JUST_AFTER); 
}
					case -32:
						break;
					case 32:
						{ 
    return makeToken (JUST_BEFORE); 
}
					case -33:
						break;
					case 33:
						{ 
    return makeToken (CONTAINS); 
}
					case -34:
						break;
					case 34:
						{ 
    return makeToken (NTH,"6th"); 
}
					case -35:
						break;
					case 35:
						{
    return makeToken (ENDOF);
}
					case -36:
						break;
					case 36:
						{ 
    return makeToken (NTH,"1st"); 
}
					case -37:
						break;
					case 37:
						{ 
    return makeToken (NTH,"5th"); 
}
					case -38:
						break;
					case 38:
						{ 
    return makeToken (NTH,"9th"); 
}
					case -39:
						break;
					case 39:
						{ 
    return makeToken (NTH,"10th"); 
}
					case -40:
						break;
					case 40:
						{ 
    return makeToken (NTH,"3rd"); 
}
					case -41:
						break;
					case 41:
						{ 
    return makeToken (AFTER); 
}
					case -42:
						break;
					case 42:
						{ 
    return makeToken (IGNORE); 
}
					case -43:
						break;
					case 43:
						{ 
    return makeToken (NTH,"2nd"); 
}
					case -44:
						break;
					case 44:
						{
    return makeToken (STARTING); 
}
					case -45:
						break;
					case 45:
						{ 
    return makeToken (PREFIX); 
}
					case -46:
						break;
					case 46:
						{ 
    return makeToken (EITHER); 
}
					case -47:
						break;
					case 47:
						{ 
    return makeToken (NTH,"8th"); 
}
					case -48:
						break;
					case 48:
						{ 
    return makeToken (NTH,"4th"); 
}
					case -49:
						break;
					case 49:
						{
    return makeToken (UNBIND);
}
					case -50:
						break;
					case 50:
						{ 
    return makeToken (BEFORE); 
}
					case -51:
						break;
					case 51:
						{
    return makeToken (INCLUDE);
}
					case -52:
						break;
					case 52:
						{ 
    return makeToken (NTH,"7th"); 
}
					case -53:
						break;
					case 53:
						{
    return makeToken (STARTOF);
}
					case -54:
						break;
					case 54:
						{
    return makeToken (FLATTEN);
}
					case -55:
						break;
					case 55:
						{ 
    return makeToken (NOTHING); 
}
					case -56:
						break;
					case 56:
						{
    return makeToken (NONEMPTY);
}
					case -57:
						break;
					case 57:
						{ 
    return makeToken (OVERLAPS); 
}
					case -58:
						break;
					case 58:
						{ 
    return makeToken (BALANCES); 
}
					case -59:
						break;
					case 59:
						{
    return makeToken (ANCESTOR);
}
					case -60:
						break;
					case 60:
						{ 
    return makeToken (AS_TEXT); 
}
					case -61:
						break;
					case 61:
						{ 
    return makeToken (NTH);
}
					case -62:
						break;
					case 62:
						{ 
    return makeToken (SEPARATED_BY); 
}
					case -63:
						break;
					case 63:
						{ 
    return makeToken (BALANCES); 
}
					case -64:
						break;
					case 64:
						{
    return makeToken (DESCENDANT);
}
					case -65:
						break;
					case 65:
						{ 
    return makeToken (AS_HTML); 
}
					case -66:
						break;
					case 66:
						{
    return makeToken (ENDING_DELIMITED); 
}
					case -67:
						break;
					case 67:
						{ 
    return makeToken (OVERLAPS_END); 
}
					case -68:
						break;
					case 68:
						{ 
    return makeToken (ANYWHERE_AFTER); 
}
					case -69:
						break;
					case 69:
						{ 
    return makeToken (CASE_SENSITIVE); 
}
					case -70:
						break;
					case 70:
						{ 
    return makeToken (ANYWHERE_BEFORE); 
}
					case -71:
						break;
					case 71:
						{
    return makeToken (STARTING_DELIMITED); 
}
					case -72:
						break;
					case 72:
						{ 
    return makeToken (OVERLAPS_START); 
}
					case -73:
						break;
					case 73:
						{ 
    return makeToken (NOT_CASE_SENSITIVE); 
}
					case -74:
						break;
					case 74:
						{ 
    return makeToken (JUST_AFTER_DELIMITED); 
}
					case -75:
						break;
					case 75:
						{ 
    return makeToken (JUST_BEFORE_DELIMITED); 
}
					case -76:
						break;
					case 76:
						{ 
    return makeToken (AFTER_DELIMITED); 
}
					case -77:
						break;
					case 77:
						{ 
    return makeToken (BEFORE_DELIMITED); 
}
					case -78:
						break;
					case 79:
						{
   col = 0;
}
					case -79:
						break;
					case 80:
						{ 
    return makeToken (ID); 
}
					case -80:
						break;
					case 81:
						{
    return recordError (makeToken (ID), "unknown character");
}
					case -81:
						break;
					case 82:
						{
    String str =  yytext().substring(1);
    return recordError (makeToken (REGEXP, str), "unterminated regular expression");
}
					case -82:
						break;
					case 83:
						{ 
    return makeToken (THEN); 
}
					case -83:
						break;
					case 84:
						{ 
    return makeToken (EQUALS); 
}
					case -84:
						break;
					case 85:
						{
    String str = yytext().substring(1, yytext().length() - 1);
    return makeToken (REGEXP, str);
}
					case -85:
						break;
					case 86:
						{ 
    return makeToken (TO);
}
					case -86:
						break;
					case 87:
						{ 
    return makeToken (NOT); 
}
					case -87:
						break;
					case 88:
						{
    return makeToken (ENDING); 
}
					case -88:
						break;
					case 89:
						{ 
    return makeToken (TRIM); 
}
					case -89:
						break;
					case 90:
						{
    return makeToken (MELT);
}
					case -90:
						break;
					case 91:
						{ 
    return makeToken (JUST_AFTER); 
}
					case -91:
						break;
					case 92:
						{ 
    return makeToken (JUST_BEFORE); 
}
					case -92:
						break;
					case 93:
						{
    return makeToken (ENDOF);
}
					case -93:
						break;
					case 94:
						{ 
    return makeToken (IGNORE); 
}
					case -94:
						break;
					case 95:
						{
    return makeToken (STARTING); 
}
					case -95:
						break;
					case 96:
						{
    return makeToken (STARTOF);
}
					case -96:
						break;
					case 97:
						{
    return makeToken (ANCESTOR);
}
					case -97:
						break;
					case 98:
						{ 
    return makeToken (AS_TEXT); 
}
					case -98:
						break;
					case 99:
						{ 
    return makeToken (NTH);
}
					case -99:
						break;
					case 100:
						{ 
    return makeToken (SEPARATED_BY); 
}
					case -100:
						break;
					case 101:
						{ 
    return makeToken (BALANCES); 
}
					case -101:
						break;
					case 102:
						{
    return makeToken (DESCENDANT);
}
					case -102:
						break;
					case 103:
						{ 
    return makeToken (AS_HTML); 
}
					case -103:
						break;
					case 104:
						{
    return makeToken (ENDING_DELIMITED); 
}
					case -104:
						break;
					case 105:
						{ 
    return makeToken (OVERLAPS_END); 
}
					case -105:
						break;
					case 106:
						{ 
    return makeToken (ANYWHERE_AFTER); 
}
					case -106:
						break;
					case 107:
						{ 
    return makeToken (CASE_SENSITIVE); 
}
					case -107:
						break;
					case 108:
						{ 
    return makeToken (ANYWHERE_BEFORE); 
}
					case -108:
						break;
					case 109:
						{
    return makeToken (STARTING_DELIMITED); 
}
					case -109:
						break;
					case 110:
						{ 
    return makeToken (OVERLAPS_START); 
}
					case -110:
						break;
					case 111:
						{ 
    return makeToken (NOT_CASE_SENSITIVE); 
}
					case -111:
						break;
					case 112:
						{ 
    return makeToken (JUST_AFTER_DELIMITED); 
}
					case -112:
						break;
					case 113:
						{ 
    return makeToken (JUST_BEFORE_DELIMITED); 
}
					case -113:
						break;
					case 114:
						{ 
    return makeToken (AFTER_DELIMITED); 
}
					case -114:
						break;
					case 115:
						{ 
    return makeToken (BEFORE_DELIMITED); 
}
					case -115:
						break;
					case 117:
						{ 
    return makeToken (ID); 
}
					case -116:
						break;
					case 118:
						{ 
    return makeToken (TO);
}
					case -117:
						break;
					case 119:
						{ 
    return makeToken (NOT); 
}
					case -118:
						break;
					case 120:
						{
    return makeToken (ENDING); 
}
					case -119:
						break;
					case 121:
						{ 
    return makeToken (TRIM); 
}
					case -120:
						break;
					case 122:
						{ 
    return makeToken (JUST_AFTER); 
}
					case -121:
						break;
					case 123:
						{ 
    return makeToken (JUST_BEFORE); 
}
					case -122:
						break;
					case 124:
						{
    return makeToken (ENDOF);
}
					case -123:
						break;
					case 125:
						{
    return makeToken (STARTING); 
}
					case -124:
						break;
					case 126:
						{
    return makeToken (STARTOF);
}
					case -125:
						break;
					case 128:
						{ 
    return makeToken (ID); 
}
					case -126:
						break;
					case 129:
						{
    return makeToken (ENDING); 
}
					case -127:
						break;
					case 130:
						{ 
    return makeToken (JUST_AFTER); 
}
					case -128:
						break;
					case 131:
						{ 
    return makeToken (JUST_BEFORE); 
}
					case -129:
						break;
					case 132:
						{
    return makeToken (ENDOF);
}
					case -130:
						break;
					case 133:
						{
    return makeToken (STARTING); 
}
					case -131:
						break;
					case 134:
						{
    return makeToken (STARTOF);
}
					case -132:
						break;
					case 136:
						{ 
    return makeToken (ID); 
}
					case -133:
						break;
					case 137:
						{ 
    return makeToken (JUST_AFTER); 
}
					case -134:
						break;
					case 139:
						{ 
    return makeToken (ID); 
}
					case -135:
						break;
					case 141:
						{ 
    return makeToken (ID); 
}
					case -136:
						break;
					case 143:
						{ 
    return makeToken (ID); 
}
					case -137:
						break;
					case 145:
						{ 
    return makeToken (ID); 
}
					case -138:
						break;
					case 147:
						{ 
    return makeToken (ID); 
}
					case -139:
						break;
					case 149:
						{ 
    return makeToken (ID); 
}
					case -140:
						break;
					case 151:
						{ 
    return makeToken (ID); 
}
					case -141:
						break;
					case 153:
						{ 
    return makeToken (ID); 
}
					case -142:
						break;
					case 155:
						{ 
    return makeToken (ID); 
}
					case -143:
						break;
					case 157:
						{ 
    return makeToken (ID); 
}
					case -144:
						break;
					case 159:
						{ 
    return makeToken (ID); 
}
					case -145:
						break;
					case 161:
						{ 
    return makeToken (ID); 
}
					case -146:
						break;
					case 163:
						{ 
    return makeToken (ID); 
}
					case -147:
						break;
					case 165:
						{ 
    return makeToken (ID); 
}
					case -148:
						break;
					case 167:
						{ 
    return makeToken (ID); 
}
					case -149:
						break;
					case 169:
						{ 
    return makeToken (ID); 
}
					case -150:
						break;
					case 171:
						{ 
    return makeToken (ID); 
}
					case -151:
						break;
					case 173:
						{ 
    return makeToken (ID); 
}
					case -152:
						break;
					case 175:
						{ 
    return makeToken (ID); 
}
					case -153:
						break;
					case 177:
						{ 
    return makeToken (ID); 
}
					case -154:
						break;
					case 179:
						{ 
    return makeToken (ID); 
}
					case -155:
						break;
					case 181:
						{ 
    return makeToken (ID); 
}
					case -156:
						break;
					case 183:
						{ 
    return makeToken (ID); 
}
					case -157:
						break;
					case 185:
						{ 
    return makeToken (ID); 
}
					case -158:
						break;
					case 187:
						{ 
    return makeToken (ID); 
}
					case -159:
						break;
					case 189:
						{ 
    return makeToken (ID); 
}
					case -160:
						break;
					case 191:
						{ 
    return makeToken (ID); 
}
					case -161:
						break;
					case 193:
						{ 
    return makeToken (ID); 
}
					case -162:
						break;
					case 195:
						{ 
    return makeToken (ID); 
}
					case -163:
						break;
					case 197:
						{ 
    return makeToken (ID); 
}
					case -164:
						break;
					case 199:
						{ 
    return makeToken (ID); 
}
					case -165:
						break;
					case 201:
						{ 
    return makeToken (ID); 
}
					case -166:
						break;
					case 203:
						{ 
    return makeToken (ID); 
}
					case -167:
						break;
					case 205:
						{ 
    return makeToken (ID); 
}
					case -168:
						break;
					case 207:
						{ 
    return makeToken (ID); 
}
					case -169:
						break;
					case 209:
						{ 
    return makeToken (ID); 
}
					case -170:
						break;
					case 211:
						{ 
    return makeToken (ID); 
}
					case -171:
						break;
					case 213:
						{ 
    return makeToken (ID); 
}
					case -172:
						break;
					case 215:
						{ 
    return makeToken (ID); 
}
					case -173:
						break;
					case 217:
						{ 
    return makeToken (ID); 
}
					case -174:
						break;
					case 219:
						{ 
    return makeToken (ID); 
}
					case -175:
						break;
					case 221:
						{ 
    return makeToken (ID); 
}
					case -176:
						break;
					case 223:
						{ 
    return makeToken (ID); 
}
					case -177:
						break;
					case 225:
						{ 
    return makeToken (ID); 
}
					case -178:
						break;
					case 227:
						{ 
    return makeToken (ID); 
}
					case -179:
						break;
					case 229:
						{ 
    return makeToken (ID); 
}
					case -180:
						break;
					case 231:
						{ 
    return makeToken (ID); 
}
					case -181:
						break;
					case 233:
						{ 
    return makeToken (ID); 
}
					case -182:
						break;
					case 235:
						{ 
    return makeToken (ID); 
}
					case -183:
						break;
					case 237:
						{ 
    return makeToken (ID); 
}
					case -184:
						break;
					case 239:
						{ 
    return makeToken (ID); 
}
					case -185:
						break;
					case 241:
						{ 
    return makeToken (ID); 
}
					case -186:
						break;
					case 243:
						{ 
    return makeToken (ID); 
}
					case -187:
						break;
					case 245:
						{ 
    return makeToken (ID); 
}
					case -188:
						break;
					case 247:
						{ 
    return makeToken (ID); 
}
					case -189:
						break;
					case 249:
						{ 
    return makeToken (ID); 
}
					case -190:
						break;
					case 251:
						{ 
    return makeToken (ID); 
}
					case -191:
						break;
					case 253:
						{ 
    return makeToken (ID); 
}
					case -192:
						break;
					case 255:
						{ 
    return makeToken (ID); 
}
					case -193:
						break;
					case 257:
						{ 
    return makeToken (ID); 
}
					case -194:
						break;
					case 259:
						{ 
    return makeToken (ID); 
}
					case -195:
						break;
					case 261:
						{ 
    return makeToken (ID); 
}
					case -196:
						break;
					case 263:
						{ 
    return makeToken (ID); 
}
					case -197:
						break;
					case 265:
						{ 
    return makeToken (ID); 
}
					case -198:
						break;
					case 267:
						{ 
    return makeToken (ID); 
}
					case -199:
						break;
					case 269:
						{ 
    return makeToken (ID); 
}
					case -200:
						break;
					case 271:
						{ 
    return makeToken (ID); 
}
					case -201:
						break;
					case 273:
						{ 
    return makeToken (ID); 
}
					case -202:
						break;
					case 275:
						{ 
    return makeToken (ID); 
}
					case -203:
						break;
					case 277:
						{ 
    return makeToken (ID); 
}
					case -204:
						break;
					case 279:
						{ 
    return makeToken (ID); 
}
					case -205:
						break;
					case 281:
						{ 
    return makeToken (ID); 
}
					case -206:
						break;
					case 283:
						{ 
    return makeToken (ID); 
}
					case -207:
						break;
					case 285:
						{ 
    return makeToken (ID); 
}
					case -208:
						break;
					case 287:
						{ 
    return makeToken (ID); 
}
					case -209:
						break;
					case 289:
						{ 
    return makeToken (ID); 
}
					case -210:
						break;
					case 291:
						{ 
    return makeToken (ID); 
}
					case -211:
						break;
					case 293:
						{ 
    return makeToken (ID); 
}
					case -212:
						break;
					case 295:
						{ 
    return makeToken (ID); 
}
					case -213:
						break;
					case 297:
						{ 
    return makeToken (ID); 
}
					case -214:
						break;
					case 299:
						{ 
    return makeToken (ID); 
}
					case -215:
						break;
					case 301:
						{ 
    return makeToken (ID); 
}
					case -216:
						break;
					case 303:
						{ 
    return makeToken (ID); 
}
					case -217:
						break;
					case 305:
						{ 
    return makeToken (ID); 
}
					case -218:
						break;
					case 307:
						{ 
    return makeToken (ID); 
}
					case -219:
						break;
					case 309:
						{ 
    return makeToken (ID); 
}
					case -220:
						break;
					case 311:
						{ 
    return makeToken (ID); 
}
					case -221:
						break;
					case 313:
						{ 
    return makeToken (ID); 
}
					case -222:
						break;
					case 315:
						{ 
    return makeToken (ID); 
}
					case -223:
						break;
					case 317:
						{ 
    return makeToken (ID); 
}
					case -224:
						break;
					case 319:
						{ 
    return makeToken (ID); 
}
					case -225:
						break;
					case 321:
						{ 
    return makeToken (ID); 
}
					case -226:
						break;
					case 323:
						{ 
    return makeToken (ID); 
}
					case -227:
						break;
					case 325:
						{ 
    return makeToken (ID); 
}
					case -228:
						break;
					case 327:
						{ 
    return makeToken (ID); 
}
					case -229:
						break;
					case 329:
						{ 
    return makeToken (ID); 
}
					case -230:
						break;
					case 331:
						{ 
    return makeToken (ID); 
}
					case -231:
						break;
					case 333:
						{ 
    return makeToken (ID); 
}
					case -232:
						break;
					case 335:
						{ 
    return makeToken (ID); 
}
					case -233:
						break;
					case 337:
						{ 
    return makeToken (ID); 
}
					case -234:
						break;
					case 339:
						{ 
    return makeToken (ID); 
}
					case -235:
						break;
					case 341:
						{ 
    return makeToken (ID); 
}
					case -236:
						break;
					case 343:
						{ 
    return makeToken (ID); 
}
					case -237:
						break;
					case 345:
						{ 
    return makeToken (ID); 
}
					case -238:
						break;
					case 347:
						{ 
    return makeToken (ID); 
}
					case -239:
						break;
					case 349:
						{ 
    return makeToken (ID); 
}
					case -240:
						break;
					case 351:
						{ 
    return makeToken (ID); 
}
					case -241:
						break;
					case 353:
						{ 
    return makeToken (ID); 
}
					case -242:
						break;
					case 355:
						{ 
    return makeToken (ID); 
}
					case -243:
						break;
					case 357:
						{ 
    return makeToken (ID); 
}
					case -244:
						break;
					case 359:
						{ 
    return makeToken (ID); 
}
					case -245:
						break;
					case 361:
						{ 
    return makeToken (ID); 
}
					case -246:
						break;
					case 363:
						{ 
    return makeToken (ID); 
}
					case -247:
						break;
					case 365:
						{ 
    return makeToken (ID); 
}
					case -248:
						break;
					case 367:
						{ 
    return makeToken (ID); 
}
					case -249:
						break;
					case 369:
						{ 
    return makeToken (ID); 
}
					case -250:
						break;
					case 371:
						{ 
    return makeToken (ID); 
}
					case -251:
						break;
					case 373:
						{ 
    return makeToken (ID); 
}
					case -252:
						break;
					case 375:
						{ 
    return makeToken (ID); 
}
					case -253:
						break;
					case 433:
						{ 
    return makeToken (ID); 
}
					case -254:
						break;
					case 434:
						{
    return makeToken (ENDING); 
}
					case -255:
						break;
					case 435:
						{ 
    return makeToken (JUST_BEFORE); 
}
					case -256:
						break;
					case 436:
						{
    return makeToken (STARTING); 
}
					case -257:
						break;
					case 462:
						{ 
    return makeToken (ID); 
}
					case -258:
						break;
					case 464:
						{ 
    return makeToken (ID); 
}
					case -259:
						break;
					case 467:
						{ 
    return makeToken (ID); 
}
					case -260:
						break;
					case 480:
						{ 
    return makeToken (ID); 
}
					case -261:
						break;
					case 497:
						{ 
    return makeToken (ID); 
}
					case -262:
						break;
					case 503:
						{ 
    return makeToken (ID); 
}
					case -263:
						break;
					case 506:
						{ 
    return makeToken (ID); 
}
					case -264:
						break;
					case 508:
						{ 
    return makeToken (ID); 
}
					case -265:
						break;
					case 510:
						{ 
    return makeToken (ID); 
}
					case -266:
						break;
					case 511:
						{ 
    return makeToken (ID); 
}
					case -267:
						break;
					case 512:
						{ 
    return makeToken (ID); 
}
					case -268:
						break;
					case 513:
						{ 
    return makeToken (ID); 
}
					case -269:
						break;
					case 514:
						{ 
    return makeToken (ID); 
}
					case -270:
						break;
					case 515:
						{ 
    return makeToken (ID); 
}
					case -271:
						break;
					case 516:
						{ 
    return makeToken (ID); 
}
					case -272:
						break;
					case 517:
						{ 
    return makeToken (ID); 
}
					case -273:
						break;
					case 518:
						{ 
    return makeToken (ID); 
}
					case -274:
						break;
					case 519:
						{ 
    return makeToken (ID); 
}
					case -275:
						break;
					case 520:
						{ 
    return makeToken (ID); 
}
					case -276:
						break;
					case 521:
						{ 
    return makeToken (ID); 
}
					case -277:
						break;
					case 522:
						{ 
    return makeToken (ID); 
}
					case -278:
						break;
					case 523:
						{ 
    return makeToken (ID); 
}
					case -279:
						break;
					case 524:
						{ 
    return makeToken (ID); 
}
					case -280:
						break;
					case 525:
						{ 
    return makeToken (ID); 
}
					case -281:
						break;
					case 526:
						{ 
    return makeToken (ID); 
}
					case -282:
						break;
					case 527:
						{ 
    return makeToken (ID); 
}
					case -283:
						break;
					case 528:
						{ 
    return makeToken (ID); 
}
					case -284:
						break;
					case 529:
						{ 
    return makeToken (ID); 
}
					case -285:
						break;
					case 530:
						{ 
    return makeToken (ID); 
}
					case -286:
						break;
					case 531:
						{ 
    return makeToken (ID); 
}
					case -287:
						break;
					case 532:
						{ 
    return makeToken (ID); 
}
					case -288:
						break;
					case 533:
						{ 
    return makeToken (ID); 
}
					case -289:
						break;
					case 534:
						{ 
    return makeToken (ID); 
}
					case -290:
						break;
					case 535:
						{ 
    return makeToken (ID); 
}
					case -291:
						break;
					case 536:
						{ 
    return makeToken (ID); 
}
					case -292:
						break;
					case 537:
						{ 
    return makeToken (ID); 
}
					case -293:
						break;
					case 538:
						{ 
    return makeToken (ID); 
}
					case -294:
						break;
					case 539:
						{ 
    return makeToken (ID); 
}
					case -295:
						break;
					case 540:
						{ 
    return makeToken (ID); 
}
					case -296:
						break;
					case 541:
						{ 
    return makeToken (ID); 
}
					case -297:
						break;
					case 542:
						{ 
    return makeToken (ID); 
}
					case -298:
						break;
					case 543:
						{ 
    return makeToken (ID); 
}
					case -299:
						break;
					case 544:
						{ 
    return makeToken (ID); 
}
					case -300:
						break;
					case 545:
						{ 
    return makeToken (ID); 
}
					case -301:
						break;
					case 546:
						{ 
    return makeToken (ID); 
}
					case -302:
						break;
					case 547:
						{ 
    return makeToken (ID); 
}
					case -303:
						break;
					case 548:
						{ 
    return makeToken (ID); 
}
					case -304:
						break;
					case 549:
						{ 
    return makeToken (ID); 
}
					case -305:
						break;
					case 550:
						{ 
    return makeToken (ID); 
}
					case -306:
						break;
					case 551:
						{ 
    return makeToken (ID); 
}
					case -307:
						break;
					case 552:
						{ 
    return makeToken (ID); 
}
					case -308:
						break;
					case 553:
						{ 
    return makeToken (ID); 
}
					case -309:
						break;
					case 554:
						{ 
    return makeToken (ID); 
}
					case -310:
						break;
					case 555:
						{ 
    return makeToken (ID); 
}
					case -311:
						break;
					case 556:
						{ 
    return makeToken (ID); 
}
					case -312:
						break;
					case 557:
						{ 
    return makeToken (ID); 
}
					case -313:
						break;
					case 558:
						{ 
    return makeToken (ID); 
}
					case -314:
						break;
					case 559:
						{ 
    return makeToken (ID); 
}
					case -315:
						break;
					case 560:
						{ 
    return makeToken (ID); 
}
					case -316:
						break;
					case 561:
						{ 
    return makeToken (ID); 
}
					case -317:
						break;
					case 562:
						{ 
    return makeToken (ID); 
}
					case -318:
						break;
					case 563:
						{ 
    return makeToken (ID); 
}
					case -319:
						break;
					case 564:
						{ 
    return makeToken (ID); 
}
					case -320:
						break;
					case 565:
						{ 
    return makeToken (ID); 
}
					case -321:
						break;
					case 566:
						{ 
    return makeToken (ID); 
}
					case -322:
						break;
					case 567:
						{ 
    return makeToken (ID); 
}
					case -323:
						break;
					case 568:
						{ 
    return makeToken (ID); 
}
					case -324:
						break;
					case 569:
						{ 
    return makeToken (ID); 
}
					case -325:
						break;
					case 570:
						{ 
    return makeToken (ID); 
}
					case -326:
						break;
					case 571:
						{ 
    return makeToken (ID); 
}
					case -327:
						break;
					case 572:
						{ 
    return makeToken (ID); 
}
					case -328:
						break;
					case 573:
						{ 
    return makeToken (ID); 
}
					case -329:
						break;
					case 574:
						{ 
    return makeToken (ID); 
}
					case -330:
						break;
					case 575:
						{ 
    return makeToken (ID); 
}
					case -331:
						break;
					case 576:
						{ 
    return makeToken (ID); 
}
					case -332:
						break;
					case 577:
						{ 
    return makeToken (ID); 
}
					case -333:
						break;
					case 578:
						{ 
    return makeToken (ID); 
}
					case -334:
						break;
					case 579:
						{ 
    return makeToken (ID); 
}
					case -335:
						break;
					case 580:
						{ 
    return makeToken (ID); 
}
					case -336:
						break;
					case 581:
						{ 
    return makeToken (ID); 
}
					case -337:
						break;
					case 582:
						{ 
    return makeToken (ID); 
}
					case -338:
						break;
					case 583:
						{ 
    return makeToken (ID); 
}
					case -339:
						break;
					case 584:
						{ 
    return makeToken (ID); 
}
					case -340:
						break;
					case 585:
						{ 
    return makeToken (ID); 
}
					case -341:
						break;
					case 586:
						{ 
    return makeToken (ID); 
}
					case -342:
						break;
					case 587:
						{ 
    return makeToken (ID); 
}
					case -343:
						break;
					case 588:
						{ 
    return makeToken (ID); 
}
					case -344:
						break;
					case 589:
						{ 
    return makeToken (ID); 
}
					case -345:
						break;
					case 590:
						{ 
    return makeToken (ID); 
}
					case -346:
						break;
					case 591:
						{ 
    return makeToken (ID); 
}
					case -347:
						break;
					case 592:
						{ 
    return makeToken (ID); 
}
					case -348:
						break;
					case 593:
						{ 
    return makeToken (ID); 
}
					case -349:
						break;
					case 594:
						{ 
    return makeToken (ID); 
}
					case -350:
						break;
					case 595:
						{ 
    return makeToken (ID); 
}
					case -351:
						break;
					case 596:
						{ 
    return makeToken (ID); 
}
					case -352:
						break;
					case 597:
						{ 
    return makeToken (ID); 
}
					case -353:
						break;
					case 598:
						{ 
    return makeToken (ID); 
}
					case -354:
						break;
					case 599:
						{ 
    return makeToken (ID); 
}
					case -355:
						break;
					case 600:
						{ 
    return makeToken (ID); 
}
					case -356:
						break;
					case 601:
						{ 
    return makeToken (ID); 
}
					case -357:
						break;
					case 602:
						{ 
    return makeToken (ID); 
}
					case -358:
						break;
					case 603:
						{ 
    return makeToken (ID); 
}
					case -359:
						break;
					case 604:
						{ 
    return makeToken (ID); 
}
					case -360:
						break;
					case 605:
						{ 
    return makeToken (ID); 
}
					case -361:
						break;
					case 606:
						{ 
    return makeToken (ID); 
}
					case -362:
						break;
					case 607:
						{ 
    return makeToken (ID); 
}
					case -363:
						break;
					case 608:
						{ 
    return makeToken (ID); 
}
					case -364:
						break;
					case 609:
						{ 
    return makeToken (IN); 
}
					case -365:
						break;
					case 610:
						{ 
    return makeToken (TRIM); 
}
					case -366:
						break;
					case 611:
						{ 
    return makeToken (CONTAINS); 
}
					case -367:
						break;
					case 613:
						{ 
    return makeToken (ID); 
}
					case -368:
						break;
					case 619:
						{ 
    return makeToken (ID); 
}
					case -369:
						break;
					case 620:
						{ 
    return makeToken (ID); 
}
					case -370:
						break;
					case 622:
						{ 
    return makeToken (ID); 
}
					case -371:
						break;
					case 623:
						{ 
    return makeToken (ID); 
}
					case -372:
						break;
					case 624:
						{ 
    return makeToken (ID); 
}
					case -373:
						break;
					case 625:
						{ 
    return makeToken (ID); 
}
					case -374:
						break;
					case 626:
						{ 
    return makeToken (ID); 
}
					case -375:
						break;
					case 627:
						{ 
    return makeToken (ID); 
}
					case -376:
						break;
					case 628:
						{ 
    return makeToken (ID); 
}
					case -377:
						break;
					case 629:
						{ 
    return makeToken (ID); 
}
					case -378:
						break;
					case 630:
						{ 
    return makeToken (ID); 
}
					case -379:
						break;
					case 631:
						{ 
    return makeToken (ID); 
}
					case -380:
						break;
					case 632:
						{ 
    return makeToken (ID); 
}
					case -381:
						break;
					case 633:
						{ 
    return makeToken (ID); 
}
					case -382:
						break;
					case 634:
						{ 
    return makeToken (ID); 
}
					case -383:
						break;
					case 635:
						{ 
    return makeToken (ID); 
}
					case -384:
						break;
					case 636:
						{ 
    return makeToken (ID); 
}
					case -385:
						break;
					case 637:
						{ 
    return makeToken (ID); 
}
					case -386:
						break;
					case 638:
						{ 
    return makeToken (ID); 
}
					case -387:
						break;
					case 639:
						{ 
    return makeToken (ID); 
}
					case -388:
						break;
					case 640:
						{ 
    return makeToken (ID); 
}
					case -389:
						break;
					case 641:
						{ 
    return makeToken (ID); 
}
					case -390:
						break;
					case 642:
						{ 
    return makeToken (ID); 
}
					case -391:
						break;
					case 643:
						{ 
    return makeToken (ID); 
}
					case -392:
						break;
					case 644:
						{ 
    return makeToken (ID); 
}
					case -393:
						break;
					case 645:
						{ 
    return makeToken (ID); 
}
					case -394:
						break;
					case 646:
						{ 
    return makeToken (ID); 
}
					case -395:
						break;
					case 647:
						{ 
    return makeToken (ID); 
}
					case -396:
						break;
					case 648:
						{ 
    return makeToken (ID); 
}
					case -397:
						break;
					case 649:
						{ 
    return makeToken (ID); 
}
					case -398:
						break;
					case 650:
						{ 
    return makeToken (ID); 
}
					case -399:
						break;
					case 651:
						{ 
    return makeToken (ID); 
}
					case -400:
						break;
					case 652:
						{ 
    return makeToken (ID); 
}
					case -401:
						break;
					case 653:
						{ 
    return makeToken (ID); 
}
					case -402:
						break;
					case 654:
						{ 
    return makeToken (ID); 
}
					case -403:
						break;
					case 655:
						{ 
    return makeToken (ID); 
}
					case -404:
						break;
					case 656:
						{ 
    return makeToken (ID); 
}
					case -405:
						break;
					case 657:
						{ 
    return makeToken (ID); 
}
					case -406:
						break;
					case 658:
						{ 
    return makeToken (ID); 
}
					case -407:
						break;
					case 659:
						{ 
    return makeToken (ID); 
}
					case -408:
						break;
					case 660:
						{ 
    return makeToken (ID); 
}
					case -409:
						break;
					case 661:
						{ 
    return makeToken (ID); 
}
					case -410:
						break;
					case 662:
						{ 
    return makeToken (ID); 
}
					case -411:
						break;
					case 663:
						{ 
    return makeToken (ID); 
}
					case -412:
						break;
					case 664:
						{ 
    return makeToken (ID); 
}
					case -413:
						break;
					case 665:
						{ 
    return makeToken (ID); 
}
					case -414:
						break;
					case 666:
						{ 
    return makeToken (ID); 
}
					case -415:
						break;
					case 667:
						{ 
    return makeToken (ID); 
}
					case -416:
						break;
					case 668:
						{ 
    return makeToken (ID); 
}
					case -417:
						break;
					case 669:
						{ 
    return makeToken (ID); 
}
					case -418:
						break;
					case 670:
						{ 
    return makeToken (ID); 
}
					case -419:
						break;
					case 671:
						{ 
    return makeToken (ID); 
}
					case -420:
						break;
					case 672:
						{ 
    return makeToken (ID); 
}
					case -421:
						break;
					case 673:
						{ 
    return makeToken (ID); 
}
					case -422:
						break;
					case 674:
						{ 
    return makeToken (ID); 
}
					case -423:
						break;
					case 675:
						{ 
    return makeToken (ID); 
}
					case -424:
						break;
					case 676:
						{ 
    return makeToken (ID); 
}
					case -425:
						break;
					case 677:
						{ 
    return makeToken (ID); 
}
					case -426:
						break;
					case 678:
						{ 
    return makeToken (ID); 
}
					case -427:
						break;
					case 679:
						{ 
    return makeToken (ID); 
}
					case -428:
						break;
					case 680:
						{ 
    return makeToken (ID); 
}
					case -429:
						break;
					case 681:
						{ 
    return makeToken (ID); 
}
					case -430:
						break;
					case 682:
						{ 
    return makeToken (ID); 
}
					case -431:
						break;
					case 683:
						{ 
    return makeToken (ID); 
}
					case -432:
						break;
					case 684:
						{ 
    return makeToken (ID); 
}
					case -433:
						break;
					case 685:
						{ 
    return makeToken (ID); 
}
					case -434:
						break;
					case 686:
						{ 
    return makeToken (ID); 
}
					case -435:
						break;
					case 687:
						{ 
    return makeToken (ID); 
}
					case -436:
						break;
					case 688:
						{ 
    return makeToken (ID); 
}
					case -437:
						break;
					case 689:
						{ 
    return makeToken (ID); 
}
					case -438:
						break;
					case 690:
						{ 
    return makeToken (ID); 
}
					case -439:
						break;
					case 691:
						{ 
    return makeToken (ID); 
}
					case -440:
						break;
					case 692:
						{ 
    return makeToken (ID); 
}
					case -441:
						break;
					case 693:
						{ 
    return makeToken (ID); 
}
					case -442:
						break;
					case 694:
						{ 
    return makeToken (ID); 
}
					case -443:
						break;
					case 695:
						{ 
    return makeToken (ID); 
}
					case -444:
						break;
					case 696:
						{ 
    return makeToken (ID); 
}
					case -445:
						break;
					case 697:
						{ 
    return makeToken (ID); 
}
					case -446:
						break;
					case 698:
						{ 
    return makeToken (ID); 
}
					case -447:
						break;
					case 699:
						{ 
    return makeToken (ID); 
}
					case -448:
						break;
					case 700:
						{ 
    return makeToken (ID); 
}
					case -449:
						break;
					case 701:
						{ 
    return makeToken (ID); 
}
					case -450:
						break;
					case 702:
						{ 
    return makeToken (ID); 
}
					case -451:
						break;
					case 703:
						{ 
    return makeToken (ID); 
}
					case -452:
						break;
					case 704:
						{ 
    return makeToken (ID); 
}
					case -453:
						break;
					case 705:
						{ 
    return makeToken (ID); 
}
					case -454:
						break;
					case 706:
						{ 
    return makeToken (ID); 
}
					case -455:
						break;
					case 709:
						{ 
    return makeToken (ID); 
}
					case -456:
						break;
					case 710:
						{ 
    return makeToken (ID); 
}
					case -457:
						break;
					case 711:
						{ 
    return makeToken (ID); 
}
					case -458:
						break;
					case 712:
						{ 
    return makeToken (ID); 
}
					case -459:
						break;
					case 713:
						{ 
    return makeToken (ID); 
}
					case -460:
						break;
					case 714:
						{ 
    return makeToken (ID); 
}
					case -461:
						break;
					case 715:
						{ 
    return makeToken (ID); 
}
					case -462:
						break;
					case 716:
						{ 
    return makeToken (ID); 
}
					case -463:
						break;
					case 717:
						{ 
    return makeToken (ID); 
}
					case -464:
						break;
					case 718:
						{ 
    return makeToken (ID); 
}
					case -465:
						break;
					case 719:
						{ 
    return makeToken (ID); 
}
					case -466:
						break;
					case 720:
						{ 
    return makeToken (ID); 
}
					case -467:
						break;
					case 721:
						{ 
    return makeToken (ID); 
}
					case -468:
						break;
					case 722:
						{ 
    return makeToken (ID); 
}
					case -469:
						break;
					case 723:
						{ 
    return makeToken (ID); 
}
					case -470:
						break;
					case 724:
						{ 
    return makeToken (ID); 
}
					case -471:
						break;
					case 725:
						{ 
    return makeToken (ID); 
}
					case -472:
						break;
					case 726:
						{ 
    return makeToken (ID); 
}
					case -473:
						break;
					case 727:
						{ 
    return makeToken (ID); 
}
					case -474:
						break;
					case 728:
						{ 
    return makeToken (ID); 
}
					case -475:
						break;
					case 729:
						{ 
    return makeToken (ID); 
}
					case -476:
						break;
					case 730:
						{ 
    return makeToken (ID); 
}
					case -477:
						break;
					case 731:
						{ 
    return makeToken (ID); 
}
					case -478:
						break;
					case 732:
						{ 
    return makeToken (ID); 
}
					case -479:
						break;
					case 733:
						{ 
    return makeToken (ID); 
}
					case -480:
						break;
					case 734:
						{ 
    return makeToken (ID); 
}
					case -481:
						break;
					case 735:
						{ 
    return makeToken (ID); 
}
					case -482:
						break;
					case 736:
						{ 
    return makeToken (ID); 
}
					case -483:
						break;
					case 737:
						{ 
    return makeToken (ID); 
}
					case -484:
						break;
					case 738:
						{ 
    return makeToken (ID); 
}
					case -485:
						break;
					case 739:
						{ 
    return makeToken (ID); 
}
					case -486:
						break;
					case 740:
						{ 
    return makeToken (ID); 
}
					case -487:
						break;
					case 741:
						{ 
    return makeToken (ID); 
}
					case -488:
						break;
					case 742:
						{ 
    return makeToken (ID); 
}
					case -489:
						break;
					case 743:
						{ 
    return makeToken (ID); 
}
					case -490:
						break;
					case 744:
						{ 
    return makeToken (ID); 
}
					case -491:
						break;
					case 745:
						{ 
    return makeToken (ID); 
}
					case -492:
						break;
					case 746:
						{ 
    return makeToken (ID); 
}
					case -493:
						break;
					case 747:
						{ 
    return makeToken (ID); 
}
					case -494:
						break;
					case 748:
						{ 
    return makeToken (ID); 
}
					case -495:
						break;
					case 749:
						{ 
    return makeToken (ID); 
}
					case -496:
						break;
					case 750:
						{ 
    return makeToken (ID); 
}
					case -497:
						break;
					case 751:
						{ 
    return makeToken (ID); 
}
					case -498:
						break;
					case 752:
						{ 
    return makeToken (ID); 
}
					case -499:
						break;
					case 753:
						{ 
    return makeToken (ID); 
}
					case -500:
						break;
					case 754:
						{ 
    return makeToken (ID); 
}
					case -501:
						break;
					case 755:
						{ 
    return makeToken (ID); 
}
					case -502:
						break;
					case 756:
						{ 
    return makeToken (ID); 
}
					case -503:
						break;
					case 757:
						{ 
    return makeToken (ID); 
}
					case -504:
						break;
					case 758:
						{ 
    return makeToken (ID); 
}
					case -505:
						break;
					case 759:
						{ 
    return makeToken (ID); 
}
					case -506:
						break;
					case 760:
						{ 
    return makeToken (ID); 
}
					case -507:
						break;
					case 761:
						{ 
    return makeToken (ID); 
}
					case -508:
						break;
					case 762:
						{ 
    return makeToken (ID); 
}
					case -509:
						break;
					case 763:
						{ 
    return makeToken (ID); 
}
					case -510:
						break;
					case 764:
						{ 
    return makeToken (ID); 
}
					case -511:
						break;
					case 765:
						{ 
    return makeToken (ID); 
}
					case -512:
						break;
					case 766:
						{ 
    return makeToken (ID); 
}
					case -513:
						break;
					case 767:
						{ 
    return makeToken (ID); 
}
					case -514:
						break;
					case 768:
						{ 
    return makeToken (ID); 
}
					case -515:
						break;
					case 769:
						{ 
    return makeToken (ID); 
}
					case -516:
						break;
					case 770:
						{ 
    return makeToken (ID); 
}
					case -517:
						break;
					case 771:
						{ 
    return makeToken (ID); 
}
					case -518:
						break;
					case 772:
						{ 
    return makeToken (ID); 
}
					case -519:
						break;
					case 773:
						{ 
    return makeToken (ID); 
}
					case -520:
						break;
					case 774:
						{ 
    return makeToken (ID); 
}
					case -521:
						break;
					case 775:
						{ 
    return makeToken (ID); 
}
					case -522:
						break;
					case 776:
						{ 
    return makeToken (ID); 
}
					case -523:
						break;
					case 777:
						{ 
    return makeToken (ID); 
}
					case -524:
						break;
					case 778:
						{ 
    return makeToken (ID); 
}
					case -525:
						break;
					case 779:
						{ 
    return makeToken (ID); 
}
					case -526:
						break;
					case 780:
						{ 
    return makeToken (ID); 
}
					case -527:
						break;
					case 781:
						{ 
    return makeToken (ID); 
}
					case -528:
						break;
					case 782:
						{ 
    return makeToken (ID); 
}
					case -529:
						break;
					case 783:
						{ 
    return makeToken (ID); 
}
					case -530:
						break;
					case 784:
						{ 
    return makeToken (ID); 
}
					case -531:
						break;
					case 785:
						{ 
    return makeToken (ID); 
}
					case -532:
						break;
					case 786:
						{ 
    return makeToken (ID); 
}
					case -533:
						break;
					case 787:
						{ 
    return makeToken (ID); 
}
					case -534:
						break;
					case 788:
						{ 
    return makeToken (ID); 
}
					case -535:
						break;
					case 789:
						{ 
    return makeToken (ID); 
}
					case -536:
						break;
					case 790:
						{ 
    return makeToken (ID); 
}
					case -537:
						break;
					case 791:
						{ 
    return makeToken (ID); 
}
					case -538:
						break;
					case 792:
						{ 
    return makeToken (ID); 
}
					case -539:
						break;
					case 793:
						{ 
    return makeToken (ID); 
}
					case -540:
						break;
					case 794:
						{ 
    return makeToken (ID); 
}
					case -541:
						break;
					case 795:
						{ 
    return makeToken (ID); 
}
					case -542:
						break;
					case 796:
						{ 
    return makeToken (ID); 
}
					case -543:
						break;
					case 797:
						{ 
    return makeToken (ID); 
}
					case -544:
						break;
					case 798:
						{ 
    return makeToken (ID); 
}
					case -545:
						break;
					case 799:
						{ 
    return makeToken (ID); 
}
					case -546:
						break;
					case 800:
						{ 
    return makeToken (ID); 
}
					case -547:
						break;
					case 801:
						{ 
    return makeToken (ID); 
}
					case -548:
						break;
					case 802:
						{ 
    return makeToken (ID); 
}
					case -549:
						break;
					case 803:
						{ 
    return makeToken (ID); 
}
					case -550:
						break;
					case 804:
						{ 
    return makeToken (ID); 
}
					case -551:
						break;
					case 805:
						{ 
    return makeToken (ID); 
}
					case -552:
						break;
					case 806:
						{ 
    return makeToken (ID); 
}
					case -553:
						break;
					case 807:
						{ 
    return makeToken (ID); 
}
					case -554:
						break;
					case 808:
						{ 
    return makeToken (ID); 
}
					case -555:
						break;
					case 809:
						{ 
    return makeToken (ID); 
}
					case -556:
						break;
					case 810:
						{ 
    return makeToken (ID); 
}
					case -557:
						break;
					case 811:
						{ 
    return makeToken (ID); 
}
					case -558:
						break;
					case 812:
						{ 
    return makeToken (ID); 
}
					case -559:
						break;
					case 813:
						{ 
    return makeToken (ID); 
}
					case -560:
						break;
					case 814:
						{ 
    return makeToken (ID); 
}
					case -561:
						break;
					case 815:
						{ 
    return makeToken (ID); 
}
					case -562:
						break;
					case 816:
						{ 
    return makeToken (ID); 
}
					case -563:
						break;
					case 817:
						{ 
    return makeToken (ID); 
}
					case -564:
						break;
					case 818:
						{ 
    return makeToken (ID); 
}
					case -565:
						break;
					case 819:
						{ 
    return makeToken (ID); 
}
					case -566:
						break;
					case 820:
						{ 
    return makeToken (ID); 
}
					case -567:
						break;
					case 821:
						{ 
    return makeToken (ID); 
}
					case -568:
						break;
					case 822:
						{ 
    return makeToken (ID); 
}
					case -569:
						break;
					case 823:
						{ 
    return makeToken (ID); 
}
					case -570:
						break;
					case 824:
						{ 
    return makeToken (ID); 
}
					case -571:
						break;
					case 825:
						{ 
    return makeToken (ID); 
}
					case -572:
						break;
					case 826:
						{ 
    return makeToken (ID); 
}
					case -573:
						break;
					case 827:
						{ 
    return makeToken (ID); 
}
					case -574:
						break;
					case 828:
						{ 
    return makeToken (ID); 
}
					case -575:
						break;
					case 829:
						{ 
    return makeToken (ID); 
}
					case -576:
						break;
					case 830:
						{ 
    return makeToken (ID); 
}
					case -577:
						break;
					case 831:
						{ 
    return makeToken (ID); 
}
					case -578:
						break;
					case 832:
						{ 
    return makeToken (ID); 
}
					case -579:
						break;
					case 833:
						{ 
    return makeToken (ID); 
}
					case -580:
						break;
					case 834:
						{ 
    return makeToken (ID); 
}
					case -581:
						break;
					case 835:
						{ 
    return makeToken (ID); 
}
					case -582:
						break;
					case 836:
						{ 
    return makeToken (ID); 
}
					case -583:
						break;
					case 837:
						{ 
    return makeToken (ID); 
}
					case -584:
						break;
					case 838:
						{ 
    return makeToken (ID); 
}
					case -585:
						break;
					case 839:
						{ 
    return makeToken (ID); 
}
					case -586:
						break;
					case 840:
						{ 
    return makeToken (ID); 
}
					case -587:
						break;
					case 841:
						{ 
    return makeToken (ID); 
}
					case -588:
						break;
					case 842:
						{ 
    return makeToken (ID); 
}
					case -589:
						break;
					case 843:
						{ 
    return makeToken (ID); 
}
					case -590:
						break;
					case 844:
						{ 
    return makeToken (ID); 
}
					case -591:
						break;
					case 845:
						{ 
    return makeToken (ID); 
}
					case -592:
						break;
					case 846:
						{ 
    return makeToken (ID); 
}
					case -593:
						break;
					case 847:
						{ 
    return makeToken (ID); 
}
					case -594:
						break;
					case 848:
						{ 
    return makeToken (ID); 
}
					case -595:
						break;
					case 849:
						{ 
    return makeToken (ID); 
}
					case -596:
						break;
					case 850:
						{ 
    return makeToken (ID); 
}
					case -597:
						break;
					case 851:
						{ 
    return makeToken (ID); 
}
					case -598:
						break;
					default:
						yy_error(YY_E_INTERNAL,false);
					case -1:
					}
					yy_initial = true;
					yy_state = yy_state_dtrans[yy_lexical_state];
					yy_next_state = YY_NO_STATE;
					yy_last_accept_state = YY_NO_STATE;
					yy_mark_start();
					yy_this_accept = yy_acpt[yy_state];
					if (YY_NOT_ACCEPT != yy_this_accept) {
						yy_last_accept_state = yy_state;
						yy_mark_end();
					}
				}
			}
		}
	}
}
