/*
 * LAPIS lightweight structured text processing system
 *
 * Copyright (C) 1998-2002 Carnegie Mellon University,
 * Copyright (C) 2003 Massachusetts Institute of Technology.
 * All rights reserved.
 *
 * This library is free software; you can redistribute it
 * and/or modify it under the terms of the GNU General
 * Public License as published by the Free Software
 * Foundation, version 2.
 *
 * LAPIS homepage: http://graphics.lcs.mit.edu/lapis/
 */

package lapis.tc;

import java.io.PrintWriter;
import lapisx.util.Str;

public class TCToken implements TCSymbols {
    
    public int sym;
    public String text;

    // line and column are numbered from 0
    public int line;
    public int columnStart;
    public int columnEnd;

    // start and end are offsets from start of stream 
    public int start;
    public int end;

    public TCToken child;
    public TCToken sibling;

    public TCToken (int sym, String text, 
             int line, int columnStart, int columnEnd,
             int start, int end) {
        this.sym = sym;
        this.text = text;
        this.line = line;
        this.columnStart = columnStart;
        this.columnEnd = columnEnd;
        this.start = start;
        this.end = end;
    }

    public String toString () {
        return text + "(#" + sym + ")";
    }

    public void addChild (TCToken tok) {
        if (child == null)
            child = tok;
        else
            child.addSibling (tok);
    }

    public void addSibling (TCToken tok) {
        TCToken p = this;
        while (p.sibling != null)
            p = p.sibling;
        p.sibling = tok;
    }

    public TCToken getLastLeaf () {
        if (child == null)
            return this;

        TCToken tok = child;
        while (true) {
            if (tok.sibling != null)
                tok = tok.sibling;
            else if (tok.child != null)
                tok = tok.child;
            else
                return tok;
        }
    }

    public void print () {
        PrintWriter out = new PrintWriter (System.err);
        print (out, 0);
        out.flush ();
    }

    public void print (PrintWriter out, int indent) {
        String s = toString ();
        out.print (s + " ");
        if (child != null)
            child.print (out, indent + s.length () + 1);
        if (sibling != null) {
            out.println ();
            out.print (Str.repeat (" ", indent));
            sibling.print (out, indent);
        }
    }
}
