/*
 * LAPIS lightweight structured text processing system
 *
 * Copyright (C) 1998-2002 Carnegie Mellon University,
 * Copyright (C) 2003 Massachusetts Institute of Technology.
 * All rights reserved.
 *
 * This library is free software; you can redistribute it
 * and/or modify it under the terms of the GNU General
 * Public License as published by the Free Software
 * Foundation, version 2.
 *
 * LAPIS homepage: http://graphics.lcs.mit.edu/lapis/
 */

package lapis.tcl;

import lapis.*;
import tcl.lang.*;
import java.io.*;

public class TclArguments extends Arguments {
    StringWriter stringWriter;

    /**
     * Make a TclArguments object.
     * @param interp Tcl interpreter
     * @param argv Sequence of Tcl arguments (argv[0] is command name)
     */
    public TclArguments (Interp interp, TclObject[] argv) {
        super (new TclInterpreter (interp));

        this.originalArgs = new Object[argv.length-1];

        boolean restAreValues = false;
        for (int i = 1; i < argv.length; ++i) {
            Object obj = toJavaObject (interp, argv[i]);

            originalArgs[i-1] = obj;

            if (!restAreValues) {
                String str = obj.toString ();
                if (str.startsWith ("-")) {
                    if (str.equals ("--"))
                        restAreValues = true;
                    else
                        addName (str.substring (1));
                    continue;
                }
            }
            addValue (obj);
        }
    }

    public static Object toJavaObject (Interp interp, TclObject arg) {
        try {
            // Otherwise convert to a Java object, if possible
            return ReflectObject.get (interp, arg);
        } catch (Exception e) {
            // Otherwise just use as a TCL string.
            return arg.toString ();
        }
    }
}
