/*
 * LAPIS lightweight structured text processing system
 *
 * Copyright (C) 1998-2002 Carnegie Mellon University,
 * Copyright (C) 2003 Massachusetts Institute of Technology.
 * All rights reserved.
 *
 * This library is free software; you can redistribute it
 * and/or modify it under the terms of the GNU General
 * Public License as published by the Free Software
 * Foundation, version 2.
 *
 * LAPIS homepage: http://graphics.lcs.mit.edu/lapis/
 */

package lapis.tcl;

import lapis.*;
import tcl.lang.*;
import lapisx.util.Debug;

public class TclCommand implements Command {
    public static Debug debug = Debug.QUIET;

    String className;
    Class cls;
    Tool tool;

    public TclCommand (String className) {
        this.className = className;
    }

    public TclCommand (Class cls) {
        this.cls = cls;
    }

    public TclCommand (Tool tool) {
        this.tool = tool;
    }

    public void cmdProc (Interp interp, TclObject argv[]) throws TclException {
        try {
            TclArguments args = makeArguments (interp, argv);
            Tool tool = makeTool (interp, args);
            Document doc = tool.invoke (args);

            if (doc == null)
                interp.setResult ("");
            else {
                args.getInterpreter ().setVar (Interpreter.DOCUMENT_VAR, doc);
                interp.setResult (ReflectObject.newInstance (interp, 
                                                             doc.getClass (),
                                                             doc));
            }
        } catch (TclException e) {
            throw e;
        } catch (Exception e) {
            debug.report (e);
            throw new WrappedTclException (interp, e);
        }
    }

    protected TclArguments makeArguments (Interp interp, TclObject[] argv) 
        throws Exception {
        return new TclArguments (interp, argv);
    }

    protected Tool makeTool (Interp interp, TclArguments args) throws Exception {
	if (tool != null)
	    return tool;
	else {
	    if (cls == null)
		cls = Class.forName (className);
	    return (Tool)cls.newInstance ();
	}
    }

    void usage () {
        throw new RuntimeException ("Usage: <tool class> <args>\n");
    }
}
