/*
 * LAPIS lightweight structured text processing system
 *
 * Copyright (C) 1998-2002 Carnegie Mellon University,
 * Copyright (C) 2003 Massachusetts Institute of Technology.
 * All rights reserved.
 *
 * This library is free software; you can redistribute it
 * and/or modify it under the terms of the GNU General
 * Public License as published by the Free Software
 * Foundation, version 2.
 *
 * LAPIS homepage: http://graphics.lcs.mit.edu/lapis/
 */
package lapis.tcl;

import lapis.*;
import tcl.lang.*;
import lapisx.net.URLUtil;

public class TclShell implements Tool {
    /**
     * Invoke the tool.
     */
    public Document invoke (Arguments args) throws Exception {
	Main.windowCreated (this);

        TclInterpreter interpreter = (TclInterpreter) args.getInterpreter ();

        lapisx.util.History history = (lapisx.util.History)
            interpreter.getVar (Interpreter.HISTORY_VAR);

        String href = null;
        String script = null;
        boolean isExpr = true;

        args.setUsage (
        "Usage: TclShell [options]\n"
        + "\n"
        + "Options:\n"
        + "    -help     Display this message\n"
        );
        while (args.hasMoreElements ()) {
            String name = args.nextName ();
            if ("e".equals (name)) {
                script = args.nextString ();
                isExpr = true;
            } else if ("f".equals (name)) {
                script = args.nextString ();
                isExpr = false;
            } else if ("href".equals (name)) {
                href = args.nextString ();
            } else 
                args.consume (name);
        }


        if (href != null) {
            Document doc = "-".equals (href)
                ? args.getFactory ().make (System.in)
                : args.getFactory ().make (URLUtil.HrefToURL (href));
            doc.putProperty (doc.CommandProperty, href);
            interpreter.setVar (Interpreter.DOCUMENT_VAR, doc);
            history.put (doc);
        } else if (args.getInput () == null) {
            Document doc = args.getFactory ().make ("", "text/plain");
            interpreter.setVar (Interpreter.DOCUMENT_VAR, doc);
        }

        if (script != null) {
            if (isExpr)
                interpreter.eval (script);
            else
                interpreter.evalFile (script);
            Document doc = (Document) interpreter.getVar (Interpreter.DOCUMENT_VAR);
            doc.putProperty (doc.CommandProperty, script);
            if (!history.contains (doc))
                history.put (doc);
        }

        new Shell (interpreter.interp, null, null, null);
        return null;
    }
}
