/*
 * LAPIS lightweight structured text processing system
 *
 * Copyright (C) 1998-2002 Carnegie Mellon University,
 * Copyright (C) 2003 Massachusetts Institute of Technology.
 * All rights reserved.
 *
 * This library is free software; you can redistribute it
 * and/or modify it under the terms of the GNU General
 * Public License as published by the Free Software
 * Foundation, version 2.
 *
 * LAPIS homepage: http://graphics.lcs.mit.edu/lapis/
 */

package lapis.tcl;

import lapis.*;
//import tcl.lang.*;
import java.io.*;
//import java.util.Enumeration;

public class TclTool implements Tool {
    File filename; 
    String script; // script commands (or null if script should be loaded from filename)

    public TclTool (File filename) {
        this.filename = filename;
    }

    public TclTool (String script) {
        this.script = script;
    }

    public File getFilename () {
        return filename;
    }

    /**
     * Invoke the tool.
     */
    public Document invoke (Arguments args) throws Exception {
        while (args.hasMoreElements ())
            args.consume (args.nextName ());

        Interpreter interp = args.getInterpreter ();

        Document doc = args.getInput ();

        Document savedDoc = (Document) interp.getVar (Interpreter.DOCUMENT_VAR);
        interp.setVar (Interpreter.DOCUMENT_VAR, doc);

        Object obj = null;
        try {
            if (script != null)
                obj = interp.eval (script);
            else if (filename != null)
                obj = interp.evalFile (filename.toString ());
        } finally {
            interp.setVar (Interpreter.DOCUMENT_VAR, savedDoc);
        }

        return (obj instanceof Document) ? (Document) obj : null;
    }
}
