/*
 * LAPIS lightweight structured text processing system
 *
 * Copyright (C) 1998-2002 Carnegie Mellon University,
 * Copyright (C) 2003 Massachusetts Institute of Technology.
 * All rights reserved.
 *
 * This library is free software; you can redistribute it
 * and/or modify it under the terms of the GNU General
 * Public License as published by the Free Software
 * Foundation, version 2.
 *
 * LAPIS homepage: http://graphics.lcs.mit.edu/lapis/
 */

package lapis.tcl;

import java.io.*;
import tcl.lang.*;

public class WrappedTclException extends TclException {

    Throwable t;

    public WrappedTclException (Interp interp, Throwable t) {
        this (interp, t, getMessageOrName (t));
    }

    public WrappedTclException (Interp interp, Throwable t, String msg) {
        super (interp, msg);
        this.t = getRootException (t);
    }

    public String toString () {
        String msg = getMessage ();
        if (msg == null)
            return t.toString ();
        else 
            return t.getClass ().getName () + ": " + msg;
    }

    public void printStackTrace () {
        t.printStackTrace ();
    }

    public void printStackTrace (PrintStream s) {
        t.printStackTrace (s);
    }

    public void printStackTrace (PrintWriter w) {
        t.printStackTrace (w);
    }

    static Throwable getRootException (Throwable t) {
        while (t instanceof WrappedTclException)
            t = ((WrappedTclException) t).t;
        return t;
    }

    static String getMessageOrName (Throwable t) {
        t = getRootException (t);
        String msg = t.getMessage ();
        if (msg == null || msg.length () == 0)
            msg = t.toString ();
        return msg;
    }
}
