/*
 * LAPIS lightweight structured text processing system
 *
 * Copyright (C) 1998-2002 Carnegie Mellon University,
 * Copyright (C) 2003 Massachusetts Institute of Technology.
 * All rights reserved.
 *
 * This library is free software; you can redistribute it
 * and/or modify it under the terms of the GNU General
 * Public License as published by the Free Software
 * Foundation, version 2.
 *
 * LAPIS homepage: http://graphics.lcs.mit.edu/lapis/
 */

package lapis.tools;

import lapis.*;
import java.io.*;
import java.util.*;
import lapisx.net.URLUtil;

public class Concat implements Tool {
    /**
     * Invoke the tool.
     */
    public Document invoke (Arguments args) throws Exception {
        args.setUsage (
        "Usage:\n"
        +"   lcat <doc> ...     concatenates documents together\n"
        +"\n"
        +"Options:\n"
        + "    -help           Display this message\n"
        );
        Vector docs = new Vector (); 
        while (args.hasMoreElements ()) {
            String name = args.nextName ();
            if ("href".equals (name))
                docs.addElement (args.getFactory ().make (URLUtil.HrefToURL (args.nextString ())));
            else if ("string".equals (name))
                docs.addElement (args.getFactory ().make (args.nextString ()));
            else if ("doc".equals (name) || name == null)
                try {
                    docs.addElement ((Document)args.nextValue ());
                } catch (ClassCastException e) {
                    args.usage ();
                }
            else if ("stream".equals (name)) {
                Object obj = args.nextValue ();
                if (!(obj instanceof Reader || obj instanceof InputStream))
                    args.usage ();
                docs.addElement (args.getFactory ().make (obj));
            } else
                args.consume (name);
        }


        DocumentWriter output = args.getOutput ();

        for (Enumeration e = docs.elements (); e.hasMoreElements (); ) {
            Document doc = (Document) e.nextElement ();

            BasicDocument.copyVitalProperties (output, doc);
            
            output.print (doc.getText ());
        }

        return output;
    }
}
