/*
 * LAPIS lightweight structured text processing system
 *
 * Copyright (C) 1998-2002 Carnegie Mellon University,
 * Copyright (C) 2003 Massachusetts Institute of Technology.
 * All rights reserved.
 *
 * This library is free software; you can redistribute it
 * and/or modify it under the terms of the GNU General
 * Public License as published by the Free Software
 * Foundation, version 2.
 *
 * LAPIS homepage: http://graphics.lcs.mit.edu/lapis/
 */

package lapis.tools;

import lapis.*;
import lapis.tc.TC;
import java.util.Vector;

public class Count implements Tool {
    /**
     * Invoke tool.
     */
    public Document invoke (Arguments args) throws Exception {
        TC tcRecords = null;
        Vector functions = new Vector ();
        boolean showCaptions = false;
        
        args.setUsage (
        "Usage:\n"
        +"   count <pattern>    returns number of matches to <pattern>\n"
        +"\n"
        +"Options:\n"
        +"    -help        display this message\n"
        );

        while (args.hasMoreElements ()) {
            String name = args.nextName ();
            if ("query".equals (name)
                || (name == null && tcRecords == null))
                tcRecords = args.nextPattern ();
            else
                args.consume (name);
        }

        if (tcRecords == null)
            // error if no pattern
            args.nextValue ();

        Document doc = args.getInput ();
        DocumentWriter output = args.getOutput ();
        RegionSet records = tcRecords.matchWithWarnings (doc);
        output.print (records.getSize ());
        return output;
    }
}
