/*
 * LAPIS lightweight structured text processing system
 *
 * Copyright (C) 1998-2002 Carnegie Mellon University,
 * Copyright (C) 2003 Massachusetts Institute of Technology.
 * All rights reserved.
 *
 * This library is free software; you can redistribute it
 * and/or modify it under the terms of the GNU General
 * Public License as published by the Free Software
 * Foundation, version 2.
 *
 * LAPIS homepage: http://graphics.lcs.mit.edu/lapis/
 */

package lapis.tools;

import lapis.*;
//import java.io.*;
//import java.net.*;
//import java.util.Enumeration;

public class Doc implements Tool {
    
    public Document invoke (Arguments args) throws Exception {
        String contentType = null;

        args.setUsage (
        "Usage:\n"
        +"    doc               returns current document\n"
        +"    doc <document>    sets current document to <document>\n"
        +"\n"
        +"Options:\n"
        +"    -type <mime-type> Set content type of document to <mime-type>\n"
        +"    -help             Display this message\n"
        );
        while (args.hasMoreElements ()) {
            String name = args.nextName ();
            if ("type".equals (name))
                contentType = args.nextString ();
            else 
                args.consume (name);
        }

        Document doc = args.getInput ();

        if (contentType != null) {
            if ("text".equalsIgnoreCase (contentType))
                contentType = "text/plain";
            else if ("html".equalsIgnoreCase (contentType))
                contentType = "text/html";
            doc = args.getFactory ().make (doc, contentType);
        }

        return doc;
    }
}
