/*
 * LAPIS lightweight structured text processing system
 *
 * Copyright (C) 1998-2002 Carnegie Mellon University,
 * Copyright (C) 2003 Massachusetts Institute of Technology.
 * All rights reserved.
 *
 * This library is free software; you can redistribute it
 * and/or modify it under the terms of the GNU General
 * Public License as published by the Free Software
 * Foundation, version 2.
 *
 * LAPIS homepage: http://graphics.lcs.mit.edu/lapis/
 */

package lapis.tools;

import lapis.*;
import lapis.tc.*;
//import java.io.*;
//import java.net.*;
//import java.util.Enumeration;
//import lapisx.net.URLUtil;
import lapisx.util.Str;

public class Enter implements Tool {
    
    public Document invoke (Arguments args) throws Exception {
        TC control = null;
        String value = null;

        args.setUsage (
        "Usage:\n"
        +"   enter <pattern> <value>\n"
        +"        Fills in form control matched by <pattern> with <value>.\n"
        +"\n"
        +"Options:\n"
        +"    -help                  Display this message\n"
        );
        while (args.hasMoreElements ()) {
            String name = args.nextName ();
            if ("control".equals (name)
                || (name == null && control == null))
                control = args.nextPattern ();
            if ("value".equals (name)
                || (name == null && value == null))
                value = args.nextString ();
            else 
                args.consume (name);
        }

        if (control == null || value == null)
            args.nextValue ();

        Document doc = args.getInput ();

        RegionSet values = 
            new TC (new TC.And (TC.make (".HTML.Attribute.Value in .HTML.Attribute.@value")
                                .getRoot (),
                                new TC.In (control.getRoot ())))
            .matchWithWarnings (doc);

        if (!values.isEmpty ())
            return new Replace ()
                .invoke (new Arguments (args.getInterpreter ())
                         .add ("query", new TC (new TC.Constant (doc, values))) 
                         .add ("replace", quote (value))
                         .add (null, doc));

        RegionSet valueLocations =
            new TC (new TC.And (new TC.Id (".HTML.Tag.StartTag"),
                                new TC.Starting (control.getRoot ())))
             .matchWithWarnings (doc);

        if (!valueLocations.isEmpty ())
            return new Replace ()
                .invoke (new Arguments (args.getInterpreter ())
                         .add ("query", new TC (new TC.Constant (doc, valueLocations)))
                         .add ("replace", "{.HTML.Tag.StartTag trim view source '>'} value=" + quote (value) + ">")
                         .add (null, doc));

        // Otherwise just return the input document unchanged
        return doc;
    }

    private String quote (String s) {
        s = Str.escape (s, '\\', "{}\\");
        if (s.indexOf ('"') == -1)
            s = '"' + s + '"';
        else if (s.indexOf ('\'') == -1)
            s = '\'' + s + '\'';
        else {
            s = Str.replace (s, "\"", "%22");
            s = '"' + s + '"';
        }
        return s;
    }
}
