/*
 * LAPIS lightweight structured text processing system
 *
 * Copyright (C) 1998-2002 Carnegie Mellon University,
 * Copyright (C) 2003 Massachusetts Institute of Technology.
 * All rights reserved.
 *
 * This library is free software; you can redistribute it
 * and/or modify it under the terms of the GNU General
 * Public License as published by the Free Software
 * Foundation, version 2.
 *
 * LAPIS homepage: http://graphics.lcs.mit.edu/lapis/
 */

package lapis.tools;

import lapis.*;
import lapis.tc.TC;
//import java.io.*;
//import java.util.Enumeration;

public class Insert extends Replace {
    /**
     * Invoke the tool.
     */
    public Document invoke (Arguments args) throws Exception {
        TC tcRecords = null;
        Object replacement = null;

        args.setUsage (
        "Usage:\n"
        +"   insert <pattern> <string>    inserts <string> at all points matched\n"
        +"                                by <pattern>\n"
        +"\n"
        +"Options:\n"
        + "    -help           Display this message\n"
        );
        while (args.hasMoreElements ()) {
            String name = args.nextName ();
            if ("query".equals (name)
                || (name == null && tcRecords == null))
                tcRecords = args.nextPattern ();
            else if ("replace".equals (name)
                     || (name == null && replacement == null))
                replacement = args.nextValue ();
            else
                args.consume (name);
        }

        // Error if no pattern or replacement
        if (tcRecords == null || replacement == null)
            args.usage ();

        args.add ("query", tcRecords.getPointPattern ());
        args.add ("replace", replacement);
        
        return super.invoke (args);
    }
}
