/*
 * LAPIS lightweight structured text processing system
 *
 * Copyright (C) 1998-2002 Carnegie Mellon University,
 * Copyright (C) 2003 Massachusetts Institute of Technology.
 * All rights reserved.
 *
 * This library is free software; you can redistribute it
 * and/or modify it under the terms of the GNU General
 * Public License as published by the Free Software
 * Foundation, version 2.
 *
 * LAPIS homepage: http://graphics.lcs.mit.edu/lapis/
 */

package lapis.tools;

import lapis.*;
import lapis.tc.TC;
//import java.io.*;
//import java.util.Enumeration;

public class Keep extends Delete {
    /**
     * Invoke the tool.
     */
    public Document invoke (Arguments args) throws Exception {
        TC tcKeep = null;
        TC tcRecords = null;

        args.setUsage (
        "Usage:\n"
        +"   keep <pattern>          keeps only records matching <pattern>\n"
        +"\n"
        +"Options:\n"
        +"    -outof <record-pattern>   records to consider; regions matching\n"
        +"                              <record-pattern> but not <keep-pattern>\n"
        +"                              are deleted.\n"
        + "    -help           Display this message\n"
        );
        while (args.hasMoreElements ()) {
            String name = args.nextName ();
            if ("query".equals (name)
                || (name == null && tcKeep == null))
                tcKeep = args.nextPattern ();
            else if ("outof".equals (name))
                tcRecords = args.nextPattern ();
            else
                args.consume (name);
        }

        // Error if no pattern
        if (tcKeep == null)
            args.usage ();

        // Compute what we really want to delete
        if (tcRecords == null)
            tcRecords = tcKeep.getUniversePattern ();

        args.add ("query", new TC (new TC.ButNot (tcRecords.getRoot (), 
                                                  tcKeep.getRoot ())));
        
        return super.invoke (args);
    }
}
