/*
 * LAPIS lightweight structured text processing system
 *
 * Copyright (C) 1998-2002 Carnegie Mellon University,
 * Copyright (C) 2003 Massachusetts Institute of Technology.
 * All rights reserved.
 *
 * This library is free software; you can redistribute it
 * and/or modify it under the terms of the GNU General
 * Public License as published by the Free Software
 * Foundation, version 2.
 *
 * LAPIS homepage: http://graphics.lcs.mit.edu/lapis/
 */

package lapis.tools;

import lapis.*;
import lapis.tc.TC;

public class Label implements Tool {
    /**
     * Invoke the tool.
     */
    public Document invoke (Arguments args) throws Exception {
        String label = null;
        TC pattern = null;

        args.setUsage (
        "Usage:\n"
        +"    label <name> <pattern>      defines named selection <name> as <pattern>\n"
        +"\n"
        +"Options:\n"
        + "    -help           Display this message\n"
        );
        while (args.hasMoreElements ()) {
            String name = args.nextName ();
            if ("name".equals (name) || 
                (name == null && label == null))
                label = args.nextString ();
            else if ("pattern".equals (name)
                     || (name == null && pattern == null))
                pattern = args.nextPattern ();
            else
                args.consume (name);
        }

        if (label == null || pattern == null)
            args.usage ();

        // Fetch existing prefix and prepend it to name
        // (unless requested prefix is absolute)
        String prefix = 
            (String) args.getInterpreter ().getVar (Interpreter.PREFIX_VAR);
        if (prefix != null
            && prefix.length () > 0
            && !label.startsWith ("."))
            label = prefix + "." + label;

        // Bind the label to the pattern
        PatternLibrary lib = PatternLibrary.getGlobalLibrary ();
        lib.put (label, pattern);

        return null;
    }
}
