/*
 * LAPIS lightweight structured text processing system
 *
 * Copyright (C) 1998-2002 Carnegie Mellon University,
 * Copyright (C) 2003 Massachusetts Institute of Technology.
 * All rights reserved.
 *
 * This library is free software; you can redistribute it
 * and/or modify it under the terms of the GNU General
 * Public License as published by the Free Software
 * Foundation, version 2.
 *
 * LAPIS homepage: http://graphics.lcs.mit.edu/lapis/
 */

package lapis.tools;

import lapis.*;
import lapis.tc.*;
import java.io.*;

public class LoadRegionSet implements Tool {
    public LoadRegionSet () {
    }

    public Document invoke (Arguments args) throws Exception {
        File file = null;
        
        args.setUsage (
                       "Usage:\n"
                       + "   load-region-set <filename>      load region set from file and assign it to a pattern derived from its filename\n"
                       + "\n"
                       + "Options:\n"
                       + "   -help        Display this message\n"
                       );
        while (args.hasMoreElements ()) {
            String name = args.nextName ();
            if ("filename".equals (name)
                || (name == null && file == null))
                file = new File (args.nextString ());
            else
                args.consume (name);
        }
        
        if (file == null)
            args.usage ();

        ObjectInputStream in = new ObjectInputStream (new FileInputStream (file));
        RegionSet r = (RegionSet) in.readObject ();
        in.close ();

        String patternName = file.getName ();
        
        // LoadRegionSet has no client calls
        //NamedRegionSet sel = new NamedRegionSet (args.getInput (), r, patternName);
		NamedRegionSet sel = new NamedRegionSet (r, patternName);
        TC tc = new TC (sel);

        PatternLibrary.getGlobalLibrary ().put (patternName, tc);
        return null;
    }
}
