/*
 * LAPIS lightweight structured text processing system
 *
 * Copyright (C) 1998-2002 Carnegie Mellon University,
 * Copyright (C) 2003 Massachusetts Institute of Technology.
 * All rights reserved.
 *
 * This library is free software; you can redistribute it
 * and/or modify it under the terms of the GNU General
 * Public License as published by the Free Software
 * Foundation, version 2.
 *
 * LAPIS homepage: http://graphics.lcs.mit.edu/lapis/
 */

package lapis.tools;

import lapis.*;
import java.io.*;
//import java.net.*;
//import java.util.*;
import lapis.tc.*;
//import lapisx.net.URLUtil;

public class Parse implements Tool {
    /**
     * Invoke the tool.
     */
    public Document invoke (Arguments args) throws Exception {
        String parser = null;

        args.setUsage (
        "Usage:\n"
        +"    parse <parser>     binds <parser> into pattern library, where\n"
        +"                       <parser> is a Tcl script, TC file, or Java class\n"
        +"\n"
        +"Options:\n"
        + "    -help           Display this message\n"
        );
        while (args.hasMoreElements ()) {
            String name = args.nextName ();
            if ("parser".equals (name) ||
                (name == null && parser == null))
                parser = args.nextString ();
            else
                args.consume (name);
        }

        if (parser == null)
            args.usage ();

        PatternLibrary lib = PatternLibrary.getGlobalLibrary ();
        Interpreter interp = args.getInterpreter ();

        // first try a Tcl file
        if (parser.endsWith (".tcl")) {
            // just evaluate the Tcl script
            interp.evalFile (parser);
            return null;
        }

        // then try a text constraints file (or resource)
        if (parser.endsWith (".tc")) {
            try {
                // check for resource (.TC file included 
                // in the lapis.jar package)
                lib.addParser (new TC (Parse.class, parser));
                return null;
            } catch (TCParseException e) {
                // Found resource matching parser, so don't keep searching
                throw e;
            } catch (Exception e) {
                // Otherwise try loading parser as a file
                try {
                    File curdir = 
                        (File) interp.getVar (Interpreter.CURRENT_DIRECTORY_VAR);
                    File f = new File (parser);
                    if (!f.isAbsolute () && curdir != null)
                        f = new File (curdir, parser);
                    lib.addParser (new TC (f));
                    return null;
                } catch (TCParseException e2) {
                    e2.setHrefContext (parser);
                    throw e2;
                }
            }
         }

        // if parser contains some whitespace, then it can't be a Java class name.
        // Try interpreting it as an inline text constraints system
        if (parser.indexOf (' ') != -1
            || parser.indexOf('\t') != -1
            || parser.indexOf('\r') != -1
            || parser.indexOf('\n') != -1) {
            lib.addParser (new TC (parser));
            return null;
        }

        // If all else fails, try loading as a Java class.
        lib.addParser (((Parser)Class.forName (parser).newInstance ()));
        return null;
    }
}
