/*
 * LAPIS lightweight structured text processing system
 *
 * Copyright (C) 1998-2002 Carnegie Mellon University,
 * Copyright (C) 2003 Massachusetts Institute of Technology.
 * All rights reserved.
 *
 * This library is free software; you can redistribute it
 * and/or modify it under the terms of the GNU General
 * Public License as published by the Free Software
 * Foundation, version 2.
 *
 * LAPIS homepage: http://graphics.lcs.mit.edu/lapis/
 */

package lapis.tools;

import lapis.*;
//import java.io.*;
//import java.util.Enumeration;

public class Prefix implements Tool {
    /**
     * Invoke the tool.
     */
    public Document invoke (Arguments args) throws Exception {
        String prefix = null;
        String body = null;

        args.setUsage (
        "Usage:\n"
        +"    prefix <name> <body>     sets <prefix> for label commands executed in\n"
        +"                             <body>\n"
        +"\n"
        +"Options:\n"
        + "    -help           Display this message\n"
        );
        while (args.hasMoreElements ()) {
            String name = args.nextName ();
            if ("name".equals (name) || 
                (name == null && prefix == null))
                prefix = args.nextString ();
            else if ("body".equals (name)
                     || (name == null && body == null))
                body = args.nextString ();
            else
                args.consume (name);
        }

        if (prefix == null || body == null)
            args.usage ();

        // Get the interpreter
        Interpreter interp = args.getInterpreter ();

        // Fetch existing prefix and prepend it to requested prefix 
        // (unless requested prefix is absolute)
        String oldPrefix = (String) interp.getVar (Interpreter.PREFIX_VAR);
        if (oldPrefix != null
            && oldPrefix.length () > 0
            && !prefix.startsWith ("."))
            prefix = oldPrefix + "." + prefix;

        // Set new prefix
        interp.setVar (Interpreter.PREFIX_VAR, prefix);

        Document doc = args.getInput ();
        try {
            // Evaluate body
            interp.eval (body);
            return null;
        } finally {
            // Restore old prefix
            interp.setVar (Interpreter.PREFIX_VAR, oldPrefix);
        }
    }
}
