/*
 * LAPIS lightweight structured text processing system
 *
 * Copyright (C) 1998-2002 Carnegie Mellon University,
 * Copyright (C) 2003 Massachusetts Institute of Technology.
 * All rights reserved.
 *
 * This library is free software; you can redistribute it
 * and/or modify it under the terms of the GNU General
 * Public License as published by the Free Software
 * Foundation, version 2.
 *
 * LAPIS homepage: http://graphics.lcs.mit.edu/lapis/
 */

package lapis.tools;

import lapis.*;
import lapis.tc.*;
import java.io.*;

public class SaveRegionSet implements Tool {

    public SaveRegionSet () {
    }

    public Document invoke (Arguments args) throws Exception {
        TC pat = null;
        File file = null;
        
        args.setUsage (
                       "Usage:\n"
                       + "   save-region-set <pattern> <filename>      save region set matching pattern to filename\n"
                       + "\n"
                       + "Options:\n"
                       + "   -help        Display this message\n"
                       );
        while (args.hasMoreElements ()) {
            String name = args.nextName ();
            if ("query".equals (name)
                || (name == null && pat == null))
                pat = args.nextPattern ();
            else if ("filename".equals (name)
                || (name == null && file == null))
                file = new File (args.nextString ());
            else
                args.consume (name);
        }
        
        if (file == null || pat == null)
            args.usage ();

        Document doc = args.getInput ();
        RegionSet r = pat.match (doc);

        save (file, r);

        return null;
    }

    protected void save (File file, RegionSet r) throws IOException {
        ObjectOutputStream out = new ObjectOutputStream (new FileOutputStream (file));
        out.writeObject (r);
        out.close ();
    }
}
