/*
 * LAPIS lightweight structured text processing system
 *
 * Copyright (C) 1998-2002 Carnegie Mellon University,
 * Copyright (C) 2003 Massachusetts Institute of Technology.
 * All rights reserved.
 *
 * This library is free software; you can redistribute it
 * and/or modify it under the terms of the GNU General
 * Public License as published by the Free Software
 * Foundation, version 2.
 *
 * LAPIS homepage: http://graphics.lcs.mit.edu/lapis/
 */

package lapis.tools;

import lapis.*;
//import java.io.*;
//import java.util.Enumeration;

public class Show implements Tool {
    public static lapisx.util.Debug debug = lapisx.util.Debug.QUIET;

    public Document invoke (Arguments args) throws Exception {
	Interpreter interp = args.getInterpreter ();
        boolean showAll = !isInteractive (interp);

        args.setUsage (
        "Usage:\n"
        +"    show      displays content of current document\n"
        +"\n"
        +"Options:\n"
        +"    -all            Display entire document\n"
        +"    -brief          Display at most lapis::displayLimit lines\n"
        +"    -help           Display this message\n"
        +"\n"
	+" Default is -brief in interactive mode, -all in batch mode.\n"
        );
        while (args.hasMoreElements ()) {
            String name = args.nextName ();
            if ("all".equals (name))
                showAll = true;
            else if ("brief".equals (name))
                showAll = false;
            else
                args.consume (name);
        }


        int limit = showAll ? 0 : getDisplayLimit (args.getInterpreter ());
	debug.println ("limit = " + limit);

        Document doc = args.getInput ();

        // print content
        String s = doc.getText ();
        if (limit > 0)
            s = lapisx.util.Str.abbreviateLines (s, 
                                              limit,
                                              "... (%d lines omitted; use \"show -all\" to view)\n");
        System.out.print (s);
        if (s.length () > 0 && !s.endsWith ("\n"))
            System.out.println ();
        
        // if document has a standard error, we'll print
        // that too
        Document err = 
            (Document) doc.getProperty (Document.StderrProperty);
        if (!showAll
            && err != null 
            && err != doc 
            && err.toRegion ().getLength () > 0) {
            
            if (doc.toRegion ().getLength () > 0)
                System.out.println ("(command also generated errors; use \"property stderr\" to view)");
            else {
                s = err.getText ();
                if (limit > 0)
                    s = lapisx.util.Str.abbreviateLines (s, 
                                                      limit,
                                                      "... (%d lines omitted; use \"property stderr ; show -all\" to view)\n");
                
                System.out.print (s);
                if (s.length () > 0 && !s.endsWith ("\n"))
                    System.out.println ();
                System.out.println ("(command had no output, only errors; use \"property stderr\" to process)");
            }
        }

        return null;
    }

    boolean isInteractive (Interpreter interp) {
        String flag = (String) interp.getVar (Interpreter.INTERACTIVE_VAR);
        return (flag != null) ? (Integer.parseInt (flag) > 0) : false;
    }

    int getDisplayLimit (Interpreter interp) {
        String limit = (String) interp.getVar (Interpreter.DISPLAY_LIMIT_VAR);
        return (limit != null) ? Integer.parseInt (limit) : 0;
    }
}
