/*
 * LAPIS lightweight structured text processing system
 *
 * Copyright (C) 1998-2002 Carnegie Mellon University,
 * Copyright (C) 2003 Massachusetts Institute of Technology.
 * All rights reserved.
 *
 * This library is free software; you can redistribute it
 * and/or modify it under the terms of the GNU General
 * Public License as published by the Free Software
 * Foundation, version 2.
 *
 * LAPIS homepage: http://graphics.lcs.mit.edu/lapis/
 */

package lapis.tools;

import lapis.*;
import lapis.tc.*;
import java.util.*;
import java.net.*;
import lapisx.net.*;

public class Submit implements Tool {
    public static lapisx.util.Debug debug = lapisx.util.Debug.QUIET; 

    /**
     * Invoke tool.
     */
    public Document invoke (Arguments args) throws Exception {
        TC tcForm = null;
        TC tcButton = null;
	Vector fields = new Vector ();
 
        args.setUsage (
          "Usage:\n"
        + "   submit         submits HTML form\n"
        + "\n"
        + "Options:\n"
	+ "    -form <pattern>    Identifies form (defaults to first form)\n"
        + "    -button <pattern>  Identifies submit button to push (defaults to first Submit button)\n"
// 	+ "    -field <field-pattern> <value-template>\n"
// 	+ "                    Fill in field matching <field-pattern> with\n"
// 	+ "                    <value-template> data from input document\n"
	+ "\n"
        + "    -help              Display this message\n"
          );
        while (args.hasMoreElements ()) {
            String name = args.nextName ();
            if ("form".equals (name))
                tcForm = args.nextPattern ();
            else if ("button".equals (name))
                tcButton = args.nextPattern ();
//             else if ("field".equals (name)) {
//                 TC field = args.nextPattern ();
// 		Template value = null;

//                 Object obj = args.nextValue ();
//                 if (obj instanceof Template)
//                     value = (Template)obj;
//                 else if (obj instanceof String) {
//                     String strTemplate = (String)obj;
//                     try {
//                         value = Template.makeFromString (strTemplate);
//                     } catch (TCParseException e) {
//                         e.setStringContext (strTemplate);
//                         throw e;
//                     }
//                 }
//                 else
//                     args.usage ();

// 		fields.addElement (new Field (field, value));
// 	    }		
            else
                args.consume (name);
        }

	// Get input document
        Document doc = args.getInput ();

	// Find form and button in page
	if (tcForm == null)
	    tcForm = TC.make ("[form]");
	Region rForm = tcForm.matchWithWarnings (doc).regions ().first ();
	if (rForm == null)
	    throw new Arguments.UsageException ("Can't find form in page");


        Region rButton = 
            (tcButton != null) 
            ? tcButton.matchWithWarnings (doc).regions ().first ()
            : null;

        // Create a FormURL from the form
        FormURL formURL = submit (doc, rForm, rButton);
        
        return args.getFactory ().make (formURL);
    }

    public static FormURL submit (Document doc, Region rForm, Region rSubmitButton) throws Exception {
        // Find form in document
        if (rForm == null) {
            TC tcForm =
                (rSubmitButton != null)
                ? new TC (new TC.And (new TC.Id (".HTML.Element.[form]"),
                                      new TC.Contains (new TC.Constant (doc, rSubmitButton))))
                : TC.make ("[form]");
            rForm = tcForm.matchWithWarnings (doc).regions ().first ();
        }
	if (rForm == null)
            throw new Arguments.UsageException ("Can't find form in page");

        // Extract form action
        String hrefAction = getAttribute (doc, rForm, "action");
        if (hrefAction == null)
	    throw new Arguments.UsageException ("Form has no ACTION attribute; don't know where to submit form");
        URL urlAction = new URL (Click.getBase (doc), hrefAction);
        debug.println ("action: " + urlAction);

        // Extract form method
        String method = getAttribute (doc, rForm, "method");
        if (method == null)
            method = "get";
        debug.println ("method: " + method);
	
	// Extract fields and values
        Vector formValues = new Vector ();
        
        RegionEnumeration fields = 
            new TC (new TC.And (new TC.Id (".Layout.Form.Control"),
                                new TC.In (new TC.Constant (doc, rForm))))
            .matchWithWarnings (doc)
            .regions ();
        for (Region f = fields.firstFast (); f != null; f = fields.nextFast ()) {
            String tag = getTag (doc, f);

            if ("input".equalsIgnoreCase (tag)) {
                String name = getAttribute (doc, f, "name");

                if (name != null) {
                    String value = getAttribute (doc, f, "value");
                    String type = getAttribute (doc, f, "type");
                    
                    debug.println ("input: type=" + type 
                                        + ", name=" + name 
                                        + ", value=" + value);
                    if (type == null
                        || "text".equalsIgnoreCase (type)
                        || "password".equalsIgnoreCase (type)
                        || "hidden".equalsIgnoreCase (type)) {
                        if (value == null)
                            value = "";
                        formValues.addElement (name);
                        formValues.addElement (value);
                    }
                    else if ("radio".equalsIgnoreCase (type)
                             || "checkbox".equalsIgnoreCase (type)) {
                        if (isAttributePresent (doc, f, "checked")) {
                            if (value == null)
                                value = "on";
                            formValues.addElement (name);
                            formValues.addElement (value);
                        }
                    }
                    else if (rSubmitButton != null 
                             && f.equals (rSubmitButton)) {
                        if ("image".equalsIgnoreCase (type)) {
                            formValues.addElement (name + ".x");
                            formValues.addElement ("0");
                            formValues.addElement (name + ".y");
                            formValues.addElement ("0");
                        } else if ("submit".equalsIgnoreCase (type)) {
//                             if (value == null)
//                                 value = "";
//                             formValues.addElement (name);
//                             formValues.addElement (value);
                        }
                    }
                }
            } else if ("select".equalsIgnoreCase (tag)) {
                String name = getAttribute (doc, f, "name");

                debug.println ("select: name=" + name);
                if (name != null) {
                    RegionEnumeration options = getElements (doc, f, "option");
                    for (Region option = options.firstFast ();
                         option != null;
                         option = options.nextFast ()) {
                        
                        String value = getAttribute (doc, option, "value");
                        if (value == null)
                            value = getText (doc, option);
                        if (value == null)
                            value = "";
                        
                        debug.println ("option: value=" + value);
                        
                        if (isAttributePresent (doc, option, "selected")) {
                            formValues.addElement (name);
                            formValues.addElement (value);
                        }
                    }
                }
            } else if ("textarea".equalsIgnoreCase (tag)) {
                String name = getAttribute (doc, f, "name");
                if (name != null) {
                    String value = getText (doc, f);
                    if (value == null)
                        value = "";
                    debug.println ("textarea: name=" + name 
                                   + ", value=" + value);
                    formValues.addElement (name);
                    formValues.addElement (value);
                }
            } else
                debug.println ("unknown form control: " + tag);
        }

//         // Set user-defined field values (from fields vector)
//         if (fields != null) {
//             RegionSet all = doc.getLabeling().get (doc.ALL);
//             formValues.clear ();
//             for (int i = 0, n = fields.size (); i < n; ++i) {
//                 Field f = (Field)fields.elementAt (i);
//                 TC tc = new TC.In (f.field, new TC.Constant (rForm));
//                 Region r = tc.match (doc).regions ().first ();
//                 String name = getAttribute (doc, r, "name");
//                 if (name != null) {
//                     f.value.bind (all, doc);
//                     replaceField formValues.put (name, f.value.match (all, doc));
//                 }
//             }
//         }
        
         debug.println ("\nForm submission: ");
         dumpForm (formValues);

        // Return URL representing query
        if ("file".equals (urlAction.getProtocol())) 
            return new LocalFormURL (method, urlAction, formValues);
        else
            return new FormURL (method, urlAction, formValues);

    }

    static void dumpForm (Vector formValues) {
	for (int i = 0,n = formValues.size (); i < n; i += 2) {
	    debug.println (formValues.elementAt(i) + "=" + formValues.elementAt (i+1));
	}
    }

    static boolean isAttributePresent (Document doc, Region element, 
                                              String attrName) {
        return 
            !(new TC (new TC.And (new TC.Id (".HTML.Attribute.@" + attrName),
                                  new TC.In (new TC.Constant (doc, element))))
              .match (doc)
              .isEmpty ());
    }

    static String getAttribute (Document doc, Region element, 
                                        String attrName) {
        TC tc = new TC 
            (new TC.And 
             (new TC.Id (".HTML.Attribute.Value"),
              new TC.In (new TC.And 
                         (new TC.Id (".HTML.Attribute.@" + attrName),
                          new TC.In (new TC.Constant (doc, element))))));
        Region r = tc.match (doc).regions ().firstFast ();
        return (r != null) 
            ? stripQuotes (doc.getText (r)) 
            : null;
    }

    static RegionEnumeration getElements (Document doc, Region scope,
                                                  String elementName) {
        return 
            new TC (new TC.And (new TC.Id (".HTML.Element.[" + elementName + "]"),
                                new TC.In (new TC.Constant (doc, scope))))
            .match (doc)
            .regions ();
    }

    static String getTag (Document doc, Region element) {
        TC tc = new TC (new TC.And (new TC.Id (".HTML.Tag.StartTag"),
                                    new TC.In (new TC.Constant (doc, element))));
        Region r = tc.match (doc).regions ().firstFast ();
        String tag = doc.getText (r);

        int start = (tag.charAt (0) == '<') ? 1 : 0;
        int end = tag.indexOf (' ');
        if (end == -1)
            end = tag.indexOf ('>');
        if (end == -1)
            end = tag.length ();
        return tag.substring (start, end);
    }

    static String getText (Document doc, Region element) {
        TC tc = new TC 
            (new TC.And 
             (new TC.Id (".HTML.Text"),
              new TC.In (new TC.Constant (doc, element))));
        Region r = tc.match (doc).regions ().firstFast ();
        return (r != null) ? doc.getText (r) : null;
    }

    static String stripQuotes (String s) {
        if ((s.startsWith ("'") && s.endsWith ("'"))
            || (s.startsWith ("\"") && s.endsWith ("\"")))
            s = s.substring (1, s.length() - 1);
        return s;
    }

    public static class Field {
	public TC field;
	public Template value;

	public Field (TC field, Template value) {
	    this.field = field;
	    this.value = value;
	}
    }
}
