/*
 * LAPIS lightweight structured text processing system
 *
 * Copyright (C) 1998-2002 Carnegie Mellon University,
 * Copyright (C) 2003 Massachusetts Institute of Technology.
 * All rights reserved.
 *
 * This library is free software; you can redistribute it
 * and/or modify it under the terms of the GNU General
 * Public License as published by the Free Software
 * Foundation, version 2.
 *
 * LAPIS homepage: http://graphics.lcs.mit.edu/lapis/
 */

package lapis.tools;

import lapis.*;
import java.util.*;
import java.net.*;
import lapisx.net.*;

public class WebQuery implements Tool {
    /**
     * Invoke tool.
     */
    public Document invoke (Arguments args) throws Exception {
        String method = "get";
	String hrefAction = null;
	Vector parameters = new Vector ();
 
        args.setUsage (
          "Usage:\n"
        + "    webquery <URL> <name> <value> ... \n"
	+ "         submits a web form query to <URL> with <name>/<value> parameters\n"
        + "\n"
        + "Options:\n"
	+ "    -get               Use GET method (default)\n"
	+ "    -post              Use POST method\n"
	+ "\n"
        + "    -help           Display this message\n"
          );
        while (args.hasMoreElements ()) {
            String name = args.nextName ();
            if ("action".equals (name)
		|| (name == null && hrefAction == null))
                hrefAction = args.nextString ();
            else if ("field".equals (name)
                     || name == null) {
                parameters.addElement (args.nextString ());
                parameters.addElement (args.nextString ());
	    }
            else if ("get".equals (name)
                     || "post".equals (name)) {
                method = name;
            }
            else
                args.consume (name);
        }

        // Error if no action URL
        if (hrefAction == null)
            args.usage ();

        URL urlAction = new URL (hrefAction);

        // Return URL representing query
        if ("file".equals (urlAction.getProtocol())) 
            return args.getFactory ().make (new LocalFormURL (method, urlAction, parameters));
        else
            return args.getFactory ().make (new FormURL (method, urlAction, parameters));
    }
}
