/*
 * LAPIS lightweight structured text processing system
 *
 * Copyright (C) 1998-2002 Carnegie Mellon University,
 * Copyright (C) 2003 Massachusetts Institute of Technology.
 * All rights reserved.
 *
 * This library is free software; you can redistribute it
 * and/or modify it under the terms of the GNU General
 * Public License as published by the Free Software
 * Foundation, version 2.
 *
 * LAPIS homepage: http://graphics.lcs.mit.edu/lapis/
 */

package lapis.trees;

import lapis.*;

/**
 * Region array that automatically flattens or melts the region set inserted in it.
 */

public class FlatteningRegionArray extends RegionArray {
    boolean melt;

    /**
     * Make a new, empty FlatteningRegionArray.
     */
	public FlatteningRegionArray (boolean melt, Document doc) {
		this (melt, doc.getVersion());		
	}
	
	public FlatteningRegionArray (boolean melt, DocumentVersion ver) {
		super (ver);
		this.melt = melt;		
	}
	
    /**
     * Make a new, empty FlatteningRegionArray.
     * @param size Expected number of regions
     * @param melt if true, combine adjacent regions as well
     */
	public FlatteningRegionArray (int size, boolean melt, Document doc) {
		this (size, melt, doc.getVersion());
	}
	
	public FlatteningRegionArray (int size, boolean melt, DocumentVersion ver) {
		super (size, ver);
		this.melt = melt;
	}

    //
    // inserting regions
    //

    public void insert (Region s) throws RepresentationChangeException {
        if (s.isEmpty ())
            return;

        insert (s.getStartLow (), s.getEndHigh (), s.getVersion());
    }

    public void insert (int start, int end, DocumentVersion ver) throws RepresentationChangeException {
        if (n > 0) {
            int lastStart = points[slOffset + n-1];
            int lastEnd = points[ehOffset + n-1];

            if (start < lastEnd
                || (melt && start == lastEnd)) {
                points[slOffset + n-1] = Math.min (start, lastStart);
                points[ehOffset + n-1] = Math.max (end, lastEnd);
                return;
            }
        }
        
        super.insert (start, end, ver);
    }

    public RegionSet crispen () {
        validate ();
        return this;
    }

    public RegionSet flatten () {
        validate ();
        return this;
    }

    public RegionSet melt () {
        validate ();
        if (melt)
            return this;
        else
            return super.melt ();
    }


}
