/*
 * LAPIS lightweight structured text processing system
 *
 * Copyright (C) 1998-2002 Carnegie Mellon University,
 * Copyright (C) 2003 Massachusetts Institute of Technology.
 * All rights reserved.
 *
 * This library is free software; you can redistribute it
 * and/or modify it under the terms of the GNU General
 * Public License as published by the Free Software
 * Foundation, version 2.
 *
 * LAPIS homepage: http://graphics.lcs.mit.edu/lapis/
 */


package lapisx.enum;
import java.util.Enumeration;
import java.util.NoSuchElementException;

/**
 * Enumeration which transforms the elements of another enumeration.
 */
public class ConcatEnumeration implements Enumeration {
    Enumeration[] e;
    int i = 0; // current enumeration in e

    public ConcatEnumeration (Enumeration e1, Enumeration e2) {
        this.e = new Enumeration[] { e1, e2 };
    }

    public ConcatEnumeration (Enumeration[] e) {
        this.e = e;
    }

    public boolean hasMoreElements () {
        while (i < e.length) {
            if (e[i].hasMoreElements ())
                return true;
            else
                ++i;
        }
        return false;
    }

    public Object nextElement () {
        while (i < e.length) {
            try {
                return e[i].nextElement ();
            } catch (NoSuchElementException e) {
                ++i;
            }
        }

        throw new NoSuchElementException ();
    }
}
