/*
 * LAPIS lightweight structured text processing system
 *
 * Copyright (C) 1998-2002 Carnegie Mellon University,
 * Copyright (C) 2003 Massachusetts Institute of Technology.
 * All rights reserved.
 *
 * This library is free software; you can redistribute it
 * and/or modify it under the terms of the GNU General
 * Public License as published by the Free Software
 * Foundation, version 2.
 *
 * LAPIS homepage: http://graphics.lcs.mit.edu/lapis/
 */


package lapisx.enum;
import java.util.Enumeration;
import java.util.NoSuchElementException;
import java.util.Vector;

/**
 * Enumeration which transforms the elements of another enumeration.
 */
public abstract class FilteredEnumeration implements Enumeration {
    Enumeration e;
    Object o; // first object waiting to be returned, or null if none
    Vector v; // other objects yielded and waiting to be returned
    int i;    // next object to return from v

    public FilteredEnumeration (Enumeration e) {
        this.e = e;
    }

    public boolean hasMoreElements () { 
        next ();
        return o != null;
    }

    public Object nextElement () { 
        next ();
        if (o == null)
            throw new NoSuchElementException ();
        Object result = o;
        o = null;
        return result;
    }

    void next () {
        // check if yielded element is waiting to be returned 
        if (o != null)
            return;

        // check in v for other yielded elements
        if (v != null) {
            if (i < v.size ()) {
                o = v.elementAt (i);
                v.setElementAt (null, i);
                ++i;
            } else {
                v.setSize (0);
                i = 0;
            }
        }

        // transform elements until an element is yielded
        while (o == null && e.hasMoreElements ())
            transform (e.nextElement ());
    }

    public void yield (Object obj) {
        if (o == null)
            o = obj;
        else {
            if (v == null)
                v = new Vector ();
            v.addElement (obj);
        }
    }

    public abstract void transform (Object o);
}
