/*
 * LAPIS lightweight structured text processing system
 *
 * Copyright (C) 1998-2002 Carnegie Mellon University,
 * Copyright (C) 2003 Massachusetts Institute of Technology.
 * All rights reserved.
 *
 * This library is free software; you can redistribute it
 * and/or modify it under the terms of the GNU General
 * Public License as published by the Free Software
 * Foundation, version 2.
 *
 * LAPIS homepage: http://graphics.lcs.mit.edu/lapis/
 */


package lapisx.enum;
import java.util.Enumeration;
import java.util.NoSuchElementException;
import java.util.Vector;
/**
 * Enumeration which can be restarted from the beginning.
 */
public class MemoizedEnumeration implements RestartableEnumeration  {
    Vector v;  // elements which have already been returned 
    Enumeration e1; // enumeration of v
    Enumeration e2; // main enumeration 

    public MemoizedEnumeration (Enumeration e) {
        this.v = new Vector ();
        this.e2 = e;
    }

    public MemoizedEnumeration (Vector v) {
        this.v = (Vector) v.clone ();
        this.e1 = this.v.elements ();
    }

    public boolean hasMoreElements () {
        if (e1 != null) {
            if (e1.hasMoreElements ())
                return true;
            else
                e1 = null;
        }

        if (e2 != null) {
            if (e2.hasMoreElements ())
                return true;
            else
                e2 = null;
        } 

        return false;
    }

    public Object nextElement () {
        if (e1 != null)
            try {
                return e1.nextElement ();
            } catch (NoSuchElementException e) {
                e1 = null;
            }

        if (e2 != null)
            try {
                Object o = e2.nextElement ();
                v.addElement (o);
                return o;
            } catch (NoSuchElementException e) {
                e2 = null;
            }

        throw new NoSuchElementException ();
    }

    public void restart () {
        e1 = v.elements ();
    }
}
