/*
 * LAPIS lightweight structured text processing system
 *
 * Copyright (C) 1998-2002 Carnegie Mellon University,
 * Copyright (C) 2003 Massachusetts Institute of Technology.
 * All rights reserved.
 *
 * This library is free software; you can redistribute it
 * and/or modify it under the terms of the GNU General
 * Public License as published by the Free Software
 * Foundation, version 2.
 *
 * LAPIS homepage: http://graphics.lcs.mit.edu/lapis/
 */

package lapisx.io;

import java.io.*;
//import java.util.*;

public abstract class FileUtil {
    /**
      * Load a file into a string.
      * @param f Filename to load
      * @return Contents of file as a string, loaded through a Reader
      */
    public static String load (File f) throws IOException {
        return load (new FileReader (f));
    }

    /**
      * Load a stream into a string.
      * @param in Stream to load
      * @return Contents of stream as a string
      */
    public static String load (InputStream in) throws IOException {
        return load (new InputStreamReader (in));
    }

    /**
      * Load a reader stream into a string.
      * @param r Reader stream to load
      * @return Contents of reader stream as a string
      */
    public static String load (Reader r) throws IOException {
        int n;
        StringBuffer sbuf = new StringBuffer ();
        char[] buf = new char[8000];
        while ((n = r.read (buf)) != -1)
            sbuf.append (buf, 0, n);
        return sbuf.toString ();
    }

    /**
      * Save a file (represented as a string) to disk.
      * @param f Filename to save
      * @param s Contents of file
      */
    public static void save (File f, String s) throws IOException {
        PrintWriter out = new PrintWriter (new FileWriter (f));
        out.print (s);
        out.close ();
    }
}
