/*
 * LAPIS lightweight structured text processing system
 *
 * Copyright (C) 1998-2002 Carnegie Mellon University,
 * Copyright (C) 2003 Massachusetts Institute of Technology.
 * All rights reserved.
 *
 * This library is free software; you can redistribute it
 * and/or modify it under the terms of the GNU General
 * Public License as published by the Free Software
 * Foundation, version 2.
 *
 * LAPIS homepage: http://graphics.lcs.mit.edu/lapis/
 */
package lapisx.io;

import java.io.*;

/**
 * NullOutputStream is used when the OutuputStream interface is
 * required, but when written bytes have no destination.  Note that
 * this class is implemented using the Singleton pattern, and is
 * accessed through the static <tt>getInstance()</tt> method.
 *
 */
public class NullOutputStream extends OutputStream {

    protected static final NullOutputStream instance = 
	new NullOutputStream();

    protected NullOutputStream() { }

    public static NullOutputStream getInstance() {
	return instance;
    }

    public void write (int b) {
	
    }

    public void write (byte[] b, int off, int len) {

    }

    public void write (byte[] b) {

    }
}
