/*
 * LAPIS lightweight structured text processing system
 *
 * Copyright (C) 1998-2002 Carnegie Mellon University,
 * Copyright (C) 2003 Massachusetts Institute of Technology.
 * All rights reserved.
 *
 * This library is free software; you can redistribute it
 * and/or modify it under the terms of the GNU General
 * Public License as published by the Free Software
 * Foundation, version 2.
 *
 * LAPIS homepage: http://graphics.lcs.mit.edu/lapis/
 */
package lapisx.io;

import java.io.*;

/**
 * TeeStream is used to simultaneously write to an OutputStream
 * (passed as an argument to the constructor) as bytes are read from
 * the underlying InputStream.
 */
public class TeeStream extends FilterInputStream {

    protected OutputStream out = null;

    public TeeStream(InputStream in, OutputStream out) {
	super(in);
	this.out = out;
    }

    public int read() throws IOException {
	int j = in.read();
	if (j != -1) {
	    out.write(j);
	}
	return j;
    }

    public int read(byte[] b) throws IOException{
	int j = in.read(b);
	if (j != -1) {
	    out.write(b, 0, j);
	}
	return j;
    }

    public int read(byte[] b, int off, int len) throws IOException {
	int j = in.read(b,off,len);
	if (j != -1) {
	    out.write(b,off,j);
	}
	return j;
    }

}
