/*
 * LAPIS lightweight structured text processing system
 *
 * Copyright (C) 1998-2002 Carnegie Mellon University,
 * Copyright (C) 2003 Massachusetts Institute of Technology.
 * All rights reserved.
 *
 * This library is free software; you can redistribute it
 * and/or modify it under the terms of the GNU General
 * Public License as published by the Free Software
 * Foundation, version 2.
 *
 * LAPIS homepage: http://graphics.lcs.mit.edu/lapis/
 */

package lapisx.io;

//import java.net.*;
import java.io.*;
import java.util.Vector;

public abstract class TempFile {
    private static String tempDir;
    private static Vector temps = new Vector ();

    static {
        if (!(tryTempDir (getTempDirProperty ())
              || tryTempDir ("c:\\temp")          // Windows
              || tryTempDir ("c:\\windows\\temp") // also Windows
              || tryTempDir ("/tmp")              // Unix
            ))
            useTempDir ("");                 // default to current directory
    }

    private static String getTempDirProperty () {
        try {
            return System.getProperty ("temp.directory");
        } catch (SecurityException e) {
            return null;
        }
    }

    private static boolean tryTempDir (String dir) {
        if (dir == null)
            return false;

        File f = new File (dir);
        if (!f.exists ()) {
            //System.err.println (dir + " does not exist");
            return false;
        }

        if (!f.isDirectory ()) {
            //System.err.println (dir + " not a directory");
            return false;
        }


        if (dir.length () > 0
            && !(dir.endsWith ("/") ||
                dir.endsWith (File.separator)))
            dir += File.separator;
        useTempDir (dir);
        return true;
    }

    private static void useTempDir (String dir) {
        tempDir = dir;
    }

    public static String getTempDirectory () {
        return tempDir;
    }

    public static File makeTempFile (String basename, String extension) {
        String dir = getTempDirectory ();
        File f;
        synchronized (temps) {
            do
                f = new File (dir
                                + basename
                                + String.valueOf ((int)(Math.random() * 999999))
                                + extension);
            while (temps.contains (f) || f.exists());
            registerTempFile (f);
        }
        return f;
    }

    public static void registerTempFile (File f) {
        temps.addElement (f);
    }

    public static void deleteAllTempFiles () {
        synchronized (temps) {
            for (int i=0; i<temps.size(); ++i) {
                File f = (File)temps.elementAt(i);
                f.delete ();
            }
            temps.setSize (0);
        }
    }
}
