/*
 * LAPIS lightweight structured text processing system
 *
 * Copyright (C) 2003 Massachusetts Institute of Technology.
 * All rights reserved.
 *
 * This library is free software; you can redistribute it
 * and/or modify it under the terms of the GNU General
 * Public License as published by the Free Software
 * Foundation, version 2.
 *
 * LAPIS homepage: http://graphics.lcs.mit.edu/lapis/
 */

package lapisx.iterator;

import java.util.*;

/**
 * Concatenates two or more Iterators.
 */
public class ConcatIterator implements Iterator {
    Iterator g;
    Iterator otherIterators;
    
    private static Iterator EMPTY = Collections.EMPTY_LIST.iterator ();
    
    /**
     * Make a concatenation of two iterators. 
     * @param g1 First iterator
     * @param g2 Second iterator
     */
    public ConcatIterator (Iterator g1, Iterator g2) {
        g = g1;
        otherIterators = Collections.singleton (g2).iterator ();
    }
    
    /**
     * Make a concatenation of a collection of iterators.
     * @param iterators collection of iterators to concatenate
     * @throws ClassCastException if the first element of iterators doesn't implement Iterator
     */
    public ConcatIterator (Collection iterators) {
        otherIterators = iterators.iterator ();
        if (otherIterators.hasNext ())
            g = (Iterator) otherIterators.next ();
        else
            g = EMPTY;
    }
    
    public boolean hasNext() {
        if (g.hasNext ())
            return true;
        while (otherIterators.hasNext ()) {
            g = (Iterator) otherIterators.next ();
            if (g.hasNext ())
                return true;
        }
        return false;
    }

   public Object next() {
        while (true) {
            try {
                return g.next();
            } catch (NoSuchElementException e) {
                if (otherIterators.hasNext ())
                    g = (Iterator) otherIterators.next ();
                else
                    throw e;
            }
        }
    }
    
    public void remove () {
        g.remove ();
    }
}
