/*
 * LAPIS lightweight structured text processing system
 *
 * Copyright (C) 2003 Massachusetts Institute of Technology.
 * All rights reserved.
 *
 * This library is free software; you can redistribute it
 * and/or modify it under the terms of the GNU General
 * Public License as published by the Free Software
 * Foundation, version 2.
 *
 * LAPIS homepage: http://graphics.lcs.mit.edu/lapis/
 */

package lapisx.iterator;

import junit.framework.*;
import java.util.*;

/**
 * Test case for ConcatIterator.
 */
public class ConcatIteratorTest extends TestCase {

    public ConcatIteratorTest (String name) {
        super(name);
    }

    protected void setUp () {
    }        
    
    public static Test suite () {        
        return new TestSuite (ConcatIteratorTest.class);
    }

    public void testConcat () {
        List l1 = Arrays.asList (new String[] {"a", "b", "c"});
        List l2 = Arrays.asList (new String[] {"d", "e", "f"});
        List l3 = Arrays.asList (new String[] {"g", "h"});
        Iterator EMPTY = Collections.EMPTY_LIST.iterator ();
        
        // concatenate two iterators
        Iterator g1 = new ConcatIterator (l1.iterator (), l2.iterator ());
        assertEquals (Arrays.asList (new String[] {"a", "b", "c", "d", "e", "f"}), accumulate (g1));
        
        // append empty iterator
        Iterator g2 = new ConcatIterator (l1.iterator (), EMPTY);
        assertEquals (Arrays.asList (new String[] {"a", "b", "c"}), accumulate (g2));

        // prefix empty iterator
        Iterator g3 = new ConcatIterator (EMPTY, l2.iterator ());
        assertEquals (Arrays.asList (new String[] {"d", "e", "f"}), accumulate (g3));

        // concatenate three iterators
        Iterator g4 = new ConcatIterator (Arrays.asList (new Iterator[] {l2.iterator (), l3.iterator (), l1.iterator ()}));
        assertEquals (Arrays.asList (new String[] {"d", "e", "f", "g", "h", "a", "b", "c", }), accumulate (g4));
      
        // concatenate one iterator
        Iterator g5 = new ConcatIterator (Collections.singleton (l3.iterator ()));
        assertEquals (Arrays.asList (new String[] {"g", "h"}), accumulate (g5));
      
        // concatenate no iterators
        Iterator g6 = new ConcatIterator (Collections.EMPTY_LIST);
        assertEquals (Collections.EMPTY_LIST, accumulate (g6));
      
        // concatenate three empty iterators
        Iterator g7 = new ConcatIterator (Collections.nCopies (3, EMPTY));
        assertEquals (Collections.EMPTY_LIST, accumulate (g7));
        
        // remove from concatenated iterator
        List ml1 = new ArrayList (); ml1.add ("x"); ml1.add ("y");
        List ml2 = new ArrayList (); ml2.add ("z");       
        Iterator g8 = new ConcatIterator (ml1.iterator (), ml2.iterator ());
        while (g8.hasNext ()) {
            g8.next ();
            g8.remove();
        }
        assertEquals (Collections.EMPTY_LIST, ml1);
        assertEquals (Collections.EMPTY_LIST, ml2);        
    }

    private List accumulate (Iterator g) {
        List s = new ArrayList ();
        while (g.hasNext ())
            s.add (g.next ());
        return s;
    }
}
