/*
 * LAPIS lightweight structured text processing system
 *
 * Copyright (C) 2003 Massachusetts Institute of Technology.
 * All rights reserved.
 *
 * This library is free software; you can redistribute it
 * and/or modify it under the terms of the GNU General
 * Public License as published by the Free Software
 * Foundation, version 2.
 *
 * LAPIS homepage: http://graphics.lcs.mit.edu/lapis/
 */

package lapisx.iterator;

import java.util.*;

/**
 * Iterator which transforms the elements of another iterator.
 */
public abstract class FilteredIterator implements Iterator {

    Iterator g;
    Object o; // first object waiting to be returned, or null if none
    ArrayList l; // other objects yielded and waiting to be returned
    int i;    // next object to return from l

    public FilteredIterator (Iterator g) {
        this.g = g;
    }

	public boolean hasNext() {
        nextElement ();
        return o != null;
	}

	public Object next() {
        nextElement ();
        if (o == null)
            throw new NoSuchElementException ();
        Object result = o;
        o = null;
        return result;
	}

	public void remove() {
        g.remove();
	}

    void nextElement () {
        // check if yielded element is waiting to be returned 
        if (o != null)
            return;

        // check in l for other yielded elements
        if (l != null) {
            if (i < l.size ()) {
                o = l.get (i);
                l.set (i, null);
                ++i;
            } else {
                l.clear();
                i = 0;
            }
        }

        // transform elements until an element is yielded
        while (o == null && g.hasNext())
            transform (g.next());
    }

    public void yield (Object obj) {
        if (o == null)
            o = obj;
        else {
            if (l == null)
                l = new ArrayList();
            l.add(obj);
        }
    }

    public abstract void transform (Object o);

}
