/*
 * LAPIS lightweight structured text processing system
 *
 * Copyright (C) 1998-2002 Carnegie Mellon University,
 * Copyright (C) 2003 Massachusetts Institute of Technology.
 * All rights reserved.
 *
 * This library is free software; you can redistribute it
 * and/or modify it under the terms of the GNU General
 * Public License as published by the Free Software
 * Foundation, version 2.
 *
 * LAPIS homepage: http://graphics.lcs.mit.edu/lapis/
 */

package lapisx.net;

import java.io.*;

public class ContentTypeGuessingReader extends Reader {
    public static lapisx.util.Debug debug = lapisx.util.Debug.QUIET;
    String contentType;
    char[] head = new char[200];
    int start, end;
    Reader tail;

    public ContentTypeGuessingReader (Reader in) throws IOException {
        start = 0;
        end = in.read (head);
        tail = in;
        if (end == -1) 
            return;

        String strHeader = new String (head, start, end);
        strHeader = strHeader.trim ();
        strHeader = strHeader.toLowerCase ();
        debug.println ("CTGR read '" + strHeader + "'");

        if (strHeader.startsWith ("<html>")
            || strHeader.startsWith ("<!doctype html")
            || strHeader.startsWith ("<title>") // for directories
            ) {
            contentType = "text/html";
        } else if (strHeader.startsWith ("content-type:")) {
            // Scan for newline (marking end of Content-type field);
            // then scan for double newline (marking end of header) so we can
            // omit the header from the document
            StringBuffer typebuf = new StringBuffer ();
            boolean readingContentType = true;
            boolean sawNewline = false;
            for (int i = "content-type:".length (); true; ++i) {
                if (i >= end) {
                    end = in.read (head);
                    if (end <= 0) {
                        end = 0;
                        break;
                    }
                    i = 0;
                }
                char c = head[i];
                if (c == '\n') {
                    readingContentType = false;
                    if (sawNewline) {
                        start = i+1;
                        break;
                    }
                    else
                        sawNewline = true;
                } else if (c != '\r') {
                    sawNewline = false;
                    if (readingContentType)
                        typebuf.append (c);
                }
            }

            contentType = typebuf.toString ();
            contentType = contentType.trim ();
        }
        debug.println ("CTGR guessed content-type " + contentType);
    }

    public String getContentType () {
        return contentType;
    }

    public int read () throws IOException {
        if (start < end)
            return head[++start];
        else
            return tail.read ();
    }                
                
    public int read (char[] b) throws IOException {
        return read (b, 0, b.length);
    }                

    public int read (char[] b, int off, int len) throws IOException {
        if (start < end) {
            int n = Math.min (end-start, len);
            System.arraycopy (head, start, b, off, n);
            start += n;

            if (n < len) {
                int n2 = tail.read (b, off+n, len-n);
                if (n2 >= 0)
                    n += n2;
            }
            return n;
        }
        else
            return tail.read (b, off, len);
    }

    public long skip (long n) throws IOException {
        if (start < end) {
            long n2 = Math.min ((long) (end-start), n);
            start += (int)n2;

            if (n2 < n)
                n2 += tail.skip (n - n2);
            return n2;
        }
        else
            return tail.skip (n);
    }

    public boolean ready () throws IOException {
        return (end > start) || tail.ready ();
    }

    public void close () throws IOException {
        tail.close ();
    }

    public void mark (int readlimit) {
    }

    public void reset () throws IOException {
        throw new IOException ("reset not supported");
    }

    public boolean markSupported () {
        return false;
    }
}
