/*
 * LAPIS lightweight structured text processing system
 *
 * Copyright (C) 1998-2002 Carnegie Mellon University,
 * Copyright (C) 2003 Massachusetts Institute of Technology.
 * All rights reserved.
 *
 * This library is free software; you can redistribute it
 * and/or modify it under the terms of the GNU General
 * Public License as published by the Free Software
 * Foundation, version 2.
 *
 * LAPIS homepage: http://graphics.lcs.mit.edu/lapis/
 */

package lapisx.progress;

import java.io.*;

public class ProgressReader extends FilterReader {
    int chunkSize;
    int n; // number of characters read for current chunk
    BasicProgressGenerator gen;

    public ProgressReader (Reader in, int chunkSize, BasicProgressGenerator gen) {
        super (in);
        this.chunkSize = chunkSize;
        this.gen = gen;
    }

    public int read () throws IOException {
        int c = super.read ();
        if (c != -1 && ++n == chunkSize) {
            gen.fireAddProgress (n);
            n = 0;
        }
        return c;
    }

    public int read (char[] buf, int off, int len) throws IOException {
        int r = super.read (buf, off, len);
        if (r != -1) {
            n += r;
            if (n >= chunkSize) {
                gen.fireAddProgress (n);
                n = 0;
            }
        }
        return r;
    }
}
