/*
 * LAPIS lightweight structured text processing system
 *
 * Copyright (C) 1998-2002 Carnegie Mellon University,
 * Copyright (C) 2003 Massachusetts Institute of Technology.
 * All rights reserved.
 *
 * This library is free software; you can redistribute it
 * and/or modify it under the terms of the GNU General
 * Public License as published by the Free Software
 * Foundation, version 2.
 *
 * LAPIS homepage: http://graphics.lcs.mit.edu/lapis/
 */

package lapisx.progress;

import java.io.*;
import lapisx.util.Str;

public class StreamProgressBar implements ProgressListener {
    PrintStream out; // output stream
    int labelWidth;  // width of label field in characters
    int barWidth;    // number of dots in progress bar
    int dotsPrinted; // number of dots already printed

    int maxLabelWidth; // label field will grow until it reaches this size

    public StreamProgressBar () {
        this (System.out);
    }

    public StreamProgressBar (OutputStream out) {
        this (new PrintStream (out), 20, 20);
    }

    public StreamProgressBar (OutputStream out, int labelWidth, int barWidth) {
        this.out = new PrintStream (out);
        this.labelWidth = labelWidth;
        this.barWidth = barWidth;
        dotsPrinted = 0;
        maxLabelWidth = 75 - barWidth;
    }

    public void startProgress (ProgressEvent event) {
        String label = event.getLabel ();

        int len = label.length();
        if (len > labelWidth)
            labelWidth = Math.min (len, maxLabelWidth);
        if (len > labelWidth)
            label = label.substring (0, labelWidth-3) + "...";
        else
            label = label + Str.repeat (" ", labelWidth - len);
                
        out.print (label);
        out.print (" [");

        dotsPrinted = 0;
        printDots (event);
    }

    public void makeProgress (ProgressEvent event) {
        printDots (event);
    }

    public void doneProgress (ProgressEvent event) {
        printDots (event);
        out.println ("]");
    }

    void printDots (ProgressEvent event) {
//         out.print (" {min=" + event.getMinimum ()
//                    + ",max=" + event.getMaximum ()
//                    + ",val=" + event.getValue ()
//                    + ",pct=" + event.getPercentComplete ()
//                    + "}");

        double percent = event.getPercentComplete ();
        int dots = (int) (percent * barWidth);
        if (dots > dotsPrinted) {
            out.print (Str.repeat (".", dots - dotsPrinted));
            dotsPrinted = dots;
        }
    }
}
