/*
 * LAPIS lightweight structured text processing system
 *
 * Copyright (C) 1998-2002 Carnegie Mellon University,
 * Copyright (C) 2003 Massachusetts Institute of Technology.
 * All rights reserved.
 *
 * This library is free software; you can redistribute it
 * and/or modify it under the terms of the GNU General
 * Public License as published by the Free Software
 * Foundation, version 2.
 *
 * LAPIS homepage: http://graphics.lcs.mit.edu/lapis/
 */
package lapisx.progress.swing;

import java.awt.*;
import java.awt.event.*;
import javax.swing.*;
import lapisx.swing.Win;
import lapisx.progress.*;

public class SwingProgressBar extends JProgressBar implements ProgressListener {

    boolean cancelled = false;
    JDialog dialog = null;

    public SwingProgressBar () {
        setStringPainted (true);
        setBorderPainted (true);
    }

    public JDialog makeDialog (Component parent, String title, boolean modal) {
        if (dialog != null)
            return dialog;

        dialog = new JDialog (Win.findFrameOrMakeFrame (parent),
                              title, modal);
        Container contentPane = dialog.getContentPane ();

        contentPane.setLayout (new BorderLayout ());
        contentPane.add (this);

        Panel bottom = new Panel ();
        Button cancelButton = new Button ("Cancel");
        cancelButton.addActionListener (new ActionListener () {
            public void actionPerformed (ActionEvent event) {
                cancel ();
            }
        });
        bottom.add (cancelButton);
        contentPane.add (bottom, BorderLayout.SOUTH);

        dialog.pack ();
        Win.center (dialog, parent);

        return dialog;
    }

    public void cancel () {
        cancelled = true;
        if (dialog != null)
            dialog.dispose ();
    }

    public void startProgress (ProgressEvent event) {
        handle (event);
    }

    public void makeProgress (ProgressEvent event) {
        handle (event);
    }

    public void doneProgress (ProgressEvent event) {
        handle (event);
    }

    private void handle (final ProgressEvent event) {
        if (cancelled)
            throw new CancelException ();
        SwingUtilities.invokeLater (new Runnable () {
            public void run () {
                setString (event.getLabel ());
                setMinimum (event.getMinimum ());
                setMaximum (event.getMaximum ());
                setValue (event.getValue ());
            }
        });
    }

    public static void main (String[] args) throws Exception {
        SwingProgressBar pb = new SwingProgressBar ();
        JDialog dlg = pb.makeDialog (null, "Progress", false);
        dlg.show ();

        BasicProgressGenerator gen = new BasicProgressGenerator (dlg);
        gen.addProgressListener (pb);
        gen.fireStartProgress ("Counting to infinity", 1000);
        Thread.currentThread ().setPriority (4);
        try {
            for (int i = 0; dlg != null && i < 20; ++i) {
                Thread.sleep (500);
                gen.fireProgress ();
            }
            gen.fireDoneProgress ();
        } catch (CancelException e) {
            System.err.println (e);
        } finally {
            dlg.dispose ();
        } 
        
        System.exit (0);
    }

}
