/*
 * LAPIS lightweight structured text processing system
 *
 * Copyright (C) 1998-2002 Carnegie Mellon University,
 * Copyright (C) 2003 Massachusetts Institute of Technology.
 * All rights reserved.
 *
 * This library is free software; you can redistribute it
 * and/or modify it under the terms of the GNU General
 * Public License as published by the Free Software
 * Foundation, version 2.
 *
 * LAPIS homepage: http://graphics.lcs.mit.edu/lapis/
 */

package lapisx.sort;

import java.util.Random;

public abstract class Quicksort {
    private static Random random = new Random ();


    //
    // sorting collections of objects
    //

    public static void sort (Sortable a) {
        sort (a, 0, a.size()-1);
    }

    public static void sort (Sortable a, int p, int r) {
        if (p < r) {
            int q = partition (a, p, r);
            sort (a, p, q);
            sort (a, q+1, r);
        }
    }

    private static int partition (Sortable a, int p, int r) {
        Object x = a.get (p + Math.abs (random.nextInt () % (r-p+1)));
        int i = p-1;
        int j = r+1;
        while (true) {
            do j = j-1;
            while (a.compare (a.get (j), x) > 0);
            do i = i+1;
            while (a.compare (a.get (i), x) < 0);
            if (i < j)
                a.swap (i, j);
            else return j;
        }
    }

    //
    // sorting collections of non-objects
    //

    public static void sort (Sortable2 a) {
        sort (a, 0, a.size()-1);
    }

    public static void sort (Sortable2 a, int p, int r) {
        if (p < r) {
            int q = partition (a, p, r);
            sort (a, p, q);
            sort (a, q+1, r);
        }
    }

    private static int partition (Sortable2 a, int p, int r) {
        int x = p + Math.abs (random.nextInt () % (r-p+1));
        int i = p-1;
        int j = r+1;

        while (true) {
            do j = j-1;
            while (a.compare (j, x) > 0);
            do i = i+1;
            while (a.compare (i, x) < 0);
            if (i < j) {
                a.swap (i, j);
                if (x == i)
                    x = j;
                else if (x == j)
                    x = i;
            } else return j;
        }
    }


    //
     // sorting linked lists
    //

    public static SortableList sort (SortableList l, int n) {
        return sort (l, n, null);
    }

    public static SortableList sort (SortableList l) {
        int n = 0;
        for (SortableList p = l; p != null; p = p.next ())
            ++n;
        return sort (l, n);
    }

    private static SortableList sort (SortableList l, int n, SortableList tail) {
        if (l == null)
            return tail;

        SortableList headLT = null, tailLT = null;
        SortableList headGT = null, tailGT = null;
        SortableList headEQ = null, tailEQ = null;
        int nLT = 0, nGT = 0;
        int pivotIndex = random.nextInt () % n;
        SortableList pivot = traverse (l, pivotIndex);
        while (l != null) {
            int c = l.compareTo (pivot);
            if (c == 0) {
                if (tailEQ == null)
                    headEQ = tailEQ = l;
                else {
                    tailEQ.setNext (l);
                    tailEQ = l;
                }
            }
            else if (c < 0) {
                ++nLT;
                if (tailLT == null)
                    headLT = tailLT = l;
                else {
                    tailLT.setNext (l);
                    tailLT = l;
                }
            }
            else {
                ++nGT;
                if (tailGT == null)
                    headGT = tailGT = l;
                else {
                    tailGT.setNext (l);
                    tailGT = l;
                }
            }

            SortableList next = l.next ();
            l.setNext (null);
            l = next;
        }

        if (headEQ == null)
            return sort (headLT, nLT, sort (headGT, nGT, tail));
        else {
            tailEQ.setNext (sort (headGT, nGT, tail));
            return sort (headLT, nLT, headEQ);
        }
    }

    private static SortableList traverse (SortableList l, int n) {
        while (n > 0) {
            l = l.next ();
            --n;
        }
        return l;
    }


}
