/*
 * LAPIS lightweight structured text processing system
 *
 * Copyright (C) 1998-2002 Carnegie Mellon University,
 * Copyright (C) 2003 Massachusetts Institute of Technology.
 * All rights reserved.
 *
 * This library is free software; you can redistribute it
 * and/or modify it under the terms of the GNU General
 * Public License as published by the Free Software
 * Foundation, version 2.
 *
 * LAPIS homepage: http://graphics.lcs.mit.edu/lapis/
 */

package lapisx.sort;
import java.util.Enumeration;
//import java.util.NoSuchElementException;
import java.util.Vector;

/**
 * Enumeration which reorders the elements of another enumeration.
 */
public abstract class SortedEnumeration implements Enumeration {
    Enumeration original; // original enumeration
    Enumeration sorted; // enumeration after sorting

    public SortedEnumeration (Enumeration e) {
        original = e;
    }

    public abstract int compare (Object o1, Object o2);

    public boolean hasMoreElements () {
        if (sorted == null)
            sorted = sort ();
        return sorted.hasMoreElements ();
    }

    public Object nextElement () {
        if (sorted == null)
            sorted = sort ();
        return sorted.nextElement ();
    }

    Enumeration sort () {
        // read the original enumeration into a vector
        Vector v = new Vector ();
        while (original.hasMoreElements ())
            v.addElement (original.nextElement ());

        // sort the vector
        MergeSort.sort (new SortableVector (v) {
                public int compare (Object o1, Object o2) {
                    return SortedEnumeration.this.compare (o1, o2);
                }
            });

        // enumerate its elements
        return v.elements ();
    }
}
