/*
 * LAPIS lightweight structured text processing system
 *
 * Copyright (C) 1998-2002 Carnegie Mellon University,
 * Copyright (C) 2003 Massachusetts Institute of Technology.
 * All rights reserved.
 *
 * This library is free software; you can redistribute it
 * and/or modify it under the terms of the GNU General
 * Public License as published by the Free Software
 * Foundation, version 2.
 *
 * LAPIS homepage: http://graphics.lcs.mit.edu/lapis/
 */

package lapisx.swing;

import java.awt.event.*;
import javax.swing.*;

public class AcceleratedAction extends AbstractAction {
    public Action action;

    public static String MNEMONIC = "MNEMONIC";
    public static String ACCELERATOR = "ACCELERATOR";

    public AcceleratedAction (String name) {
        int ampersand = name.indexOf ('&');
        if (ampersand > -1 && ampersand < name.length()) {
            char mnemonic = Character.toUpperCase (name.charAt (ampersand+1));
            putValue (MNEMONIC, new Character (mnemonic));
            name = name.substring (0, ampersand) + name.substring (ampersand + 1);
        }
        putValue (NAME, name);
    }

    public AcceleratedAction (String name, String tooltip) {
        this (name);
        putValue (SHORT_DESCRIPTION, tooltip);
    }

    public AcceleratedAction (String name, Icon icon) {
        this (name);
        putValue (SMALL_ICON, icon);
    }

    public AcceleratedAction (String name, Icon icon, String tooltip) {
        this (name, icon);
        putValue (SHORT_DESCRIPTION, tooltip);
    }

    public AcceleratedAction (String name, int keycode, int modifiers) {
        this (name);
        putValue (ACCELERATOR, KeyStroke.getKeyStroke (keycode, modifiers));
    }

    public AcceleratedAction (String name, int keycode, int modifiers,
                              String tooltip) {
        this (name, keycode, modifiers);
        putValue (SHORT_DESCRIPTION, tooltip);
    }

    public AcceleratedAction (String name, Icon icon, 
                              int keycode, int modifiers) {
        this (name, keycode, modifiers);
        putValue (SMALL_ICON, icon);
    }


    public AcceleratedAction (String name, Icon icon, 
                              int keycode, int modifiers, String tooltip) {
        this (name, icon, keycode, modifiers);
        putValue (SHORT_DESCRIPTION, tooltip);
    }

    public AcceleratedAction (String name, int keycode, int modifiers, 
                              Action action) {
        this (name, keycode, modifiers);
        this.action = action;
    }

    public AcceleratedAction (String name,
                              Action action) {
        this (name);
        this.action = action;
    }

    public void actionPerformed (ActionEvent event) {
        if (action != null)
            action.actionPerformed (event);
    }
}
