/*
 * LAPIS lightweight structured text processing system
 *
 * Copyright (C) 1998-2002 Carnegie Mellon University,
 * Copyright (C) 2003 Massachusetts Institute of Technology.
 * All rights reserved.
 *
 * This library is free software; you can redistribute it
 * and/or modify it under the terms of the GNU General
 * Public License as published by the Free Software
 * Foundation, version 2.
 *
 * LAPIS homepage: http://graphics.lcs.mit.edu/lapis/
 */

package lapisx.swing;

import java.awt.*;
import javax.swing.*;

public abstract class ActionAdapters {

    public static Action toMenuAction (Action action) {
        return new MaskedAction (Action.SMALL_ICON, action);
    }

    public static Action toToolbarAction (Action action) {
        return new MaskedAction (Action.NAME, action);
    }

    public static JToggleButton toToggleButton (Action action,
                                                  ButtonGroup group) {
        JToggleButton button = 
            new JToggleButton ((Icon) action.getValue (Action.SMALL_ICON));

        button.addActionListener (action);

        String tooltip = (String) action.getValue (Action.SHORT_DESCRIPTION);
        if (tooltip != null)
            button.setToolTipText (tooltip);
        
        if (group != null)
            group.add (button);
        return button;
    }

    public static JRadioButtonMenuItem toRadioButtonMenuItem (Action action,
                                                              ButtonGroup group) {
        JRadioButtonMenuItem item = 
            new JRadioButtonMenuItem ((String) action.getValue (Action.NAME));

        item.addActionListener (action);

        Object mn = action.getValue (AcceleratedAction.MNEMONIC);
        if (mn != null)
            item.setMnemonic (((Character)mn).charValue ());

        Object acc = action.getValue (AcceleratedAction.ACCELERATOR);
        if (acc != null)
            item.setAccelerator ((KeyStroke) acc);

        if (group != null)
            group.add (item);

        return item;
    }
    public static JRadioButton toRadioButton (Action action, ButtonGroup group) {
        JRadioButton item = 
            new JRadioButton ((String) action.getValue (Action.NAME));

        item.addActionListener (action);

        Object mn = action.getValue (AcceleratedAction.MNEMONIC);
        if (mn != null)
            item.setMnemonic (((Character)mn).charValue ());

        if (group != null)
            group.add (item);

        return item;
    }
    /** 
     * constructs a new JButton attached to an Action
     * @returns a new JButton
     * 
     **/
    public static JButton toButton (Action a) {
        JButton b = new JButton ((String) a.getValue (Action.NAME));
        b.addActionListener (a);
        return b;
    }

    /** 
     * constructs a new JCheckBox attached to an Action
     * @returns a new JCheckBox
     * 
     **/
    public static JCheckBox toCheckBox (Action a) {
        JCheckBox b = new JCheckBox ((String) a.getValue (Action.NAME));
        b.addActionListener (a);
        return b;
    }


    /** 
     * Make a new JButton attached to an Action.  This JButton
     * is shorter than a default JButtons, and uses a smaller font.
     * @param action Action to trigger when button is pressed.
     * @returns a new tiny JButton
     **/
    public static JButton toTinyButton (Action a) {
        int height = new JLabel ("X").getPreferredSize ().height;

        JButton button = new JButton ((String) a.getValue (Action.NAME));
        button.addActionListener (a);

        Font oldFont = button.getFont ();
        Font font = new Font (oldFont.getName (), 
                              oldFont.getStyle (),
                              oldFont.getSize () - 2);
        button.setFont (font);

        Dimension d = new Dimension (button.getPreferredSize ().width,
                                     height);
        button.setPreferredSize (d);
        button.setMaximumSize (d);

        return button;
    }


}
