/*
 * LAPIS lightweight structured text processing system
 *
 * Copyright (C) 1998-2002 Carnegie Mellon University,
 * Copyright (C) 2003 Massachusetts Institute of Technology.
 * All rights reserved.
 *
 * This library is free software; you can redistribute it
 * and/or modify it under the terms of the GNU General
 * Public License as published by the Free Software
 * Foundation, version 2.
 *
 * LAPIS homepage: http://graphics.lcs.mit.edu/lapis/
 */

package lapisx.swing;

import java.awt.*;
import java.awt.event.*;
import javax.swing.*;

public class Animation extends JComponent {
    public static lapisx.util.Debug debug = lapisx.util.Debug.QUIET;

    boolean animating;
    Image animatedImage;
    Image frozenImage;

    public Animation (Image animatedImage, Image frozenImage) {
        this (animatedImage, frozenImage, true);
    }

    public Animation (Image animatedImage, Image frozenImage, boolean animating) {
        this.animatedImage = animatedImage;
        this.frozenImage = frozenImage;

        MediaTracker mt = new MediaTracker (this);
        mt.addImage (animatedImage, 0);
        mt.addImage (frozenImage, 1);
        try {
            mt.waitForAll ();
        } catch (InterruptedException e) {}

        int w = animatedImage.getWidth (null);
        int h = animatedImage.getHeight (null);
        if (w == -1 || h == -1)
            throw new RuntimeException ("image error: can't get width and height");

        w = Math.max (w, frozenImage.getWidth (null));
        h = Math.max (h, frozenImage.getHeight (null));

        setPreferredSize (new Dimension (w, h));

        this.animating = animating;
    }

    public synchronized boolean getAnimating () {
        return animating;
    }

    public synchronized void setAnimating (boolean animating) {
        this.animating = animating;
        repaint ();
    }

    public void paintComponent (Graphics g) {
        super.paintComponent (g);
        debug.println ("Animation.paintComponent");
            
        if (animating)
            g.drawImage (animatedImage, 0, 0, this);
        else {
            animatedImage.flush ();
            g.drawImage (frozenImage, 0, 0, this);
        }
    }

    public static void main (String[] argv) throws Exception {
        final Animation anim = 
            new Animation (Toolkit.getDefaultToolkit ().getImage (argv[0]),
                           Toolkit.getDefaultToolkit ().getImage (argv[1]),
                           true);
        JFrame f = new JFrame ("Animation"); 
        f.getContentPane ().add (anim, BorderLayout.CENTER);
        f.getContentPane ().setBackground (Color.red);
        f.addWindowListener (new WindowAdapter () {
            public void windowClosing (WindowEvent evt) {
                System.exit(0);
            }
        });
        f.addMouseListener (new MouseAdapter () {
                public void mouseClicked (MouseEvent event) {
                    anim.setAnimating (!anim.getAnimating ());
                }
            });
        f.pack ();
        f.show ();
    }
}
