/*
 * LAPIS lightweight structured text processing system
 *
 * Copyright (C) 1998-2002 Carnegie Mellon University,
 * Copyright (C) 2003 Massachusetts Institute of Technology.
 * All rights reserved.
 *
 * This library is free software; you can redistribute it
 * and/or modify it under the terms of the GNU General
 * Public License as published by the Free Software
 * Foundation, version 2.
 *
 * LAPIS homepage: http://graphics.lcs.mit.edu/lapis/
 */
package lapisx.swing;

import javax.swing.*;
import javax.swing.filechooser.*;
import java.beans.*;
import java.io.*;

/**
 * Extends JFileChooser to preserve the current directory from one
 * invocation of the dialog box to the next.
 */
public class FileChooser extends JFileChooser {
    private static File savedDirectory = 
        new File (System.getProperty ("user.dir", "."));

    /**
     * Creates a JFileChooser pointing to the user's home directory.
     */
    public FileChooser() {
        super ();
        setCurrentDirectory (savedDirectory);
        setup2 ();
    }
    
    /**
     * Creates a FileChooser using the given path. Passing in a null
     * string causes the file chooser to point to the users home directory.
     *
     * @param path  a String giving the path to a file or directory
     */
    public FileChooser(String currentDirectoryPath) {
	super (currentDirectoryPath);
        setup2 ();
    }

    /**
     * Creates a FileChooser using the given File as the path. Passing
     * in a null file causes the file chooser to point to the users's
     * home directory.
     *
     * @param directory  a File object specifying the path to a file 
     *                   or directory
     */
    public FileChooser(File currentDirectory) {
	super (currentDirectory);
        setup2 ();
    }

    /**
     * Creates a FileChooser using the given FileSystemView
     */
    public FileChooser(FileSystemView fsv) {
	super (fsv);
        setCurrentDirectory (savedDirectory);
        setup2 ();
    }


    /**
     * Creates a FileChooser using the given current directory and FileSystemView
     */
    public FileChooser(File currentDirectory, FileSystemView fsv) {
	super (currentDirectory, fsv);
	setup2 ();
    }

    /**
     * Creates a FileChooser using the given current directory path and FileSystemView
     */
    public FileChooser(String currentDirectoryPath, FileSystemView fsv) {
	super (currentDirectoryPath, fsv);
	setup2 ();
    }

    protected void setup2 () {
        savedDirectory = getCurrentDirectory ();
        addPropertyChangeListener (new PropertyChangeListener () {
            public void propertyChange (PropertyChangeEvent event) {
                if (event.getPropertyName().equals (DIRECTORY_CHANGED_PROPERTY))
                    savedDirectory = (File)event.getNewValue ();
            }
        });
    }        
}
