/*
 * LAPIS lightweight structured text processing system
 *
 * Copyright (C) 1998-2002 Carnegie Mellon University,
 * Copyright (C) 2003 Massachusetts Institute of Technology.
 * All rights reserved.
 *
 * This library is free software; you can redistribute it
 * and/or modify it under the terms of the GNU General
 * Public License as published by the Free Software
 * Foundation, version 2.
 *
 * LAPIS homepage: http://graphics.lcs.mit.edu/lapis/
 */
package lapisx.swing;

import java.awt.Color;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;

import javax.swing.JLabel;
import javax.swing.Timer;

 /**
   * Label that can flash (change color briefly) on demand.
   * Useful for status messages that need to call attention to themselves.
   */    
public class FlashingLabel extends JLabel {
    Timer timer;
    Color flashColor;
    Color normalColor;

    static int DELAY = 500; // milliseconds
    
    /**
     * Make a FlashingLabel.
     * @param text Text for label
     */
    public FlashingLabel (String text) {
        super (text);
        timer = new Timer (DELAY, new ActionListener () {
            public void actionPerformed (ActionEvent event) {
                stopFlashing ();
            }
        });
        timer.setCoalesce (true);
        timer.setRepeats (false);
        
        flashColor = Color.red;
        normalColor = getForeground ();
    }
    
    public void setForeground (Color c) {
        super.setForeground (c);
        normalColor = c;
    }
    
    /**
     * Set the color used when the label flashes. 
     * @param c flash color
     */
    public void setFlashColor (Color c) {
        flashColor = c;
    }
    
    /**
     * Get the color used when the label flashes. 
     * @return flash color
     */
    public Color getFlashColor (Color c) {
        return flashColor;
    }
    
    /**
     * Flash the label.  Automatically stops flashing after a delay.
     */
    public void startFlashing () {
        if (flashColor == null)
            return;
        super.setForeground (flashColor);
        timer.restart ();
    }

    /**
     * Force the label to stop flashing, if it's currently flashing.
     * Normally happens automatically after a delay, so it's
     * not usually necessary to call this.
     */ 
    public void stopFlashing () {
        super.setForeground (normalColor);
        timer.stop ();
    }
}
