/*
 * LAPIS lightweight structured text processing system
 *
 * Copyright (C) 1998-2002 Carnegie Mellon University,
 * Copyright (C) 2003 Massachusetts Institute of Technology.
 * All rights reserved.
 *
 * This library is free software; you can redistribute it
 * and/or modify it under the terms of the GNU General
 * Public License as published by the Free Software
 * Foundation, version 2.
 *
 * LAPIS homepage: http://graphics.lcs.mit.edu/lapis/
 */

package lapisx.swing;

import java.awt.*;
import javax.swing.*;

public class HighlightingScrollPane extends JScrollPane {
    
    static {
        UIManager.put ("HighlightingScrollBarUI", "lapisx.swing.HighlightingScrollBarUI");
    }


    public HighlightingScrollPane () {
        super ();
    }

    public HighlightingScrollPane (Component view) {
        super (view);
    }
    
    public JScrollBar createVerticalScrollBar () {
        return new HighlightingScrollBar (JScrollBar.VERTICAL);
    }

    public JScrollBar createHorizontalScrollBar () {
        return new HighlightingScrollBar (JScrollBar.HORIZONTAL);
    }

    public void setVerticalHighlighter (ScrollBarHighlighter h) {
        ((HighlightingScrollBar) getVerticalScrollBar ()).setHighlighter (h);
    }
        
    public ScrollBarHighlighter getVerticalHighlighter () {
        return ((HighlightingScrollBar) getVerticalScrollBar ()).getHighlighter ();
    }

    public void setHorizontalHighlighter (ScrollBarHighlighter h) {
        ((HighlightingScrollBar) getHorizontalScrollBar ()).setHighlighter (h);
    }
        
    public ScrollBarHighlighter getHorizontalHighlighter () {
        return ((HighlightingScrollBar) getHorizontalScrollBar ()).getHighlighter ();
    }

    public class HighlightingScrollBar extends ScrollBar {
        ScrollBarHighlighter highlighter;

        public HighlightingScrollBar (int orientation) {
            super (orientation);
        }
    
        public String getUIClassID () {
            return "HighlightingScrollBarUI";
        }
    
        public void setHighlighter (ScrollBarHighlighter h) {
            this.highlighter = h;
        }
        
        public ScrollBarHighlighter getHighlighter () {
            return highlighter;
        }
    }

}
