/*
 * LAPIS lightweight structured text processing system
 *
 * Copyright (C) 1998-2002 Carnegie Mellon University,
 * Copyright (C) 2003 Massachusetts Institute of Technology.
 * All rights reserved.
 *
 * This library is free software; you can redistribute it
 * and/or modify it under the terms of the GNU General
 * Public License as published by the Free Software
 * Foundation, version 2.
 *
 * LAPIS homepage: http://graphics.lcs.mit.edu/lapis/
 */
/* A simple Dialog box that contains 3 buttons and an input field. 

 */






package lapisx.swing;

import javax.swing.JOptionPane;
import javax.swing.JDialog;
import javax.swing.JTextField;
import java.beans.*; //Property change stuff
import java.awt.*;
import java.awt.event.*;



public class InputThreeButtonDialog extends JDialog {
    private String typedText = null;


    private JOptionPane optionPane;

    private int selection;

    public String getText() {
        return typedText;
    }

    public int getSelection (){
	return selection;
    }
    public InputThreeButtonDialog(Frame aFrame, String title, String message, String initialText, Object[] option) {
        super(aFrame, true);
        setTitle(title);

        final String msgString = message;
	final Object[] options = option;
                                  
        final JTextField textField = new JTextField(initialText);
        Object[] array = {msgString, textField};

	optionPane = new JOptionPane(array, 
                                    JOptionPane.QUESTION_MESSAGE,
                                    JOptionPane.YES_NO_CANCEL_OPTION,
                                    null,
                                    options,
                                    null);
        setContentPane(optionPane);
        setDefaultCloseOperation(DO_NOTHING_ON_CLOSE);
        addWindowListener(new WindowAdapter() {
                public void windowClosing(WindowEvent we) {
                /*
                 * Instead of directly closing the window,
                 * we're going to change the JOptionPane's
                 * value property.
                 */
                    optionPane.setValue(new Integer(
                                        JOptionPane.CLOSED_OPTION));
            }
        });

        textField.addActionListener(new ActionListener() {
		public void actionPerformed(ActionEvent e) {
		    optionPane.setValue(options[0]);
		}
	    });
	
        optionPane.addPropertyChangeListener(new PropertyChangeListener() {
		public void propertyChange(PropertyChangeEvent e) {
		    String prop = e.getPropertyName();
		    
		    if (isVisible() 
			&& (e.getSource() == optionPane)
			&& (prop.equals(JOptionPane.VALUE_PROPERTY) ||
			    prop.equals(JOptionPane.INPUT_VALUE_PROPERTY))) {
			Object value = optionPane.getValue();
			if (value == JOptionPane.UNINITIALIZED_VALUE) {
			    //ignore reset
			    return;
			}
			
			// Reset the JOptionPane's value.
			// If you don't do this, then if the user
			// presses the same button next time, no
			// property change event will be fired.
			optionPane.setValue(JOptionPane.UNINITIALIZED_VALUE);
			//user has chosed typed field
			if (value.equals(options[0])) { 
                            typedText = textField.getText();
			    if (typedText.trim().equals("")) 
				typedText = null;
			    selection = JOptionPane.YES_OPTION;
			    setVisible(false);
			    
			}
			//user has chosen pre-set field 
			else  if (value.equals(options[1])){ 
			    selection = JOptionPane.NO_OPTION;
			    setVisible(false);
			}
			else {
			    selection = JOptionPane.CANCEL_OPTION;
			    setVisible(false);
			}
		    }
		}
	    });





    }

    protected void setInitialPosition () {
        Component parent = getParent ();
        Dimension size = getSize();
        Dimension parentSize = (parent != null) ? parent.getSize() : Toolkit.getDefaultToolkit().getScreenSize();
        Point origin = (parent != null) ? parent.getLocationOnScreen () : new Point (0, 0);
        
        if (parentSize != null) {
            int x = Math.max (0, origin.x + (parentSize.width - size.width) / 2);
            int y = Math.max (0, origin.y + (parentSize.height - size.height) / 2);
            setLocation (x, y);
        }
    }
    public void show () {
        setInitialPosition ();
        super.show ();
    }


}
