/*
 * LAPIS lightweight structured text processing system
 *
 * Copyright (C) 1998-2002 Carnegie Mellon University,
 * Copyright (C) 2003 Massachusetts Institute of Technology.
 * All rights reserved.
 *
 * This library is free software; you can redistribute it
 * and/or modify it under the terms of the GNU General
 * Public License as published by the Free Software
 * Foundation, version 2.
 *
 * LAPIS homepage: http://graphics.lcs.mit.edu/lapis/
 */

package lapisx.swing;

import java.awt.*;
import javax.swing.*;

/**
 * Lightweight component that just draws a one-pixel horizontal or 
 * vertical line.
 */
public class Line extends JComponent {
    int orientation;
    
    public int getOrientation () { return orientation; }
    public void setOrientation (int orientation) { this.orientation = orientation; repaint (); }

    /**
     * Make a horizontal line in a 10x10 bounding box.
     */
    public Line () {
        this (10, 10, SwingConstants.HORIZONTAL);
    }
        
    /**
     * Make a Line.
     * @param w Width of line's bounding box
     * @param h Height of line's bounding box
     * @param orientation SwingConstants.HORIZONTAL for horizontal line
     * w pixels long;
     * SwingConstants.VERTICAL for vertical line h pixels long.
     */
    public Line (int width, int height, int orientation) {
        this.orientation = orientation;
        setPreferredSize (new Dimension (width, height));
    }

    public void paintComponent (Graphics g) {
        super.paintComponent (g);

        Insets insets = getInsets ();
        Dimension size = getSize ();
        int width = size.width - insets.left - insets.right;
        int height = size.height - insets.top - insets.bottom;

        g.setColor (getForeground ());
        switch (orientation) {
        case SwingConstants.HORIZONTAL:
            {
                int x = insets.left;
                int y = insets.top + height/2;
                g.drawLine (x, y, x + width, y);
                break;
            }
        case SwingConstants.VERTICAL:
            {
                int x = insets.left + width/2;
                int y = insets.top;
                g.drawLine (x, y, x, y + height);
                break;
            }
        }
    }
}

