/*
 * LAPIS lightweight structured text processing system
 *
 * Copyright (C) 1998-2002 Carnegie Mellon University,
 * Copyright (C) 2003 Massachusetts Institute of Technology.
 * All rights reserved.
 *
 * This library is free software; you can redistribute it
 * and/or modify it under the terms of the GNU General
 * Public License as published by the Free Software
 * Foundation, version 2.
 *
 * LAPIS homepage: http://graphics.lcs.mit.edu/lapis/
 */

package lapisx.swing;

import java.beans.*;
import javax.swing.*;

public class LineBeanInfo extends SimpleBeanInfo {
    public BeanDescriptor getBeanDescriptor () {
        return new BeanDescriptor (Line.class);
    }

    public PropertyDescriptor[] getPropertyDescriptors () {
        try {
            PropertyDescriptor[] props  =
                new PropertyDescriptor [] {
                    new PropertyDescriptor ("foreground", Line.class),
                    new PropertyDescriptor ("orientation", Line.class),
                };
            props[1].setPropertyEditorClass (OrientationEditor.class);
            return props;
        } catch (IntrospectionException e) {
            return super.getPropertyDescriptors ();
        }
    }

    public static class OrientationEditor extends PropertyEditorSupport {
        public String[] getTags () {
            return new String[] { "horizontal", "vertical" };
        }

        public void setAsText (String s) {
            if ("horizontal".equalsIgnoreCase (s))
                setValue (new Integer (SwingConstants.HORIZONTAL));
            else if ("vertical".equalsIgnoreCase (s))
                setValue (new Integer (SwingConstants.VERTICAL));
            else
                throw new IllegalArgumentException (s);
        }
       
        public String getAsText () {
            switch (((Number) getValue ()).intValue ()) {
            default:
            case SwingConstants.HORIZONTAL:
                return "horizontal";
            case SwingConstants.VERTICAL:
                return "vertical";
            }
        }
            
        public String getJavaInitializationString () {
            switch (((Number) getValue ()).intValue ()) {
            default:
            case SwingConstants.HORIZONTAL:
                return "javax.swing.SwingConstants.HORIZONTAL";
            case SwingConstants.VERTICAL:
                return "javax.swing.SwingConstants.VERTICAL";
            }
        }
    }
    
}
