/*
 * LAPIS lightweight structured text processing system
 *
 * Copyright (C) 1998-2002 Carnegie Mellon University,
 * Copyright (C) 2003 Massachusetts Institute of Technology.
 * All rights reserved.
 *
 * This library is free software; you can redistribute it
 * and/or modify it under the terms of the GNU General
 * Public License as published by the Free Software
 * Foundation, version 2.
 *
 * LAPIS homepage: http://graphics.lcs.mit.edu/lapis/
 */

package lapisx.swing;

import java.awt.event.*;
import java.beans.*;
import javax.swing.*;

public class MaskedAction implements Action, PropertyChangeListener {
    String masked;
    Action action;
    PropertyChangeSupport support = new PropertyChangeSupport (this);

    public MaskedAction (String masked, Action action) {
        this.masked = masked;
        this.action = action;
        action.addPropertyChangeListener (this);
    }

    public Object getValue (String name) {
        if (name.equals (masked))
            return null;
        else
            return action.getValue (name);
    }

    public void putValue (String name, Object obj) {
        if (!name.equals (masked))
            action.putValue (name, obj);
    }

    public void setEnabled (boolean f) {
        action.setEnabled (f);
    }

    public boolean isEnabled () {
        return action.isEnabled ();
    }

    public void propertyChange (PropertyChangeEvent event) {
        String name = event.getPropertyName ();
        if (!name.equals (masked))
            support.firePropertyChange (name, 
                                        event.getOldValue (),
                                        event.getNewValue ());
    }

    public void addPropertyChangeListener (PropertyChangeListener listener) {
        support.addPropertyChangeListener (listener);
    }

    public void removePropertyChangeListener (PropertyChangeListener listener) {
        support.removePropertyChangeListener (listener);
    }

    public void actionPerformed (ActionEvent event) {
        action.actionPerformed (event);
    }
}
