/*
 * LAPIS lightweight structured text processing system
 *
 * Copyright (C) 1998-2002 Carnegie Mellon University,
 * Copyright (C) 2003 Massachusetts Institute of Technology.
 * All rights reserved.
 *
 * This library is free software; you can redistribute it
 * and/or modify it under the terms of the GNU General
 * Public License as published by the Free Software
 * Foundation, version 2.
 *
 * LAPIS homepage: http://graphics.lcs.mit.edu/lapis/
 */


package lapisx.swing;

import java.awt.*;

public abstract class Win {
    public static void center (Window window, Component ref) {
        position (window, ref, 0.5, 0.5);
    }

    public static void position (Window frame, Component ref, 
                                 double xfrac, double yfrac) {
        Dimension screenSize = Toolkit.getDefaultToolkit().getScreenSize();
        Dimension size = frame.getSize();
        Dimension refSize = (ref != null) 
            ? ref.getSize() 
            : screenSize;
        Point origin = (ref != null)
            ? ref.getLocationOnScreen () 
            : new Point (0, 0);

        int x = origin.x + relativePoint (xfrac, refSize.width, size.width);
        int y = origin.y + relativePoint (yfrac, refSize.height, size.height);

        // make sure frame is entirely on screen
        x = Math.max (0, Math.min (screenSize.width - size.width, x));
        y = Math.max (0, Math.min (screenSize.height - size.height, y));
        
        frame.setLocation (x, y);
    }

    static int relativePoint (double frac, int parentLength, int childLength) {
        if (frac < 0)
            return (int) (frac * childLength);
        else if (frac > 1)
            return (int) (parentLength + (frac - 2) * childLength);
        else
            return (int) (frac * (parentLength - childLength));
    }


    public static Frame findFrame (Component comp) {
        for (; comp!=null; comp = comp.getParent ())
            if (comp instanceof Frame) {
                return (Frame)comp;
            }
        return null;
    }

    public static Frame findFrameOrMakeFrame (Component parent) {
        return (parent != null) ? findFrame (parent) : new Frame ();
    }
        

}
