/*
 * LAPIS lightweight structured text processing system
 *
 * Copyright (C) 1998-2002 Carnegie Mellon University,
 * Copyright (C) 2003 Massachusetts Institute of Technology.
 * All rights reserved.
 *
 * This library is free software; you can redistribute it
 * and/or modify it under the terms of the GNU General
 * Public License as published by the Free Software
 * Foundation, version 2.
 *
 * LAPIS homepage: http://graphics.lcs.mit.edu/lapis/
 */


package lapisx.util;

/**
 * String which compares case-insensitively with other strings.
 * Especially useful as a case-insensitive hashtable key.
 */
public class CaselessString {
    String string;

    public CaselessString (String string) {
        this.string = string;
    }

    public boolean equals (Object obj) {
        if (obj instanceof String
            || obj instanceof CaselessString)
            return string.equalsIgnoreCase (obj.toString ());
        else
            return false;
    }

    public int hashCode() {
    	int hash = 0;
    	int len = string.length ();

    	if (len < 16) {
    	    // use all characters
     	    for (int i = 0; i < len; ++i)
         		hash = (hash * 37) + Character.toUpperCase (string.charAt (i));
     	} else {
     	    int skip = len / 8; // sample every 8th char
     	    for (int i = 0; i < len; i += skip)
         		hash = (hash * 39) + Character.toUpperCase (string.charAt (i));
     	}

    	return hash;
    }

    public String toString () {
        return string;
    }
}
