/*
 * LAPIS lightweight structured text processing system
 *
 * Copyright (C) 1998-2002 Carnegie Mellon University,
 * Copyright (C) 2003 Massachusetts Institute of Technology.
 * All rights reserved.
 *
 * This library is free software; you can redistribute it
 * and/or modify it under the terms of the GNU General
 * Public License as published by the Free Software
 * Foundation, version 2.
 *
 * LAPIS homepage: http://graphics.lcs.mit.edu/lapis/
 */


package lapisx.util;

import java.util.*;
import java.io.*;

public class Config extends Properties {
    File file;
    IOException lastException;

    public Config (String fileBaseName) {
        this (fileBaseName, null);
    }

    public Config (File file) {
        this (file, null);
    }

    public Config (String fileBaseName, Config defaults) {
        this (new File (getHomeDirectory (), fileBaseName),
              defaults);
    }

    public Config (File file, Config defaults) {
        super (defaults);
        this.file = file;
	if(file.getParentFile()!=null)
	    file.getParentFile().mkdirs();
        try {
            FileInputStream in = 
                new FileInputStream (file);
            load (in);
            in.close ();
        } catch (IOException e) {
	    lastException = e;
        }
    }

    public IOException getLastException () {
        return lastException;
    }

//     public String getProperty (String key, String defaultValue) {
//         String val = super.getProperty (key, defaultValue);
//         if (val != null && val == defaultValue)
//             put (key, defaultValue);
//         return val;
//     }

    public void save () {
        try {
            FileOutputStream out = new FileOutputStream (file);
            store (out, "");
            out.close ();
            lastException = null;
        } catch (IOException e) {
            lastException = e;
        }
    }

    public void rename(String fileName) {
	rename(new File (getHomeDirectory(), fileName));
    }

    public void rename(File newFile) {
	file.delete();
	this.file = newFile;
	if(file.getParentFile()!=null)
	    file.getParentFile().mkdirs();
    }
	
    public int countKeysStartingWith (String prefix) {
        int n = 0;
        for (Enumeration e = propertyNames (); e.hasMoreElements (); ) {
            String name = (String)e.nextElement ();
            if (name.startsWith (prefix))
                ++n;
        }
        return n;
    }

    public void removeAllKeysStartingWith (String prefix) {
        Vector keysToDelete = new Vector ();
        for (Enumeration e = propertyNames (); e.hasMoreElements (); ) {
            String name = (String)e.nextElement ();
            if (name.startsWith (prefix))
                keysToDelete.addElement (name);
        }
        
        for (Enumeration e = keysToDelete.elements ();
             e.hasMoreElements (); )
            remove (e.nextElement ());
    }
    
    public static File getHomeDirectory () {
        String homedir;
        if ((homedir = System.getProperty ("user.home")) == null
            && (homedir = System.getProperty ("user.dir")) == null)
            homedir = ".";
        
        return new File (homedir);
    }
}
