/*
 * LAPIS lightweight structured text processing system
 *
 * Copyright (C) 1998-2002 Carnegie Mellon University,
 * Copyright (C) 2003 Massachusetts Institute of Technology.
 * All rights reserved.
 *
 * This library is free software; you can redistribute it
 * and/or modify it under the terms of the GNU General
 * Public License as published by the Free Software
 * Foundation, version 2.
 *
 * LAPIS homepage: http://graphics.lcs.mit.edu/lapis/
 */


package lapisx.util;

public abstract class Mem {

    public static long free () {
        return Runtime.getRuntime ().freeMemory ();
    }

    public static long used () {
        Runtime r = Runtime.getRuntime ();
        return r.totalMemory() - r.freeMemory ();
    }

    public static long total () {
        return Runtime.getRuntime ().totalMemory ();
    }

    public static String getReport () {
        return "Memory: used " + (used()/1000) + "KB, free "
            + (free()/1000) + "KB, total " + (total()/1000) + "KB";
    }

    public static void gc () {
        Runtime r = Runtime.getRuntime ();
        r.runFinalization ();
        r.gc ();
    }

    public static void dumpThreadInfo () {
        ThreadGroup g = Thread.currentThread().getThreadGroup ();
        Thread[] t = new Thread[g.activeCount ()];
        g.enumerate (t);
        System.err.println ("Active threads in " + g);
        for (int i=0; i<t.length; ++i)
            System.err.println (t[i]);
    }

}
