/*
 * LAPIS lightweight structured text processing system
 *
 * Copyright (C) 1998-2002 Carnegie Mellon University,
 * Copyright (C) 2003 Massachusetts Institute of Technology.
 * All rights reserved.
 *
 * This library is free software; you can redistribute it
 * and/or modify it under the terms of the GNU General
 * Public License as published by the Free Software
 * Foundation, version 2.
 *
 * LAPIS homepage: http://graphics.lcs.mit.edu/lapis/
 */


package lapisx.util;

import java.lang.reflect.*;

/**
 * Handy reflection routines.
 */
public abstract class Reflect {
    /**
     * Create a new instance of a class by calling a constructor with 
     * arguments.
     */
    public static Object newInstance (String className, 
                                      Class[] signature,
                                      Object[] args) 
        throws Exception {
        
        Class cls = Class.forName (className);
        Constructor constructor = cls.getConstructor (signature);
        return constructor.newInstance (args);
    }

    /**
     * Call a method of an object.
     */
    public static Object callMethod (Object obj, 
                                     String methodName,
                                     Class[] signature,
                                     Object[] args) 
        throws Exception {

        Class cls = obj.getClass ();
        Method method = cls.getMethod (methodName, signature);
        return method.invoke (obj, args);
    }

    /**
     * Call a static method of a class.
     */
    public static Object callStaticMethod (String className, 
                                           String methodName,
                                           Class[] signature,
                                           Object[] args) 
        throws Exception {
        
        Class cls = Class.forName (className);
        Method method = cls.getMethod (methodName, signature);
        return method.invoke (cls, args);
    }

    /**
     * Fetch a static field from a class.
     */
    public static Object getStaticField (String className, 
                                         String fieldName) 
        throws Exception {
        
        Class cls = Class.forName (className);
        Field fld = cls.getField (fieldName);

        if (!Modifier.isStatic (fld.getModifiers ()))
            throw new NoSuchFieldException ();

        return fld.get (null);
    }
}
