/*
 * LAPIS lightweight structured text processing system
 *
 * Copyright (C) 1998-2002 Carnegie Mellon University,
 * Copyright (C) 2003 Massachusetts Institute of Technology.
 * All rights reserved.
 *
 * This library is free software; you can redistribute it
 * and/or modify it under the terms of the GNU General
 * Public License as published by the Free Software
 * Foundation, version 2.
 *
 * LAPIS homepage: http://graphics.lcs.mit.edu/lapis/
 */
package lapisx.util;

import junit.framework.*;
import java.util.*;

/**
 * A collection of JUnit testcases to test the SafeIteratorSet class.
 */
public class SafeIteratorSetTest extends TestCase {

    public SafeIteratorSetTest (String name) {
        super(name);
    }

    protected void setUp () {
    }        
    
    public static Test suite () {        
        return new TestSuite (SafeIteratorSetTest.class);
    }

    public void testSafeIteration () {
        // fill a SafeIteratorSet from another set
        Set s1 = new HashSet (Arrays.asList (new String[] {"a", "b", "c"}));
        Set s2 = new SafeIteratorSet (s1);
        assertEquals (s1, s2);

        // test whether s2's iterator returns same values as s1 
        Iterator g1 = s2.iterator ();
        assertEquals (s1, accumulate (g1));

        // survives adds?
        Iterator g2 = s2.iterator ();
        s2.add ("d");
        assertEquals (s1, accumulate (g2));
        s1.add ("d");

        // survives removes?
        Iterator g3 = s2.iterator ();
        s2.remove ("a");
        assertEquals (s1, accumulate (g3));
        s1.remove ("a");
        
        // survives clear?
        Iterator g4 = s2.iterator ();
        s2.clear ();
        assertEquals (s1, accumulate (g4));

        // iterator itself refuses remove?
        Iterator g5 = s2.iterator ();
        try {
            g5.remove ();
            fail ();
        } catch (UnsupportedOperationException e) {
        }
    }

    private Set accumulate (Iterator g) {
        Set s = new HashSet ();
        while (g.hasNext ())
            s.add (g.next ());
        return s;
    }
}

