/*
 * LAPIS lightweight structured text processing system
 *
 * Copyright (C) 1998-2002 Carnegie Mellon University,
 * Copyright (C) 2003 Massachusetts Institute of Technology.
 * All rights reserved.
 *
 * This library is free software; you can redistribute it
 * and/or modify it under the terms of the GNU General
 * Public License as published by the Free Software
 * Foundation, version 2.
 *
 * LAPIS homepage: http://graphics.lcs.mit.edu/lapis/
 */


package lapisx.util;

public abstract class Thr {
    /**
      * Test whether the current thread has been interrupted with 
      * Thread.interrupt().  If so, a ThreadDeath exception is thrown
      * to kill it cleanly.  If a background thread
      * calls check() periodically, then Thread.interrupt() will
      * kill it cleanly and safely at the next check() call.  Catch ThreadDeath
      * or use a try-finally construct if your background thread needs to do 
      * any resource cleanup.
      *
      * @exception ThreadDeath if and only if 
      * Thread.currentThread().isInterrupted() is true.
      */
    public static void check () throws ThreadDeath {
        if (Thread.currentThread ().isInterrupted ())
            throw new ThreadDeath ();
    }
}
