/*
 * LAPIS lightweight structured text processing system
 *
 * Copyright (C) 1998-2002 Carnegie Mellon University,
 * Copyright (C) 2003 Massachusetts Institute of Technology.
 * All rights reserved.
 *
 * This library is free software; you can redistribute it
 * and/or modify it under the terms of the GNU General
 * Public License as published by the Free Software
 * Foundation, version 2.
 *
 * LAPIS homepage: http://graphics.lcs.mit.edu/lapis/
 */
package tcl.lang;

import lapis.Document;
import lapis.Interpreter;
import java.io.File;
import lapisx.util.Debug;

/**
 * Methods that need tcl.lang package access are put here.
 */
public abstract class LapisUtil {
    public static Debug debug = Debug.QUIET;

    public static File getWorkingDir (Interp interp) {
        return interp.getWorkingDir ();
    }

    public static void setWorkingDir (Interp interp, File dirName) throws TclException {
        interp.setWorkingDir (dirName.toString ());
    }

    public static Object getCurrentDocument (Interp interp) {
        try {
            // Scan up call stack looking for definition of Interpreter.DOCUMENT_VAR.
            // Thanks to the stupidity of CallFrame.lookupVar(), which always looks
            // in interp.varFrame instead of in itself (!!), we have to do this by
            // setting interp.varFrame to every CallFrame we want to examine.

            CallFrame savedFrame = interp.varFrame;
            try {
                while (true) {
                    TclObject tobj = interp.getVar (Interpreter.DOCUMENT_VAR, 
                                                    TCL.DONT_THROW_EXCEPTION);
                    
                    if (tobj != null)
                        return (Document) tclObjectToJavaObject (interp, tobj);
                    
                    if (interp.varFrame == interp.globalFrame)
                        break;
                    else
                        interp.varFrame = interp.varFrame.callerVar;
                }
            } finally {
                interp.varFrame = savedFrame;
            }

            debug.println ("no " + Interpreter.DOCUMENT_VAR + " found");
            return null;
        } catch (TclException e) {
            debug.report (e);
            return null;
        }
    }

    public static void setCurrentDocument (Interp interp, Object doc) throws TclException {
//         debug.printStackTrace ();
        debug.println ("setting doc to " + doc);
        TclObject tobj = ReflectObject.newInstance (interp, 
                                                    (doc != null)
                                                    ? doc.getClass ()
                                                    : Object.class,
                                                    doc);
        interp.setVar (Interpreter.DOCUMENT_VAR, tobj, 0);
    }

    public static Object tclObjectToJavaObject (Interp interp, TclObject obj) {
        obj.preserve ();
        try {
            return ReflectObject.get (interp, obj);
        } catch (TclException e) {
            return obj.toString ();
        } finally {
            obj.release ();
        }
    }


}
