/*
 * LAPIS lightweight structured text processing system
 *
 * Copyright (C) 1998-2002 Carnegie Mellon University,
 * Copyright (C) 2003 Massachusetts Institute of Technology.
 * All rights reserved.
 *
 * This library is free software; you can redistribute it
 * and/or modify it under the terms of the GNU General
 * Public License as published by the Free Software
 * Foundation, version 2.
 *
 * LAPIS homepage: http://graphics.lcs.mit.edu/lapis/
 */
#include <stdio.h>
#include <string.h>
#include <stdlib.h>

char *getMyPath (char *script) {
    FILE *f;
    int maxBuf = 100;
    char *buf = malloc (maxBuf);
    int c;
    int i = 0;
    int state = 0;

    f = fopen (script, "r");
    if (f == NULL) {
        perror ("can't open script file");
        exit (-1);
    }

    while (state >= 0 && (c = getc (f)) != EOF) {
        switch (state) {
        case 0:
            if (c == '#')
                state = 1;
            else if (isspace (c))
                state = -1;
            break;

        case 1:
            if (c == '!')
                state = 2;
            else if (!isspace (c))
                state = -1;
            break;

        case 2:
            if (!isspace (c)) {
                state = 3;
                buf[i++] = c;
            }
            break;

        case 3:
            if (!isspace (c)) {
                if (i >= maxBuf-1) {
                    buf = realloc (buf, maxBuf *= 2);
                    if (!buf) {
                        fprintf (stderr, "out of memory\n");
                        exit (-1);
                    }
                }
                buf[i++] = c;
            } else
                state = -2;
            break;
        }
    }

    if (state == -1) {
        fprintf (stderr, "can't find #!filename on first line of %s\n", script);
        exit (-1);
    }

    fclose (f);

    buf[i] = 0;
    return buf;
}

void toDirectory (char *path) {
    int i;
    for (i = strlen (path) - 1; i >= 0 && path[i] != '/'; --i)
        ;
    path[i+1] = 0;
}

int main (int argc, char *const argv[]) {
    int scriptIndex;
    int i, j;
    char *path;
    char **new_argv;

#ifdef DEBUG
    for (i = 0; i < argc; ++i)
        fprintf (stderr, "argv[%d]=%s\n", i, argv[i]);
#endif

    /* open script file, which should be argv[1] */

    for (scriptIndex = 1; scriptIndex < argc && argv[scriptIndex][0] == '-'; ++scriptIndex)
        ;

    if (scriptIndex >= argc) {
        fprintf (stderr, "usage: %s <LAPIS script file>\n", argv[0]);
        exit (-1);
    }

    path = getMyPath (argv[scriptIndex]);
#ifdef DEBUG
    fprintf (stderr, "my path=%s\n", path);
#endif

    /* construct name of "lapis" script */
    toDirectory (path);
    strcat (path, "lapis");
#ifdef DEBUG
    fprintf (stderr, "lapis=%s\n", path);
#endif

    /* copy argv list (including argv[argc]==NULL), substituting path for argv[0]
      and inserting -f option before script name */
    new_argv = malloc (sizeof(char*) * (argc+2));
    new_argv[0] = path;
    for (i = 1, j = 1; i <= argc; ) {
        if (i == scriptIndex)
            new_argv[j++] = "-f";
        new_argv[j++] = argv[i++];
    }

    /* execute lapis-invoke script */
    execv (path, new_argv);

    /* if we got here, we failed */
    perror ("executing lapis");
    return -1;
}
