/*
 * LAPIS lightweight structured text processing system
 *
 * Copyright (C) 1998-2002 Carnegie Mellon University,
 * Copyright (C) 2003 Massachusetts Institute of Technology.
 * All rights reserved.
 *
 * This library is free software; you can redistribute it
 * and/or modify it under the terms of the GNU General
 * Public License as published by the Free Software
 * Foundation, version 2.
 *
 * LAPIS homepage: http://graphics.lcs.mit.edu/lapis/
 */



package lapis;

/**
 * Dense set of regions in a document [startLow,startHigh; endLow,endHigh], where:
 *     startLow <= start <= startHigh
 * and   endLow <= end   <= endHigh
 */
public class FuzzyRegion extends Region {

    // Region.start and Region.end serve as
    // startLow and endHigh, respectively
    protected int startHigh;
    protected int endLow;
    
    protected FuzzyRegion () {
    }

    /**
     * Makes a FuzzyRegion.
     * @param startLow Lower bound for starting offset
     * @param startHigh Upper bound for starting offset
     * @param endLow Lower bound for ending offset
     * @param endHigh Upper bound for ending offset
     */
    public FuzzyRegion (int startLow, int startHigh,
    					int endLow, int endHigh, DocumentVersion ver) {
    	super (startLow, endHigh, ver);
    	this.startHigh = Math.min (startHigh, endHigh);
    	this.endLow = Math.max (startLow, endLow);
    }
    
    public FuzzyRegion (int startLow, int startHigh, 
    					int endLow, int endHigh, Document doc) {
		this(startLow, startHigh, endLow, endHigh, doc.getVersion());
    }
    //
    // Accessor methods
    //

    public int getStartHigh () {
        return startHigh;
    }

    public int getEndLow () {
        return endLow;
    }
}
